@@ -13,12 +13,9 @@
 #include "mess.h"
 #include "includes/dragon.h"
 
-DEVICE_INIT(coco_vhd);
-DEVICE_LOAD(coco_vhd);
-
 READ8_HANDLER(coco_vhd_io_r);
 WRITE8_HANDLER(coco_vhd_io_w);
 
-void coco_vhd_device_getinfo(struct IODevice *dev);
+void coco_vhd_device_getinfo(const device_class *devclass, UINT32 state, union devinfo *info);
 
 #endif /* COCOVHD_H */
