@@ -1,6 +1,18 @@
+/*********************************************************************
+
+  filemngr.c
+
+  MESS's clunky built-in file manager
+
+*********************************************************************/
+
 #include "driver.h"
-#include <signal.h>
 #include "utils.h"
+#include "image.h"
+#include "ui_text.h"
+
+#define SEL_BITS	12
+#define SEL_MASK	((1<<SEL_BITS)-1)
 
 static int count_chars_entered;
 static char *enter_string;
@@ -19,7 +31,7 @@ static void start_enter_string(char *string_buffer, int max_string_size, int fil
 
 
 /* code, lower case (w/o shift), upper case (with shift), control */
-static int code_to_char_table[] =
+static const int code_to_char_table[] =
 {
 	KEYCODE_0, '0', ')', 0,
 	KEYCODE_1, '1', '!', 0,
@@ -77,7 +89,7 @@ static int code_to_char_table[] =
  * Maybe change this for different platforms?
  * Put it to osd_cpu? Make it an osd_... function?
  */
-static char valid_filename_char[256] =
+static const char valid_filename_char[256] =
 {
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 	/* 00-0f */
 	0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 	/* 10-1f */
@@ -97,7 +109,7 @@ static char valid_filename_char[256] =
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0		/* f0-ff */
 };
 
-static char code_to_ascii(InputCode code)
+static char code_to_ascii(input_code code)
 {
 	int i;
 
@@ -106,11 +118,11 @@ static char code_to_ascii(InputCode code)
 	{
 		if (code_to_char_table[i * 4] == code)
 		{
-			if (keyboard_pressed(KEYCODE_LCONTROL) ||
-				keyboard_pressed(KEYCODE_RCONTROL))
+			if (code_pressed(KEYCODE_LCONTROL) ||
+				code_pressed(KEYCODE_RCONTROL))
 				return code_to_char_table[i * 4 + 3];
-			if (keyboard_pressed(KEYCODE_LSHIFT) ||
-				keyboard_pressed(KEYCODE_RSHIFT))
+			if (code_pressed(KEYCODE_LSHIFT) ||
+				code_pressed(KEYCODE_RSHIFT))
 				return code_to_char_table[i * 4 + 2];
 			return code_to_char_table[i * 4 + 1];
 		}
@@ -121,11 +133,11 @@ static char code_to_ascii(InputCode code)
 
 static char *update_entered_string(void)
 {
-	InputCode code;
+	input_code code;
 	int ascii_char;
 
 	/* get key */
-	code = keyboard_read_async();
+	code = code_read_async();
 
 	/* key was pressed? */
 	if (code == CODE_NONE)
@@ -186,13 +198,12 @@ const char fs_device[] = "[DRIVE]";
 const char fs_file[] = "[FILE]";
 /*const char fs_archive[] = "[ARCHIVE]"; */
 
-static const char **fs_item;
-static const char **fs_subitem;
-static char *fs_flags;
+static ui_menu_item *fs_item;
 static int *fs_types;
 static int *fs_order;
 static int fs_chunk;
 static int fs_total;
+static int fs_insession;
 
 enum {
 	FILESELECT_NONE,
@@ -204,25 +215,15 @@ enum {
 } FILESELECT_ENTRY_TYPE;
 
 
-char *fs_dupe(const char *src, int len)
+static char *fs_dupe(const char *src, int len)
 {
 	char *dst;
-	int display_length;
-	int display_width;
-
-	display_width = (Machine->uiwidth / Machine->uifontwidth);
-	display_length = len;
-
-	if (display_length>display_width)
-		display_length = display_width;
 
 	/* malloc space for string + NULL char + extra char.*/
 	dst = malloc(len+2);
 	if (dst)
 	{
 		strcpy(dst, src);
-		/* copy old char to end of string */
-		dst[len+1]=dst[display_length];
 		/* put in NULL to cut string. */
 		dst[len+1]='\0';
 	}
@@ -231,7 +232,7 @@ char *fs_dupe(const char *src, int len)
 }
 
 
-void fs_free(void)
+static void fs_free(void)
 {
 	if (fs_chunk > 0)
 	{
@@ -239,13 +240,15 @@ void fs_free(void)
 		/* free duplicated strings of file and directory names */
 		for (i = 0; i < fs_total; i++)
 		{
-			if (fs_types[i] == FILESELECT_FILE ||
-				fs_types[i] == FILESELECT_DIRECTORY)
-				free((char *)fs_item[i]);
+			switch(fs_types[i]) {
+			case FILESELECT_FILE:
+			case FILESELECT_DIRECTORY:
+				if (fs_item[i].text != ui_getstring(UI_emptyslot))
+					free((char *) fs_item[i].text);
+				break;
+			}
 		}
 		free(fs_item);
-		free(fs_subitem);
-		free(fs_flags);
 		free(fs_types);
 		free(fs_order);
 		fs_chunk = 0;
@@ -253,125 +256,98 @@ void fs_free(void)
 	}
 }
 
-int fs_alloc(void)
+static int fs_alloc(void)
 {
-	if (fs_total < fs_chunk)
+	if (fs_total >= fs_chunk)
 	{
-		fs_order[fs_total] = fs_total;
-		return (fs_total += 1) - 1;
-	}
-	if (fs_chunk)
-	{
-		fs_chunk += 256;
-		logerror("fs_alloc() next chunk (total %d)\n", fs_chunk);
-		fs_item = realloc(fs_item, fs_chunk * sizeof(char **));
-		fs_subitem = realloc(fs_subitem, fs_chunk * sizeof(char **));
-		fs_flags = realloc(fs_flags, fs_chunk * sizeof(char *));
-		fs_types = realloc(fs_types, fs_chunk * sizeof(int));
-		fs_order = realloc(fs_order, fs_chunk * sizeof(int));
-	}
-	else
-	{
-		fs_chunk = 512;
-		logerror("fs_alloc() first chunk %d\n", fs_chunk);
-		fs_item = malloc(fs_chunk * sizeof(char **));
-		fs_subitem = malloc(fs_chunk * sizeof(char **));
-		fs_flags = malloc(fs_chunk * sizeof(char *));
-		fs_types = malloc(fs_chunk * sizeof(int));
-		fs_order = malloc(fs_chunk * sizeof(int));
-	}
+		if (fs_chunk)
+		{
+			fs_chunk += 256;
+			logerror("fs_alloc() next chunk (total %d)\n", fs_chunk);
+			fs_item = realloc(fs_item, fs_chunk * sizeof(*fs_item));
+			fs_types = realloc(fs_types, fs_chunk * sizeof(int));
+			fs_order = realloc(fs_order, fs_chunk * sizeof(int));
+		}
+		else
+		{
+			fs_chunk = 512;
+			logerror("fs_alloc() first chunk %d\n", fs_chunk);
+			fs_item = malloc(fs_chunk * sizeof(*fs_item));
+			fs_types = malloc(fs_chunk * sizeof(int));
+			fs_order = malloc(fs_chunk * sizeof(int));
+		}
 
-	/* what do we do if reallocation fails? raise(SIGABRT) seems a way outa here */
-	if (!fs_item || !fs_subitem || !fs_flags || !fs_types || !fs_order)
-	{
-		logerror("failed to allocate fileselect buffers!\n");
-		raise(SIGABRT);
+		/* what do we do if reallocation fails? raise(SIGABRT) seems a way outa here */
+		if (!fs_item || !fs_types || !fs_order)
+		{
+			logerror("failed to allocate fileselect buffers!\n");
+			exit(-1);
+		}
 	}
-
+	
+	memset(&fs_item[fs_total], 0, sizeof(fs_item[fs_total]));
 	fs_order[fs_total] = fs_total;
-	return (fs_total += 1) - 1;
+	return fs_total++;
 }
 
 static int DECL_SPEC fs_compare(const void *p1, const void *p2)
 {
-	const int i1 = *(int *)p1;
-	const int i2 = *(int *)p2;
+	int i1 = *(int *)p1;
+	int i2 = *(int *)p2;
 
 	if (fs_types[i1] != fs_types[i2])
 		return fs_types[i1] - fs_types[i2];
-	return strcmp(fs_item[i1], fs_item[i2]);
-
+	return strcmp(fs_item[i1].text, fs_item[i2].text);
 }
 
-#define MAX_ENTRIES_IN_MENU (SEL_MASK-1)
+#define MAX_ENTRIES_IN_MENU ((1<<12)-2)
 
-int fs_init_done = 0;
-
-void fs_generate_filelist(void)
+static void fs_generate_filelist(void)
 {
 	void *dir;
 	int qsort_start, count, i, n;
-	const char **tmp_menu_item;
-	const char **tmp_menu_subitem;
-	char *tmp_flags;
+	ui_menu_item *tmp_menu_item;
 	int *tmp_types;
 
-	/* should be moved inside mess.c ??? */
-	if (fs_init_done==0)
-	{
-		/* this will not work if roms is not a sub-dir of mess, and
-		   will also not work if we are not in the mess dir */
-		/* go to initial roms directory */
-		osd_change_directory("software");
-		osd_change_directory(Machine->gamedrv->name);
-		fs_init_done = 1;
-	}
-
 	/* just to be safe */
 	fs_free();
 
 	/* quit back to main menu option at top */
 	n = fs_alloc();
-	fs_item[n] = "Quit Fileselector";
-	fs_subitem[n] = 0;
+	fs_item[n].text = ui_getstring(UI_quitfileselector);
 	fs_types[n] = FILESELECT_QUIT;
-	fs_flags[n] = 0;
 
 	/* insert blank line */
 	n = fs_alloc();
-	fs_item[n] = "-";
-	fs_subitem[n] = 0;
+	fs_item[n].text = "-";
 	fs_types[n] = FILESELECT_NONE;
-	fs_flags[n] = 0;
 
 	/* current directory */
 	n = fs_alloc();
-	fs_item[n] = osd_get_cwd();
-	fs_subitem[n] = 0;
+	fs_item[n].text = osd_get_cwd();
 	fs_types[n] = FILESELECT_NONE;
-	fs_flags[n] = 0;
 
 	/* blank line */
 	n = fs_alloc();
-	fs_item[n] = "-";
-	fs_subitem[n] = 0;
+	fs_item[n].text = "-";
 	fs_types[n] = FILESELECT_NONE;
-	fs_flags[n] = 0;
-
 
 	/* file specification */
 	n = fs_alloc();
-	fs_item[n] = "File Specification";
-	fs_subitem[n] = current_filespecification;
+	fs_item[n].text = ui_getstring(UI_filespecification);
+	fs_item[n].subtext = current_filespecification;
 	fs_types[n] = FILESELECT_FILESPEC;
-	fs_flags[n] = 0;
 
 	/* insert blank line */
 	n = fs_alloc();
-	fs_item[n] = "-";
-	fs_subitem[n] = 0;
+	fs_item[n].text = "-";
 	fs_types[n] = FILESELECT_NONE;
-	fs_flags[n] = 0;
+
+	/* insert empty specifier */
+	n = fs_alloc();
+	fs_item[n].text = ui_getstring(UI_emptyslot);
+	fs_item[n].subtext = "";
+	fs_types[n] = FILESELECT_FILE;
 
 	qsort_start = fs_total;
 
@@ -385,10 +361,9 @@ void fs_generate_filelist(void)
 			if (fs_total >= MAX_ENTRIES_IN_MENU)
 				break;
 			n = fs_alloc();
-			fs_item[n] = osd_get_device_name(i);
-			fs_subitem[n] = fs_device;
+			fs_item[n].text = osd_get_device_name(i);
+			fs_item[n].subtext = fs_device;
 			fs_types[n] = FILESELECT_DEVICE;
-			fs_flags[n] = 0;
 		}
 	}
 
@@ -404,77 +379,83 @@ void fs_generate_filelist(void)
 			if (fs_total >= MAX_ENTRIES_IN_MENU)
 				break;
 			n = fs_alloc();
-			fs_item[n] = fs_dupe(filename,len);
+			fs_item[n].text = fs_dupe(filename,len);
 			if (filetype)
 			{
 				fs_types[n] = FILESELECT_DIRECTORY;
-				fs_subitem[n] = fs_directory;
+				fs_item[n].subtext = fs_directory;
 			}
 			else
 			{
 				fs_types[n] = FILESELECT_FILE;
-				fs_subitem[n] = fs_file;
+				fs_item[n].subtext = fs_file;
 			}
-			fs_flags[n] = 0;
 			len = osd_dir_get_entry(dir, filename, sizeof(filename), &filetype);
 		}
 		osd_dir_close(dir);
 	}
 
-	n = fs_alloc();
-	fs_item[n] = 0; 		 /* terminate array */
-	fs_subitem[n] = 0;
-	fs_types[n] = FILESELECT_NONE;
-	fs_flags[n] = 0;
-
 	logerror("fs_generate_filelist: sorting %d entries\n", n - qsort_start);
 	qsort(&fs_order[qsort_start], n - qsort_start, sizeof(int), fs_compare);
 
-	tmp_menu_item = malloc(n * sizeof(char *));
-	tmp_menu_subitem = malloc(n * sizeof(char *));
-	tmp_flags = malloc(n * sizeof(char));
+	tmp_menu_item = malloc(n * sizeof(*tmp_menu_item));
 	tmp_types = malloc(n * sizeof(int));
 
 	/* no space to sort? have to leave now... */
-	if (!tmp_menu_item || !tmp_menu_subitem || !tmp_flags || !tmp_types )
+	if (!tmp_menu_item || !tmp_types )
 		return;
 
 	/* copy items in original order */
-	memcpy(tmp_menu_item, fs_item, n * sizeof(char *));
-	memcpy(tmp_menu_subitem, fs_subitem, n * sizeof(char *));
-	memcpy(tmp_flags, fs_flags, n * sizeof(char));
+	memcpy(tmp_menu_item, fs_item, n * sizeof(*tmp_menu_item));
 	memcpy(tmp_types, fs_types, n * sizeof(int));
 
 	for (i = qsort_start; i < n; i++)
 	{
 		int j = fs_order[i];
 		fs_item[i] = tmp_menu_item[j];
-		fs_subitem[i] = tmp_menu_subitem[j];
-		fs_flags[i] = tmp_flags[j];
 		fs_types[i] = tmp_types[j];
 	}
 
 	free(tmp_menu_item);
-	free(tmp_menu_subitem);
-	free(tmp_flags);
 	free(tmp_types);
 }
 
-#define UI_SHIFT_PRESSED		(keyboard_pressed(KEYCODE_LSHIFT) || keyboard_pressed(KEYCODE_RSHIFT))
-#define UI_CONTROL_PRESSED		(keyboard_pressed(KEYCODE_LCONTROL) || keyboard_pressed(KEYCODE_RCONTROL))
+#define UI_SHIFT_PRESSED		(code_pressed(KEYCODE_LSHIFT) || code_pressed(KEYCODE_RSHIFT))
+#define UI_CONTROL_PRESSED		(code_pressed(KEYCODE_LCONTROL) || code_pressed(KEYCODE_RCONTROL))
 /* and mask to get bits */
 #define SEL_BITS_MASK			(~SEL_MASK)
 
-int fileselect(struct mame_bitmap *bitmap, int selected)
+static int fileselect(int selected, const char *default_selection)
 {
 	int sel, total, arrowize;
 	int visible;
 
 	sel = selected - 1;
 
+	/* beginning a file manager session */
+	if (fs_insession == 0)
+	{
+		fs_insession = 1;
+		if (default_selection)
+		{
+			char *dirname;
+			dirname = osd_dirname((char *) default_selection);
+			osd_change_directory(dirname);
+			free(dirname);
+		}
+		else
+		{
+			osd_change_directory(mess_path);
+			osd_change_directory("software");
+			osd_change_directory(Machine->gamedrv->name);
+		}
+	}
+
 	/* generate menu? */
 	if (fs_total == 0)
+	{
 		fs_generate_filelist();
+	}
 
 	total = fs_total - 1;
 
@@ -511,10 +492,10 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 			char *name;
 
 			/* change menu item to show this filename */
-			fs_subitem[sel & SEL_MASK] = current_filespecification;
+			fs_item[sel & SEL_MASK].subtext = current_filespecification;
 
 			/* display the menu */
-			ui_displaymenu(bitmap, fs_item, fs_subitem, fs_flags, sel & SEL_MASK, 3);
+			ui_draw_menu(fs_item, fs_total, sel & SEL_MASK);
 
 			/* update string with any keys that are pressed */
 			name = update_entered_string();
@@ -538,10 +519,10 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 		}
 
 
-		ui_displaymenu(bitmap, fs_item, fs_subitem, fs_flags, sel, arrowize);
+		ui_draw_menu(fs_item, fs_total, sel);
 
 		/* borrowed from usrintrf.c */
-		visible = Machine->uiheight / (3 * Machine->uifontheight /2) -1;
+		visible = 0; /*Machine->uiheight / (3 * Machine->uifontheight /2) -1; */
 
 		if (input_ui_pressed_repeat(IPT_UI_DOWN, 8))
 		{
@@ -552,11 +533,13 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 			else
 			if (UI_SHIFT_PRESSED)
 			{
-				sel = (sel + visible) % total;
+				sel = (sel + visible - 1);
+				sel = MIN(sel,total);
 			}
 			else
 			{
-				sel = (sel + 1) % total;
+				sel++;
+				sel = MIN(sel,total);
 			}
 		}
 
@@ -564,15 +547,17 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 		{
 			if (UI_CONTROL_PRESSED)
 			{
-				sel = 0;
+				sel = 1;
 			}
 			if (UI_SHIFT_PRESSED)
 			{
-				sel = (sel + total - visible) % total;
+				sel = (sel - visible + 1);
+				sel = MAX(0,sel);
 			}
 			else
 			{
-				sel = (sel + total - 1) % total;
+				sel--;
+				sel = MAX(0,sel);
 			}
 		}
 
@@ -588,14 +573,26 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 
 				case FILESELECT_FILESPEC:
 					start_enter_string(current_filespecification, 32, 0);
+
+					/* flush keyboard buffer */
+					while (code_read_async() != CODE_NONE)
+						;
+
 					sel |= 1 << SEL_BITS; /* we'll ask for a key */
 					schedule_full_refresh();
 					break;
 
 				case FILESELECT_FILE:
 					/* copy filename */
-					strncpyz(entered_filename, osd_get_cwd(), sizeof(entered_filename) / sizeof(entered_filename[0]));
-					strncatz(entered_filename, fs_item[sel], sizeof(entered_filename) / sizeof(entered_filename[0]));
+					if (fs_item[sel].text == ui_getstring(UI_emptyslot))
+					{
+						entered_filename[0] = '\0';
+					}
+					else
+					{
+						strncpyz(entered_filename, osd_get_cwd(), sizeof(entered_filename) / sizeof(entered_filename[0]));
+						strncatz(entered_filename, fs_item[sel].text, sizeof(entered_filename) / sizeof(entered_filename[0]));
+					}
 
 					fs_free();
 					sel = -3;
@@ -603,7 +600,7 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 
 				case FILESELECT_DIRECTORY:
 					/*	fs_chdir(fs_item[sel]); */
-					osd_change_directory(fs_item[sel]);
+					osd_change_directory(fs_item[sel].text);
 					fs_free();
 
 					schedule_full_refresh();
@@ -611,7 +608,7 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 
 				case FILESELECT_DEVICE:
 					/*	 fs_chdir("/"); */
-					osd_change_device(fs_item[sel]);
+					osd_change_device(fs_item[sel].text);
 					fs_free();
 					schedule_full_refresh();
 					break;
@@ -637,59 +634,55 @@ int fileselect(struct mame_bitmap *bitmap, int selected)
 		fs_free();
 
 	if (sel == -1 || sel == -2 || sel == -3)
+	{
 		schedule_full_refresh();
+		fs_insession = 0;
+	}
 
 	return sel + 1;
 }
 
-int filemanager(struct mame_bitmap *bitmap, int selected)
+int filemanager(int selected)
 {
 	static int previous_sel;
 	const char *name;
-	const char *menu_item[40];
-	const char *menu_subitem[40];
-	int types[40];
+	ui_menu_item menu_items[40];
+	const struct IODevice *devices[40];
 	int ids[40];
-	char flag[40];
-
-	int sel, total, arrowize, type, id;
-
-	const struct IODevice *dev = Machine->gamedrv->dev;
+	char names[40][64];
+	int sel, total, arrowize, id;
+	const struct IODevice *dev;
+	mess_image *img;
 
 	sel = selected - 1;
-
-
 	total = 0;
 
 	/* Cycle through all devices for this system */
-	while(dev->type != IO_END)
+	for (dev = Machine->devices; dev->type < IO_COUNT; dev++)
 	{
-		type = dev->type;
 		for (id = 0; id < dev->count; id++)
 		{
-			name = device_typename_id(type, id);
+			img = image_from_device_and_index(dev, id);
+			strcpy( names[total], image_typename_id(img) );
+			name = image_filename(img);
 
-			menu_item[total] = (name) ? name : "---";
+			memset(&menu_items[total], 0, sizeof(menu_items[total]));
+			menu_items[total].text = (names[total]) ? names[total] : "---";
+			menu_items[total].subtext = (name) ? name : "---";
 
-			name = device_filename(type, id);
-
-			menu_subitem[total] = (name) ? name : "---";
-
-			flag[total] = 0;
-			types[total] = type;
+			devices[total] = dev;
 			ids[total] = id;
 
 			total++;
-
 		}
-		dev++;
 	}
 
 
 	/* if the fileselect() mode is active */
 	if (sel & (2 << SEL_BITS))
 	{
-		sel = fileselect(bitmap, selected & ~(2 << SEL_BITS));
+		img = image_from_device_and_index(devices[previous_sel & SEL_MASK], ids[previous_sel & SEL_MASK]);
+		sel = fileselect(selected & ~(2 << SEL_BITS), image_filename(img));
 		if (sel != 0 && sel != -1 && sel!=-2)
 			return sel | (2 << SEL_BITS);
 
@@ -701,23 +694,19 @@ int filemanager(struct mame_bitmap *bitmap, int selected)
 			previous_sel = previous_sel & SEL_MASK;
 
 			/* attempt a filename change */
-			device_filename_change(types[previous_sel], ids[previous_sel], entered_filename);
+			img = image_from_device_and_index(devices[previous_sel], ids[previous_sel]);
+			image_load(img, entered_filename[0] ? entered_filename : NULL);
 		}
 
 		sel = previous_sel;
 
 		/* change menu item to show this filename */
-		menu_subitem[sel & SEL_MASK] = entered_filename;
-
+		menu_items[sel & SEL_MASK].subtext = entered_filename;
 	}
 
-	menu_item[total] = "Return to Main Menu";
-	menu_subitem[total] = 0;
-	flag[total] = 0;
+	memset(&menu_items[total], 0, sizeof(menu_items[total]));
+	menu_items[total].text = ui_getstring(UI_returntomain);
 	total++;
-	menu_item[total] = 0;			   /* terminate array */
-	menu_subitem[total] = 0;
-	flag[total] = 0;
 
 	arrowize = 0;
 	if (sel < total - 1)
@@ -726,10 +715,10 @@ int filemanager(struct mame_bitmap *bitmap, int selected)
 	if (sel & (1 << SEL_BITS))	/* are we waiting for a new key? */
 	{
 		/* change menu item to show this filename */
-		menu_subitem[sel & SEL_MASK] = entered_filename;
+		menu_items[sel & SEL_MASK].subtext = entered_filename;
 
 		/* display the menu */
-		ui_displaymenu(bitmap, menu_item, menu_subitem, flag, sel & SEL_MASK, 3);
+		ui_draw_menu(menu_items, total, sel & SEL_MASK);
 
 		/* update string with any keys that are pressed */
 		name = update_entered_string();
@@ -739,17 +728,15 @@ int filemanager(struct mame_bitmap *bitmap, int selected)
 		{
 			/* yes */
 			sel &= SEL_MASK;
-			if (strlen(name) == 0)
-				device_filename_change(types[sel], ids[sel], NULL);
-			else
-				device_filename_change(types[sel], ids[sel], name);
+			img = image_from_device_and_index(devices[sel], ids[sel]);
+			image_load(img, NULL);
 		}
 
 		schedule_full_refresh();
 		return sel + 1;
 	}
 
-	ui_displaymenu(bitmap, menu_item, menu_subitem, flag, sel, arrowize);
+	ui_draw_menu(menu_items, total, sel);
 
 	if (input_ui_pressed_repeat(IPT_UI_DOWN, 8))
 		sel = (sel + 1) % total;
@@ -761,6 +748,8 @@ int filemanager(struct mame_bitmap *bitmap, int selected)
 	{
 		int os_sel;
 
+		img = NULL;
+
 		/* Return to main menu? */
 		if (sel == total-1)
 		{
@@ -768,14 +757,18 @@ int filemanager(struct mame_bitmap *bitmap, int selected)
 			os_sel = -1;
 		}
 		/* no, let the osd code have a crack at changing files */
-		else os_sel = osd_select_file (sel, entered_filename);
+		else
+		{
+			img = image_from_device_and_index(devices[sel], ids[sel]);
+			os_sel = osd_select_file(img, entered_filename);
+		}
 
 		if (os_sel != 0)
 		{
 			if (os_sel == 1)
 			{
 				/* attempt a filename change */
-				device_filename_change(types[sel], ids[sel], entered_filename);
+				image_load(img, entered_filename);
 			}
 		}
 		/* osd code won't handle it, lets use our clunky interface */
@@ -789,12 +782,16 @@ int filemanager(struct mame_bitmap *bitmap, int selected)
 		else
 		{
 			{
-				if (strcmp(menu_subitem[sel], "---") == 0)
+				if (strcmp(menu_items[sel].text, "---") == 0)
 					entered_filename[0] = '\0';
 				else
-					strcpy(entered_filename, menu_subitem[sel]);
+					strcpy(entered_filename, menu_items[sel].text);
 				start_enter_string(entered_filename, (sizeof(entered_filename) / sizeof(entered_filename[0])) - 1, 1);
 
+				/* flush keyboard buffer */
+				while (code_read_async() != CODE_NONE)
+					;
+
 				sel |= 1 << SEL_BITS;	/* we'll ask for a key */
 
 				/* tell updatescreen() to clean after us (in case the window changes size) */
