@@ -13,7 +13,7 @@
 #include "cassimg.h"
 #include "utils.h"
 #include "pool.h"
-#include "mamecore.h"
+#include "mame.h"
 
 /* debugging parameters */
 #define LOG_PUT_SAMPLES			0
@@ -550,11 +550,12 @@ casserr_t cassette_put_samples(cassette_image *cassette, int channel,
 		cassette->sample_count = ranges.sample_last + 1;
 	cassette->flags |= CASSETTE_FLAG_DIRTY;
 
-#if LOG_PUT_SAMPLES
-	logerror("cassette_put_samples(): Putting samples TIME=[%2.6g..%2.6g] INDEX=[%i..%i]\n",
-		time_index,				time_index + sample_period,
-		ranges.sample_first,	ranges.sample_last);
-#endif
+	if (LOG_PUT_SAMPLES)
+	{
+		logerror("cassette_put_samples(): Putting samples TIME=[%2.6g..%2.6g] INDEX=[%i..%i]\n",
+			time_index,				time_index + sample_period,
+			(int)ranges.sample_first,	(int)ranges.sample_last);
+	}
 
 	for (sample_index = ranges.sample_first; sample_index <= ranges.sample_last; sample_index++)
 	{
