@@ -4,14 +4,6 @@
 #include "driver.h"
 #include "cbmserb.h"
 
-#ifdef RUNTIME_LOADER
-# ifdef __cplusplus
-	extern "C" void c16_runtime_loader_init(void);
-# else
-	extern void c16_runtime_loader_init(void);
-# endif
-#endif
-
 #define JOYSTICK1_PORT (input_port_7_r(0)&0x80)
 #define JOYSTICK2_PORT (input_port_7_r(0)&0x40)
 
@@ -135,42 +127,38 @@
 #define TYPE_PLUS4 ((input_port_9_r(0)&0xc)==4)
 #define TYPE_364 ((input_port_9_r(0)&0xc)==8)
 
-#define DIPMEMORY (input_port_9_r(0)&3)
-#define MEMORY16K (0)
-#define MEMORY32K (2)
-#define MEMORY64K (3)
-
 extern UINT8 *c16_memory;
 
-extern WRITE_HANDLER(c16_m7501_port_w);
-extern READ_HANDLER(c16_m7501_port_r);
+UINT8 c16_m7501_port_read(void);
+void c16_m7501_port_write(UINT8 data);
 
-extern WRITE_HANDLER(c16_6551_port_w);
-extern READ_HANDLER(c16_6551_port_r);
+extern WRITE8_HANDLER(c16_6551_port_w);
+extern  READ8_HANDLER(c16_6551_port_r);
 
-extern READ_HANDLER(c16_fd1x_r);
-extern WRITE_HANDLER(plus4_6529_port_w);
-extern READ_HANDLER(plus4_6529_port_r);
+extern  READ8_HANDLER(c16_fd1x_r);
+extern WRITE8_HANDLER(plus4_6529_port_w);
+extern  READ8_HANDLER(plus4_6529_port_r);
 
-extern WRITE_HANDLER(c16_6529_port_w);
-extern READ_HANDLER(c16_6529_port_r);
+extern WRITE8_HANDLER(c16_6529_port_w);
+extern  READ8_HANDLER(c16_6529_port_r);
 
-extern WRITE_HANDLER(c364_speech_w);
-extern READ_HANDLER(c364_speech_r);
+extern WRITE8_HANDLER(c364_speech_w);
+extern  READ8_HANDLER(c364_speech_r);
+
+extern void c364_speech_init(void);
 
 #if 0
-extern WRITE_HANDLER(c16_iec9_port_w);
-extern READ_HANDLER(c16_iec9_port_r);
+extern WRITE8_HANDLER(c16_iec9_port_w);
+extern  READ8_HANDLER(c16_iec9_port_r);
 
-extern WRITE_HANDLER(c16_iec8_port_w);
-extern READ_HANDLER(c16_iec8_port_r);
+extern WRITE8_HANDLER(c16_iec8_port_w);
+extern  READ8_HANDLER(c16_iec8_port_r);
 
 #endif
 
-extern WRITE_HANDLER(c16_select_roms);
-extern WRITE_HANDLER(c16_switch_to_rom);
-extern WRITE_HANDLER(c16_switch_to_ram);
-extern WRITE_HANDLER(plus4_switch_to_ram);
+extern WRITE8_HANDLER(c16_select_roms);
+extern WRITE8_HANDLER(c16_switch_to_rom);
+extern WRITE8_HANDLER(c16_switch_to_ram);
 
 /* ted reads */
 extern int c16_read_keyboard (int databus);
@@ -178,11 +166,10 @@ extern void c16_interrupt (int);
 
 extern void c16_driver_init (void);
 extern void c16_driver_shutdown (void);
-extern void c16_init_machine (void);
-extern void c16_shutdown_machine (void);
-extern int c16_frame_interrupt (void);
+extern MACHINE_INIT( c16 );
+extern INTERRUPT_GEN( c16_frame_interrupt );
 
-extern int c16_rom_init (int id);
-extern int c16_rom_load (int id);
+extern DEVICE_LOAD(c16_rom);
+extern DEVICE_UNLOAD(c16_rom);
 
 #endif
