@@ -33,18 +33,14 @@ extern UINT8 CURLINE;		/* Current scanline */
 extern UINT8 STAT;			/* returned when port 249 read */
 
 void coupe_update_memory(void);
-int coupe_floppy_init(int);
 
-void coupe_init_machine_256(void);
-void coupe_init_machine_512(void);
-void coupe_shutdown_machine(void);
-int coupe_vh_start(void);
-void coupe_vh_stop(void);
+DEVICE_LOAD( coupe_floppy );
+MACHINE_INIT( coupe );
+
 void coupe_eof_callback(void);
-void coupe_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
 
-void drawMode1_line(struct mame_bitmap *,int);
-void drawMode2_line(struct mame_bitmap *,int);
-void drawMode3_line(struct mame_bitmap *,int);
-void drawMode4_line(struct mame_bitmap *,int);
+void drawMode1_line(mame_bitmap *,int);
+void drawMode2_line(mame_bitmap *,int);
+void drawMode3_line(mame_bitmap *,int);
+void drawMode4_line(mame_bitmap *,int);
 
