@@ -1,3 +1,14 @@
+/*********************************************************************
+
+	pc1350.h
+
+	Pocket Computer 1350
+
+*********************************************************************/
+
+#ifndef PC1350_H
+#define PC1350_H
+
 void pc1350_outa(int data);
 void pc1350_outb(int data);
 void pc1350_outc(int data);
@@ -5,16 +16,17 @@ void pc1350_outc(int data);
 bool pc1350_brk(void);
 int pc1350_ina(void);
 int pc1350_inb(void);
-void init_pc1350(void);
-void pc1350_machine_init(void);
-void pc1350_machine_stop(void);
+
+DRIVER_INIT( pc1350 );
+MACHINE_INIT( pc1350 );
+NVRAM_HANDLER( pc1350 );
 
 /* in vidhrdw/pocketc.c */
-extern READ_HANDLER(pc1350_lcd_read);
-extern WRITE_HANDLER(pc1350_lcd_write);
+READ8_HANDLER(pc1350_lcd_read);
+WRITE8_HANDLER(pc1350_lcd_write);
+VIDEO_UPDATE( pc1350 );
 
 int pc1350_keyboard_line_r(void);
-void pc1350_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
 
 /* in systems/pocketc.c */
 #define PC1350_KEY_OFF input_port_0_r(0)&0x80
@@ -92,3 +104,4 @@ void pc1350_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
 #define PC1350_RAM20K (input_port_8_r(0)&0x80)==0x80
 #define PC1350_CONTRAST (input_port_8_r(0)&7)
 
+#endif /* PC1350_H */
