@@ -1,7 +1,7 @@
-extern int  spectrum_snap_load(int id);
-extern void spectrum_snap_exit(int id);
+#ifndef SPECTRUM_H
+#define SPECTRUM_H
 
-extern int  load_snap(void);
+#include "devices/snapquik.h"
 
 typedef enum
 {
@@ -15,25 +15,21 @@ TIMEX_CART_TYPE;
 extern TIMEX_CART_TYPE timex_cart_type;
 extern UINT8 timex_cart_chunks;
 extern UINT8 * timex_cart_data;
-extern int  spectrum_cart_load(int id);
-extern void spectrum_cart_exit(int id);
 
-extern int  timex_cart_load(int id);
-extern void timex_cart_exit(int id);
+DEVICE_LOAD( timex_cart );
+DEVICE_UNLOAD( timex_cart );
 extern void ts2068_update_memory(void);
 
-extern void spectrum_init_machine(void);
-extern void spectrum_shutdown_machine(void);
+extern MACHINE_INIT( spectrum );
 
-extern int  spec_quick_init (int id);
-extern void spec_quick_exit (int id);
-extern int  spec_quick_open (int id, int mode, void *arg);
+extern SNAPSHOT_LOAD( spectrum );
+extern QUICKLOAD_LOAD( spectrum );
 
 /*-----------------27/02/00 10:49-------------------
  code for WAV reading writing
 --------------------------------------------------*/
-extern int spectrum_cassette_init(int);
-extern void spectrum_cassette_exit(int);
+DEVICE_LOAD( spectrum_cassette );
+DEVICE_UNLOAD( spectrum_cassette );
 
 extern int spectrum_128_port_7ffd_data;
 extern int spectrum_plus3_port_1ffd_data;
@@ -41,31 +37,28 @@ extern int ts2068_port_ff_data;
 extern int ts2068_port_f4_data;
 extern int PreviousFE;
 extern unsigned char *spectrum_128_screen_location;
-extern unsigned char *ts2068_ram;
-
 
 extern void spectrum_128_update_memory(void);
 extern void spectrum_plus3_update_memory(void);
 
+extern VIDEO_START( spectrum );
+extern VIDEO_UPDATE( spectrum );
+extern VIDEO_EOF( spectrum );
 
-extern int  spectrum_vh_start(void);
-extern void spectrum_vh_stop(void);
-extern void spectrum_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
-extern void spectrum_eof_callback(void);
+extern VIDEO_START( spectrum_128 );
+extern VIDEO_UPDATE( spectrum_128 );
 
-extern int spectrum_128_vh_start(void);
-extern void spectrum_128_vh_stop(void);
-extern void spectrum_128_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
+extern VIDEO_EOF( ts2068 );
+extern VIDEO_UPDATE( ts2068 );
 
-extern void ts2068_eof_callback(void);
-extern void ts2068_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
+extern VIDEO_UPDATE( tc2048 );
 
-extern void tc2048_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
-
-extern WRITE_HANDLER ( spectrum_characterram_w );
-extern READ_HANDLER  ( spectrum_characterram_r );
-extern WRITE_HANDLER ( spectrum_colorram_w );
-extern READ_HANDLER  ( spectrum_colorram_r );
+extern unsigned char *spectrum_characterram;
+extern unsigned char *spectrum_colorram;
+extern WRITE8_HANDLER ( spectrum_characterram_w );
+extern  READ8_HANDLER  ( spectrum_characterram_r );
+extern WRITE8_HANDLER ( spectrum_colorram_w );
+extern  READ8_HANDLER  ( spectrum_colorram_r );
 
 /* Spectrum screen size in pixels */
 #define SPEC_UNSEEN_LINES  16   /* Non-visible scanlines before first border
@@ -102,3 +95,5 @@ extern READ_HANDLER  ( spectrum_colorram_r );
 #define TS2068_DISPLAY_XSIZE 512  /* Horizontal screen resolution */
 #define TS2068_RIGHT_BORDER  96   /* Number of right hand border pixels */
 #define TS2068_SCREEN_WIDTH (TS2068_LEFT_BORDER + TS2068_DISPLAY_XSIZE + TS2068_RIGHT_BORDER)
+
+#endif /* SPECTRUM_H */
