@@ -14,8 +14,8 @@
 /* pal version */
 /* dma_read: videochip fetched 1 byte data from system bus */
 extern void ted7360_init (int pal);
-extern void ted7360_set_dma (mem_read_handler dma_read, 
-							 mem_read_handler dma_read_rom);
+extern void ted7360_set_dma (read8_handler dma_read, 
+							 read8_handler dma_read_rom);
 
 #define TED7360NTSC_VRETRACERATE 60
 #define TED7360PAL_VRETRACERATE 50
@@ -44,31 +44,29 @@ extern void ted7360_set_dma (mem_read_handler dma_read,
 #define TED7360PAL_LINES 312
 #define TED7360_LINES (ted7360_pal?TED7360PAL_LINES:TED7360NTSC_LINES)
 
-extern int ted7360_vh_start (void);
-extern void ted7360_vh_stop (void);
-extern void ted7360_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
+extern VIDEO_START( ted7360 );
+extern VIDEO_STOP( ted7360 );
+extern VIDEO_UPDATE( ted7360 );
 extern unsigned char ted7360_palette[16 * 8 * 3];
 
 /* to be inserted in GameDriver-Structure */
 extern struct CustomSound_interface ted7360_sound_interface;
 
 /* to be called when writting to port */
-extern WRITE_HANDLER ( ted7360_port_w );
+extern WRITE8_HANDLER ( ted7360_port_w );
 
 /* to be called when reading from port */
-extern READ_HANDLER  ( ted7360_port_r );
+extern  READ8_HANDLER  ( ted7360_port_r );
 
 /* to be called each vertical retrace */
-extern int ted7360_frame_interrupt (void);
-int ted7360_raster_interrupt (void);
+extern void ted7360_frame_interrupt (void);
+extern void ted7360_raster_interrupt (void);
 
 /* private area */
 
 /* from sndhrdw/pc.c */
-extern int ted7360_custom_start (const struct MachineSound *driver);
-extern void ted7360_custom_stop (void);
-extern void ted7360_custom_update (void);
-extern void ted7360_soundport_w (int mode, int data);
+void *ted7360_custom_start (int clock, const struct CustomSound_interface *config);
+void ted7360_soundport_w (int mode, int data);
 
 extern UINT8 ted7360[0x20];
 extern bool ted7360_pal;
