@@ -26,43 +26,28 @@ static const SOUNDBLASTER_CONFIG soundblaster = { 1,5, {1,0} };
 
 
 
-static void at286_set_gate_a20(int a20)
+static void at_set_gate_a20(int a20)
 {
+	/* set the CPU's A20 line */
 	cpunum_set_input_line(0, INPUT_LINE_A20, a20);
 }
 
 
 
-static void at386_set_gate_a20(int a20)
-{
-	offs_t mirror = a20 ? 0xff000000 : 0xfff00000;
-	cpunum_set_input_line(0, INPUT_LINE_A20, a20);
-	memory_install_read32_handler(0,  ADDRESS_SPACE_PROGRAM, 0x000000, 0x09ffff, 0, mirror, MRA32_BANK10);
-	memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x09ffff, 0, mirror, MWA32_BANK10);
-	memory_set_bankptr(10, mess_ram);
-
-	if (a20)
-	{
-		offs_t ram_limit = 0x100000 + mess_ram_size - 0x0a0000;
-		memory_install_read32_handler(0,  ADDRESS_SPACE_PROGRAM, 0x100000,  ram_limit - 1,	0, 0, MRA32_BANK1);
-		memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0x100000,  ram_limit - 1,	0, 0, MWA32_BANK1);
-		memory_install_read32_handler(0,  ADDRESS_SPACE_PROGRAM, ram_limit, 0xffffff,		0, 0, MRA32_NOP);
-		memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, ram_limit, 0xffffff,		0, 0, MWA32_NOP);
-		memory_install_read32_handler(0,  ADDRESS_SPACE_PROGRAM, 0xff0000,  0xffffff,		0, 0, MRA32_BANK2);
-		memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0xff0000,  0xffffff,		0, 0, MWA32_ROM);
-		memory_set_bankptr(1, mess_ram + 0xa0000);
-		memory_set_bankptr(2, memory_region(REGION_CPU1) + 0x0f0000);
-	}
-}
-
-
-
 static void init_at_common(const struct kbdc8042_interface *at8042)
 {
 	init_pc_common(PCCOMMON_KEYBOARD_AT | PCCOMMON_DMA8237_AT | PCCOMMON_TIMER_8254);
 	mc146818_init(MC146818_STANDARD);
 	soundblaster_config(&soundblaster);
 	kbdc8042_init(at8042);
+
+	if (mess_ram_size > 0x0a0000)
+	{
+		offs_t ram_limit = 0x100000 + mess_ram_size - 0x0a0000;
+		memory_install_read_handler(0,  ADDRESS_SPACE_PROGRAM, 0x100000,  ram_limit - 1, 0, 0, STATIC_BANK1);
+		memory_install_write_handler(0, ADDRESS_SPACE_PROGRAM, 0x100000,  ram_limit - 1, 0, 0, STATIC_BANK1);
+		memory_set_bankptr(1, mess_ram + 0xa0000);
+	}
 }
 
 
@@ -78,7 +63,7 @@ DRIVER_INIT( atcga )
 {
 	struct kbdc8042_interface at8042 =
 	{
-		KBDC8042_STANDARD, at286_set_gate_a20, at_keyboard_interrupt
+		KBDC8042_STANDARD, at_set_gate_a20, at_keyboard_interrupt
 	};
 	init_at_common(&at8042);
 }
@@ -89,7 +74,7 @@ DRIVER_INIT( at386 )
 {
 	struct kbdc8042_interface at8042 =
 	{
-		KBDC8042_AT386, at386_set_gate_a20, at_keyboard_interrupt
+		KBDC8042_AT386, at_set_gate_a20, at_keyboard_interrupt
 	};
 	init_at_common(&at8042);
 }
@@ -131,7 +116,7 @@ DRIVER_INIT( at_vga )
 {
 	struct kbdc8042_interface at8042 =
 	{
-		KBDC8042_STANDARD, at286_set_gate_a20, at_keyboard_interrupt
+		KBDC8042_STANDARD, at_set_gate_a20, at_keyboard_interrupt
 	};
 
 	init_at_common(&at8042);
@@ -145,7 +130,7 @@ DRIVER_INIT( ps2m30286 )
 {
 	struct kbdc8042_interface at8042 =
 	{
-		KBDC8042_PS2, at386_set_gate_a20, at_keyboard_interrupt
+		KBDC8042_PS2, at_set_gate_a20, at_keyboard_interrupt
 	};
 	init_at_common(&at8042);
 	pc_turbo_setup(0, 3, 0x02, 4.77/12, 1);
