@@ -19,10 +19,12 @@
 #include "vidhrdw/m6847.h"
 #include "includes/atom.h"
 #include "includes/i8271.h"
-#include "includes/basicdsk.h"
-#include "includes/flopdrv.h"
 #include "machine/6522via.h"
-#include "cassette.h"
+#include "devices/basicdsk.h"
+#include "devices/flopdrv.h"
+#include "devices/cassette.h"
+#include "devices/printer.h"
+#include "sound/speaker.h"
 
 static UINT8	atom_8255_porta;
 static UINT8	atom_8255_portb;
@@ -30,8 +32,6 @@ static UINT8	atom_8255_portc;
 
 /* printer data written */
 static char atom_printer_data = 0x07f;
-/* 2.4khz timer state */
-static void *atom_timer = NULL;
 
 /* I am not sure if this is correct, the atom appears to have a 2.4Khz timer used for reading tapes?? */
 static int	timer_state = 0;
@@ -40,24 +40,34 @@ static void atom_via_irq_func(int state)
 {
 	if (state)
 	{
-		cpu_set_irq_line(0,0, HOLD_LINE);
+		cpunum_set_input_line(0,0, HOLD_LINE);
 	}
 	else
 	{
-		cpu_set_irq_line(0,0, CLEAR_LINE);
+		cpunum_set_input_line(0,0, CLEAR_LINE);
 	}
 
 
 }
 
+static mess_image *cassette_device_image(void)
+{
+	return image_from_devtype_and_index(IO_CASSETTE, 0);
+}
+
+static mess_image *printer_image(void)
+{
+	return image_from_devtype_and_index(IO_PRINTER, 0);
+}
+
 /* printer status */
-READ_HANDLER(atom_via_in_a_func)
+static  READ8_HANDLER(atom_via_in_a_func)
 {
 	unsigned char data;
 
 	data = atom_printer_data;
 
-	if (!device_status(IO_PRINTER,0,0))
+	if (!printer_status(printer_image(),0))
 	{
 		/* offline */
 		data |=0x080;
@@ -67,7 +77,7 @@ READ_HANDLER(atom_via_in_a_func)
 }
 
 /* printer data */
-WRITE_HANDLER(atom_via_out_a_func)
+static WRITE8_HANDLER(atom_via_out_a_func)
 {
 	/* data is written to port, this causes a pulse on ca2 (printer /strobe input),
 	and data is written */
@@ -78,7 +88,7 @@ WRITE_HANDLER(atom_via_out_a_func)
 static unsigned char previous_ca2_data = 0;
 
 /* one of these is pulsed! */
-WRITE_HANDLER(atom_via_out_ca2_func)
+static WRITE8_HANDLER(atom_via_out_ca2_func)
 {
 	/* change in state of ca2 output? */
 	if (((previous_ca2_data^data)&0x01)!=0)
@@ -87,7 +97,7 @@ WRITE_HANDLER(atom_via_out_ca2_func)
 		if (data & 0x01)
 		{
 			/* output data to printer */
-			device_output(IO_PRINTER, 0, atom_printer_data);
+			printer_output(printer_image(), atom_printer_data);
 		}
 	}
 
@@ -104,26 +114,13 @@ struct via6522_interface atom_6522_interface=
 	NULL,
 	atom_via_out_a_func,	/* printer data */
 	NULL,
+	NULL,
+	NULL,
 	atom_via_out_ca2_func,	/* printer strobe */
 	NULL,
 	atom_via_irq_func,
-	NULL,
-	NULL,
-	NULL,
-	NULL
 };
 
-READ_HANDLER(atom_via_r)
-{
-	return via_0_r(offset & 0x0f);
-}
-
-WRITE_HANDLER(atom_via_w)
-{
-	via_0_w(offset & 0x0f, data);
-
-}
-
 
 
 static	ppi8255_interface	atom_8255_int =
@@ -153,7 +150,7 @@ static void atom_8271_interrupt_callback(int state)
 		{
 			/* I'll pulse it because if I used hold-line I'm not sure
 			it would clear - to be checked */
-			cpu_set_nmi_line(0, PULSE_LINE);
+			cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE);
 		}
 	}
 
@@ -166,7 +163,35 @@ static struct i8271_interface atom_8271_interface=
 	NULL
 };
 
+/*
+                                                                  +--------+
+PC0,  Tape Output ------------------------------------------------|
+                                                                  |
+                                                  +---------|     | NAND   |------CAS OUT
+PC1, Enable 2400 Hz ------------------------------|         |     |        |
+                                  +------+        | NAND    |--B--|        |
+PC4, 2400 Hz ---------------+-----|  INV | ---A---|         |     +--------+
+                            |     +------+        +---------+
+                            |
+                            2400 Hz
 
+
+PC4      PC1 PC0     :   A     B  CAS OUT
+  0      0      0    :    1     1        1
+  0      0      1    :    1     1        0
+  0      1      0    :    1     0        1
+  0      1      1    :    1     0        1
+  1      0      0    :    0     1        1
+  1      0      1    :    0     1        0
+  1      1      0    :    0     1        1
+  1      1      1    :    0     1        0
+
+
+Here is a detail from the Atom circuit diagram about Tape Input:
+
+PC5, Cassette
+Input ----------------------------------------------------------------CAS IN
+*/
 static void atom_timer_callback(int dummy)
 {
 	/* change timer state */
@@ -189,7 +214,7 @@ static void atom_timer_callback(int dummy)
 		result = (~(B & atom_8255_portc)) & 0x01;
 
 		/* tape output */
-		device_output(IO_CASSETTE, 0, (result & 0x01) ? -32768 : 32767);
+		cassette_output(cassette_device_image(), (result & 0x01) ? -1.0 : +1.0);
 	}
 }
 
@@ -209,9 +234,10 @@ static OPBASE_HANDLER(atom_opbase_handler)
 	memory_region(REGION_CPU1)[0x0a] = rand() & 0x0ff;
 	memory_region(REGION_CPU1)[0x0b] = rand() & 0x0ff;
 
-	return cpu_get_pc() & 0x0ffff;
+	return activecpu_get_pc() & 0x0ffff;
 }
-void atom_init_machine(void)
+
+MACHINE_INIT( atom )
 {
 	ppi8255_init (&atom_8255_int);
 	atom_8255_porta = 0xff;
@@ -225,72 +251,11 @@ void atom_init_machine(void)
 	via_reset();
 
 	timer_state = 0;
-	atom_timer = timer_pulse(TIME_IN_HZ(2400*2), 0, atom_timer_callback);
-
-	/* cassette motor control */
-	device_status(IO_CASSETTE, 0, 1);
+	timer_pulse(TIME_IN_HZ(2400*2), 0, atom_timer_callback);
 
 	memory_set_opbase_handler(0,atom_opbase_handler);
-
 }
 
-void atom_stop_machine(void)
-{
-	if (atom_timer)
-		timer_remove(atom_timer);
-
-	i8271_stop();
-
-	/* cassette motor control */
-	device_status(IO_CASSETTE, 0, 0);
-}
-
-
-
-/* load image */
-int atom_load(int type, int id, unsigned char **ptr)
-{
-	void *file;
-
-	file = image_fopen(type, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-
-	if (file)
-	{
-		int datasize;
-		unsigned char *data;
-
-		/* get file size */
-		datasize = osd_fsize(file);
-
-		if (datasize!=0)
-		{
-			/* malloc memory for this data */
-			data = malloc(datasize);
-
-			if (data!=NULL)
-			{
-				/* read whole file */
-				osd_fread(file, data, datasize);
-
-				*ptr = data;
-
-				/* close file */
-				osd_fclose(file);
-
-				logerror("File loaded!\r\n");
-
-				/* ok! */
-				return 1;
-			}
-			osd_fclose(file);
-
-		}
-	}
-
-	return 0;
-}
-
-
 struct atm
 {
 	UINT8	atm_name[16];
@@ -305,73 +270,75 @@ struct atm
 /* this only works if loaded using file-manager. This should work
 for binary files, but will not work with basic files. This also does not support
 .tap files which contain multiple .atm files joined together! */
-int atom_init_atm (int id)
+QUICKLOAD_LOAD(atom)
 {
 	unsigned char *quickload_data;
+	int i;
+	unsigned char *data;
+	struct atm *atm_header;
+	unsigned long addr;
+	unsigned long exec;
+	unsigned long size;
 
-	if (atom_load(IO_QUICKLOAD, id, &quickload_data))
+	quickload_data = malloc(quickload_size);
+	if (!quickload_data)
+		return INIT_FAIL;
+
+	if (mame_fread(fp, quickload_data, quickload_size) != quickload_size)
 	{
-		if (quickload_data!=NULL)
-		{
-			int i;
-			unsigned char *data;
-			struct atm *atm_header = (struct atm *)quickload_data;
-			unsigned long addr;
-			unsigned long exec;
-			unsigned long size;
-
-			/* calculate data address */
-			data = (unsigned char *)((unsigned long)quickload_data + sizeof(struct atm));
-
-			/* get start address */
-			addr = (
-					(atm_header->atm_start_low & 0x0ff) |
-					((atm_header->atm_start_high & 0x0ff)<<8)
-					);
-
-			/* get size */
-			size = (
-					(atm_header->atm_size_low & 0x0ff) |
-					((atm_header->atm_size_high & 0x0ff)<<8)
-					);
-
-			/* get execute address */
-			exec = (
-				(atm_header->atm_exec_low & 0x0ff)	|
-				((atm_header->atm_exec_high & 0x0ff)<<8)
-				);
-
-			/* copy data into memory */
-			for (i=size-1; i>=0; i--)
-			{
-				cpu_writemem16(addr, data[0]);
-				addr++;
-				data++;
-			}
-
-
-			/* set new pc address */
-			cpunum_set_pc(0,exec);
-
-			/* free the data */
-			free(quickload_data);
-
-			return INIT_PASS;
-		}
+		free(quickload_data);
+		return INIT_FAIL;
 	}
 
+	atm_header = (struct atm *)quickload_data;
+
+	/* calculate data address */
+	data = (unsigned char *)((unsigned long)quickload_data + sizeof(struct atm));
+
+	/* get start address */
+	addr = (
+			(atm_header->atm_start_low & 0x0ff) |
+			((atm_header->atm_start_high & 0x0ff)<<8)
+			);
+
+	/* get size */
+	size = (
+			(atm_header->atm_size_low & 0x0ff) |
+			((atm_header->atm_size_high & 0x0ff)<<8)
+			);
+
+	/* get execute address */
+	exec = (
+		(atm_header->atm_exec_low & 0x0ff)	|
+		((atm_header->atm_exec_high & 0x0ff)<<8)
+		);
+
+	/* copy data into memory */
+	for (i=size-1; i>=0; i--)
+	{
+		program_write_byte(addr, data[0]);
+		addr++;
+		data++;
+	}
+
+
+	/* set new pc address */
+	activecpu_set_reg(REG_PC, exec);
+
+	/* free the data */
+	free(quickload_data);
 	return INIT_PASS;
 }
 
 
 /* load floppy */
-int atom_floppy_init(int id)
+DEVICE_LOAD( atom_floppy )
 {
-	if (basicdsk_floppy_init(id)==INIT_PASS)
+	if (device_load_basicdsk_floppy(image, file)==INIT_PASS)
 	{
 		/* sector id's 0-9 */
 		/* drive, tracks, heads, sectors per track, sector length, dir_sector, dir_length, first sector id */
-		basicdsk_set_geometry(id,80,1,10,256,0,0);
+		basicdsk_set_geometry(image, 80, 1, 10, 256, 0, 0, FALSE);
 
 		return INIT_PASS;
 	}
@@ -380,13 +347,13 @@ int atom_floppy_init(int id)
 }
 
 
-READ_HANDLER (atom_8255_porta_r )
+ READ8_HANDLER (atom_8255_porta_r )
 {
 	/* logerror("8255: Read port a\n"); */
 	return (atom_8255_porta);
 }
 
-READ_HANDLER ( atom_8255_portb_r )
+ READ8_HANDLER ( atom_8255_portb_r )
 {
 	/* ilogerror("8255: Read port b: %02X %02X\n",
 			readinputport ((atom_8255.atom_8255_porta & 0x0f) + 1),
@@ -395,14 +362,14 @@ READ_HANDLER ( atom_8255_portb_r )
 											(readinputport (11) & 0xc0));
 }
 
-READ_HANDLER ( atom_8255_portc_r )
+ READ8_HANDLER ( atom_8255_portc_r )
 {
 
 /* | */
 	atom_8255_portc &= 0x0f;
 
 	/* cassette input */
-	if (device_input(IO_CASSETTE,0)>255)
+	if (cassette_input(cassette_device_image()) > 0.0)
 	{
 		atom_8255_portc |= (1<<5);
 	}
@@ -433,7 +400,7 @@ READ_HANDLER ( atom_8255_portc_r )
 
 */
 
-WRITE_HANDLER ( atom_8255_porta_w )
+WRITE8_HANDLER ( atom_8255_porta_w )
 {
 	if ((data & 0xf0) != (atom_8255_porta & 0xf0))
 	{
@@ -448,13 +415,13 @@ WRITE_HANDLER ( atom_8255_porta_w )
 /*	logerror("8255: Write port a, %02x\n", data); */
 }
 
-WRITE_HANDLER ( atom_8255_portb_w )
+WRITE8_HANDLER ( atom_8255_portb_w )
 {
 	atom_8255_portb = data;
 /*	logerror("8255: Write port b, %02x\n", data); */
 }
 
-WRITE_HANDLER (atom_8255_portc_w)
+WRITE8_HANDLER (atom_8255_portc_w)
 {
 	atom_8255_portc = data;
 	speaker_level_w(0, (data & 0x04) >> 2);
@@ -465,7 +432,7 @@ WRITE_HANDLER (atom_8255_portc_w)
 
 
 /* KT- I've assumed that the atom 8271 is linked in exactly the same way as on the bbc */
-READ_HANDLER(atom_8271_r)
+ READ8_HANDLER(atom_8271_r)
 {
 	switch (offset)
 	{
@@ -484,7 +451,7 @@ READ_HANDLER(atom_8271_r)
 	return 0x0ff;
 }
 
-WRITE_HANDLER(atom_8271_w)
+WRITE8_HANDLER(atom_8271_w)
 {
 	switch (offset)
 	{
@@ -504,21 +471,6 @@ WRITE_HANDLER(atom_8271_w)
 }
 
 
-int atom_cassette_init(int id)
-{
-	struct cassette_args args;
-	memset(&args, 0, sizeof(args));
-	args.create_smpfreq = 22050;	/* maybe 11025 Hz would be sufficient? */
-	return cassette_init(id, &args);
-}
-
-void atom_cassette_exit(int id)
-{
-	device_close(IO_CASSETTE, id);
-}
-
-
-
 /*********************************************/
 /* emulates a 16-slot eprom box for the Atom */
 static unsigned char selected_eprom = 0;
@@ -530,7 +482,7 @@ static void atom_eprom_box_refresh(void)
 	/* get address of eprom data */
 	eprom_data = memory_region(REGION_CPU1) + 0x010000 + (selected_eprom<<12);
 	/* set bank address */
-	cpu_setbank(1, eprom_data);
+	memory_set_bankptr(1, eprom_data);
 }
 
 void atom_eprom_box_init(void)
@@ -538,13 +490,12 @@ void atom_eprom_box_init(void)
 	/* set initial eprom */
 	selected_eprom = 0;
 	/* set memory handler */
-    memory_set_bankhandler_r(1, 0, MRA_BANK1);
 	/* init */
 	atom_eprom_box_refresh();
 }
 
 /* write to eprom box, changes eprom selected */
-WRITE_HANDLER(atom_eprom_box_w)
+WRITE8_HANDLER(atom_eprom_box_w)
 {
 	selected_eprom = data & 0x0f;
 
@@ -552,14 +503,14 @@ WRITE_HANDLER(atom_eprom_box_w)
 }
 
 /* read from eprom box register, can this be done in the real hardware */
-READ_HANDLER(atom_eprom_box_r)
+ READ8_HANDLER(atom_eprom_box_r)
 {
 	return selected_eprom;
 }
 
-void	atomeb_init_machine(void)
+MACHINE_INIT( atomeb )
 {
-	atom_init_machine();
+	machine_init_atom();
 	atom_eprom_box_init();
 }
 
