@@ -182,25 +182,25 @@ void c128_bankswitch_64 (int reset)
 	if ((!c64_game && c64_exrom)
 		|| (loram && hiram && !c64_exrom))
 	{
-		memory_set_bankptr (8, c64_roml);
+		memory_set_bankptr(8, c64_roml);
 	}
 	else
 	{
-		memory_set_bankptr (8, c64_memory + 0x8000);
+		memory_set_bankptr(8, c64_memory + 0x8000);
 	}
 
 	if ((!c64_game && c64_exrom && hiram)
 		|| (!c64_exrom))
 	{
-		memory_set_bankptr (9, c64_romh);
+		memory_set_bankptr(9, c64_romh);
 	}
 	else if (loram && hiram)
 	{
-		memory_set_bankptr (9, c64_basic);
+		memory_set_bankptr(9, c64_basic);
 	}
 	else
 	{
-		memory_set_bankptr (9, c64_memory + 0xa000);
+		memory_set_bankptr(9, c64_memory + 0xa000);
 	}
 
 	if ((!c64_game && c64_exrom)
@@ -214,31 +214,31 @@ void c128_bankswitch_64 (int reset)
 		rh = MRA8_BANK5;
 		c128_write_io = 0;
 		if ((!charen && (loram || hiram)))
-			memory_set_bankptr (13, c64_chargen);
+			memory_set_bankptr(13, c64_chargen);
 		else
-			memory_set_bankptr (13, c64_memory + 0xd000);
+			memory_set_bankptr(13, c64_memory + 0xd000);
 	}
 	c128_set_m8502_read_handler(0xd000, 0xdfff, rh);
 
 	if (!c64_game && c64_exrom)
 	{
-		memory_set_bankptr (14, c64_romh);
-		memory_set_bankptr (15, c64_romh+0x1f00);
-		memory_set_bankptr (16, c64_romh+0x1f05);
+		memory_set_bankptr(14, c64_romh);
+		memory_set_bankptr(15, c64_romh+0x1f00);
+		memory_set_bankptr(16, c64_romh+0x1f05);
 	}
 	else
 	{
 		if (hiram)
 		{
-			memory_set_bankptr (14, c64_kernal);
-			memory_set_bankptr (15, c64_kernal+0x1f00);
-			memory_set_bankptr (16, c64_kernal+0x1f05);
+			memory_set_bankptr(14, c64_kernal);
+			memory_set_bankptr(15, c64_kernal+0x1f00);
+			memory_set_bankptr(16, c64_kernal+0x1f05);
 		}
 		else
 		{
-			memory_set_bankptr (14, c64_memory + 0xe000);
-			memory_set_bankptr (15, c64_memory + 0xff00);
-			memory_set_bankptr (16, c64_memory + 0xff05);
+			memory_set_bankptr(14, c64_memory + 0xe000);
+			memory_set_bankptr(15, c64_memory + 0xff00);
+			memory_set_bankptr(16, c64_memory + 0xff05);
 		}
 	}
 	old = data;
@@ -288,8 +288,8 @@ static int mmu_page0, mmu_page1;
 	 c128_ram = c64_memory + MMU_RAM_ADDR;
 	 c128_va1617 = MMU_VIC_ADDR;
 #if 1
-	 memory_set_bankptr (10, c128_z80);
-	 memory_set_bankptr (11, c128_ram+0x1000);
+	 memory_set_bankptr(10, c128_z80);
+	 memory_set_bankptr(11, c128_ram+0x1000);
 	 if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 		  ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) )
 		 c128_ram=NULL;
@@ -300,32 +300,32 @@ static int mmu_page0, mmu_page1;
 		 c128_ram_bottom = 0;
 
 	 if (MMU_RAM_ADDR==0) { /* this is used in z80 mode for rom on/off switching !*/
-		 memory_set_bankptr (10, c128_z80);
-		 memory_set_bankptr (11, c128_z80+0x400);
+		 memory_set_bankptr(10, c128_z80);
+		 memory_set_bankptr(11, c128_z80+0x400);
 	 } else {
-		 memory_set_bankptr (10, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
-		 memory_set_bankptr (11, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+		 memory_set_bankptr(10, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
+		 memory_set_bankptr(11, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
 	 }
-	 memory_set_bankptr (1, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
-	 memory_set_bankptr (2, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+	 memory_set_bankptr(1, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
+	 memory_set_bankptr(2, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
 
-	 memory_set_bankptr (3, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
-	 memory_set_bankptr (4, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
-	 memory_set_bankptr (5, c128_ram + 0x4000);
+	 memory_set_bankptr(3, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
+	 memory_set_bankptr(4, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
+	 memory_set_bankptr(5, c128_ram + 0x4000);
 
 	 if (MMU_TOP)
 		 c128_ram_top = 0x10000 - MMU_SIZE;
 	 else
 		 c128_ram_top = 0x10000;
 
-	 if (c128_ram_top > 0xc000) { memory_set_bankptr (6, c128_ram + 0xc000); }
-	 else { memory_set_bankptr (6, c64_memory + 0xc000); }
-	 if (c128_ram_top > 0xe000) { memory_set_bankptr (7, c128_ram + 0xe000); }
-	 else { memory_set_bankptr (7, c64_memory + 0xd000); }
-	 if (c128_ram_top > 0xf000) { memory_set_bankptr (8, c128_ram + 0xf000); }
-	 else { memory_set_bankptr (8, c64_memory + 0xe000); }
-	 if (c128_ram_top > 0xff05) { memory_set_bankptr (9, c128_ram + 0xff05); }
-	 else { memory_set_bankptr (9, c64_memory + 0xff05); }
+	 if (c128_ram_top > 0xc000) { memory_set_bankptr(6, c128_ram + 0xc000); }
+	 else { memory_set_bankptr(6, c64_memory + 0xc000); }
+	 if (c128_ram_top > 0xe000) { memory_set_bankptr(7, c128_ram + 0xe000); }
+	 else { memory_set_bankptr(7, c64_memory + 0xd000); }
+	 if (c128_ram_top > 0xf000) { memory_set_bankptr(8, c128_ram + 0xf000); }
+	 else { memory_set_bankptr(8, c64_memory + 0xe000); }
+	 if (c128_ram_top > 0xff05) { memory_set_bankptr(9, c128_ram + 0xff05); }
+	 else { memory_set_bankptr(9, c64_memory + 0xff05); }
 
 	 if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 		  ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) )
@@ -346,17 +346,17 @@ static void c128_bankswitch_128 (int reset)
 		c128_ram_bottom = 0;
 		c128_ram_top = 0x10000;
 
-		memory_set_bankptr (1, c64_memory);
-		memory_set_bankptr (2, c64_memory + 0x100);
+		memory_set_bankptr(1, c64_memory);
+		memory_set_bankptr(2, c64_memory + 0x100);
 
-		memory_set_bankptr (3, c64_memory + 0x200);
-		memory_set_bankptr (4, c64_memory + 0x400);
-		memory_set_bankptr (5, c64_memory + 0x1000);
-		memory_set_bankptr (6, c64_memory + 0x2000);
+		memory_set_bankptr(3, c64_memory + 0x200);
+		memory_set_bankptr(4, c64_memory + 0x400);
+		memory_set_bankptr(5, c64_memory + 0x1000);
+		memory_set_bankptr(6, c64_memory + 0x2000);
 
-		memory_set_bankptr (7, c64_memory + 0x4000);
+		memory_set_bankptr(7, c64_memory + 0x4000);
 
-		memory_set_bankptr (12, c64_memory + 0xc000);
+		memory_set_bankptr(12, c64_memory + 0xc000);
 
 		c128_bankswitch_64 (reset);
 	}
@@ -364,48 +364,48 @@ static void c128_bankswitch_128 (int reset)
 	{
 		c128_ram = c64_memory + MMU_RAM_ADDR;
 		c128_va1617 = MMU_VIC_ADDR;
-		memory_set_bankptr (1, c64_memory + mmu_page0);
-		memory_set_bankptr (2, c64_memory + mmu_page1);
+		memory_set_bankptr(1, c64_memory + mmu_page0);
+		memory_set_bankptr(2, c64_memory + mmu_page1);
 		if (MMU_BOTTOM)
 			{
 				c128_ram_bottom = MMU_SIZE;
 			}
 		else
 			c128_ram_bottom = 0;
-		memory_set_bankptr (3, (c128_ram_bottom > 0x200 ? c64_memory : c128_ram) + 0x200);
-		memory_set_bankptr (4, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
-		memory_set_bankptr (5, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
-		memory_set_bankptr (6, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
+		memory_set_bankptr(3, (c128_ram_bottom > 0x200 ? c64_memory : c128_ram) + 0x200);
+		memory_set_bankptr(4, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+		memory_set_bankptr(5, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
+		memory_set_bankptr(6, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
 
 		if (MMU_RAM_LO)
-			{
-				memory_set_bankptr (7, c128_ram + 0x4000);
-			}
+		{
+			memory_set_bankptr(7, c128_ram + 0x4000);
+		}
 		else
-			{
-				memory_set_bankptr (7, c128_basic);
-			}
+		{
+			memory_set_bankptr(7, c128_basic);
+		}
 
 		if (MMU_RAM_MID)
-			{
-				memory_set_bankptr (8, c128_ram + 0x8000);
-				memory_set_bankptr (9, c128_ram + 0xa000);
-			}
+		{
+			memory_set_bankptr(8, c128_ram + 0x8000);
+			memory_set_bankptr(9, c128_ram + 0xa000);
+		}
 		else if (MMU_ROM_MID)
-			{
-				memory_set_bankptr (8, c128_basic + 0x4000);
-				memory_set_bankptr (9, c128_basic + 0x6000);
-			}
+		{
+			memory_set_bankptr(8, c128_basic + 0x4000);
+			memory_set_bankptr(9, c128_basic + 0x6000);
+		}
 		else if (MMU_INTERNAL_ROM_MID)
-			{
-				memory_set_bankptr (8, c128_internal_function);
-				memory_set_bankptr (9, c128_internal_function + 0x2000);
-			}
+		{
+			memory_set_bankptr(8, c128_internal_function);
+			memory_set_bankptr(9, c128_internal_function + 0x2000);
+		}
 		else
-			{
-				memory_set_bankptr (8, c128_external_function);
-				memory_set_bankptr (9, c128_external_function + 0x2000);
-			}
+		{
+			memory_set_bankptr(8, c128_external_function);
+			memory_set_bankptr(9, c128_external_function + 0x2000);
+		}
 
 		if (MMU_TOP)
 		{
@@ -432,66 +432,66 @@ static void c128_bankswitch_128 (int reset)
 		{
 			if (c128_ram_top > 0xc000)
 			{
-				memory_set_bankptr (12, c128_ram + 0xc000);
+				memory_set_bankptr(12, c128_ram + 0xc000);
 			}
 			else
 			{
-				memory_set_bankptr (12, c64_memory + 0xc000);
+				memory_set_bankptr(12, c64_memory + 0xc000);
 			}
 			if (!MMU_IO_ON)
 			{
 				if (c128_ram_top > 0xd000)
 				{
-					memory_set_bankptr (13, c128_ram + 0xd000);
+					memory_set_bankptr(13, c128_ram + 0xd000);
 				}
 				else
 				{
-					memory_set_bankptr (13, c64_memory + 0xd000);
+					memory_set_bankptr(13, c64_memory + 0xd000);
 				}
 			}
 			if (c128_ram_top > 0xe000)
 			{
-				memory_set_bankptr (14, c128_ram + 0xe000);
+				memory_set_bankptr(14, c128_ram + 0xe000);
 			}
 			else
 			{
-				memory_set_bankptr (14, c64_memory + 0xe000);
+				memory_set_bankptr(14, c64_memory + 0xe000);
 			}
 			if (c128_ram_top > 0xff05)
 			{
-				memory_set_bankptr (16, c128_ram + 0xff05);
+				memory_set_bankptr(16, c128_ram + 0xff05);
 			}
 			else
 			{
-				memory_set_bankptr (16, c64_memory + 0xff05);
+				memory_set_bankptr(16, c64_memory + 0xff05);
 			}
 		}
 		else if (MMU_ROM_HI)
 		{
-			memory_set_bankptr (12, c128_editor);
+			memory_set_bankptr(12, c128_editor);
 			if (!MMU_IO_ON) {
-				memory_set_bankptr (13, c128_chargen);
+				memory_set_bankptr(13, c128_chargen);
 			}
-			memory_set_bankptr (14, c128_kernal);
-			memory_set_bankptr (16, c128_kernal + 0x1f05);
+			memory_set_bankptr(14, c128_kernal);
+			memory_set_bankptr(16, c128_kernal + 0x1f05);
 		}
 		else if (MMU_INTERNAL_ROM_HI)
 		{
-			memory_set_bankptr (12, c128_internal_function);
+			memory_set_bankptr(12, c128_internal_function);
 			if (!MMU_IO_ON) {
-				memory_set_bankptr (13, c128_internal_function + 0x1000);
+				memory_set_bankptr(13, c128_internal_function + 0x1000);
 			}
-			memory_set_bankptr (14, c128_internal_function + 0x2000);
-			memory_set_bankptr (16, c128_internal_function + 0x3f05);
+			memory_set_bankptr(14, c128_internal_function + 0x2000);
+			memory_set_bankptr(16, c128_internal_function + 0x3f05);
 		}
 		else					   /*if (MMU_EXTERNAL_ROM_HI) */
 		{
-			memory_set_bankptr (12, c128_external_function);
+			memory_set_bankptr(12, c128_external_function);
 			if (!MMU_IO_ON) {
-				memory_set_bankptr (13, c128_external_function + 0x1000);
+				memory_set_bankptr(13, c128_external_function + 0x1000);
 			}
-			memory_set_bankptr (14, c128_external_function + 0x2000);
-			memory_set_bankptr (16, c128_external_function + 0x3f05);
+			memory_set_bankptr(14, c128_external_function + 0x2000);
+			memory_set_bankptr(16, c128_external_function + 0x3f05);
 		}
 		if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 			 ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) ) c128_ram=NULL;
@@ -501,47 +501,60 @@ static void c128_bankswitch_128 (int reset)
 
 static void c128_bankswitch (int reset)
 {
-	if (mmu_cpu != MMU_CPU8502) {
+	if (mmu_cpu != MMU_CPU8502)
+	{
 		if (!MMU_CPU8502)
-			{
-				{
-					DBG_LOG (1, "switching to z80",
-							 ("active %d\n",cpu_getactivecpu()) );
-					memory_set_context(0);
-					c128_bankswitch_z80();
-					memory_set_context(1);
-					cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
-					cpunum_set_input_line(1, INPUT_LINE_HALT, 1);
-				}
-			}
+		{
+			DBG_LOG (1, "switching to z80",
+						("active %d\n",cpu_getactivecpu()) );
+			memory_set_context(0);
+			c128_bankswitch_z80();
+			memory_set_context(1);
+			cpunum_set_input_line(0, INPUT_LINE_HALT, CLEAR_LINE);
+			cpunum_set_input_line(1, INPUT_LINE_HALT, ASSERT_LINE);
+		}
 		else
-			{
-				DBG_LOG (1, "switching to m6502",
-						 ("active %d\n",cpu_getactivecpu()) );
-				memory_set_context(1);
-				c128_bankswitch_128(reset);
-				memory_set_context(0);
-				cpunum_set_input_line(1, INPUT_LINE_HALT, 0);
-				cpunum_set_input_line(0, INPUT_LINE_HALT, 1);
-			}
+		{
+			DBG_LOG (1, "switching to m6502",
+						("active %d\n",cpu_getactivecpu()) );
+			memory_set_context(1);
+			c128_bankswitch_128(reset);
+			memory_set_context(0);
+			cpunum_set_input_line(0, INPUT_LINE_HALT, ASSERT_LINE);
+			cpunum_set_input_line(1, INPUT_LINE_HALT, CLEAR_LINE);
+
+			/* NPW 19-Nov-2005 - In the C128, CPU #0 starts out and hands over
+			 * control to CPU #1.  CPU #1 seems to execute garbage from 0x0000
+			 * up to 0x1100, at which point it finally hits some code
+			 * (presumably set up by CPU #1.) This always worked, but when I
+			 * changed the m8502 CPU core to use an internal memory map, it
+			 * started BRK-ing forever when trying to execute 0x0000.
+			 * 
+			 * I am not sure whether the C128 actually executes this invalid
+			 * memory or if this is a bug in the C128 driver.  In any case, the
+			 * driver used to work with this behavior, so I am doing this hack
+			 * where I set CPU #1's PC to 0x1100 on reset.
+			 */
+			if (cpunum_get_reg(1, REG_PC) == 0x0000)
+				cpunum_set_reg(1, REG_PC, 0x1100);
+		}
 		mmu_cpu = MMU_CPU8502;
 		return;
 	}
-	if (!MMU_CPU8502) {
+	if (!MMU_CPU8502)
 		c128_bankswitch_z80();
-	} else {
+	else
 		c128_bankswitch_128(reset);
-	}
 }
 
 static void c128_mmu8722_reset (void)
 {
-	memset (c128_mmu, 0, sizeof (c128_mmu));
+	memset(c128_mmu, 0, sizeof (c128_mmu));
 	c128_mmu[5] |= 0x38;
 	c128_mmu[10] = 1;
-	mmu_cpu=0;
-    mmu_page0=0;
-    mmu_page1=0x0100;
+	mmu_cpu = 0;
+    mmu_page0 = 0;
+    mmu_page1 = 0x0100;
 	c128_bankswitch (1);
 }
 
@@ -753,6 +766,8 @@ static void c128_common_driver_init (void)
 	cpunum_set_info_fct(1, CPUINFO_PTR_M6510_PORTREAD, (genf *) c64_m6510_port_read);
 	cpunum_set_info_fct(1, CPUINFO_PTR_M6510_PORTWRITE, (genf *) c64_m6510_port_write);
 
+	c64_memory = memory_region(REGION_CPU1);
+
 	c128_basic = memory_region(REGION_CPU1)+0x100000;
 	c64_basic = memory_region(REGION_CPU1)+0x108000;
 	c64_kernal = memory_region(REGION_CPU1)+0x10a000;
@@ -769,7 +784,6 @@ static void c128_common_driver_init (void)
 	for (i=0; i<0x100; i++)
 		gfx[i]=i;
 
-	c128 = 1;
 	vc20_tape_open (c64_tape_read);
 
 	cia6526_init();
@@ -803,7 +817,6 @@ DRIVER_INIT( c128pal )
 
 MACHINE_INIT( c128 )
 {
-	logerror("reset\n");
 	c64_common_init_machine ();
 	c128_vicaddr = c64_vicaddr = c64_memory;
 
@@ -814,8 +827,8 @@ MACHINE_INIT( c128 )
 
 	c64mode = 0;
 	c128_mmu8722_reset ();
-	cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
-	cpunum_set_input_line(1, INPUT_LINE_HALT, 1);
+	cpunum_set_input_line(0, INPUT_LINE_HALT, CLEAR_LINE);
+	cpunum_set_input_line(1, INPUT_LINE_HALT, ASSERT_LINE);
 }
 
 VIDEO_START( c128 )
