@@ -1,11 +1,18 @@
+/***************************************************************************
+
+	cococart.c
+
+	Code for emulating CoCo cartridges, like the disk drive cartridge
+
+***************************************************************************/
+  
 #include "includes/cococart.h"
 #include "includes/wd179x.h"
-#include "includes/basicdsk.h"
-#include "formats/dmkdsk.h"
-#include "formats/cocovdk.h"
+#include "devices/coco_vhd.h"
 #include "ds1315.h"
 #include "m6242b.h"
 #include "includes/dragon.h"
+#include "sound/dac.h"
 
 static const struct cartridge_callback *cartcallbacks;
 
@@ -51,12 +58,11 @@ static const struct cartridge_callback *cartcallbacks;
 #define LOG(x)
 #endif
 
-static int dskreg;
-static int diskKind[4];
-static void coco_fdc_callback(int event);
-static void dragon_fdc_callback(int event);
-static int drq_state;
-static int intrq_state;
+static int	dskreg;
+static void	coco_fdc_callback(int event);
+static void	dragon_fdc_callback(int event);
+static int	drq_state;
+static int	intrq_state;
 
 #define       COCO_HALTENABLE   (dskreg & 0x80)
 #define   SET_COCO_HALTENABLE    dskreg &= 0x80
@@ -76,7 +82,7 @@ static void coco_fdc_init(const struct cartridge_callback *callbacks)
     wd179x_init(WD_TYPE_179X,coco_fdc_callback);
 	dskreg = 0;
 	cartcallbacks = callbacks;
-	drq_state = CLEAR_LINE;
+	drq_state = ASSERT_LINE;
 	intrq_state = CLEAR_LINE;
 }
 
@@ -92,14 +98,14 @@ static void raise_nmi(int dummy)
 {
 	LOG(("cococart: Raising NMI (and clearing halt), source: wd179x INTRQ\n" ));
 
-	cpu_set_nmi_line(0, ASSERT_LINE);
+	cpunum_set_input_line(0, INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 static void raise_halt(int dummy)
 {
 	LOG(("cococart: Raising HALT\n" ));
 
-	cpu_set_halt_line(0, ASSERT_LINE);
+	coco_set_halt_line(ASSERT_LINE);
 }
 
 static void coco_fdc_callback(int event)
@@ -107,28 +113,29 @@ static void coco_fdc_callback(int event)
 	switch(event) {
 	case WD179X_IRQ_CLR:
 		intrq_state = CLEAR_LINE;
-		cpu_set_nmi_line(0, CLEAR_LINE);
+		cpunum_set_input_line(0, INPUT_LINE_NMI, CLEAR_LINE);
 		break;
+
 	case WD179X_IRQ_SET:
 		intrq_state = ASSERT_LINE;
 		CLEAR_COCO_HALTENABLE;
-		cpu_set_halt_line(0, CLEAR_LINE);
+		coco_set_halt_line(CLEAR_LINE);
 		if( COCO_NMIENABLE )
 			timer_set( TIME_IN_USEC(0), 0, raise_nmi);
 		else
-			cpu_set_nmi_line(0, CLEAR_LINE);
+			cpunum_set_input_line(0, INPUT_LINE_NMI, CLEAR_LINE);
 		break;
+
 	case WD179X_DRQ_CLR:
 		drq_state = CLEAR_LINE;
 		if( COCO_HALTENABLE )
 			timer_set( TIME_IN_CYCLES(7,0), 0, raise_halt);
-/*			cpu_set_halt_line(0, ASSERT_LINE);*/
 		else
-			cpu_set_halt_line(0, CLEAR_LINE);
+			coco_set_halt_line(CLEAR_LINE);
 		break;
 	case WD179X_DRQ_SET:
 		drq_state = ASSERT_LINE;
-		cpu_set_halt_line(0, CLEAR_LINE);
+		coco_set_halt_line(CLEAR_LINE);
 		break;
 	}
 }
@@ -138,7 +145,7 @@ static void dragon_fdc_callback(int event)
 	switch(event) {
 	case WD179X_IRQ_CLR:
 		LOG(("dragon_fdc_callback(): WD179X_IRQ_CLR\n" ));
-		cpu_set_nmi_line(0, CLEAR_LINE);
+		cpunum_set_input_line(0, INPUT_LINE_NMI, CLEAR_LINE);
 		break;
 	case WD179X_IRQ_SET:
 		LOG(("dragon_fdc_callback(): WD179X_IRQ_SET\n" ));
@@ -156,108 +163,13 @@ static void dragon_fdc_callback(int event)
 	}
 }
 
-void dragon_floppy_exit( int id)
-{
-	switch( diskKind[ id ] )
-	{
-		case DSK_DMK:
-			dmkdsk_floppy_exit( id );
-			break;
-		case DSK_BASIC:
-			basicdsk_floppy_exit( id );
-			break;
-		default:
-			break;
-	}
-}
-
-int dragon_floppy_init(int id)
-{
-	if (dmkdsk_floppy_init(id)==INIT_PASS)
-	{
-		diskKind[ id ] = DSK_DMK;
-		return INIT_PASS;
-	}
-	
-	if(cocovdk_floppy_init(id)==INIT_PASS)
-	{
-		diskKind[ id ] = DSK_BASIC;
-		return INIT_PASS;
-	}
-
-	if (basicdsk_floppy_init(id)==INIT_PASS)
-	{
-		void *file;
-
-		diskKind[ id ] = DSK_BASIC;
-		file = image_fopen(IO_FLOPPY, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-		if (file) {
-			int 	filesize = osd_fsize(file),
-					headerSize = filesize % 256,
-					sectorPerTrack = 18,
-					sectorSizeCode = 1,
-					firstSectorID = 1,
-					sideCount = 1,
-					attributeFlag,
-					tracks;
-			UINT8	*buffer = malloc( headerSize+1 );
-			
-			if( buffer == NULL )
-				return INIT_FAIL;
-				
-			osd_fread(file, buffer, headerSize);
-
-			if( headerSize > 0 )
-				sectorPerTrack = buffer[0];
-
-			if( headerSize > 1 )
-				sideCount = buffer[1];
-
-			if( headerSize > 2 )
-				sectorSizeCode = buffer[2];
-
-			if( headerSize > 3 )
-				firstSectorID = buffer[3];
-
-			if( headerSize > 4 )
-			{
-				attributeFlag = buffer[4];
-				
-				if( attributeFlag != 0 )
-				{
-					osd_fclose(file);
-					free( buffer );
-					logerror("JVC: Attribute bytes not supported.\n");
-					return INIT_FAIL;
-				}
-			}
-
-			tracks = (filesize - headerSize) / (sectorPerTrack * (128 << sectorSizeCode)) / sideCount;
-
-			if( (filesize - headerSize) != (tracks * sectorPerTrack * (128 << sectorSizeCode) * sideCount) )
-			{
-				osd_fclose(file);
-				free( buffer );
-				logerror("JVC: Not a JVC disk.\n");
-				return INIT_FAIL;
-			}
-
-			basicdsk_set_geometry(id, tracks, sideCount, sectorPerTrack, (128 << sectorSizeCode), firstSectorID, headerSize);
-			
-			free( buffer );
-			osd_fclose(file);
-		}
-	}
-	return INIT_PASS;
-}
-
 static void set_coco_dskreg(int data)
 {
 	UINT8 drive = 0;
 	UINT8 head = 0;
 	int motor_mask = 0;
 
-	LOG(("set_coco_dskreg(): %c%c%c%c%c%c%c%c ($%02x)\n",  
+	LOG(("set_coco_dskreg(): %c%c%c%c%c%c%c%c ($%02x)\n",
 									data & 0x80 ? 'H' : 'h',
 									data & 0x40 ? '3' : '.',
 									data & 0x20 ? 'D' : 'S',
@@ -274,7 +186,7 @@ static void set_coco_dskreg(int data)
 		 * selected in other situations, then both drives are selected, and any
 		 * read signals get yucky.
 		 */
-	 
+
 		motor_mask = 0x08;
 
 		if (data & 0x04)
@@ -294,18 +206,17 @@ static void set_coco_dskreg(int data)
 
 	if( COCO_HALTENABLE && (drq_state == CLEAR_LINE) )
 		timer_set( TIME_IN_CYCLES(7,0), 0, raise_halt);
-/*		cpu_set_halt_line(0, ASSERT_LINE);*/
 	else
-		cpu_set_halt_line(0, CLEAR_LINE);
-	
+		coco_set_halt_line(CLEAR_LINE);
+
 	if( COCO_NMIENABLE  && (intrq_state == ASSERT_LINE) )
 	{
 		CLEAR_COCO_HALTENABLE;
-		cpu_set_halt_line(0, CLEAR_LINE);
+		coco_set_halt_line(CLEAR_LINE);
 		timer_set( TIME_IN_USEC(0), 0, raise_nmi);
 	}
 	else
-		cpu_set_nmi_line(0, CLEAR_LINE);
+		cpunum_set_input_line(0, INPUT_LINE_NMI, CLEAR_LINE);
 
 	wd179x_set_drive(drive);
 	wd179x_set_side(head);
@@ -314,7 +225,7 @@ static void set_coco_dskreg(int data)
 
 static void set_dragon_dskreg(int data)
 {
-	LOG(("set_dragon_dskreg(): %c%c%c%c%c%c%c%c ($%02x)\n",  
+	LOG(("set_dragon_dskreg(): %c%c%c%c%c%c%c%c ($%02x)\n",
 								data & 0x80 ? 'X' : 'x',
 								data & 0x40 ? 'X' : 'x',
 								data & 0x20 ? 'N' : 'n',
@@ -325,18 +236,16 @@ static void set_dragon_dskreg(int data)
 								data & 0x01 ? '1' : '0',
 								data ));
 
-	if (data & 0x04) {
+	if (data & 0x04)
 		wd179x_set_drive( data & 0x03 );
-		wd179x_set_side( 0 );
-	}
+
 	wd179x_set_density( (data & 0x08) ? DEN_FM_LO: DEN_MFM_LO );
 	dskreg = data;
 }
 
 /* ---------------------------------------------------- */
 
-READ_HANDLER(coco_floppy_r);
-READ_HANDLER(coco_floppy_r)
+ READ8_HANDLER(coco_floppy_r)
 {
 	int result = 0;
 
@@ -353,6 +262,9 @@ READ_HANDLER(coco_floppy_r)
 	case 11:
 		result = wd179x_data_r(0);
 		break;
+	default:
+		result = coco_vhd_io_r( offset );
+		break;
 	}
 
 	if( (readinputport(13) & 0x03) == 0 )
@@ -360,10 +272,7 @@ READ_HANDLER(coco_floppy_r)
 		/* This is the real time clock in Disto's many products */
 
 		if( offset == ( 0xff50-0xff40 ) )
-			result = m6242_data_r(0);
-			
-		if( offset == ( 0xff51-0xff40 ) )
-			result = m6242_address_r(0);
+			result = m6242_data_r( 0 );
 	}
 	else
 	{
@@ -371,21 +280,20 @@ READ_HANDLER(coco_floppy_r)
 
 		if( offset == ( 0xff79-0xff40 ) )
 			ds1315_r_1( offset );
-			
+
 		if( offset == ( 0xff78-0xff40 ) )
 			ds1315_r_0( offset );
-			
+
 		if( offset == ( 0xff7c-0xff40 ) )
 			result = ds1315_r_data( offset );
 	}
 
 /*	logerror("SCS read:  address %4.4X, data %2.2X\n", 0xff40+offset, result );*/
-	
+
 	return result;
 }
 
-WRITE_HANDLER(coco_floppy_w);
-WRITE_HANDLER(coco_floppy_w)
+WRITE8_HANDLER(coco_floppy_w)
 {
 	switch(offset & 0xef) {
 	case 0:
@@ -418,16 +326,17 @@ WRITE_HANDLER(coco_floppy_w)
 
 		if( offset == ( 0xff50-0xff40 ) )
 			m6242_data_w( 0, data );
-			
+
 		if( offset == ( 0xff51-0xff40 ) )
 			m6242_address_w( 0, data );
 	}
-	
+
+	coco_vhd_io_w( offset, data );
+
 /*	logerror("SCS write: address %4.4X, data %2.2X\n", 0xff40+offset, data );*/
 }
 
-READ_HANDLER(dragon_floppy_r);
-READ_HANDLER(dragon_floppy_r)
+ READ8_HANDLER(dragon_floppy_r)
 {
 	int result = 0;
 
@@ -444,16 +353,20 @@ READ_HANDLER(dragon_floppy_r)
 	case 3:
 		result = wd179x_data_r(0);
 		break;
+	default:
+		break;
 	}
 	return result;
 }
 
-WRITE_HANDLER(dragon_floppy_w);
-WRITE_HANDLER(dragon_floppy_w)
+WRITE8_HANDLER(dragon_floppy_w)
 {
 	switch(offset & 0xef) {
 	case 0:
 		wd179x_command_w(0, data);
+
+		/* disk head is encoded in the command byte */
+		wd179x_set_side((data & 0x02) ? 1 : 0);
 		break;
 	case 1:
 		wd179x_track_w(0, data);
@@ -482,7 +395,7 @@ WRITE_HANDLER(dragon_floppy_w)
 const struct cartridge_slot cartridge_fdc_coco =
 {
 	coco_fdc_init,
-	wd179x_exit,
+	NULL,
 	coco_floppy_r,
 	coco_floppy_w,
 	NULL
@@ -491,7 +404,7 @@ const struct cartridge_slot cartridge_fdc_coco =
 const struct cartridge_slot cartridge_fdc_dragon =
 {
 	dragon_fdc_init,
-	wd179x_exit,
+	NULL,
 	dragon_floppy_r,
 	dragon_floppy_w,
 	NULL
@@ -505,29 +418,57 @@ static void cartidge_standard_init(const struct cartridge_callback *callbacks)
 	cartcallbacks->setcartline(CARTLINE_Q);
 }
 
-static WRITE_HANDLER(cartridge_banks_io_w)
+static WRITE8_HANDLER(cartridge_banks_io_w)
 {
 /* TJL- trying to turn this into a generic banking call */
 	if (offset == 0 )
+	{
 		cartcallbacks->setbank(data);
+		LOG( ("Bankswitch: set bank: %d\n", data ) );
+	}
+	else
+		LOG( ("Bankswitch: Writing to unmapped SCS memory: $%4.4X (PC=$%4.4X)\n", 0xff40+offset, activecpu_get_pc() ) );
 }
 
-static WRITE_HANDLER(cartridge_Orch90_io_w)
+static  READ8_HANDLER(cartridge_banks_io_r)
+{
+/* TJL- trying to turn this into a generic banking call */
+	if (offset == 0 )
+		LOG( ("Bankswitch: reading bank (not implemented\n" ) );
+	else
+		LOG( ("Bankswitch: Reading from unmapped SCS memory: $%4.4X (PC=$%4.4X)\n", 0xff40+offset, activecpu_get_pc() ) );
+		
+	return 0;
+}
+
+static WRITE8_HANDLER(cartridge_std_io_w)
+{
+	LOG( ("Standard Cart: Writing to unmapped SCS memory: $%4.4X (PC=$%4.4X)\n", 0xff40+offset, activecpu_get_pc() ) );
+}
+
+static  READ8_HANDLER(cartridge_std_io_r)
+{
+	LOG( ("Standard Cart: Reading from unmapped SCS memory: $%4.4X (PC=$%4.4X)\n", 0xff40+offset, activecpu_get_pc() ) );
+
+	return 0xff;
+}
+
+static WRITE8_HANDLER(cartridge_Orch90_io_w)
 {
 	if( offset == 58 )
 		DAC_data_w(0, data);
-	
+
 	if( offset == 59 )
 		DAC_data_w(0, data);
-		
+
 }
 
 const struct cartridge_slot cartridge_standard =
 {
 	cartidge_standard_init,
 	NULL,
-	NULL,
-	NULL,
+	cartridge_std_io_r,
+	cartridge_std_io_w,
 	NULL
 };
 
@@ -535,7 +476,7 @@ const struct cartridge_slot cartridge_banks =
 {
 	cartidge_standard_init,
 	NULL,
-	NULL,
+	cartridge_banks_io_r,
 	cartridge_banks_io_w,
 	NULL
 };
