@@ -14,6 +14,7 @@
 #include "cpu/z80/z80.h"
 #include "includes/wd179x.h"
 #include "cpm_bios.h"
+#include "image.h"
 
 #define VERBOSE 		1
 #define VERBOSE_FDD 	1
@@ -37,11 +38,11 @@ static int fmt[NDSK] = {0,};		/* index of disk formats */
 static int mode[NDSK] = {0,};		/* 0 read only, !0 read/write */
 static int bdos_trk[NDSK] = {0,};	/* BDOS track number */
 static int bdos_sec[NDSK] = {0,};	/* BDOS sector number */
-static void *fp[NDSK] = {NULL, };	/* image file pointer */
+static mame_file *fp[NDSK] = {NULL, };	/* image file pointer */
 static int ff[NDSK] = {0, };            /* image filenames specified flags */
-static void *lp = NULL; 			/* list file handle (ie. PIP LST:=X:FILE.EXT) */
-/*static void *pp = NULL;			   punch file handle (ie. PIP PUN:=X:FILE.EXT)    */
-/*static void *rp = NULL;			   reader file handle (ie. PIP X:FILE.EXE=RDR:)    */
+static mame_file *lp = NULL; 			/* list file handle (ie. PIP LST:=X:FILE.EXT) */
+/*static mame_file *pp = NULL;			   punch file handle (ie. PIP PUN:=X:FILE.EXT)    */
+/*static mame_file *rp = NULL;			   reader file handle (ie. PIP X:FILE.EXE=RDR:)    */
 static int dma = 0; 				/* DMA transfer address */
 
 static UINT8 zeropage0[8] =
@@ -76,7 +77,7 @@ cpm_dph dph[NDSK] = {
  *****************************************************************************/
 static void cpm_jumptable(void)
 {
-	UINT8 * RAM = memory_region(REGION_CPU1);
+	UINT8 * RAM = memory_get_write_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000);
 	int i;
 	int jmp_addr, fun_addr;
 
@@ -108,19 +109,28 @@ static void cpm_jumptable(void)
 	RAM[BIOS_EXEC + 2] = 0xc9;			/* RET */
 }
 
-int cpm_floppy_init(int id)
+DEVICE_LOAD( cpm_floppy )
 {
-	ff[id] = device_filename(IO_FLOPPY,id) != NULL;
-	return 0;
+	int id = image_index_in_device(image);
+
+	ff[id] = TRUE;
+
+	/* now try to open the image if a filename is given */
+	fp[id] = file;
+	mode[id] = image_is_writable(image);
+
+	return INIT_PASS;
 }
 
+/*TODO: implement DEVICE_UNLOAD that clears ff[id]*/
+
 /*****************************************************************************
  *	cpm_init
  *	Initialize the BIOS simulation for 'n' drives of types stored in 'ids'
  *****************************************************************************/
 int cpm_init(int n, const char *ids[])
 {
-	UINT8 * RAM = memory_region(REGION_CPU1);
+	UINT8 * RAM = memory_get_write_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000);
 	dsk_fmt *f;
 	int i, d;
 
@@ -137,11 +147,13 @@ int cpm_init(int n, const char *ids[])
 	for (i = 0; i < 8; i++)
 		RAM[i] = zeropage0[i];
 
-#if VERBOSE
-	logerror("CPM CCP     %04X\n", CCP);
-	logerror("CPM BDOS    %04X\n", BDOS);
-	logerror("CPM BIOS    %04X\n", BIOS);
-#endif
+	if (VERBOSE)
+	{
+		logerror("CPM CCP     %04X\n", CCP);
+		logerror("CPM BDOS    %04X\n", BDOS);
+		logerror("CPM BIOS    %04X\n", BIOS);
+	}
+
 	/* Start allocating CSV & ALV */
 	i = DATA_START;
 
@@ -154,9 +166,8 @@ int cpm_init(int n, const char *ids[])
 			/* select a format by name */
 			if( cpm_disk_select_format(d, ids[d]) )
 			{
-#if VERBOSE
-				logerror("Error drive #%d id '%s' is unknown\n", d, ids[d]);
-#endif
+				if (VERBOSE)
+					logerror("Error drive #%d id '%s' is unknown\n", d, ids[d]);
 				return 1;
 			}
 
@@ -178,46 +189,41 @@ int cpm_init(int n, const char *ids[])
 			RAM[DPB0 + d * DPBL + 12] = f->dpb.cks >> 8;
 			RAM[DPB0 + d * DPBL + 13] = f->dpb.off & 0xff;
 			RAM[DPB0 + d * DPBL + 14] = f->dpb.off >> 8;
-#if VERBOSE
-			logerror("CPM DPB%d    %04X\n", d, DPB0 + d * DPBL);
-#endif
+
+			if (VERBOSE)
+				logerror("CPM DPB%d    %04X\n", d, DPB0 + d * DPBL);
 
 			/* TODO: generate sector translation table and
 			   allocate space for it; for now it is always 0 */
 			dph[d].xlat = 0;
-#if VERBOSE
-			logerror("CPM XLAT%d   %04X\n", d, dph[d].xlat);
-#endif
+			if (VERBOSE)
+				logerror("CPM XLAT%d   %04X\n", d, dph[d].xlat);
 
 			/* memory address for dirbuf */
 			dph[d].dirbuf = DIRBUF + d * RECL;
-#if VERBOSE
-			logerror("CPM DIRBUF%d %04X\n", d, dph[d].dirbuf);
-#endif
+			if (VERBOSE)
+				logerror("CPM DIRBUF%d %04X\n", d, dph[d].dirbuf);
 
 			/* memory address for CSV */
 			dph[d].csv = i;
-#if VERBOSE
-			logerror("CPM CSV%d    %04X\n", d, dph[d].csv);
-#endif
+			if (VERBOSE)
+				logerror("CPM CSV%d    %04X\n", d, dph[d].csv);
 
 			/* length is CKS bytes */
 			i += f->dpb.cks;
 
 			/* memory address for ALV */
 			dph[d].alv = i;
-#if VERBOSE
-			logerror("CPM ALV%d    %04X\n", d, dph[d].alv);
-#endif
+			if (VERBOSE)
+				logerror("CPM ALV%d    %04X\n", d, dph[d].alv);
 
 			/* length is DSM+1 bits */
 			i += (f->dpb.dsm + 1 + 7) >> 3;
 
 			if (i >= BIOS_00)
 			{
-#if VERBOSE
-				logerror("Error configuring BIOS tables: out of memory!\n");
-#endif
+				if (VERBOSE)
+					logerror("Error configuring BIOS tables: out of memory!\n");
 				return 1;
 			}
 		}
@@ -245,33 +251,10 @@ int cpm_init(int n, const char *ids[])
 		RAM[DPH0 + d * DPHL + 13] = dph[d].csv >> 8;
 		RAM[DPH0 + d * DPHL + 14] = dph[d].alv & 0xff;
 		RAM[DPH0 + d * DPHL + 15] = dph[d].alv >> 8;
-
-		/* now try to open the image if a filename is given */
-		if( ff[d] && strlen(device_filename(IO_FLOPPY,d)) )
-		{
-			{
-				mode[d] = 1;
-				fp[d] = image_fopen(IO_FLOPPY, d, OSD_FILETYPE_IMAGE, OSD_FOPEN_RW);
-				if( !fp[d] )
-				{
-					mode[d] = 0;
-					fp[d] = image_fopen(IO_FLOPPY, d, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-				}
-				if( !fp[d] )
-				{
-					mode[d] = 1;
-					fp[d] = image_fopen(IO_FLOPPY, d, OSD_FILETYPE_IMAGE, OSD_FOPEN_WRITE);
-				}
-				if( !fp[d] )
-				{
-					ff[d] = 0;
-				}
-			}
-		}
 	}
 
 	/* create a file to receive list output (ie. PIP LST:=FILE.EXT) */
-	lp = osd_fopen(Machine->gamedrv->name, "cpm.lst", OSD_FILETYPE_IMAGE, 1);
+	lp = mame_fopen(Machine->gamedrv->name, "cpm.lst", FILETYPE_IMAGE, 1);
 
 	cpm_jumptable();
 
@@ -289,7 +272,7 @@ void cpm_exit(void)
 	/* if a list file is still open close it now */
 	if (lp)
 	{
-		osd_fclose(lp);
+		mame_fclose(lp);
 		lp = NULL;
 	}
 
@@ -309,14 +292,14 @@ void cpm_exit(void)
  *****************************************************************************/
 static void cpm_conout_chr(int data)
 {
-	cpu_writeport16(BIOS_CONOUT, data);
+	io_write_byte_8(BIOS_CONOUT, data);
 }
 
 /*****************************************************************************
  * cpm_conout_str
  * send a zero terminated string to the console
  *****************************************************************************/
-static void cpm_conout_str(char *src)
+static void cpm_conout_str(const char *src)
 {
 	while (*src)
 		cpm_conout_chr(*src++);
@@ -333,35 +316,32 @@ int cpm_disk_select_format(int d, const char *id)
 	if (!id)
 		return 1;
 
-#if VERBOSE
-	logerror("CPM search format '%s'\n", id);
-#endif
+	if (VERBOSE)
+		logerror("CPM search format '%s'\n", id);
 
-	for (i = 0; formats[i].id && stricmp(formats[i].id, id); i++)
+	for (i = 0; formats[i].id && mame_stricmp(formats[i].id, id); i++)
 		;
 
 	if (!formats[i].id)
 	{
-#if VERBOSE
-		logerror("CPM format '%s' not supported\n", id);
-#endif
+		if (VERBOSE)
+			logerror("CPM format '%s' not supported\n", id);
 		return 1;
 	}
 
 	/* references another type id? */
 	if (formats[i].ref)
 	{
-#if VERBOSE
-		logerror("CPM search format '%s' for '%s'\n", formats[i].ref, id);
-#endif
-	/* search for the referred id */
-		for (j = 0; formats[j].id && stricmp(formats[j].id, formats[i].ref); j++)
+		if (VERBOSE)
+			logerror("CPM search format '%s' for '%s'\n", formats[i].ref, id);
+
+		/* search for the referred id */
+		for (j = 0; formats[j].id && mame_stricmp(formats[j].id, formats[i].ref); j++)
 			;
 		if (!formats[j].id)
 		{
-#if VERBOSE
-			logerror("CPM format '%s' not supported\n", formats[i].ref);
-#endif
+			if (VERBOSE)
+				logerror("CPM format '%s' not supported\n", formats[i].ref);
 			return 1;
 		}
 		/* set current format */
@@ -372,8 +352,8 @@ int cpm_disk_select_format(int d, const char *id)
 		/* set current format */
 		fmt[d] = i;
 	}
-#if VERBOSE
 
+	if (VERBOSE)
 	{
 		dsk_fmt *f = &formats[fmt[d]];
 
@@ -383,7 +363,6 @@ int cpm_disk_select_format(int d, const char *id)
 			f->cylinders * f->sides * f->spt * f->seclen / 1024,
 			f->cylinders, f->sides, f->spt, f->seclen);
 	}
-#endif
 
 	return 0;
 }
@@ -416,9 +395,9 @@ static void cpm_disk_image_seek(void)
 		offs += (h * f->spt + s) * f->seclen + r * RECL;
 		if (bdos_trk[curdisk] >= f->cylinders)
 			offs += (int)f->cylinders * f->sides * f->spt * f->seclen / 2;
-#if VERBOSE_FDD
-		logerror("CPM image #%d ord_cylinders C:%2d H:%d S:%2d REC:%d -> 0x%08X\n", curdisk, bdos_trk[curdisk], h, s, r, offs * RECL);
-#endif
+
+		if (VERBOSE_FDD)
+			logerror("CPM image #%d ord_cylinders C:%2d H:%d S:%2d REC:%d -> 0x%08X\n", curdisk, bdos_trk[curdisk], h, s, r, offs * RECL);
 		break;
 
 	/* TRACK  0   1   2 	   n/2-1 n/2  n/2+1  n/2+3	   n-1		*/
@@ -435,9 +414,9 @@ static void cpm_disk_image_seek(void)
 		s = (s >= f->spt) ? f->side2[s+1] : f->side1[s+1];
 		s -= f->side1[1];		/* subtract first sector number */
 		offs += (h * f->spt + s) * f->seclen + r * RECL;
-#if VERBOSE_FDD
-		logerror("CPM image #%d ord_eagle     C:%2d H:%d S:%2d REC:%d -> 0x%08X\n", curdisk, bdos_trk[curdisk], h, s, r, offs);
-#endif
+
+		if (VERBOSE_FDD)
+			logerror("CPM image #%d ord_eagle     C:%2d H:%d S:%2d REC:%d -> 0x%08X\n", curdisk, bdos_trk[curdisk], h, s, r, offs);
 		break;
 
 	/* TRACK	 0		1	  2 		  n-1 */
@@ -453,13 +432,13 @@ static void cpm_disk_image_seek(void)
 		s = (s >= f->spt) ? f->side2[s+1] : f->side1[s+1];
 		s -= f->side1[1];		/* subtract first sector number */
 		offs += (h * f->spt + s) * f->seclen + r * RECL;
-#if VERBOSE_FDD
-		logerror("CPM image #%d ord_sides     C:%2d H:%d S:%2d REC:%d -> 0x%08X\n", curdisk, bdos_trk[curdisk], h, s, r, offs);
-#endif
+
+		if (VERBOSE_FDD)
+			logerror("CPM image #%d ord_sides     C:%2d H:%d S:%2d REC:%d -> 0x%08X\n", curdisk, bdos_trk[curdisk], h, s, r, offs);
 		break;
 
 	}
-	osd_fseek(fp[curdisk], offs, SEEK_SET);
+	mame_fseek(fp[curdisk], offs, SEEK_SET);
 }
 
 
@@ -520,7 +499,7 @@ void cpm_disk_set_dma(int d)
 
 static void dump_sector(void)
 {
-	UINT8 *DMA = memory_region(REGION_CPU1) + dma;
+	UINT8 *DMA = ((UINT8 *) memory_get_write_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000)) + dma;
 
 	{
 		int i;
@@ -545,7 +524,7 @@ int cpm_disk_read_sector(void)
 	int result = -1;
 
 	/* TODO: remove this */
-	unsigned char *RAM = memory_region(REGION_CPU1);
+	unsigned char *RAM = memory_get_write_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000);
 
 	if (curdisk >= 0 &&
 		curdisk < num_disks &&
@@ -557,7 +536,7 @@ int cpm_disk_read_sector(void)
 			if (fp[curdisk])
 			{
 				cpm_disk_image_seek();
-				if (osd_fread(fp[curdisk], &RAM[dma], RECL) == RECL)
+				if (mame_fread(fp[curdisk], &RAM[dma], RECL) == RECL)
 					result = 0;
 			}
 		}
@@ -575,7 +554,7 @@ int cpm_disk_write_sector(void)
 	int result = -1;
 
 	/* TODO: remove this */
-	unsigned char *RAM = memory_region(REGION_CPU1);
+	unsigned char *RAM = memory_get_write_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000);
 
 	if (curdisk >= 0 &&
 		curdisk < num_disks &&
@@ -587,7 +566,7 @@ int cpm_disk_write_sector(void)
 			if (fp[curdisk])
 			{
 				cpm_disk_image_seek();
-				if (osd_fwrite(fp[curdisk], &RAM[dma], RECL) == RECL)
+				if (mame_fwrite(fp[curdisk], &RAM[dma], RECL) == RECL)
 					result = 0;
 			}
 		}
@@ -597,31 +576,30 @@ int cpm_disk_write_sector(void)
 	return result;
 }
 
-READ_HANDLER (	cpm_bios_command_r )
+ READ8_HANDLER (	cpm_bios_command_r )
 {
 	return 0xff;
 }
 
-WRITE_HANDLER ( cpm_bios_command_w )
+WRITE8_HANDLER ( cpm_bios_command_w )
 {
 	dsk_fmt *f;
 	char buff[256];
-	UINT8 * RAM = memory_region(REGION_CPU1);
+	UINT8 * RAM = memory_get_write_ptr(0, ADDRESS_SPACE_PROGRAM, 0x0000);
 	UINT16 tmp, af, bc, de, hl;
 	int i;
 
 	/* Get the values of the basic Z80 registers */
-	af = cpu_get_reg( Z80_AF );
-	bc = cpu_get_reg( Z80_BC );
-	de = cpu_get_reg( Z80_DE );
-	hl = cpu_get_reg( Z80_HL );
+	af = activecpu_get_reg( Z80_AF );
+	bc = activecpu_get_reg( Z80_BC );
+	de = activecpu_get_reg( Z80_DE );
+	hl = activecpu_get_reg( Z80_HL );
 
 	switch( data )
 	{
 	case 0x00: /* CBOOT */
-#if VERBOSE
-		logerror("BIOS 00 cold boot\n");
-#endif
+		if (VERBOSE)
+			logerror("BIOS 00 cold boot\n");
 
 		cpm_conout_str("MESS CP/M 2.2 Emulator\r\n\n");
 		for (i = 0; i < NDSK; i++)
@@ -648,9 +626,9 @@ WRITE_HANDLER ( cpm_bios_command_w )
 		/* fall through */
 
 	case 0x01: /* WBOOT */
-#if VERBOSE
-		logerror("BIOS 01 warm boot\n");
-#endif
+		if (VERBOSE)
+			logerror("BIOS 01 warm boot\n");
+
 		zeropage0[4] = curdisk;
 		/* copy substantial zero page data */
 		for (i = 0; i < 8; i++)
@@ -663,56 +641,53 @@ WRITE_HANDLER ( cpm_bios_command_w )
 		/* build the bios jump table */
 		cpm_jumptable();
 		bc = curdisk;
-		cpu_set_reg( Z80_BC, bc );
-		cpu_set_reg( Z80_SP, 0x0080  );
-		cpu_set_reg( Z80_PC, CCP + 3 );
+		activecpu_set_reg( Z80_BC, bc );
+		activecpu_set_reg( Z80_SP, 0x0080  );
+		activecpu_set_reg( Z80_PC, CCP + 3 );
 		break;
 
 	case 0x02: /* CSTAT */
-		tmp = cpu_readport16(BIOS_CONST) & 0xff;
+		tmp = io_read_byte_8(BIOS_CONST) & 0xff;
 		af = (af & 0xff) | (tmp << 8);
-#if VERBOSE_CONIO
-		logerror("BIOS 02 console status      A:%02X\n", tmp);
-#endif
+
+		if (VERBOSE_CONIO)
+			logerror("BIOS 02 console status      A:%02X\n", tmp);
 		break;
 
 	case 0x03: /* CONIN */
-		if ( cpu_readport16(BIOS_CONST) == 0 )
+		if ( io_read_byte_8(BIOS_CONST) == 0 )
 		{
-			cpu_set_reg( Z80_PC, cpu_get_reg(Z80_PC) - 2 );
+			activecpu_set_reg( Z80_PC, activecpu_get_reg(Z80_PC) - 2 );
 			break;
 		}
-		tmp = cpu_readport16(BIOS_CONIN) & 0xff;
+		tmp = io_read_byte_8(BIOS_CONIN) & 0xff;
 		af = (af & 0xff) | (tmp << 8);
-#if VERBOSE_CONIO
-		logerror("BIOS 03 console input       A:%02X\n", tmp);
-#endif
+		if (VERBOSE_CONIO)
+			logerror("BIOS 03 console input       A:%02X\n", tmp);
 		break;
 
 	case 0x04: /* CONOUT */
 		tmp = bc & 0xff;
-#if VERBOSE_CONIO
-		logerror("BIOS 04 console output      C:%02X\n", tmp);
-#endif
+		if (VERBOSE_CONIO)
+			logerror("BIOS 04 console output      C:%02X\n", tmp);
 		cpm_conout_chr( tmp );
 		break;
 
 	case 0x05: /* LSTOUT */
 		tmp = bc & 0xff;
-#if VERBOSE_BIOS
-		logerror("BIOS 05 list output         C:%02X\n", tmp);
-#endif
+		if (VERBOSE_BIOS)
+			logerror("BIOS 05 list output         C:%02X\n", tmp);
 		/* If the line printer file is created */
 		if (lp)
-			osd_fwrite(lp, &tmp, 1);
+			mame_fwrite(lp, &tmp, 1);
 		break;
 
 
 	case 0x06: /* PUNOUT */
 		tmp = bc & 0xff;
-#if VERBOSE_BIOS
-		logerror("BIOS 06 punch output        C:%02X\n", tmp);
-#endif
+		if (VERBOSE_BIOS)
+			logerror("BIOS 06 punch output        C:%02X\n", tmp);
+
 		/* We have no punch in MESS (yet ;-) */
 		break;
 
@@ -721,51 +696,53 @@ WRITE_HANDLER ( cpm_bios_command_w )
 		/* We have no reader in MESS (yet ;-) */
 		tmp = 0x00;
 		af = (af & 0xff) | (tmp << 8);
-#if VERBOSE_BIOS
-		logerror("BIOS 07 reader input        A:%02X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 07 reader input        A:%02X\n", tmp);
 		break;
 
 
 	case 0x08: /* HOME */
-#if VERBOSE_BIOS
-		logerror("BIOS 08 home\n");
-#endif
+		if (VERBOSE_BIOS)
+			logerror("BIOS 08 home\n");
+
 		cpm_disk_home();
 		break;
 
 
 	case 0x09: /* SELDSK */
 		tmp = bc & 0xff;
-#if VERBOSE_BIOS
-		logerror("BIOS 09 select disk         C:%02X\n", tmp);
-#endif
+		if (VERBOSE_BIOS)
+			logerror("BIOS 09 select disk         C:%02X\n", tmp);
+
 		hl = cpm_disk_select(tmp);
 		break;
 
 	case 0x0a: /* SETTRK */
 		tmp = bc;
-#if VERBOSE_BIOS
-		logerror("BIOS 0A set bdos_trk        BC:%04X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 0A set bdos_trk        BC:%04X\n", tmp);
+
 		cpm_disk_set_track(tmp);
 		break;
 
 
 	case 0x0b: /* SETSEC */
 		tmp = bc & 0xff;
-#if VERBOSE_BIOS
-		logerror("BIOS 0B set bdos_sec        C:%02X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 0B set bdos_sec        C:%02X\n", tmp);
+
 		cpm_disk_set_sector(tmp);
 		break;
 
 
 	case 0x0c: /* SETDMA */
 		tmp = bc;
-#if VERBOSE_BIOS
-		logerror("BIOS 0C set DMA             BC:%04X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 0C set DMA             BC:%04X\n", tmp);
 		cpm_disk_set_dma(tmp);
 		break;
 
@@ -773,26 +750,26 @@ WRITE_HANDLER ( cpm_bios_command_w )
 	case 0x0d: /* RDSEC */
 		tmp = cpm_disk_read_sector();
 		af = (af & 0xff) | (tmp << 8);
-#if VERBOSE_BIOS
-		logerror("BIOS 0D read sector         A:%02X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 0D read sector         A:%02X\n", tmp);
 		break;
 
 
 	case 0x0e: /* WRSEC */
 		tmp = cpm_disk_write_sector();
 		af = (af & 0xff) | (tmp << 8);
-#if VERBOSE_BIOS
-		logerror("BIOS 0E write sector        A:%02X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 0E write sector        A:%02X\n", tmp);
 		break;
 
 	case 0x0f: /* LSTSTA */
 		tmp = 0xff;    /* always ready */
 		af = (af & 0xff) | (tmp << 8);
-#if VERBOSE_BIOS
-		logerror("BIOS 0F list status         A:%02X\n", tmp);
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 0F list status         A:%02X\n", tmp);
 		break;
 
 	case 0x10: /* SECTRA */
@@ -806,7 +783,7 @@ WRITE_HANDLER ( cpm_bios_command_w )
 			/* DAD B   */
 			hl += bc;
 			/* MOV A,M */
-			af = (af & 0xff) | ( cpu_readmem16(hl) << 8);
+			af = (af & 0xff) | ( program_read_byte(hl) << 8);
 			/* MOV L,A */
 			hl = (hl & 0xff00) | (af >> 8);
 		}
@@ -818,27 +795,28 @@ WRITE_HANDLER ( cpm_bios_command_w )
 		}
 		if( curdisk >= 0 && curdisk < num_disks )
 			bdos_sec[curdisk] = hl & 0xff;
-#if VERBOSE_BIOS
-		logerror("BIOS 10 sector trans        BC:%04X DE:%04X HL:%04X A:%02X\n", bc, de, hl, af>>8 );
-#endif
+
+		if (VERBOSE_BIOS)
+			logerror("BIOS 10 sector trans        BC:%04X DE:%04X HL:%04X A:%02X\n", bc, de, hl, af>>8 );
 		break;
 
 
 	case 0x11: /* TRAP */
 		sprintf( buff, "Program traps in BIOS:\r\n%s\r\n", activecpu_dump_state() );
 		cpm_conout_str(buff);
-#if VERBOSE_BIOS
+
+		if (VERBOSE_BIOS)
+		{
 			logerror("BIOS 11 trap\n");
 			logerror("%s\n", activecpu_dump_state() );
-#endif
+		}
 		break;
 	}
 
 	/* Write back the possibly modified Z80 basic registers */
-	cpu_set_reg( Z80_AF, af );
-	cpu_set_reg( Z80_BC, bc );
-	cpu_set_reg( Z80_DE, de );
-	cpu_set_reg( Z80_HL, hl );
-
+	activecpu_set_reg( Z80_AF, af );
+	activecpu_set_reg( Z80_BC, bc );
+	activecpu_set_reg( Z80_DE, de );
+	activecpu_set_reg( Z80_HL, hl );
 }
 
