@@ -1,50 +1,37 @@
 #include "driver.h"
 #include "vidhrdw/stic.h"
 #include "includes/intv.h"
-#include "cpu/cp1600/cp1600.h"
+#include "cpu/cp1610/cp1610.h"
+#include "image.h"
 
-static unsigned int intvkbd_dualport_ram[0x4000];
+UINT8 intv_gramdirty;
+UINT8 intv_gram[512];
+UINT8 intv_gramdirtybytes[512];
 
-READ16_HANDLER ( intvkbd_dualport16_r )
-{
-	/*if (offset == 0x6c) */
-		/*logerror("---read() = %04x\n",intvkbd_dualport_ram[offset]); */
-	return intvkbd_dualport_ram[offset];
-}
+UINT16 *intvkbd_dualport_ram;
 
 WRITE16_HANDLER ( intvkbd_dualport16_w )
 {
 	unsigned char *RAM;
 
-	/*if (offset == 0x6c) */
-		/*logerror("---write() = %04x\n",data); */
-	intvkbd_dualport_ram[offset] = data;
+	COMBINE_DATA(&intvkbd_dualport_ram[offset]);
 
 	/* copy the LSB over to the 6502 OP RAM, in case they are opcodes */
 	RAM	 = memory_region(REGION_CPU2);
-	RAM[offset] = data&0xff;
+	RAM[offset] = (UINT8) (data >> 0);
 }
 
-READ_HANDLER ( intvkbd_dualport8_lsb_r )
+READ8_HANDLER ( intvkbd_dualport8_lsb_r )
 {
-	/*if (offset == 0x6c) */
-		/*logerror("---lsb_r() = %02x\n",intvkbd_dualport_ram[offset]&0xff); */
-	unsigned char *RAM;
-
-	RAM	 = memory_region(REGION_CPU2);
-	return RAM[offset]&0xff;
-	/*return intvkbd_dualport_ram[offset]&0xff; */
+	return (UINT8) (intvkbd_dualport_ram[offset] >> 0);
 }
 
-WRITE_HANDLER ( intvkbd_dualport8_lsb_w )
+WRITE8_HANDLER ( intvkbd_dualport8_lsb_w )
 {
-	UINT16 mask;
 	unsigned char *RAM;
 
-	/*if (offset == 0x6c) */
-		/*logerror("---lsb_w() = %02x\n",data); */
-	mask = intvkbd_dualport_ram[offset] & 0xff00;
-	intvkbd_dualport_ram[offset] = mask | data;
+	intvkbd_dualport_ram[offset] &= ~0x00FF;
+	intvkbd_dualport_ram[offset] |= ((UINT16) data) << 0;
 
 	/* copy over to the 6502 OP RAM, in case they are opcodes */
 	RAM	 = memory_region(REGION_CPU2);
@@ -57,7 +44,7 @@ static int sr1_int_pending;
 
 int intvkbd_text_blanked;
 
-READ_HANDLER ( intvkbd_dualport8_msb_r )
+READ8_HANDLER ( intvkbd_dualport8_msb_r )
 {
 	unsigned char rv;
 
@@ -169,13 +156,13 @@ READ_HANDLER ( intvkbd_dualport8_msb_r )
 static int tape_interrupts_enabled;
 static int tape_unknown_write[6];
 static int tape_motor_mode;
-static char *tape_motor_mode_desc[8] =
+static const char *tape_motor_mode_desc[8] =
 {
 	"IDLE", "IDLE", "IDLE", "IDLE",
 	"EJECT", "PLAY/RECORD", "REWIND", "FF"
 };
 
-WRITE_HANDLER ( intvkbd_dualport8_msb_w )
+WRITE8_HANDLER ( intvkbd_dualport8_msb_w )
 {
 	unsigned int mask;
 
@@ -213,16 +200,16 @@ WRITE_HANDLER ( intvkbd_dualport8_msb_w )
 				break;
 			case 0x041:
 				if (data & 1)
-					logerror("TAPE: Tape Interrupts Enabled\n",data,offset);
+					logerror("TAPE: Tape Interrupts Enabled\n");
 				else
-					logerror("TAPE: Tape Interrupts Disabled\n",data,offset);
+					logerror("TAPE: Tape Interrupts Disabled\n");
 				tape_interrupts_enabled = (data & 1);
 				break;
 			case 0x042:
 				if (data & 1)
-					logerror("TAPE: Cart Bus Interrupts Disabled\n",data,offset);
+					logerror("TAPE: Cart Bus Interrupts Disabled\n");
 				else
-					logerror("TAPE: Cart Bus Interrupts Enabled\n",data,offset);
+					logerror("TAPE: Cart Bus Interrupts Enabled\n");
 				break;
 			case 0x043:
 				if (data & 0x01)
@@ -274,7 +261,7 @@ WRITE_HANDLER ( intvkbd_dualport8_msb_w )
 				intvkbd_tms9927_w(offset-0xc0, data);
 				break;
 			default:
-				logerror("%04X: Unknown write %02x to 0x40%02x\n",cpu_get_pc(),data,offset);
+				logerror("%04X: Unknown write %02x to 0x40%02x\n",activecpu_get_pc(),data,offset);
 				break;
 		}
 	}
@@ -285,9 +272,6 @@ WRITE_HANDLER ( intvkbd_dualport8_msb_w )
 	}
 }
 
-UINT8 intv_gram[512];
-UINT8 intv_gramdirty[64];
-
 READ16_HANDLER( intv_gram_r )
 {
 	/*logerror("read: %d = GRAM(%d)\n",intv_gram[offset],offset); */
@@ -296,9 +280,11 @@ READ16_HANDLER( intv_gram_r )
 
 WRITE16_HANDLER( intv_gram_w )
 {
-	intv_gram[offset]=data&0xff;
-	intv_gramdirty[offset>>3] = 1;
-	/*logerror("write: GRAM(%d) = %d\n",offset,data); */
+    data &= 0xFF;
+
+	intv_gram[offset] = data;
+	intv_gramdirtybytes[offset] = 1;
+    intv_gramdirty = 1;
 }
 
 static unsigned char intv_ram8[256];
@@ -330,10 +316,8 @@ WRITE16_HANDLER( intv_ram16_w )
 	intv_ram16[offset] = data&0xffff;
 }
 
-int intv_load_rom_file(int id, int required)
+static int intv_load_rom_file(mess_image *image, mame_file *romfile, int required)
 {
-	const char *rom_name = device_filename(IO_CARTSLOT,id);
-    FILE *romfile;
     int i;
 
 	UINT8 temp;
@@ -342,14 +326,14 @@ int intv_load_rom_file(int id, int required)
 	UINT8 end_seg;
 
 	UINT16 current_address;
-	UINT16 end_address;
+	UINT32 end_address;
 
 	UINT8 high_byte;
 	UINT8 low_byte;
 
 	UINT8 *memory = memory_region(REGION_CPU1);
 
-	if(!rom_name)
+	if (romfile == NULL)
 	{
 		if (required)
 		{
@@ -360,20 +344,15 @@ int intv_load_rom_file(int id, int required)
 			printf("intvkbd legacy cartridge slot empty - ok\n");
 	}
 
-	if (!(romfile = image_fopen (IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, 0)))
-	{
-		return INIT_FAIL;
-	}
-
-	osd_fread(romfile,&temp,1);			/* header */
+	mame_fread(romfile,&temp,1);			/* header */
 	if (temp != 0xa8)
 	{
 		return INIT_FAIL;
 	}
 
-	osd_fread(romfile,&num_segments,1);
+	mame_fread(romfile,&num_segments,1);
 
-	osd_fread(romfile,&temp,1);
+	mame_fread(romfile,&temp,1);
 	if (temp != (num_segments ^ 0xff))
 	{
 		return INIT_FAIL;
@@ -381,36 +360,49 @@ int intv_load_rom_file(int id, int required)
 
 	for(i=0;i<num_segments;i++)
 	{
-		osd_fread(romfile,&start_seg,1);
+		mame_fread(romfile,&start_seg,1);
 		current_address = start_seg*0x100;
 
-		osd_fread(romfile,&end_seg,1);
+		mame_fread(romfile,&end_seg,1);
 		end_address = end_seg*0x100 + 0xff;
 
 		while(current_address <= end_address)
 		{
-			osd_fread(romfile,&low_byte,1);
+			mame_fread(romfile,&low_byte,1);
 			memory[(current_address<<1)+1] = low_byte;
-			osd_fread(romfile,&high_byte,1);
+			mame_fread(romfile,&high_byte,1);
 			memory[current_address<<1] = high_byte;
 			current_address++;
 		}
 
-		osd_fread(romfile,&temp,1);
-		osd_fread(romfile,&temp,1);
+		mame_fread(romfile,&temp,1);
+		mame_fread(romfile,&temp,1);
 	}
 
 	for(i=0;i<(16+32+2);i++)
 	{
-		osd_fread(romfile,&temp,1);
+		mame_fread(romfile,&temp,1);
 	}
-
-	osd_fclose(romfile);
-
 	return INIT_PASS;
 }
 
-int intv_load_rom(int id)
+DEVICE_INIT( intv_cart )
+{
+	/* First, initialize these as empty so that the intellivision
+	 * will think that the playcable and keyboard are not attached */
+	UINT8 *memory = memory_region(REGION_CPU1);
+
+	/* assume playcable is absent */
+	memory[0x4800<<1] = 0xff;
+	memory[(0x4800<<1)+1] = 0xff;
+
+	/* assume keyboard is absent */
+	memory[0x7000<<1] = 0xff;
+	memory[(0x7000<<1)+1] = 0xff;
+	return INIT_PASS;
+}
+
+DEVICE_LOAD( intv_cart )
 {
 	/* First, initialize these as empty so that the intellivision
 	 * will think that the playcable and keyboard are not attached */
@@ -424,38 +416,37 @@ int intv_load_rom(int id)
 	memory[0x7000<<1] = 0xff;
 	memory[(0x7000<<1)+1] = 0xff;
 
-	return intv_load_rom_file(id, 1);
+	return intv_load_rom_file(image, file, 1);
+}
+
+DRIVER_INIT( intv )
+{
 }
 
 /* Set Reset and INTR/INTRM Vector */
-void init_intv(void)
+MACHINE_INIT( intv )
 {
-}
-
-void intv_machine_init(void)
-{
-	cpu_irq_line_vector_w(0, CP1600_RESET, 0x1000);
+	cpunum_set_input_line_vector(0, CP1610_RESET, 0x1000);
 
 	/* These are actually the same vector, and INTR is unused */
-	cpu_irq_line_vector_w(0, CP1600_INT_INTRM, 0x1004);
-	cpu_irq_line_vector_w(0, CP1600_INT_INTR,  0x1004);
+	cpunum_set_input_line_vector(0, CP1610_INT_INTRM, 0x1004);
+	cpunum_set_input_line_vector(0, CP1610_INT_INTR,  0x1004);
 
 	return;
 }
 
 
-void intv_interrupt_complete(int x)
+static void intv_interrupt_complete(int x)
 {
-	cpu_set_irq_line(0, CP1600_INT_INTRM, CLEAR_LINE);
+	cpunum_set_input_line(0, CP1610_INT_INTRM, CLEAR_LINE);
 }
 
-int intv_interrupt(void)
+INTERRUPT_GEN( intv_interrupt )
 {
-	cpu_set_irq_line(0, CP1600_INT_INTRM, ASSERT_LINE);
+	cpunum_set_input_line(0, CP1610_INT_INTRM, ASSERT_LINE);
 	sr1_int_pending = 1;
 	timer_set(TIME_NOW+TIME_IN_CYCLES(3791, 0), 0, intv_interrupt_complete);
 	stic_screenrefresh();
-	return 0;
 }
 
 static UINT8 controller_table[] =
@@ -465,7 +456,7 @@ static UINT8 controller_table[] =
 	0x04, 0x16, 0x02, 0x13, 0x01, 0x19, 0x08, 0x1c
 };
 
-READ_HANDLER( intv_right_control_r )
+ READ8_HANDLER( intv_right_control_r )
 {
 	UINT8 rv = 0x00;
 
@@ -497,7 +488,7 @@ READ_HANDLER( intv_right_control_r )
 	return rv ^ 0xff;
 }
 
-READ_HANDLER( intv_left_control_r )
+ READ8_HANDLER( intv_left_control_r )
 {
 	return 0xff;
 }
@@ -508,8 +499,9 @@ void init_intvkbd(void)
 {
 }
 
-int intvkbd_load_rom (int id)
+DEVICE_LOAD( intvkbd_cart )
 {
+	int id = image_index_in_device(image);
 	if (id == 0) /* Legacy cartridge slot */
 	{
 		/* First, initialize these as empty so that the intellivision
@@ -520,31 +512,21 @@ int intvkbd_load_rom (int id)
 		memory[0x4800<<1] = 0xff;
 		memory[(0x4800<<1)+1] = 0xff;
 
-		intv_load_rom_file(id, 0);
+		intv_load_rom_file(image, file, 0);
 	}
 
 	if (id == 1) /* Keyboard component cartridge slot */
 	{
-		const char *rom_name = device_filename(IO_CARTSLOT,id);
-    	FILE *romfile;
-
 		UINT8 *memory = memory_region(REGION_CPU2);
 
-		if(!rom_name)
+		if (file == NULL)
 		{
-			printf("intvkbd cartridge slot empty - ok\n");
+			logerror("intvkbd cartridge slot empty - ok\n");
 			return INIT_PASS;
 		}
 
-		if (!(romfile = image_fopen (IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, 0)))
-		{
-			return INIT_FAIL;
-		}
-
 		/* Assume an 8K cart, like BASIC */
-		osd_fread(romfile,&memory[0xe000],0x2000);
-
-		osd_fclose(romfile);
+		mame_fread(file,&memory[0xe000],0x2000);
 	}
 
 	return INIT_PASS;
