@@ -3,11 +3,12 @@
 #include "machine/z80fmly.h"
 #include "cpu/z80/z80.h"
 #include "includes/kc.h"
+#include "devices/cassette.h"
+#include "sound/speaker.h"
+#include "image.h"
 
 #define KC_DEBUG
 
-static int kc85_boot = 0;
-
 static int kc85_pio_data[2];
 
 static void kc85_4_update_0x0c000(void);
@@ -15,8 +16,6 @@ static void kc85_4_update_0x0e000(void);
 static void kc85_4_update_0x08000(void);
 /*static void kc85_4_update_0x04000(void); */
 
-unsigned char *kc85_ram;
-
 /* PIO PORT A: port 0x088:
 
 bit 7: ROM C (BASIC)
@@ -41,44 +40,15 @@ bit 0: TRUCK */
 
 
 /* load image */
-void kc_dump_ram(void)
+static int kc_load(mame_file *file, unsigned char **ptr)
 {
-	void *file;
-
-	file = osd_fopen(Machine->gamedrv->name, "kcram.bin", OSD_FILETYPE_MEMCARD,OSD_FOPEN_WRITE);
-
-	if (file)
-	{
-		int i;
-		for (i=0; i<65536; i++)
-		{
-			char data;
-
-			data = kc85_ram[i];
-
-			osd_fwrite(file, &data, 1);
-
-		}
-
-		/* close file */
-		osd_fclose(file);
-	}
-}
-
-/* load image */
-int kc_load(int type, int id, unsigned char **ptr)
-{
-	void *file;
-
-	file = image_fopen(type, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-
 	if (file)
 	{
 		int datasize;
 		unsigned char *data;
 
 		/* get file size */
-		datasize = osd_fsize(file);
+		datasize = mame_fsize(file);
 
 		if (datasize!=0)
 		{
@@ -88,20 +58,15 @@ int kc_load(int type, int id, unsigned char **ptr)
 			if (data!=NULL)
 			{
 				/* read whole file */
-				osd_fread(file, data, datasize);
+				mame_fread(file, data, datasize);
 
 				*ptr = data;
 
-				/* close file */
-				osd_fclose(file);
-
 				logerror("File loaded!\r\n");
 
 				/* ok! */
 				return 1;
 			}
-			osd_fclose(file);
-
 		}
 	}
 
@@ -126,33 +91,25 @@ struct kcc_header
 /* now type name that has appeared! */
 
 /* load snapshot */
-int kc_quickload_load(int id)
+QUICKLOAD_LOAD(kc)
 {
 	unsigned char *data;
+	struct kcc_header *header;
+	int addr;
+	int datasize;
+	int i;
 
-	if (device_filename(IO_QUICKLOAD,id)==NULL)
-		return INIT_PASS;
+	if (!kc_load(fp, &data))
+		return INIT_FAIL;
 
-	if (kc_load(IO_QUICKLOAD,id,&data))
-	{
-		struct kcc_header *header = (struct kcc_header *)data;
-		int addr;
-		int datasize;
-		int i;
+	header = (struct kcc_header *) data;
+	datasize = (header->length_l & 0x0ff) | ((header->length_h & 0x0ff)<<8);
+	datasize = datasize-128;
+	addr = (header->load_address_l & 0x0ff) | ((header->load_address_h & 0x0ff)<<8);
 
-		datasize = (header->length_l & 0x0ff) | ((header->length_h & 0x0ff)<<8);
-		datasize = datasize-128;
-		addr = (header->load_address_l & 0x0ff) | ((header->load_address_h & 0x0ff)<<8);
-
-		for (i=0; i<datasize; i++)
-		{
-			kc85_ram[(addr+i) & 0x0ffff] = data[i+128];
-		}
-
-		return INIT_PASS;
-	}
-
-	return INIT_FAIL;
+	for (i=0; i<datasize; i++)
+		mess_ram[(addr+i) & 0x0ffff] = data[i+128];
+	return INIT_PASS;
 }
 
 
@@ -173,36 +130,35 @@ int kc_quickload_load(int id)
 /* bit 4: Index pulse from disc */
 static unsigned char kc85_disc_hw_input_gate;
 
-int kc85_floppy_init(int id)
+DEVICE_LOAD( kc85_floppy )
 {
-	if (device_filename(IO_FLOPPY, id)==NULL)
-		return INIT_PASS;
-
-	if (basicdsk_floppy_init(id)==INIT_PASS)
+	if (device_load_basicdsk_floppy(image, file)==INIT_PASS)
 	{
-		basicdsk_set_geometry(id, 80, 2, 9, 512, 1, 0);
+		basicdsk_set_geometry(image, 80, 2, 9, 512, 1, 0, FALSE);
 		return INIT_PASS;
 	}
 
 	return INIT_FAIL;
 }
 
+#if 0
 static void kc85_disc_hw_ctc_interrupt(int state)
 {
-	cpu_cause_interrupt(1, Z80_VECTOR(0, state));
+	cpunum_set_input_line(1, 0, state);
 }
+#endif
 
-READ_HANDLER(kc85_disk_hw_ctc_r)
+ READ8_HANDLER(kc85_disk_hw_ctc_r)
 {
 	return z80ctc_1_r(offset);
 }
 
-WRITE_HANDLER(kc85_disk_hw_ctc_w)
+WRITE8_HANDLER(kc85_disk_hw_ctc_w)
 {
 	z80ctc_1_w(offset,data);
 }
 
-WRITE_HANDLER(kc85_disc_interface_ram_w)
+WRITE8_HANDLER(kc85_disc_interface_ram_w)
 {
 	int addr;
 
@@ -213,10 +169,10 @@ WRITE_HANDLER(kc85_disc_interface_ram_w)
 
 	logerror("interface ram w: %04x %02x\n",addr,data);
 
-	cpu_writemem16(addr|0x0f000,data);
+	program_write_byte(addr|0x0f000,data);
 }
 
-READ_HANDLER(kc85_disc_interface_ram_r)
+ READ8_HANDLER(kc85_disc_interface_ram_r)
 {
 	int addr;
 
@@ -225,22 +181,21 @@ READ_HANDLER(kc85_disc_interface_ram_r)
 
 	logerror("interface ram r: %04x\n",addr);
 
-	return cpu_readmem16(addr|0x0f000);
+	return program_read_byte(addr|0x0f000);
 }
 
 /* 4-bit latch used to reset disc interface etc */
-WRITE_HANDLER(kc85_disc_interface_latch_w)
+WRITE8_HANDLER(kc85_disc_interface_latch_w)
 {
 	logerror("kc85 disc interface latch w\n");
-
 }
 
-READ_HANDLER(kc85_disc_hw_input_gate_r)
+ READ8_HANDLER(kc85_disc_hw_input_gate_r)
 {
 	return kc85_disc_hw_input_gate;
 }
 
-WRITE_HANDLER(kc85_disc_hw_terminal_count_w)
+WRITE8_HANDLER(kc85_disc_hw_terminal_count_w)
 {
 	logerror("kc85 disc hw tc w: %02x\n",data);
 	nec765_set_tc_state(data & 0x01);
@@ -251,22 +206,16 @@ WRITE_HANDLER(kc85_disc_hw_terminal_count_w)
 static void kc85_fdc_interrupt(int state)
 {
 	kc85_disc_hw_input_gate &=~(1<<6);
-
 	if (state)
-	{
 		kc85_disc_hw_input_gate |=(1<<6);
-	}
 }
 
 /* callback for /DRQ output from FDC */
-static void kc85_fdc_dma_drq(int state, int read)
+static void kc85_fdc_dma_drq(int state, int read_)
 {
 	kc85_disc_hw_input_gate &=~(1<<7);
-
 	if (state)
-	{
 		kc85_disc_hw_input_gate |=(1<<7);
-	}
 }
 
 static struct nec765_interface kc_fdc_interface=
@@ -275,24 +224,25 @@ static struct nec765_interface kc_fdc_interface=
 	kc85_fdc_dma_drq
 };
 
-void	kc_disc_interface_init(void)
+static void kc85_disk_reset_timer_callback(int dummy)
 {
+	cpunum_set_reg(1, REG_PC, 0x0f000);
+	cpunum_set_reg(0, REG_PC, 0x0f000);
+}
+
+static void kc_disc_interface_init(void)
+{
+	timer_set(TIME_NOW, 0, kc85_disk_reset_timer_callback);
+
 	nec765_init(&kc_fdc_interface,NEC765A);
 
 	/* reset ctc */
 	z80ctc_reset(1); 
 
 	/* hold cpu at reset */
-	cpu_set_reset_line(1,ASSERT_LINE);
+	cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
 }
 
-
-void	kc_disc_interface_exit(void)
-{
-	nec765_stop();
-}
-
-
 /*****************/
 /* MODULE SYSTEM */
 /*****************/
@@ -331,11 +281,11 @@ struct kc85_module
 	/* id of module */
 	int id;
 	/* name */
-	char *module_name;
+	const char *module_name;
 	/* description */
-	char *module_description;
+	const char *module_description;
 	/* enable module */
-	void	(*enable)(int state);
+	void (*enable)(int state);
 };
 /*
 static struct kc85_module kc85_v24_module=
@@ -369,7 +319,7 @@ static struct kc85_module	*modules[256>>2];
 
 /* bus drivers 4 */
 
-READ_HANDLER(kc85_module_r)
+ READ8_HANDLER(kc85_module_r)
 {
 	int port_upper;
 	int module_index;
@@ -395,7 +345,7 @@ READ_HANDLER(kc85_module_r)
 	return 0x0ff;
 }
 
-WRITE_HANDLER(kc85_module_w)
+WRITE8_HANDLER(kc85_module_w)
 {
 	logerror("kc85 module w: %04x %02x\n",offset,data);
 }
@@ -414,10 +364,6 @@ static void kc85_module_system_init(void)
 	modules[30] = &kc85_disk_interface_device;
 }
 
-static void kc85_module_system_exit(void)
-{
-}
-
 
 
 /**********************/
@@ -439,50 +385,8 @@ static void kc85_module_system_exit(void)
 
 #define KC_CASSETTE_TIMER_FREQUENCY TIME_IN_HZ(4800)
 
-int kc_cassette_device_init(int id)
-{
-	void *file;
-
-	if (device_filename(IO_CASSETTE, id)==NULL)
-		return INIT_PASS;
-
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if (file)
-	{
-		struct wave_args wa = {0,};
-		wa.file = file;
-		wa.display = 1;
-
-		if (device_open(IO_CASSETTE, id, 0, &wa))
-			return INIT_FAIL;
-
-		return INIT_PASS;
-	}
-
-	/* HJB 02/18: no file, create a new file instead */
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_WRITE);
-	if (file)
-	{
-		struct wave_args wa = {0,};
-		wa.file = file;
-		wa.display = 1;
-		wa.smpfreq = 22050; /* maybe 11025 Hz would be sufficient? */
-		/* open in write mode */
-        if (device_open(IO_CASSETTE, id, 1, &wa))
-            return INIT_FAIL;
-		return INIT_PASS;
-    }
-
-	return INIT_FAIL;
-}
-
-void kc_cassette_device_exit(int id)
-{
-	device_close(IO_CASSETTE, id);
-}
-
 /* this timer is used to update the cassette */
-static void *kc_cassette_timer;
+static mame_timer *kc_cassette_timer;
 /* this is the current state of the cassette motor */
 static int kc_cassette_motor_state;
 /* ardy output from pio */
@@ -498,54 +402,37 @@ static void kc_cassette_timer_callback(int dummy)
 	bit = 0;
 
 	/* get data from cassette */
-	if (device_input(IO_CASSETTE,0) > 255)
+	if (cassette_input(image_from_devtype_and_index(IO_CASSETTE, 0)) > 0.0038)
 		bit = 1;
 
 	/* update astb with bit */
 	z80pio_astb_w(0,bit & kc_ardy);
 }
 
-/* free timer used for cassette update */
-static void kc_cassette_remove_timer(void)
-{
-	if (kc_cassette_timer)
-	{
-		timer_remove(kc_cassette_timer);
-		kc_cassette_timer = NULL;
-	}
-
-	/* set initial state */
-	kc_cassette_motor_state = 0;
-}
-
 static void	kc_cassette_init(void)
 {
-	kc_cassette_timer = NULL;
+	kc_cassette_timer = timer_alloc(kc_cassette_timer_callback);
 }
 
-static void	kc_cassette_exit(void)
-{
-	kc_cassette_remove_timer();
-}
-
-
 static void	kc_cassette_set_motor(int motor_state)
 {
 	/* state changed? */
 	if (((kc_cassette_motor_state^motor_state)&0x01)!=0)
 	{
 		/* set new motor state in cassette device */
-		device_status(IO_CASSETTE, 0, motor_state);
+		cassette_change_state(image_from_devtype_and_index(IO_CASSETTE, 0),
+			motor_state ? CASSETTE_MOTOR_ENABLED : CASSETTE_MOTOR_DISABLED,
+			CASSETTE_MASK_MOTOR);
 
 		if (motor_state)
 		{
 			/* start timer */
-			kc_cassette_timer = timer_pulse(KC_CASSETTE_TIMER_FREQUENCY, 0, kc_cassette_timer_callback);
+			timer_adjust(kc_cassette_timer, 0, 0, KC_CASSETTE_TIMER_FREQUENCY);
 		}
 		else
 		{
 			/* stop timer */
-			kc_cassette_remove_timer();
+			timer_reset(kc_cassette_timer, TIME_NEVER);
 		}
 	}
 
@@ -553,10 +440,7 @@ static void	kc_cassette_set_motor(int motor_state)
 	kc_cassette_motor_state = motor_state;
 }
 
-
-
 /*
-
   pin 2 = gnd
   pin 3 = read
   pin 1 = k1		?? modulating signal
@@ -939,12 +823,6 @@ typedef struct kc_keyboard
 
 	/* pulses to transmit */
 	unsigned char transmit_buffer[32];
-
-	/* transmit timer */
-	void	*transmit_timer;
-
-	/* update timer */
-	void	*update_timer;
 } kc_keyboard;
 
 /* previous state of keyboard - currently used to detect if a key has been pressed/released  since last scan */
@@ -1025,10 +903,10 @@ static void kc_keyboard_init(void)
 	keyboard_data.head = (keyboard_data.tail = 0);
 
 	/* 50hz is just a arbitrary value - used to put scan-codes into the queue for transmitting */
-	keyboard_data.update_timer = timer_pulse(TIME_IN_HZ(50), 0, kc_keyboard_update);
+	timer_pulse(TIME_IN_HZ(50), 0, kc_keyboard_update);
 
 	/* timer to transmit pulses to kc base unit */
-	keyboard_data.transmit_timer = timer_pulse(TIME_IN_MSEC(1.024), 0, kc_keyboard_transmit_timer_callback);
+	timer_pulse(TIME_IN_MSEC(1.024), 0, kc_keyboard_transmit_timer_callback);
 
 	/* kc keyboard is not transmitting */
 	keyboard_data.transmit_state = KC_KEYBOARD_TRANSMIT_IDLE;
@@ -1058,25 +936,6 @@ static void kc_keyboard_queue_scancode(int scan_code)
 	keyboard_data.tail = (keyboard_data.tail + 1) % KC_KEYCODE_QUEUE_LENGTH;
 }
 
-
-/* exit keyboard */
-static void kc_keyboard_exit(void)
-{
-	/* turn off update timer */
-	if (keyboard_data.update_timer!=NULL)
-	{
-		timer_remove(keyboard_data.update_timer);
-		keyboard_data.update_timer = NULL;
-	}
-
-	/* turn off transmit timer */
-	if (keyboard_data.transmit_timer!=NULL)
-	{
-		timer_remove(keyboard_data.transmit_timer);
-		keyboard_data.transmit_timer = NULL;
-	}
-}
-
 /* fill transmit buffer with pulse for 0 or 1 bit */
 static void kc_keyboard_add_bit(int bit)
 {
@@ -1223,11 +1082,6 @@ static void	kc_keyboard_update(int dummy)
 	}
 
 	kc_keyboard_attempt_transmit();
-
-	if (readinputport(0))
-	{
-		kc_dump_ram();
-	}
 }
 
 /*********************************************************************/
@@ -1282,30 +1136,23 @@ static void kc85_4_update_0x08000(void)
     {
 		int ram8_block;
 		unsigned char *mem_ptr;
-#ifdef KC_DEBUG
-		/* RAM8 ACCESS */
-		logerror("RAM8 enabled\n");
-#endif
 
 		/* ram8 block chosen */
 		ram8_block = ((kc85_84_data)>>4) & 0x01;
 
-		mem_ptr = kc85_ram+0x08000+(ram8_block<<14);
+		mem_ptr = mess_ram+0x08000+(ram8_block<<14);
 
-		cpu_setbank(3, mem_ptr);
-		cpu_setbank(4, mem_ptr+0x02800);
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
-		memory_set_bankhandler_r(4, 0, MRA_BANK4);
+		memory_set_bankptr(3, mem_ptr);
+		memory_set_bankptr(4, mem_ptr+0x02800);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MRA8_BANK3);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MRA8_BANK4);
 
 		/* write protect RAM8 ? */
 		if ((kc85_pio_data[1] & (1<<6))==0)
 		{
-#ifdef KC_DEBUG
-			logerror("RAM8 write protected\n");
-#endif
 			/* ram8 is enabled and write protected */
-			memory_set_bankhandler_w(9, 0, MWA_NOP);
-			memory_set_bankhandler_w(10, 0, MWA_NOP);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MWA8_NOP);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MWA8_NOP);
 		}
 		else
 		{
@@ -1313,10 +1160,10 @@ static void kc85_4_update_0x08000(void)
 			logerror("RAM8 write enabled\n");
 #endif
 			/* ram8 is enabled and write enabled */
-			memory_set_bankhandler_w(9, 0, MWA_BANK9);
-			memory_set_bankhandler_w(10, 0, MWA_BANK10);
-			cpu_setbank(9, mem_ptr);
-			cpu_setbank(10, mem_ptr+0x02800);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MWA8_BANK9);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MWA8_BANK10);
+			memory_set_bankptr(9, mem_ptr);
+			memory_set_bankptr(10, mem_ptr+0x02800);
 		}
     }
     else
@@ -1324,137 +1171,98 @@ static void kc85_4_update_0x08000(void)
 #ifdef KC_DEBUG
 		logerror("no memory at ram8\n");
 #endif
-		memory_set_bankhandler_r(3, 0, MRA_NOP);
-		memory_set_bankhandler_r(4, 0, MRA_NOP);
-		memory_set_bankhandler_w(9, 0, MWA_NOP);
-		memory_set_bankhandler_w(10, 0, MWA_NOP);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MRA8_NOP);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MWA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MWA8_NOP);
     }
 
 	/* if IRM is enabled override block 3/9 settings */
 	if (kc85_pio_data[0] & (1<<2))
 	{
 		/* IRM enabled - has priority over RAM8 enabled */
-#ifdef KC_DEBUG
-		logerror("IRM enabled\n");
-
-        if (kc85_84_data & 0x04)
-        {
-            logerror("access screen 1\n");
-        }
-        else
-        {
-            logerror("access screen 0\n");
-        }
-
-        if (kc85_84_data & 0x02)
-        {
-            logerror("access colour\n");
-        }
-        else
-        {
-			logerror("access pixel\n");
-        }
-#endif
 		ram_page = kc85_4_get_video_ram_base((kc85_84_data & 0x04), (kc85_84_data & 0x02));
 
-		cpu_setbank(3, ram_page);
-		cpu_setbank(9, ram_page);
-
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
-		memory_set_bankhandler_w(9, 0, MWA_BANK9);
+		memory_set_bankptr(3, ram_page);
+		memory_set_bankptr(9, ram_page);
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MRA8_BANK3);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xa7ff, 0, 0, MWA8_BANK9);
 
 		ram_page = kc85_4_get_video_ram_base(0, 0);
 
-		cpu_setbank(4, ram_page+0x02800);
-		cpu_setbank(10, ram_page+0x02800);
-
-		memory_set_bankhandler_r(4, 0, MRA_BANK4);
-		memory_set_bankhandler_w(10, 0, MWA_BANK10);
-
+		memory_set_bankptr( 4, ram_page + 0x2800);
+		memory_set_bankptr(10, ram_page + 0x2800);
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MRA8_BANK4);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa800, 0xbfff, 0, 0, MWA8_BANK10);
 	}
-
 }
 
 /* update status of memory area 0x0000-0x03fff */
 static void kc85_4_update_0x00000(void)
 {
-	if (kc85_boot)
+	/* access ram? */
+	if (kc85_pio_data[0] & (1<<1))
 	{
-		cpu_setbank(1,memory_region(REGION_CPU1) + 0x013000+0x01000);
-		memory_set_bankhandler_r(1,0, MRA_BANK1);
-		memory_set_bankhandler_w(7,0, MWA_NOP);
-		kc85_boot = 0;
-	}
-	else
-	{
-		/* access ram? */
-		if (kc85_pio_data[0] & (1<<1))
+#ifdef KC_DEBUG
+		logerror("ram0 enabled\n");
+#endif
+
+		/* yes; set address of bank */
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, MRA8_BANK1);
+		memory_set_bankptr(1, mess_ram);
+
+		/* write protect ram? */
+		if ((kc85_pio_data[0] & (1<<3))==0)
 		{
-	#ifdef KC_DEBUG
-			logerror("ram0 enabled\n");
-	#endif
-
 			/* yes */
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			/* set address of bank */
-			cpu_setbank(1, kc85_ram);
+#ifdef KC_DEBUG
+			logerror("ram0 write protected\n");
+#endif
 
-			/* write protect ram? */
-			if ((kc85_pio_data[0] & (1<<3))==0)
-			{
-				/* yes */
-	#ifdef KC_DEBUG
-				logerror("ram0 write protected\n");
-	#endif
-
-				/* ram is enabled and write protected */
-				memory_set_bankhandler_w(7, 0, MWA_NOP);
-			}
-			else
-			{
-	#ifdef KC_DEBUG
-				logerror("ram0 write enabled\n");
-	#endif
-
-				/* ram is enabled and write enabled */
-				memory_set_bankhandler_w(7, 0, MWA_BANK7);
-				/* set address of bank */
-				cpu_setbank(7, kc85_ram);
-			}
+			/* ram is enabled and write protected */
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, MWA8_ROM);
 		}
 		else
 		{
-	#ifdef KC_DEBUG
-			logerror("no memory at ram0!\n");
-	#endif
+#ifdef KC_DEBUG
+			logerror("ram0 write enabled\n");
+#endif
 
-	/*		cpu_setbank(1,memory_region(REGION_CPU1) + 0x013000); */
-			/* ram is disabled */
-			memory_set_bankhandler_r(1, 0, MRA_NOP);
-
-
-			memory_set_bankhandler_w(7, 0, MWA_NOP);
+			/* ram is enabled and write enabled; and set address of bank */
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, MWA8_BANK7);
+			memory_set_bankptr(7, mess_ram);
 		}
 	}
+	else
+	{
+#ifdef KC_DEBUG
+		logerror("no memory at ram0!\n");
+#endif
+
+/*		memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x013000); */
+		/* ram is disabled */
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, MWA8_NOP);
+	}
 }
 
 /* update status of memory area 0x4000-0x07fff */
 static void kc85_4_update_0x04000(void)
 {
+	read8_handler rh;
+	write8_handler wh;
+
 	/* access ram? */
 	if (kc85_86_data & (1<<0))
 	{
-		unsigned char *mem_ptr;
+		UINT8 *mem_ptr;
 
-#ifdef KC_DEBUG
-		logerror("ram4 enabled\n");
-#endif
-		mem_ptr = kc85_ram+0x04000;
+		mem_ptr = mess_ram + 0x04000;
 
 		/* yes */
-		memory_set_bankhandler_r(2, 0,MRA_BANK2);
+		rh = MRA8_BANK2;
 		/* set address of bank */
-		cpu_setbank(2, mem_ptr);
+		memory_set_bankptr(2, mem_ptr);
 
 		/* write protect ram? */
 		if ((kc85_86_data & (1<<1))==0)
@@ -1465,7 +1273,7 @@ static void kc85_4_update_0x04000(void)
 #endif
 
 			/* ram is enabled and write protected */
-			memory_set_bankhandler_w(8, 0, MWA_NOP);
+			wh = MWA8_NOP;
 		}
 		else
 		{
@@ -1473,9 +1281,9 @@ static void kc85_4_update_0x04000(void)
 			logerror("ram4 write enabled\n");
 #endif
 			/* ram is enabled and write enabled */
-			memory_set_bankhandler_w(8, 0, MWA_BANK8);
+			wh = MWA8_BANK8;
 			/* set address of bank */
-			cpu_setbank(8, mem_ptr);
+			memory_set_bankptr(8, mem_ptr);
 		}
 	}
 	else
@@ -1484,34 +1292,37 @@ static void kc85_4_update_0x04000(void)
 		logerror("no memory at ram4!\n");
 #endif
 		/* ram is disabled */
-		memory_set_bankhandler_r(2, 0,MRA_NOP);
-		memory_set_bankhandler_w(8, 0,MWA_NOP);
+		rh = MRA8_NOP;
+		wh = MWA8_NOP;
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, rh);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, wh);
 }
 
 
 /* update memory address 0x0c000-0x0e000 */
 static void kc85_4_update_0x0c000(void)
 {
+	read8_handler rh;
+
 	if (kc85_86_data & (1<<7))
 	{
 		/* CAOS rom takes priority */
 #ifdef KC_DEBUG
 		logerror("CAOS rom 0x0c000\n");
 #endif
-		cpu_setbank(5,memory_region(REGION_CPU1) + 0x012000);
-		memory_set_bankhandler_r(5, 0, MRA_BANK5);
+		memory_set_bankptr(5,memory_region(REGION_CPU1) + 0x012000);
+		rh = MRA8_BANK5;
 	}
-	else
-	if (kc85_pio_data[0] & (1<<7))
+	else if (kc85_pio_data[0] & (1<<7))
 	{
 #ifdef KC_DEBUG
 		/* BASIC takes next priority */
         logerror("BASIC rom 0x0c000\n");
 #endif
 
-        cpu_setbank(5, memory_region(REGION_CPU1) + 0x010000);
-		memory_set_bankhandler_r(5, 0, MRA_BANK5);
+        memory_set_bankptr(5, memory_region(REGION_CPU1) + 0x010000);
+		rh = MRA8_BANK5;
 	}
 	else
 	{
@@ -1519,8 +1330,8 @@ static void kc85_4_update_0x0c000(void)
 		{
 			logerror("module rom at 0xc000\n");
 
-			cpu_setbank(5, kc85_module_rom);
-			memory_set_bankhandler_r(5,0,MRA_BANK5);
+			memory_set_bankptr(5, kc85_module_rom);
+			rh = MRA8_BANK5;
 		}
 		else
 		{
@@ -1528,15 +1339,17 @@ static void kc85_4_update_0x0c000(void)
 #ifdef KC_DEBUG
 			logerror("No roms 0x0c000\n");
 #endif
-
-			memory_set_bankhandler_r(5, 0, MRA_NOP);
+			rh = MRA8_NOP;
 		}
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, rh);
 }
 
 /* update memory address 0x0e000-0x0ffff */
 static void kc85_4_update_0x0e000(void)
 {
+	read8_handler rh;
+
 	if (kc85_pio_data[0] & (1<<0))
 	{
 		/* enable CAOS rom in memory range 0x0e000-0x0ffff */
@@ -1544,16 +1357,17 @@ static void kc85_4_update_0x0e000(void)
 		logerror("CAOS rom 0x0e000\n");
 #endif
 		/* read will access the rom */
-		cpu_setbank(6,memory_region(REGION_CPU1) + 0x013000);
-		memory_set_bankhandler_r(6,0, MRA_BANK6);
+		memory_set_bankptr(6,memory_region(REGION_CPU1) + 0x013000);
+		rh = MRA8_BANK6;
 	}
 	else
 	{
 #ifdef KC_DEBUG
 		logerror("no rom 0x0e000\n");
 #endif
-		memory_set_bankhandler_r(6,0, MRA_NOP);
+		rh = MRA8_NOP;
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, rh);
 }
 
 /* PIO PORT A: port 0x088:
@@ -1578,7 +1392,7 @@ bit 2: TONE 2
 bit 1: TONE 1
 bit 0: TRUCK */
 
-WRITE_HANDLER ( kc85_4_pio_data_w )
+WRITE8_HANDLER ( kc85_4_pio_data_w )
 {
 	kc85_pio_data[offset] = data;
 	z80pio_d_w(0, offset, data);
@@ -1615,7 +1429,7 @@ WRITE_HANDLER ( kc85_4_pio_data_w )
 }
 
 
-WRITE_HANDLER ( kc85_4_86_w )
+WRITE8_HANDLER ( kc85_4_86_w )
 {
 #ifdef KC_DEBUG
 	logerror("0x086 W: %02x\n",data);
@@ -1627,13 +1441,13 @@ WRITE_HANDLER ( kc85_4_86_w )
 	kc85_4_update_0x04000();
 }
 
-READ_HANDLER ( kc85_4_86_r )
+ READ8_HANDLER ( kc85_4_86_r )
 {
 	return kc85_86_data;
 }
 
 
-WRITE_HANDLER ( kc85_4_84_w )
+WRITE8_HANDLER ( kc85_4_84_w )
 {
 #ifdef KC_DEBUG
 	logerror("0x084 W: %02x\n",data);
@@ -1645,7 +1459,7 @@ WRITE_HANDLER ( kc85_4_84_w )
 	kc85_4_update_0x08000();
 }
 
-READ_HANDLER ( kc85_4_84_r )
+ READ8_HANDLER ( kc85_4_84_r )
 {
 	return kc85_84_data;
 }
@@ -1654,113 +1468,114 @@ READ_HANDLER ( kc85_4_84_r )
 /* update memory region 0x0c000-0x0e000 */
 static void kc85_3_update_0x0c000(void)
 {
+	read8_handler rh;
+
 	if (kc85_pio_data[0] & (1<<7))
 	{
 #ifdef KC_DEBUG
 		/* BASIC takes next priority */
 		logerror("BASIC rom 0x0c000\n");
 #endif
-		cpu_setbank(4, memory_region(REGION_CPU1) + 0x010000);
-		memory_set_bankhandler_r(4, 0, MRA_BANK4);
+		memory_set_bankptr(4, memory_region(REGION_CPU1) + 0x010000);
+		rh = MRA8_BANK4;
 	}
 	else
 	{
 #ifdef KC_DEBUG
 		logerror("No roms 0x0c000\n");
 #endif
-		memory_set_bankhandler_r(4, 0, MRA_NOP);
+		rh = MRA8_NOP;
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, rh);
 }
 
 /* update memory address 0x0e000-0x0ffff */
 static void kc85_3_update_0x0e000(void)
 {
+	read8_handler rh;
+
 	if (kc85_pio_data[0] & (1<<0))
 	{
 #ifdef KC_DEBUG
 		/* enable CAOS rom in memory range 0x0e000-0x0ffff */
 		logerror("CAOS rom 0x0e000\n");
 #endif
-		cpu_setbank(5,memory_region(REGION_CPU1) + 0x012000);
-        memory_set_bankhandler_r(5, 0, MRA_BANK5);
+		memory_set_bankptr(5,memory_region(REGION_CPU1) + 0x012000);
+        rh = MRA8_BANK5;
 	}
 	else
 	{
 #ifdef KC_DEBUG
 		logerror("no rom 0x0e000\n");
 #endif
-		memory_set_bankhandler_r(5, 0, MRA_NOP);
+		rh = MRA8_NOP;
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, rh);
 }
 
 /* update status of memory area 0x0000-0x03fff */
-/* MRA_BANK1 is used for read operations and MRA_BANK5 is used
+/* MRA8_BANK1 is used for read operations and MWA8_BANK6 is used
 for write operations */
 static void kc85_3_update_0x00000(void)
 {
-	if (kc85_boot)
+	read8_handler rh;
+	write8_handler wh;
+
+	/* access ram? */
+	if (kc85_pio_data[0] & (1<<1))
 	{
-		/* the real hardware changes the first few opcode fetches */
-		/* I can't do that with MESS */
-		/* CAOS rom 0x0f000 to 0x0000 */
-		cpu_setbank(1, memory_region(REGION_CPU1)+0x012000+0x01000);
-		memory_set_bankhandler_r(1, 0,MRA_BANK1);
-		memory_set_bankhandler_w(6, 0,MWA_NOP);
-		kc85_boot = 0;
-	}
-	else
-	{
-		/* access ram? */
-		if (kc85_pio_data[0] & (1<<1))
+#ifdef KC_DEBUG
+		logerror("ram0 enabled\n");
+#endif
+		/* yes */
+		rh = MRA8_BANK1;
+		/* set address of bank */
+		memory_set_bankptr(1, mess_ram);
+
+		/* write protect ram? */
+		if ((kc85_pio_data[0] & (1<<3))==0)
 		{
-	#ifdef KC_DEBUG
-			logerror("ram0 enabled\n");
-	#endif
 			/* yes */
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			/* set address of bank */
-			cpu_setbank(1, kc85_ram);
+#ifdef KC_DEBUG
+			logerror("ram0 write protected\n");
+#endif
 
-			/* write protect ram? */
-			if ((kc85_pio_data[0] & (1<<3))==0)
-			{
-				/* yes */
-	#ifdef KC_DEBUG
-				logerror("ram0 write protected\n");
-	#endif
-
-				/* ram is enabled and write protected */
-				memory_set_bankhandler_w(6, 0, MWA_NOP);
-			}
-			else
-			{
-	#ifdef KC_DEBUG
-			logerror("ram0 write enabled\n");
-	#endif
-
-				/* ram is enabled and write enabled */
-				memory_set_bankhandler_w(6, 0, MWA_BANK6);
-				/* set address of bank */
-				cpu_setbank(6, kc85_ram);
-			}
+			/* ram is enabled and write protected */
+			wh = MWA8_NOP;
 		}
 		else
 		{
-	#ifdef KC_DEBUG
-			logerror("no memory at ram0!\n");
-	#endif
+#ifdef KC_DEBUG
+		logerror("ram0 write enabled\n");
+#endif
 
-			/* ram is disabled */
-			memory_set_bankhandler_r(1, 0, MRA_NOP);
-			memory_set_bankhandler_w(6, 0, MWA_NOP);
+			/* ram is enabled and write enabled */
+			wh = MWA8_BANK6;
+			/* set address of bank */
+			memory_set_bankptr(6, mess_ram);
 		}
 	}
+	else
+	{
+#ifdef KC_DEBUG
+		logerror("no memory at ram0!\n");
+#endif
+
+		/* ram is disabled */
+		rh = MRA8_NOP;
+		wh = MWA8_NOP;
+	}
+
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, rh);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x3fff, 0, 0, wh);
 }
 
 /* update status of memory area 0x08000-0x0ffff */
-/* MRA_BANK2 is used for read, MRA_BANK6 is used for write */
+/* MRA8_BANK3 is used for read, MWA8_BANK8 is used for write */
 static void kc85_3_update_0x08000(void)
 {
+	read8_handler rh;
+	write8_handler wh;
     unsigned char *ram_page;
 
     if (kc85_pio_data[0] & (1<<2))
@@ -1769,25 +1584,24 @@ static void kc85_3_update_0x08000(void)
 #ifdef KC_DEBUG
         logerror("IRM enabled\n");
 #endif
-		ram_page = kc85_ram+0x08000;
+		ram_page = mess_ram+0x08000;
 
-		cpu_setbank(3, ram_page);
-		cpu_setbank(8, ram_page);
+		memory_set_bankptr(3, ram_page);
+		memory_set_bankptr(8, ram_page);
 
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
-		memory_set_bankhandler_w(8, 0, MWA_BANK8);
+		rh = MRA8_BANK3;
+		wh = MWA8_BANK8;
     }
-    else
-    if (kc85_pio_data[1] & (1<<5))
+    else if (kc85_pio_data[1] & (1<<5))
     {
 		/* RAM8 ACCESS */
 #ifdef KC_DEBUG
 		logerror("RAM8 enabled\n");
 #endif
-		ram_page = kc85_ram + 0x04000;
+		ram_page = mess_ram + 0x04000;
 
-		cpu_setbank(3, ram_page);
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
+		memory_set_bankptr(3, ram_page);
+		rh = MRA8_BANK3;
 
 		/* write protect RAM8 ? */
 		if ((kc85_pio_data[1] & (1<<6))==0)
@@ -1796,7 +1610,7 @@ static void kc85_3_update_0x08000(void)
 			logerror("RAM8 write protected\n");
 #endif
 			/* ram8 is enabled and write protected */
-			memory_set_bankhandler_w(8, 0, MWA_NOP);
+			wh = MWA8_NOP;
 		}
 		else
 		{
@@ -1804,8 +1618,8 @@ static void kc85_3_update_0x08000(void)
 			logerror("RAM8 write enabled\n");
 #endif
 			/* ram8 is enabled and write enabled */
-			memory_set_bankhandler_w(8, 0, MWA_BANK8);
-			cpu_setbank(8,ram_page);
+			wh = MWA8_BANK8;
+			memory_set_bankptr(8,ram_page);
 		}
     }
     else
@@ -1813,9 +1627,12 @@ static void kc85_3_update_0x08000(void)
 #ifdef KC_DEBUG
 		logerror("no memory at ram8!\n");
 #endif
-		memory_set_bankhandler_r(3, 0, MRA_NOP);
-		memory_set_bankhandler_w(8, 0, MWA_NOP);
+		rh = MRA8_NOP;
+		wh = MWA8_NOP;
     }
+
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, rh);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0, wh);
 }
 
 
@@ -1841,7 +1658,7 @@ bit 2: TONE 2
 bit 1: TONE 1
 bit 0: TRUCK */
 
-WRITE_HANDLER ( kc85_3_pio_data_w )
+WRITE8_HANDLER ( kc85_3_pio_data_w )
 {
    kc85_pio_data[offset] = data;
    z80pio_d_w(0, offset, data);
@@ -1880,23 +1697,23 @@ WRITE_HANDLER ( kc85_3_pio_data_w )
 /*****************************************************************/
 
 /* used by KC85/4 and KC85/3 */
-static void *kc85_15khz_timer;
 static int kc85_50hz_state;
 static int kc85_15khz_state;
 static int kc85_15khz_count;
 
-READ_HANDLER ( kc85_unmapped_r )
+ READ8_HANDLER ( kc85_unmapped_r )
 {
 	return 0x0ff;
 }
 
+#if 0
 static OPBASE_HANDLER( kc85_3_opbaseoverride )
 {
 	memory_set_opbase_handler(0,0);
 
 	kc85_3_update_0x00000();
 
-	return (cpunum_get_pc(0) & 0x0ffff);
+	return (cpunum_get_reg(0, REG_PC) & 0x0ffff);
 }
 
 
@@ -1906,29 +1723,35 @@ static OPBASE_HANDLER( kc85_4_opbaseoverride )
 	
 	kc85_4_update_0x00000();
 
-	return (cpunum_get_pc(0) & 0x0ffff);
+	return (cpunum_get_reg(0, REG_PC) & 0x0ffff);
+}
+#endif
+
+
+static void kc85_reset_timer_callback(int dummy)
+{
+	cpunum_set_reg(0, REG_PC, 0x0f000);
 }
 
-
-READ_HANDLER ( kc85_pio_data_r )
+ READ8_HANDLER ( kc85_pio_data_r )
 {
 	return z80pio_d_r(0,offset);
 }
 
-READ_HANDLER ( kc85_pio_control_r )
+ READ8_HANDLER ( kc85_pio_control_r )
 {
 	return z80pio_c_r(0,offset);
 }
 
 
 
-WRITE_HANDLER ( kc85_pio_control_w )
+WRITE8_HANDLER ( kc85_pio_control_w )
 {
    z80pio_c_w(0, offset, data);
 }
 
 
-READ_HANDLER ( kc85_ctc_r )
+ READ8_HANDLER ( kc85_ctc_r )
 {
 	unsigned char data;
 
@@ -1939,7 +1762,7 @@ READ_HANDLER ( kc85_ctc_r )
 	return data;
 }
 
-WRITE_HANDLER ( kc85_ctc_w )
+WRITE8_HANDLER ( kc85_ctc_w )
 {
 	/*logerror("ctc data w:%02x\n",data); */
 
@@ -1949,12 +1772,12 @@ WRITE_HANDLER ( kc85_ctc_w )
 
 static void kc85_pio_interrupt(int state)
 {
-	cpu_cause_interrupt(0, Z80_VECTOR(0, state));
+	cpunum_set_input_line(0, 0, state);
 }
 
 static void kc85_ctc_interrupt(int state)
 {
-	cpu_cause_interrupt(0, Z80_VECTOR(1, state));
+	cpunum_set_input_line(0, 1, state);
 }
 
 /* callback for ardy output from PIO */
@@ -1993,14 +1816,14 @@ static z80pio_interface kc85_pio_intf =
 };
 
 /* used in cassette write -> K0 */
-static WRITE_HANDLER(kc85_zc0_callback)
+static WRITE8_HANDLER(kc85_zc0_callback)
 {
 
 
 }
 
 /* used in cassette write -> K1 */
-static WRITE_HANDLER(kc85_zc1_callback)
+static WRITE8_HANDLER(kc85_zc1_callback)
 {
 
 }
@@ -2031,7 +1854,7 @@ static void kc85_15khz_timer_callback(int dummy)
 }
 
 /* video blink */
-static WRITE_HANDLER(kc85_zc2_callback)
+static WRITE8_HANDLER(kc85_zc2_callback)
 {
 	/* is blink enabled? */
 	if (kc85_pio_data[1] & (1<<7))
@@ -2071,34 +1894,16 @@ static void	kc85_common_init(void)
 	kc85_50hz_state = 0;
 	kc85_15khz_state = 0;
 	kc85_15khz_count = 0;
-	kc85_15khz_timer = timer_pulse(TIME_IN_HZ(15625), 0, kc85_15khz_timer_callback);
-
+	timer_pulse(TIME_IN_HZ(15625), 0, kc85_15khz_timer_callback);
+	timer_set(TIME_NOW, 0, kc85_reset_timer_callback);
 	kc85_module_system_init();
 }
 
-static void	kc85_common_shutdown_machine(void)
-{
-	kc85_module_system_exit();
-
-	if (kc85_15khz_timer)
-	{
-		timer_remove(kc85_15khz_timer);
-		kc85_15khz_timer = NULL;
-	}
-
-	kc_keyboard_exit();
-	kc_cassette_exit();
-
-}
-
 /*****************************************************************/
 
-
-void kc85_4_init_machine(void)
+MACHINE_INIT( kc85_4 )
 {
-	kc85_ram = malloc(64*1024);
-
-	kc85_84_data = 0x028;
+	kc85_84_data = 0x0828;
 	kc85_86_data = 0x063;
 	/* enable CAOS rom in range 0x0e000-0x0ffff */
 	/* ram0 enable, irm enable */
@@ -2112,50 +1917,32 @@ void kc85_4_init_machine(void)
 
 	kc85_common_init();
 
-	kc85_boot = 1;
 	kc85_4_update_0x00000();
 
+
+#if 0
 	/* this is temporary. Normally when a Z80 is reset, it will
 	execute address 0. It appears the KC85 series pages the rom
 	at address 0x0000-0x01000 which has a single jump in it,
 	can't see yet where it disables it later!!!! so for now
 	here will be a override */
 	memory_set_opbase_handler(0, kc85_4_opbaseoverride);
-
+#endif
 }
 
-void kc85_4_shutdown_machine(void)
+MACHINE_INIT( kc85_4d )
 {
-	if (kc85_ram)
-	{
-		free(kc85_ram);
-		kc85_ram = NULL;
-	}
-
-	kc85_common_shutdown_machine();
-}
-
-void kc85_4d_init_machine(void)
-{
-	kc85_4_init_machine();
+	machine_init_kc85_4();
 	kc_disc_interface_init();
 }
 
-void kc85_4d_shutdown_machine(void)
+MACHINE_INIT( kc85_3 )
 {
-	kc85_4_shutdown_machine();
-	kc_disc_interface_exit();
-}
-
-
-void kc85_3_init_machine(void)
-{
-	kc85_ram = malloc(64*1024);
 	kc85_pio_data[0] = 0x0f;
 	kc85_pio_data[1] = 0x0f1;
 
-	cpu_setbank(2,kc85_ram+0x0c000);
-	cpu_setbank(7,kc85_ram+0x0c000);
+	memory_set_bankptr(2,mess_ram+0x0c000);
+	memory_set_bankptr(7,mess_ram+0x0c000);
 
 	kc85_3_update_0x08000();
 	kc85_3_update_0x0c000();
@@ -2163,27 +1950,14 @@ void kc85_3_init_machine(void)
 
 	kc85_common_init();
 
-	kc85_boot = 1;
 	kc85_3_update_0x00000();
 
+#if 0
 	/* this is temporary. Normally when a Z80 is reset, it will
 	execute address 0. It appears the KC85 series pages the rom
 	at address 0x0000-0x01000 which has a single jump in it,
 	can't see yet where it disables it later!!!! so for now
 	here will be a override */
 	memory_set_opbase_handler(0, kc85_3_opbaseoverride);
-
+#endif
 }
-
-void kc85_3_shutdown_machine(void)
-{
-	if (kc85_ram)
-	{
-		free(kc85_ram);
-		kc85_ram = NULL;
-	}
-
-	kc85_common_shutdown_machine();
-}
-
-
