@@ -1,4 +1,5 @@
 /***************************************************************************
+
 	microbee.c
 
     machine driver
@@ -10,8 +11,11 @@
 #include "machine/z80fmly.h"
 #include "vidhrdw/generic.h"
 #include "includes/wd179x.h"
-#include "machine/mbee.h"
-#include "cassette.h"
+#include "includes/mbee.h"
+#include "devices/cassette.h"
+#include "cpu/z80/z80.h"
+#include "sound/speaker.h"
+#include "image.h"
 
 static UINT8 fdc_drv = 0;
 static UINT8 fdc_head = 0;
@@ -30,18 +34,18 @@ static z80pio_interface pio_intf =
 
 static void pio_interrupt(int state)
 {
-	cpu_cause_interrupt(0, Z80_VECTOR(0, state));
+	cpunum_set_input_line(0, 0, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
-void mbee_init_machine(void)
+MACHINE_INIT( mbee )
 {
 	z80pio_init(&pio_intf);
     wd179x_init(WD_TYPE_179X,mbee_fdc_callback);
 }
 
-void mbee_shutdown_machine(void)
+static mess_image *cassette_device_image(void)
 {
-	wd179x_exit();
+	return image_from_devtype_and_index(IO_CASSETTE, 0);
 }
 
 /* PIO B data bits
@@ -54,25 +58,25 @@ void mbee_shutdown_machine(void)
  * 6	speaker
  * 7	network interrupt
  */
-READ_HANDLER ( mbee_pio_r )
+ READ8_HANDLER ( mbee_pio_r )
 {
     int data = z80pio_0_r(offset);
 	if( offset != 2 )
 		return data;
 
     data |= 0x01;
-	if( device_input(IO_CASSETTE,0) > 255 )
+	if (cassette_input(cassette_device_image()) > 0.03)
 		data &= ~0x01;
 
     return data;
 }
 
-WRITE_HANDLER ( mbee_pio_w )
+WRITE8_HANDLER ( mbee_pio_w )
 {
     z80pio_0_w(offset,data);
 	if( offset == 2 )
 	{
-		device_output(IO_CASSETTE,0,(data & 0x02) ? -32768 : 32767);
+		cassette_output(cassette_device_image(), (data & 0x02) ? -1.0 : +1.0);
 		speaker_level_w(0, (data >> 6) & 1);
 	}
 }
@@ -82,11 +86,11 @@ static void mbee_fdc_callback(int param)
 	switch( param )
 	{
 	case WD179X_IRQ_CLR:
-/*		cpu_set_irq_line(0,0,CLEAR_LINE); */
+/*		cpunum_set_input_line(0,0,CLEAR_LINE); */
 		fdc_status &= ~0x40;
         break;
 	case WD179X_IRQ_SET:
-/*		cpu_set_irq_line(0,0,HOLD_LINE); */
+/*		cpunum_set_input_line(0,0,HOLD_LINE); */
 		fdc_status |= 0x40;
         break;
 	case WD179X_DRQ_CLR:
@@ -98,13 +102,13 @@ static void mbee_fdc_callback(int param)
     }
 }
 
-READ_HANDLER ( mbee_fdc_status_r )
+ READ8_HANDLER ( mbee_fdc_status_r )
 {
 	logerror("mbee fdc_motor_r $%02X\n", fdc_status);
 	return fdc_status;
 }
 
-WRITE_HANDLER ( mbee_fdc_motor_w )
+WRITE8_HANDLER ( mbee_fdc_motor_w )
 {
 	logerror("mbee fdc_motor_w $%02X\n", data);
 	/* Controller latch bits
@@ -129,63 +133,25 @@ WRITE_HANDLER ( mbee_fdc_motor_w )
 
 }
 
-int mbee_interrupt(void)
+void mbee_interrupt(void)
 {
-	int tape = readinputport(9);
-
-	if( tape & 1 )
-		device_status(IO_CASSETTE,0,1);
-	if( tape & 2 )
-		device_status(IO_CASSETTE,0,0);
-	if( tape & 4 )
-		device_seek(IO_CASSETTE,0,0,SEEK_SET);
-
     /* once per frame, pulse the PIO B bit 7 */
     logerror("mbee interrupt\n");
 	z80pio_p_w(0, 1, 0x80);
     z80pio_p_w(0, 1, 0x00);
-    return ignore_interrupt();
 }
 
-int mbee_cassette_init(int id)
+DEVICE_LOAD( mbee_cart )
 {
-	struct cassette_args args;
-	memset(&args, 0, sizeof(args));
-	args.create_smpfreq = 11025;
-	return cassette_init(id, &args);
-}
-
-void mbee_cassette_exit(int id)
-{
-	device_close(IO_CASSETTE,id);
-}
-#if 0
-int mbee_floppy_init(int id)
-{
-	flop_specified[id] = device_filename(IO_FLOPPY,id) != NULL;
-	return 0;
-}
-#endif
-
-int mbee_rom_load(int id)
-{
-    void *file;
-
-	file = image_fopen(IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if( file )
+	int size = mame_fsize(file);
+	UINT8 *mem = malloc(size);
+	if( mem )
 	{
-		int size = osd_fsize(file);
-		UINT8 *mem = malloc(size);
-		if( mem )
+		if( mame_fread(file, mem, size) == size )
 		{
-			if( osd_fread(file, mem, size) == size )
-			{
-				memcpy(memory_region(REGION_CPU1)+0x8000, mem, size);
-			}
-			free(mem);
+			memcpy(memory_region(REGION_CPU1)+0x8000, mem, size);
 		}
-		osd_fclose(file);
+		free(mem);
 	}
 	return INIT_PASS;
 }
-
