@@ -10,6 +10,8 @@
 #include "driver.h"
 #include "vidhrdw/m6847.h"
 #include "includes/mc10.h"
+#include "devices/cassette.h"
+#include "sound/dac.h"
 
 static int mc10_keyboard_strobe;
 
@@ -18,38 +20,31 @@ void mc10_init_machine(void)
 	mc10_keyboard_strobe = 0xff;
 
 	/* NPW: Taken from Juergen's MC-10 attempt that I just noticed... */
-    if( readinputport(7) & 0x80 )
-    {
-		install_mem_read_handler(0, 0x5000, 0xbffe, MRA_RAM);
-		install_mem_write_handler(0, 0x5000, 0xbffe, MWA_RAM);
-    }
-    else
-    {
-		install_mem_read_handler(0, 0x5000, 0xbffe, MRA_NOP);
-		install_mem_write_handler(0, 0x5000, 0xbffe, MWA_NOP);
-    }
-	/* Install DOS ROM ? */
-	if( readinputport(7) & 0x40 )
+	if( readinputport(7) & 0x80 )
 	{
-		void *rom = osd_fopen(Machine->gamedrv->name, "mc10ext.rom", OSD_FILETYPE_IMAGE, 0);
-		if( rom )
-		{
-			osd_fread(rom, memory_region(REGION_CPU1) + 0xc000, 0x2000);
-			osd_fclose(rom);
-        }
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0xbffe, 0, 0, MRA8_RAM);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0xbffe, 0, 0, MWA8_RAM);
 	}
 	else
 	{
-		install_mem_read_handler(0, 0xc000, 0xdfff, MRA_NOP);
-		install_mem_write_handler(0, 0xc000, 0xdfff, MWA_NOP);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0xbffe, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0xbffe, 0, 0, MWA8_NOP);
+	}
+	/* Install DOS ROM ? */
+	if( readinputport(7) & 0x40 )
+	{
+		mame_file *rom = mame_fopen(Machine->gamedrv->name, "mc10ext.rom", FILETYPE_IMAGE, 0);
+		if( rom )
+			mame_fread(rom, memory_region(REGION_CPU1) + 0xc000, 0x2000);
+	}
+	else
+	{
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, MWA8_NOP);
     }
 }
 
-void mc10_stop_machine(void)
-{
-}
-
-READ_HANDLER ( mc10_bfff_r )
+ READ8_HANDLER ( mc10_bfff_r )
 {
 	/*   BIT 0 KEYBOARD ROW 1
 	 *   BIT 1 KEYBOARD ROW 2
@@ -59,7 +54,7 @@ READ_HANDLER ( mc10_bfff_r )
 	 *   BIT 5 KEYBOARD ROW 6
 	 */
 
-    int val = 0x60;
+	int val = 0x40;
 
 	if ((input_port_0_r(0) | mc10_keyboard_strobe) == 0xff)
 		val |= 0x01;
@@ -77,12 +72,12 @@ READ_HANDLER ( mc10_bfff_r )
 	return val;
 }
 
-READ_HANDLER ( mc10_port1_r )
+ READ8_HANDLER ( mc10_port1_r )
 {
 	return mc10_keyboard_strobe;
 }
 
-WRITE_HANDLER ( mc10_port1_w )
+WRITE8_HANDLER ( mc10_port1_w )
 {
 	/*   BIT 0  KEYBOARD COLUMN 1 STROBE
 	 *   BIT 1  KEYBOARD COLUMN 2 STROBE
@@ -96,7 +91,7 @@ WRITE_HANDLER ( mc10_port1_w )
 	mc10_keyboard_strobe = data;
 }
 
-READ_HANDLER ( mc10_port2_r )
+ READ8_HANDLER ( mc10_port2_r )
 {
 	/*   BIT 1 KEYBOARD SHIFT/CONTROL KEYS INPUT
 	 * ! BIT 2 PRINTER OTS INPUT
@@ -104,30 +99,33 @@ READ_HANDLER ( mc10_port2_r )
 	 *   BIT 4 CASSETTE TAPE INPUT
 	 */
 
+	mess_image *img = image_from_devtype_and_index(IO_CASSETTE, 0);
 	int val = 0xed;
 
 	if ((input_port_6_r(0) | mc10_keyboard_strobe) == 0xff)
 		val |= 0x02;
 
-	if (device_input(IO_CASSETTE, 0) >= 0)
+	if (cassette_input(img) >= 0)
 		val |= 0x10;
 
 	return val;
 }
 
-WRITE_HANDLER ( mc10_port2_w )
+WRITE8_HANDLER ( mc10_port2_w )
 {
+	mess_image *img = image_from_devtype_and_index(IO_CASSETTE, 0);
+
 	/*   BIT 0 PRINTER OUTFUT & CASS OUTPUT
 	 */
 
-	device_output(IO_CASSETTE, 0, (data & 0x01) ? 32767 : -32768);
+	cassette_output(img, (data & 0x01) ? +1.0 : -1.0);
 }
 
 /* --------------------------------------------------
  * Video hardware
  * -------------------------------------------------- */
 
-int mc10_vh_start(void)
+VIDEO_START( mc10 )
 {
 	extern void dragon_charproc(UINT8 c);
 	struct m6847_init_params p;
@@ -135,18 +133,15 @@ int mc10_vh_start(void)
 	m6847_vh_normalparams(&p);
 	p.version = M6847_VERSION_ORIGINAL_NTSC;
 	p.artifactdipswitch = 7;
-	p.ram = memory_region(REGION_CPU1);
-	p.ramsize = 0x8000;
+	p.ram = mess_ram;
+	p.ramsize = mess_ram_size;
 	p.charproc = dragon_charproc;
+	p.initial_video_offset = 0;
 
-	if (m6847_vh_start(&p))
-		return 1;
-
-	m6847_set_video_offset(0x4000);
-	return 0;
+	return video_start_m6847(&p);
 }
 
-WRITE_HANDLER ( mc10_bfff_w )
+WRITE8_HANDLER ( mc10_bfff_w )
 {
 	/*   BIT 2 GM2 6847 CONTROL & INT/EXT CONTROL
 	 *   BIT 3 GM1 6847 CONTROL
@@ -167,9 +162,25 @@ WRITE_HANDLER ( mc10_bfff_w )
 	schedule_full_refresh();
 }
 
-WRITE_HANDLER ( mc10_ram_w )
+
+
+static WRITE8_HANDLER ( mc10_ram_w )
 {
-	/* from vidhrdw/dragon.c */
-	extern void coco_ram_w (int offset_loc, int data_loc);
-	coco_ram_w(offset + 0x4000, data);
+	if (mess_ram[offset] != data)
+	{
+		m6847_touch_vram(offset);
+		mess_ram[offset] = data;
+	}
 }
+
+
+
+DRIVER_INIT( mc10 )
+{
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x4000 + mess_ram_size - 1,
+		0, 0, MRA8_BANK1);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x4000 + mess_ram_size - 1,
+		0, 0, mc10_ram_w);
+	memory_set_bankptr(1, mess_ram);
+}
+
