@@ -13,7 +13,9 @@
  *****************************************************************************/
 
 #include "includes/microtan.h"
-#include "cassette.h"
+#include "devices/cassette.h"
+#include "image.h"
+#include "devices/snapquik.h"
 
 #ifndef VERBOSE
 #define VERBOSE 0
@@ -28,10 +30,7 @@
 static UINT8 microtan_keypad_column;
 static UINT8 microtan_keyboard_ascii;
 
-static UINT8 *snapshot_buff;
-static int snapshot_size;
-
-static void *microtan_timer = NULL;
+static mame_timer *microtan_timer = NULL;
 
 static int via_0_irq_line = CLEAR_LINE;
 static int via_1_irq_line = CLEAR_LINE;
@@ -134,72 +133,77 @@ static void microtan_set_irq_line(void)
     /* The 6502 IRQ line is active low and probably driven
        by open collector outputs (guess). Since MAME/MESS use
        a non-0 value for ASSERT_LINE we OR the signals here */
-    cpu_set_irq_line(0, 0, via_0_irq_line | via_1_irq_line | kbd_irq_line);
+    cpunum_set_input_line(0, 0, via_0_irq_line | via_1_irq_line | kbd_irq_line);
+}
+
+static mess_image *cassette_device_image(void)
+{
+	return image_from_devtype_and_index(IO_CASSETTE, 0);
 }
 
 /**************************************************************
  * VIA callback functions for VIA #0
  **************************************************************/
-static READ_HANDLER (via_0_in_a )
+static  READ8_HANDLER (via_0_in_a )
 {
     int data = readinputport(10);
     LOG(("microtan_via_0_in_a %02X\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_0_in_b )
+static  READ8_HANDLER ( via_0_in_b )
 {
     int data = 0xff;
     LOG(("microtan_via_0_in_b %02X\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_0_in_ca1 )
+static  READ8_HANDLER ( via_0_in_ca1 )
 {
     int data = 1;
     LOG(("microtan_via_0_in_ca1 %d\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_0_in_cb1 )
+static  READ8_HANDLER ( via_0_in_cb1 )
 {
     int data = 1;
     LOG(("microtan_via_0_in_cb1 %d\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_0_in_ca2 )
+static  READ8_HANDLER ( via_0_in_ca2 )
 {
     int data = 1;
     LOG(("microtan_via_0_in_ca2 %d\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_0_in_cb2 )
+static  READ8_HANDLER ( via_0_in_cb2 )
 {
     int data = 1;
     LOG(("microtan_via_0_in_cb2 %d\n", data));
     return data;
 }
 
-static WRITE_HANDLER ( via_0_out_a )
+static WRITE8_HANDLER ( via_0_out_a )
 {
     LOG(("microtan_via_0_out_a %02X\n", data));
 }
 
-static WRITE_HANDLER (via_0_out_b )
+static WRITE8_HANDLER (via_0_out_b )
 {
     LOG(("microtan_via_0_out_b %02X\n", data));
     /* bit #7 is the cassette output signal */
-    wave_output(0, data & 0x80 ? +32767 : -32768);
+    cassette_output(cassette_device_image(), data & 0x80 ? +1.0 : -1.0);
 }
 
-static WRITE_HANDLER ( via_0_out_ca2 )
+static WRITE8_HANDLER ( via_0_out_ca2 )
 {
     LOG(("microtan_via_0_out_ca2 %d\n", data));
 }
 
-static WRITE_HANDLER (via_0_out_cb2 )
+static WRITE8_HANDLER (via_0_out_cb2 )
 {
     LOG(("microtan_via_0_out_cb2 %d\n", data));
 }
@@ -214,64 +218,64 @@ static void via_0_irq(int state)
 /**************************************************************
  * VIA callback functions for VIA #1
  **************************************************************/
-static READ_HANDLER ( via_1_in_a )
+static  READ8_HANDLER ( via_1_in_a )
 {
     int data = 0xff;
     LOG(("microtan_via_1_in_a %02X\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_1_in_b )
+static  READ8_HANDLER ( via_1_in_b )
 {
     int data = 0xff;
     LOG(("microtan_via_1_in_b %02X\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_1_in_ca1 )
+static  READ8_HANDLER ( via_1_in_ca1 )
 {
     int data = 1;
     LOG(("microtan_via_1_in_ca1 %d\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_1_in_cb1 )
+static  READ8_HANDLER ( via_1_in_cb1 )
 {
     int data = 1;
     LOG(("microtan_via_1_in_cb1 %d\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_1_in_ca2 )
+static  READ8_HANDLER ( via_1_in_ca2 )
 {
     int data = 1;
     LOG(("microtan_via_1_in_ca2 %d\n", data));
     return data;
 }
 
-static READ_HANDLER ( via_1_in_cb2 )
+static  READ8_HANDLER ( via_1_in_cb2 )
 {
     int data = 1;
     LOG(("microtan_via_1_in_cb2 %d\n", data));
     return data;
 }
 
-static WRITE_HANDLER ( via_1_out_a )
+static WRITE8_HANDLER ( via_1_out_a )
 {
     LOG(("microtan_via_1_out_a %02X\n", data));
 }
 
-static WRITE_HANDLER ( via_1_out_b )
+static WRITE8_HANDLER ( via_1_out_b )
 {
     LOG(("microtan_via_1_out_b %02X\n", data));
 }
 
-static WRITE_HANDLER (via_1_out_ca2 )
+static WRITE8_HANDLER (via_1_out_ca2 )
 {
     LOG(("microtan_via_1_out_ca2 %d\n", data));
 }
 
-static WRITE_HANDLER ( via_1_out_cb2 )
+static WRITE8_HANDLER ( via_1_out_cb2 )
 {
     LOG(("microtan_via_1_out_cb2 %d\n", data));
 }
@@ -295,14 +299,14 @@ static char *via_name[16] = {
 };
 #endif
 
-READ_HANDLER( microtan_via_0_r )
+ READ8_HANDLER( microtan_via_0_r )
 {
     int data = via_0_r(offset);
     LOG(("microtan_via_0_r %s -> %02X\n", via_name[offset], data));
     return data;
 }
 
-READ_HANDLER( microtan_via_1_r )
+ READ8_HANDLER( microtan_via_1_r )
 {
     int data = via_1_r(offset);
     LOG(("microtan_via_1_r %s -> %02X\n", via_name[offset], data));
@@ -312,13 +316,13 @@ READ_HANDLER( microtan_via_1_r )
 /**************************************************************
  * VIA write wrappers
  **************************************************************/
-WRITE_HANDLER( microtan_via_0_w )
+WRITE8_HANDLER( microtan_via_0_w )
 {
     LOG(("via_0_w (%2d) %s <- %02X\n", offset, via_name[offset], data));
     via_0_w(offset,data);
 }
 
-WRITE_HANDLER( microtan_via_1_w )
+WRITE8_HANDLER( microtan_via_1_w )
 {
     LOG(("via_1_w (%2d) %s <- %02X\n", offset, via_name[offset], data));
     via_1_w(offset,data);
@@ -334,6 +338,7 @@ static struct via6522_interface via6522[2] =
         via_0_in_ca1, via_0_in_cb1,
         via_0_in_ca2, via_0_in_cb2,
         via_0_out_a,  via_0_out_b,
+		0, 0,
         via_0_out_ca2,via_0_out_cb2,
         via_0_irq,
     },
@@ -342,24 +347,24 @@ static struct via6522_interface via6522[2] =
         via_1_in_ca1, via_1_in_cb1,
         via_1_in_ca2, via_1_in_cb2,
         via_1_out_a,  via_1_out_b,
+		0, 0,
         via_1_out_ca2,via_1_out_cb2,
         via_1_irq,
     }
 };
 
-void microtan_read_cassette(int param)
+static void microtan_read_cassette(int param)
 {
-    int level = device_input(IO_CASSETTE,0);
+	double level = cassette_input(cassette_device_image());
 
-    LOG(("microtan_read_cassette: %+5d\n", level));
-    if (level < -511)
-        via_set_input_cb2(0,0);
-    else
-    if (level > +511)
-        via_set_input_cb2(0,1);
+	LOG(("microtan_read_cassette: %+5d\n", level));
+	if (level < -0.07)
+		via_set_input_cb2(0,0);
+	else if (level > +0.07)
+		via_set_input_cb2(0,1);
 }
 
-READ_HANDLER( microtan_sio_r )
+ READ8_HANDLER( microtan_sio_r )
 {
     int data;
 	data = acia_6551_r(offset);
@@ -367,27 +372,27 @@ READ_HANDLER( microtan_sio_r )
     return data;
 }
 
-WRITE_HANDLER( microtan_sio_w )
+WRITE8_HANDLER( microtan_sio_w )
 {
     LOG(("microtan_sio_w: %d <- %02x\n", offset, data));
 	acia_6551_w(offset,data);
 }
 
 
-READ_HANDLER( microtan_sound_r )
+ READ8_HANDLER( microtan_sound_r )
 {
     int data = 0xff;
     LOG(("microtan_sound_r: -> %02x\n", data));
     return data;
 }
 
-WRITE_HANDLER( microtan_sound_w )
+WRITE8_HANDLER( microtan_sound_w )
 {
     LOG(("microtan_sound_w: <- %02x\n", data));
 }
 
 
-READ_HANDLER ( microtan_bffx_r )
+ READ8_HANDLER ( microtan_bffx_r )
 {
     int data = 0xff;
     switch( offset & 3 )
@@ -413,10 +418,10 @@ READ_HANDLER ( microtan_bffx_r )
 /* This callback is called one clock cycle after BFF2 is written (delayed nmi) */
 static void microtan_pulse_nmi(int param)
 {
-    cpu_set_nmi_line(0,PULSE_LINE);
+    cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE);
 }
 
-WRITE_HANDLER ( microtan_bffx_w )
+WRITE8_HANDLER ( microtan_bffx_w )
 {
     switch( offset & 3 )
     {
@@ -441,22 +446,6 @@ WRITE_HANDLER ( microtan_bffx_w )
     }
 }
 
-int microtan_cassette_init(int id)
-{
-	struct cassette_args args;
-	memset(&args, 0, sizeof(args));
-	args.chunk_size = 1;
-	args.chunk_samples = 8;
-	args.input_smpfreq = Machine->sample_rate;
-	args.create_smpfreq = Machine->sample_rate;
-	return cassette_init(id, &args);
-}
-
-void microtan_cassette_exit(int id)
-{
-    device_close(IO_CASSETTE,id);
-}
-
 static int microtan_varify_snapshot(UINT8 *data, int size)
 {
 	if (size == 8263)
@@ -476,47 +465,7 @@ static int microtan_varify_snapshot(UINT8 *data, int size)
     return IMAGE_VERIFY_FAIL;
 }
 
-int microtan_snapshot_init(int id)
-{
-    void *file;
-
-	/* If no image specified, I guess we should start! */
-	if (!device_filename(IO_SNAPSHOT,id) || !strlen(device_filename(IO_SNAPSHOT,id) ))
-	{
-		logerror("warning: no sanpshot specified!\n");
-		return INIT_PASS;
-	}
-
-    file = image_fopen(IO_SNAPSHOT, id, OSD_FILETYPE_IMAGE, 0);
-    if (file)
-    {
-        snapshot_size = osd_fsize(file);
-        snapshot_buff = malloc(snapshot_size);
-        if (!snapshot_buff)
-        {
-            LOG(("microtan_snapshot_load: could not allocate %d bytes of buffer\n", snapshot_size));
-            return INIT_FAIL;
-        }
-        osd_fread(file, snapshot_buff, snapshot_size);
-        osd_fclose(file);
-
-/*		if (microtan_varify_snapshot(snapshot_buff, snapshot_size)==IMAGE_VERIFY_FAIL) */
-/*			return INIT_FAIL; */
-/*		else */
-			return INIT_PASS;
-    }
-    return INIT_FAIL;
-}
-
-void microtan_snapshot_exit(int id)
-{
-    if (snapshot_buff)
-        free(snapshot_buff);
-    snapshot_buff = NULL;
-    snapshot_size = 0;
-}
-
-int parse_intel_hex(char *src)
+static int parse_intel_hex(UINT8 *snapshot_buff, char *src)
 {
     char line[128];
     int row = 0, column = 0, last_addr = 0, last_size = 0;
@@ -597,7 +546,7 @@ int parse_intel_hex(char *src)
     return INIT_PASS;
 }
 
-int parse_zillion_hex(char *src)
+static int parse_zillion_hex(UINT8 *snapshot_buff, char *src)
 {
     char line[128];
     int parsing = 0, row = 0, column = 0;
@@ -655,7 +604,7 @@ int parse_zillion_hex(char *src)
 
                     row++;
                     line[column] = '\0';
-                    n = sscanf(line, "G%x", &addr);
+                    n = sscanf(line, "G%x", (unsigned int *) &addr);
                     if (n == 1 && !snapshot_buff[8192+64+1] && !snapshot_buff[8192+64+1])
                     {
                         LOG(("microtan_hexfile_init: go addr %04X\n", addr));
@@ -680,58 +629,6 @@ int parse_zillion_hex(char *src)
     return INIT_PASS;
 }
 
-int microtan_hexfile_init(int id)
-{
-    void *file;
-
-	/* If no image specified, I guess we should start! */
-	if (!device_filename(IO_QUICKLOAD,id) || !strlen(device_filename(IO_QUICKLOAD,id) ))
-	{
-		logerror("warning: no quikload specified!\n");
-		return INIT_PASS;
-	}
-
-    file = image_fopen(IO_QUICKLOAD, id, OSD_FILETYPE_IMAGE, 0);
-    if (file)
-    {
-        int size = osd_fsize(file);
-        char *buff;
-
-        snapshot_size = 8263;   /* magic size */
-        snapshot_buff = malloc(snapshot_size);
-        if (!snapshot_buff)
-        {
-            LOG(("microtan_hexfile_load: could not allocate %d bytes of buffer\n", snapshot_size));
-            return INIT_FAIL;
-        }
-        memset(snapshot_buff, 0, snapshot_size);
-
-        buff = malloc(size + 1);
-        if (!buff)
-        {
-            LOG(("microtan_hexfile_load: could not allocate %d bytes of buffer\n", size));
-            return INIT_FAIL;
-        }
-        osd_fread(file, buff, size);
-        osd_fclose(file);
-
-        buff[size] = '\0';
-
-        if (buff[0] == ':')
-            return parse_intel_hex(buff);
-        return parse_zillion_hex(buff);
-    }
-    return INIT_FAIL;
-}
-
-void microtan_hexfile_exit(int id)
-{
-    if (snapshot_buff)
-        free(snapshot_buff);
-    snapshot_buff = NULL;
-    snapshot_size = 0;
-}
-
 static void store_key(int key)
 {
     LOG(("microtan: store key '%c'\n", key));
@@ -740,43 +637,21 @@ static void store_key(int key)
     microtan_set_irq_line();
 }
 
-int microtan_interrupt(void)
+INTERRUPT_GEN( microtan_interrupt )
 {
     int mod, row, col, chg, new;
     static int lastrow = 0, mask = 0x00, key = 0x00, repeat = 0, repeater = 0;
 
-    if( setup_active() || onscrd_active() )
-        return ignore_interrupt();
-
     if( repeat )
     {
         if( !--repeat )
             repeater = 4;
     }
-    else
-    if( repeater )
+    else if( repeater )
     {
         repeat = repeater;
     }
 
-    if (readinputport(11) & 1) /* F5 tape stop */
-    {
-        device_status(IO_CASSETTE,0,0);
-        if (microtan_timer)
-            timer_remove(microtan_timer);
-        microtan_timer = NULL;
-    }
-    if (readinputport(11) & 2) /* F6 tape start */
-    {
-        device_status(IO_CASSETTE,0,1);
-        if (!microtan_timer)
-            microtan_timer = timer_pulse(TIME_IN_HZ(11025), 0, microtan_read_cassette);
-    }
-    if (readinputport(11) & 4) /* F7 tape rewind */
-    {
-        device_seek(IO_CASSETTE,0,0,SEEK_SET);
-    }
-
     row = 9;
     new = readinputport(row);
     chg = keyrows[--row] ^ new;
@@ -849,23 +724,22 @@ int microtan_interrupt(void)
     {
         store_key(key);
     }
-    return ignore_interrupt();
 }
 
-static void microtan_set_cpu_regs(int base)
+static void microtan_set_cpu_regs(const UINT8 *snapshot_buff, int base)
 {
     LOG(("microtan_snapshot_copy: PC:%02X%02X P:%02X A:%02X X:%02X Y:%02X SP:1%02X",
         snapshot_buff[base+1], snapshot_buff[base+0], snapshot_buff[base+2], snapshot_buff[base+3],
         snapshot_buff[base+4], snapshot_buff[base+5], snapshot_buff[base+6]);
-    cpu_set_reg(M6502_PC, snapshot_buff[base+0] + 256 * snapshot_buff[base+1]));
-    cpu_set_reg(M6502_P, snapshot_buff[base+2]);
-    cpu_set_reg(M6502_A, snapshot_buff[base+3]);
-    cpu_set_reg(M6502_X, snapshot_buff[base+4]);
-    cpu_set_reg(M6502_Y, snapshot_buff[base+5]);
-    cpu_set_reg(M6502_S, snapshot_buff[base+6]);
+    activecpu_set_reg(M6502_PC, snapshot_buff[base+0] + 256 * snapshot_buff[base+1]));
+    activecpu_set_reg(M6502_P, snapshot_buff[base+2]);
+    activecpu_set_reg(M6502_A, snapshot_buff[base+3]);
+    activecpu_set_reg(M6502_X, snapshot_buff[base+4]);
+    activecpu_set_reg(M6502_Y, snapshot_buff[base+5]);
+    activecpu_set_reg(M6502_S, snapshot_buff[base+6]);
 }
 
-static void microtan_snapshot_copy(int param)
+static void microtan_snapshot_copy(UINT8 *snapshot_buff, int snapshot_size)
 {
     UINT8 *RAM = memory_region(REGION_CPU1);
 
@@ -891,7 +765,7 @@ static void microtan_snapshot_copy(int param)
             dirtybuffer[i] = 1;
         }
         base += 64;
-        microtan_set_cpu_regs(base);
+        microtan_set_cpu_regs(snapshot_buff, base);
     }
     else
     {
@@ -962,11 +836,65 @@ static void microtan_snapshot_copy(int param)
         }
         base += 64;
 
-        microtan_set_cpu_regs(base);
+        microtan_set_cpu_regs(snapshot_buff, base);
     }
 }
 
-void init_microtan(void)
+SNAPSHOT_LOAD( microtan )
+{
+	UINT8 *snapshot_buff;
+
+	snapshot_buff = malloc(snapshot_size);
+	mame_fread(fp, snapshot_buff, snapshot_size);
+
+	if (microtan_varify_snapshot(snapshot_buff, snapshot_size)==IMAGE_VERIFY_FAIL)
+	{
+		free(snapshot_buff);
+		return INIT_FAIL;
+	}
+
+	microtan_snapshot_copy(snapshot_buff, snapshot_size);
+	free(snapshot_buff);
+	return INIT_PASS;
+}
+
+QUICKLOAD_LOAD( microtan_hexfile )
+{
+	int snapshot_size;
+	UINT8 *snapshot_buff;
+	char *buff;
+	int rc;
+
+	snapshot_size = 8263;   /* magic size */
+	snapshot_buff = malloc(snapshot_size);
+	if (!snapshot_buff)
+	{
+		LOG(("microtan_hexfile_load: could not allocate %d bytes of buffer\n", snapshot_size));
+		return INIT_FAIL;
+	}
+	memset(snapshot_buff, 0, snapshot_size);
+
+	buff = malloc(quickload_size + 1);
+	if (!buff)
+	{
+		LOG(("microtan_hexfile_load: could not allocate %d bytes of buffer\n", quickload_size));
+		return INIT_FAIL;
+	}
+	mame_fread(fp, buff, quickload_size);
+
+    buff[quickload_size] = '\0';
+
+    if (buff[0] == ':')
+        rc = parse_intel_hex(snapshot_buff, buff);
+	else
+		rc = parse_zillion_hex(snapshot_buff, buff);
+	if (rc == INIT_PASS)
+		microtan_snapshot_copy(snapshot_buff, snapshot_size);
+	free(snapshot_buff);
+	return rc;
+}
+
+DRIVER_INIT( microtan )
 {
     UINT8 *dst = memory_region(REGION_GFX2);
     int i;
@@ -1010,23 +938,24 @@ void init_microtan(void)
     switch (readinputport(0) & 3)
     {
         case 0:  /* 1K only :) */
-            install_mem_read_handler(0, 0x0400, 0xbbff, MRA_NOP);
-            install_mem_write_handler(0, 0x0400, 0xbbff, MWA_NOP);
+            memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0400, 0xbbff, 0, 0, MRA8_NOP);
+            memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0400, 0xbbff, 0, 0, MWA8_NOP);
             break;
         case 1:  /* +7K TANEX */
-            install_mem_read_handler(0, 0x0400, 0x1fff, MRA_RAM);
-            install_mem_write_handler(0, 0x0400, 0x1fff, MWA_RAM);
-            install_mem_read_handler(0, 0x2000, 0xbbff, MRA_NOP);
-            install_mem_write_handler(0, 0x2000, 0xbbff, MWA_NOP);
+            memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0400, 0x1fff, 0, 0, MRA8_RAM);
+            memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0400, 0x1fff, 0, 0, MWA8_RAM);
+            memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0xbbff, 0, 0, MRA8_NOP);
+            memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0xbbff, 0, 0, MWA8_NOP);
             break;
         default: /* +7K TANEX + 40K TANRAM */
-            install_mem_read_handler(0, 0x0400, 0xbbff, MRA_RAM);
-            install_mem_write_handler(0, 0x0400, 0xbbff, MWA_RAM);
+            memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0400, 0xbbff, 0, 0, MRA8_RAM);
+            memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0400, 0xbbff, 0, 0, MWA8_RAM);
             break;
     }
+
 }
 
-void microtan_init_machine(void)
+MACHINE_INIT( microtan )
 {
     int i;
 
@@ -1034,19 +963,10 @@ void microtan_init_machine(void)
         keyrows[i] = readinputport(1+i);
     set_led_status(1, (keyrows[3] & 0x80) ? 0 : 1);
 
-    if (snapshot_size)
-    {
-        /* setup a timer to copy the snapshot data into RAM */
-        timer_set(0.5, 0, microtan_snapshot_copy);
-    }
-
     via_config(0, &via6522[0]);
     via_config(1, &via6522[1]);
 
 	acia_6551_init();
-}
 
-void	microtan_exit_machine(void)
-{
-	acia_6551_stop();
+	microtan_timer = timer_alloc(microtan_read_cassette);
 }
