@@ -136,44 +136,34 @@ static  READ8_HANDLER ( pet_pia1_cb1_read )
 	return cbm_ieee_srq_r();
 }
 
-static struct pia6821_interface pet_pia0={
-#if 0
-	int (*in_a_func)(int offset);
-	int (*in_b_func)(int offset);
-	int (*in_ca1_func)(int offset);
-	int (*in_cb1_func)(int offset);
-	int (*in_ca2_func)(int offset);
-	int (*in_cb2_func)(int offset);
-	void (*out_a_func)(int offset, int val);
-	void (*out_b_func)(int offset, int val);
-	void (*out_ca2_func)(int offset, int val);
-	void (*out_cb2_func)(int offset, int val);
-	void (*irq_a_func)(int state);
-	void (*irq_b_func)(int state);
-#endif
-	pet_pia0_port_a_read,
-	pet_pia0_port_b_read,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	pet_pia0_port_a_write,
-	NULL,
-	pet_pia0_ca2_out,
-	NULL,
-	NULL,
-	pet_irq
-}, pet_pia1= {
-	pet_pia1_port_a_read,
-	NULL,
-    pet_pia1_ca1_read,
-    pet_pia1_cb1_read,
-	NULL,
-	NULL,
-	NULL,
-    pet_pia1_port_b_write,
-    pet_pia1_ca2_write,
-    pet_pia1_cb2_write,
+static struct pia6821_interface pet_pia0 =
+{
+	pet_pia0_port_a_read,		/* in_a_func */
+	pet_pia0_port_b_read,		/* in_b_func */
+	NULL,						/* in_ca1_func */
+	NULL,						/* in_cb1_func */
+	NULL,						/* in_ca2_func */
+	NULL,						/* in_cb2_func */
+	pet_pia0_port_a_write,		/* out_a_func */
+	NULL,						/* out_b_func */
+	pet_pia0_ca2_out,			/* out_ca2_func */
+	NULL,						/* out_cb2_func */
+	NULL,						/* irq_a_func */
+	pet_irq						/* irq_b_func */
+};
+
+static struct pia6821_interface pet_pia1 =
+{
+	pet_pia1_port_a_read,		/* in_a_func */
+	NULL,						/* in_b_func */
+    pet_pia1_ca1_read,			/* in_ca1_func */
+    pet_pia1_cb1_read,			/* in_cb1_func */
+	NULL,						/* in_ca2_func */
+	NULL,						/* in_cb2_func */
+	NULL,						/* out_a_func */
+    pet_pia1_port_b_write,		/* out_b_func */
+    pet_pia1_ca2_write,			/* out_ca2_func */
+    pet_pia1_cb2_write,			/* out_cb2_func */
 };
 
 static WRITE8_HANDLER( pet_address_line_11 )
@@ -216,33 +206,17 @@ static WRITE8_HANDLER( pet_via_port_b_w )
 }
 
 
-static struct via6522_interface pet_via={
-#if 0
-	int (*in_a_func)(int offset);
-	int (*in_b_func)(int offset);
-	int (*in_ca1_func)(int offset);
-	int (*in_cb1_func)(int offset);
-	int (*in_ca2_func)(int offset);
-	int (*in_cb2_func)(int offset);
-	void (*out_a_func)(int offset, int val);
-	void (*out_b_func)(int offset, int val);
-	void (*out_ca2_func)(int offset, int val);
-	void (*out_cb2_func)(int offset, int val);
-	void (*irq_func)(int state);
-
-    /* kludges for the Vectrex */
-	void (*out_shift_func)(int val);
-	void (*t2_callback)(double time);
-#endif
-	NULL,
-	pet_via_port_b_r,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	pet_via_port_b_w,
-	pet_address_line_11
+static struct via6522_interface pet_via = 
+{
+	NULL,					/* in_a_func */
+	pet_via_port_b_r,		/* in_b_func */
+	NULL,					/* in_ca1_func */
+	NULL,					/* in_cb1_func */
+	NULL,					/* in_ca2_func */
+	NULL,					/* in_cb2_func */
+	NULL,					/* out_a_func */
+	pet_via_port_b_w,		/* out_b_func */
+	pet_address_line_11		/* out_ca2_func */
 };
 
 static struct {
@@ -392,28 +366,36 @@ WRITE8_HANDLER(cbm8096_w)
 	}
 }
 
- READ8_HANDLER(superpet_r)
+READ8_HANDLER(superpet_r)
 {
 	return 0xff;
 }
 
-extern WRITE8_HANDLER(superpet_w)
+WRITE8_HANDLER(superpet_w)
 {
-	switch (offset) {
-	case 6:case 7:
-		spet.rom=data&1;
+	switch (offset)
+	{
+		case 0:
+		case 1:
+		case 2:
+		case 3:
+			/* 3: 1 pull down diagnostic pin on the userport
+			   1: 1 if jumpered programable ram r/w
+			   0: 0 if jumpered programable m6809, 1 m6502 selected */
+			break;
 
-		break;
-	case 4:case 5:
-		spet.bank=data&0xf;
-		memory_set_bankptr(3,superpet_memory+(spet.bank<<12));
-		/* 7 low writeprotects systemlatch */
-		break;
-	case 0:case 1:case 2:case 3:
-		/* 3: 1 pull down diagnostic pin on the userport
-		   1: 1 if jumpered programable ram r/w
-		   0: 0 if jumpered programable m6809, 1 m6502 selected */
-		break;
+		case 4:
+		case 5:
+			spet.bank = data & 0xf;
+			memory_configure_bank(1, 0, 16, superpet_memory, 0x1000);
+			memory_set_bank(1, spet.bank);
+			/* 7 low writeprotects systemlatch */
+			break;
+
+		case 6:
+		case 7:
+			spet.rom = data & 1;
+			break;
 	}
 }
 
@@ -428,11 +410,26 @@ static void pet_interrupt(int param)
 static void pet_common_driver_init (void)
 {
 	int i;
+
+	/* BIG HACK; need to phase out this retarded memory management */
+	if (!pet_memory)
+		pet_memory = mess_ram;
+
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, mess_ram_size - 1, 0, 0, MRA8_BANK10);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, mess_ram_size - 1, 0, 0, MWA8_BANK10);
+	memory_set_bankptr(10, pet_memory);
+
+	if (mess_ram_size < 0x8000)
+	{
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, mess_ram_size, 0x7FFF, 0, 0, MRA8_NOP);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, mess_ram_size, 0x7FFF, 0, 0, MWA8_NOP);
+	}
+
 	/* 2114 poweron ? 64 x 0xff, 64x 0, and so on */
-	for (i=0; i<0x8000; i+=0x40) {
+	for (i = 0; i < mess_ram_size; i += 0x40)
+	{
 		memset (pet_memory + i, i & 0x40 ? 0 : 0xff, 0x40);
 	}
-	memset(pet_memory+0xe800, 0xff, 0x800);
 
 	/* pet clock */
 	timer_pulse(0.01, 0, pet_interrupt);
@@ -444,50 +441,49 @@ static void pet_common_driver_init (void)
 	cbm_ieee_open();
 }
 
-void pet_driver_init (void)
+DRIVER_INIT( pet )
 {
 	pet_common_driver_init ();
 	pet_vh_init();
 }
 
-void pet_basic1_driver_init (void)
+DRIVER_INIT( pet1 )
 {
-	pet_basic1=1;
+	pet_basic1 = 1;
 	pet_common_driver_init ();
 	pet_vh_init();
 }
 
-static struct crtc6845_config crtc_pet= { 800000 /*?*/};
+static struct crtc6845_config crtc_pet = { 800000 /*?*/};
 
-void pet40_driver_init (void)
+DRIVER_INIT( pet40 )
 {
 	pet_common_driver_init ();
 	pet_vh_init();
 	crtc6845_init(&crtc_pet);
 }
 
-void cbm80_driver_init (void)
+DRIVER_INIT( cbm80 )
 {
-	cbm8096=1;
+	cbm8096 = 1;
+	pet_memory = memory_region(REGION_CPU1);
+
 	pet_common_driver_init ();
-	videoram_size=0x800;
+	videoram = &pet_memory[0x8000];
+	videoram_size = 0x800;
 	pet80_vh_init();
 	crtc6845_init(&crtc_pet);
 }
 
-void superpet_driver_init(void)
+DRIVER_INIT( superpet )
 {
-	superpet=1;
+	superpet = 1;
 	pet_common_driver_init ();
 
-	superpet_memory=memory_region(REGION_CPU2+0x10000);
+	superpet_memory = auto_malloc(0x10000);
 
-	memory_set_bankptr(3, superpet_memory);
-	memory_set_context(1);
-	memory_set_bankptr(1, pet_memory);
-	memory_set_bankptr(2, pet_memory+0x8000);
-	memory_set_bankptr(3, superpet_memory);
-	memory_set_context(0);
+	memory_configure_bank(1, 0, 16, superpet_memory, 0x1000);
+	memory_set_bank(1, 0);
 
 	superpet_vh_init();
 	crtc6845_init(&crtc_pet);
@@ -498,46 +494,31 @@ MACHINE_INIT( pet )
 	via_reset();
 	pia_reset();
 
-	if (superpet) {
-		spet.rom=0;
-		if (M6809_SELECT) {
+	if (superpet)
+	{
+		spet.rom = 0;
+		if (M6809_SELECT)
+		{
 			cpunum_set_input_line(0, INPUT_LINE_HALT, 1);
 			cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
-			pet_font=2;
-		} else {
+			pet_font = 2;
+		}
+		else
+		{
 			cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
 			cpunum_set_input_line(0, INPUT_LINE_HALT, 1);
-			pet_font=0;
+			pet_font = 0;
 		}
 	}
 
-	switch (MEMORY) {
-	case MEMORY_4:
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x1000, 0x1fff, 0, 0, MWA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_NOP);
-		break;
-	case MEMORY_8:
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x1000, 0x1fff, 0, 0, MWA8_RAM);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_NOP);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_NOP);
-		break;
-	case MEMORY_16:
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x1000, 0x1fff, 0, 0, MWA8_RAM);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_RAM);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_NOP);
-		break;
-	case MEMORY_32:
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x1000, 0x1fff, 0, 0, MWA8_RAM);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_RAM);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_RAM);
-		break;
-	}
-
-	if (cbm8096) {
-		if (CBM8096_MEMORY) {
+	if (cbm8096)
+	{
+		if (CBM8096_MEMORY)
+		{
 			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfff0, 0xfff0, 0, 0, cbm8096_w);
-		} else {
+		}
+		else
+		{
 			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xfff0, 0xfff0, 0, 0, MWA8_NOP);
 		}
 		cbm8096_w(0,0);
