@@ -15,6 +15,7 @@
 #include "driver.h"
 #include "osd_cpu.h"
 #include "driver.h"
+#include "image.h"
 #include "cpu/m6502/m6502.h"
 #include "vidhrdw/generic.h"
 
@@ -56,27 +57,27 @@ UINT8 *vc20_memory_9400;
 */
 static void vc20_via0_irq (int level)
 {
-	cpu_set_nmi_line (0, level);
+	cpunum_set_input_line(0, INPUT_LINE_NMI, level);
 }
 
-static READ_HANDLER( vc20_via0_read_ca1 )
+static  READ8_HANDLER( vc20_via0_read_ca1 )
 {
 	return !KEY_RESTORE;
 }
 
-static READ_HANDLER( vc20_via0_read_ca2 )
+static  READ8_HANDLER( vc20_via0_read_ca2 )
 {
 	DBG_LOG (1, "tape", ("motor read %d\n", via0_ca2));
 	return via0_ca2;
 }
 
-static WRITE_HANDLER( vc20_via0_write_ca2 )
+static WRITE8_HANDLER( vc20_via0_write_ca2 )
 {
 	via0_ca2 = data ? 1 : 0;
 	vc20_tape_motor (via0_ca2);
 }
 
-static READ_HANDLER( vc20_via0_read_porta )
+static  READ8_HANDLER( vc20_via0_read_porta )
 {
 	UINT8 value = 0xff;
 
@@ -101,7 +102,7 @@ static READ_HANDLER( vc20_via0_read_porta )
 	return value;
 }
 
-static WRITE_HANDLER( vc20_via0_write_porta )
+static WRITE8_HANDLER( vc20_via0_write_porta )
 {
 	cbm_serial_atn_write (serial_atn = !(data & 0x80));
 	DBG_LOG (1, "serial out", ("atn %s\n", serial_atn ? "high" : "low"));
@@ -120,10 +121,10 @@ static WRITE_HANDLER( vc20_via0_write_porta )
  */
 static void vc20_via1_irq (int level)
 {
-	cpu_set_irq_line (0, M6502_IRQ_LINE, level);
+	cpunum_set_input_line (0, M6502_IRQ_LINE, level);
 }
 
-static READ_HANDLER( vc20_via1_read_porta )
+static  READ8_HANDLER( vc20_via1_read_porta )
 {
 	int value = 0xff;
 
@@ -154,17 +155,17 @@ static READ_HANDLER( vc20_via1_read_porta )
 	return value;
 }
 
-static READ_HANDLER( vc20_via1_read_ca1 )
+static  READ8_HANDLER( vc20_via1_read_ca1 )
 {
 	return vc20_tape_read ();
 }
 
-static WRITE_HANDLER( vc20_via1_write_ca2 )
+static WRITE8_HANDLER( vc20_via1_write_ca2 )
 {
 	cbm_serial_clock_write (serial_clock = !data);
 }
 
-static READ_HANDLER( vc20_via1_read_portb )
+static  READ8_HANDLER( vc20_via1_read_portb )
 {
 	UINT8 value = 0xff;
 
@@ -275,26 +276,26 @@ static READ_HANDLER( vc20_via1_read_portb )
 	return value;
 }
 
-static WRITE_HANDLER( vc20_via1_write_porta )
+static WRITE8_HANDLER( vc20_via1_write_porta )
 {
 	via1_porta = data;
 }
 
 
-static WRITE_HANDLER( vc20_via1_write_portb )
+static WRITE8_HANDLER( vc20_via1_write_portb )
 {
 /*  if( errorlog ) fprintf(errorlog, "via1_write_portb: $%02X\n", data); */
 	vc20_tape_write (data & 8 ? 1 : 0);
 	via1_portb = data;
 }
 
-static READ_HANDLER( vc20_via1_read_cb1 )
+static  READ8_HANDLER( vc20_via1_read_cb1 )
 {
 	DBG_LOG (1, "serial in", ("request read\n"));
 	return cbm_serial_request_read ();
 }
 
-static WRITE_HANDLER( vc20_via1_write_cb2 )
+static WRITE8_HANDLER( vc20_via1_write_cb2 )
 {
 	cbm_serial_data_write (serial_data = !data);
 }
@@ -310,7 +311,7 @@ static WRITE_HANDLER( vc20_via1_write_cb2 )
   6 ndac in
   7 atn in
  */
-static READ_HANDLER( vc20_via4_read_portb )
+static  READ8_HANDLER( vc20_via4_read_portb )
 {
 	UINT8 data=0;
 	if (cbm_ieee_eoi_r()) data|=8;
@@ -321,7 +322,7 @@ static READ_HANDLER( vc20_via4_read_portb )
 	return data;
 }
 
-static WRITE_HANDLER( vc20_via4_write_portb )
+static WRITE8_HANDLER( vc20_via4_write_portb )
 {
 	cbm_ieee_dav_w(0,data&1);
 	cbm_ieee_nrfd_w(0,data&2);
@@ -335,27 +336,27 @@ static WRITE_HANDLER( vc20_via4_write_portb )
    cb2 eoi out
    ca2 atn out
 */
-static WRITE_HANDLER( vc20_via5_write_porta )
+static WRITE8_HANDLER( vc20_via5_write_porta )
 {
 	cbm_ieee_data_w(0,data);
 }
 
-static READ_HANDLER( vc20_via5_read_portb )
+static  READ8_HANDLER( vc20_via5_read_portb )
 {
 	return cbm_ieee_data_r();
 }
 
-static WRITE_HANDLER( vc20_via5_write_ca2 )
+static WRITE8_HANDLER( vc20_via5_write_ca2 )
 {
 	cbm_ieee_atn_w(0,data);
 }
 
-static READ_HANDLER( vc20_via5_read_cb1 )
+static  READ8_HANDLER( vc20_via5_read_cb1 )
 {
 	return cbm_ieee_srq_r();
 }
 
-static WRITE_HANDLER( vc20_via5_write_cb2 )
+static WRITE8_HANDLER( vc20_via5_write_cb2 )
 {
 	cbm_ieee_eoi_w(0,data);
 }
@@ -370,6 +371,8 @@ static struct via6522_interface via0 =
 	0,								   /*via0_read_cb2, */
 	vc20_via0_write_porta,
 	0,								   /*via0_write_portb, */
+	0,                                 /*via0_write_ca1, */
+	0,                                 /*via0_write_cb1, */
 	vc20_via0_write_ca2,
 	0,								   /*via0_write_cb2, */
 	vc20_via0_irq
@@ -383,6 +386,8 @@ static struct via6522_interface via0 =
 	0,								   /*via1_read_cb2, */
 	vc20_via1_write_porta,								   /*via1_write_porta, */
 	vc20_via1_write_portb,
+	0,                                 /*via1_write_ca1, */
+	0,                                 /*via1_write_cb1, */
 	vc20_via1_write_ca2,
 	vc20_via1_write_cb2,
 	vc20_via1_irq
@@ -398,6 +403,8 @@ via4 =
 	0,								   /*via1_read_cb2, */
 	0,								   /*via1_write_porta, */
 	vc20_via4_write_portb,
+	0,                                 /*via0_write_ca1, */
+	0,                                 /*via0_write_cb1, */
 	0, /*vc20_via5_write_ca2, */
 	0, /*vc20_via5_write_cb2, */
 	vc20_via1_irq
@@ -411,12 +418,14 @@ via4 =
 	0,								   /*via1_read_cb2, */
 	vc20_via5_write_porta,
 	0,/*vc20_via5_write_portb, */
+	0,                                 /*via0_write_ca1, */
+	0,                                 /*via0_write_cb1, */
 	vc20_via5_write_ca2,
 	vc20_via5_write_cb2,
 	vc20_via1_irq
 };
 
-WRITE_HANDLER ( vc20_write_9400 )
+WRITE8_HANDLER ( vc20_write_9400 )
 {
 	vc20_memory_9400[offset] = data | 0xf0;
 }
@@ -430,7 +439,7 @@ int vic6560_dma_read_color (int offset)
 int vic6560_dma_read (int offset)
 {
 	/* should read real system bus between 0x9000 and 0xa000 */
-	return vc20_memory[VIC6560ADDR2VC20ADDR (offset)];
+	return program_read_byte(VIC6560ADDR2VC20ADDR (offset));
 }
 
 static void vc20_memory_init(void)
@@ -485,11 +494,6 @@ static void vc20_common_driver_init (void)
 
 	vc20_tape_open (via_1_ca1_w);
 
-	cbm_drive_open ();
-
-	cbm_drive_attach_fs (0);
-	cbm_drive_attach_fs (1);
-
 #ifdef VC1541
 	vc1541_config (0, 0, &vc1541);
 #endif
@@ -500,23 +504,27 @@ static void vc20_common_driver_init (void)
 /* currently not used, but when time comes */
 void vc20_driver_shutdown (void)
 {
-	cbm_drive_close ();
 	vc20_tape_close ();
 }
 
-void vc20_driver_init (void)
+DRIVER_INIT( vc20 )
 {
 	vc20_common_driver_init ();
 	vic6561_init (vic6560_dma_read, vic6560_dma_read_color);
 }
 
-void vic20_driver_init (void)
+DRIVER_INIT( vic20 )
 {
 	vc20_common_driver_init ();
 	vic6560_init (vic6560_dma_read, vic6560_dma_read_color);
 }
 
-extern void vic20ieee_driver_init (void)
+DRIVER_INIT( vic1001 )
+{
+	init_vic20();
+}
+
+DRIVER_INIT( vic20i )
 {
 	ieee=1;
 	vc20_common_driver_init ();
@@ -526,62 +534,62 @@ extern void vic20ieee_driver_init (void)
 	cbm_ieee_open();
 }
 
-void vc20_init_machine (void)
+MACHINE_INIT( vc20 )
 {
 	if (RAMIN0X0400)
 	{
-		install_mem_write_handler (0, 0x400, 0xfff, MWA_RAM);
-		install_mem_read_handler (0, 0x400, 0xfff, MRA_RAM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x400, 0xfff, 0, 0, MWA8_RAM);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x400, 0xfff, 0, 0, MRA8_RAM);
 	}
 	else
 	{
-		install_mem_write_handler (0, 0x400, 0xfff, MWA_NOP);
-		install_mem_read_handler (0, 0x400, 0xfff, MRA_ROM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x400, 0xfff, 0, 0, MWA8_NOP);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x400, 0xfff, 0, 0, MRA8_ROM);
 	}
 	if (RAMIN0X2000)
 	{
-		install_mem_write_handler (0, 0x2000, 0x3fff, MWA_RAM);
-		install_mem_read_handler (0, 0x2000, 0x3fff, MRA_RAM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_RAM);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MRA8_RAM);
 	}
 	else
 	{
-		install_mem_write_handler (0, 0x2000, 0x3fff, MWA_NOP);
-		install_mem_read_handler (0, 0x2000, 0x3fff, MRA_ROM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MWA8_NOP);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x3fff, 0, 0, MRA8_ROM);
 	}
 	if (RAMIN0X4000)
 	{
-		install_mem_write_handler (0, 0x4000, 0x5fff, MWA_RAM);
-		install_mem_read_handler (0, 0x4000, 0x5fff, MRA_RAM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MWA8_RAM);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MRA8_RAM);
 	}
 	else
 	{
-		install_mem_write_handler (0, 0x4000, 0x5fff, MWA_NOP);
-		install_mem_read_handler (0, 0x4000, 0x5fff, MRA_ROM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MWA8_NOP);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x5fff, 0, 0, MRA8_ROM);
 	}
 	if (RAMIN0X6000)
 	{
-		install_mem_write_handler (0, 0x6000, 0x7fff, MWA_RAM);
-		install_mem_read_handler (0, 0x6000, 0x7fff, MRA_RAM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MWA8_RAM);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_RAM);
 	}
 	else
 	{
-		install_mem_write_handler (0, 0x6000, 0x7fff, MWA_NOP);
-		install_mem_read_handler (0, 0x6000, 0x7fff, MRA_ROM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MWA8_NOP);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_ROM);
 	}
 	if (ieee)
 	{
-		install_mem_write_handler (0, 0xa000, 0xbfff, MWA_ROM);
-		install_mem_read_handler (0, 0xa000, 0xbfff, MRA_ROM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0,MWA8_ROM);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, MRA8_ROM);
 	}
 	else if	(RAMIN0XA000)
 	{
-		install_mem_write_handler (0, 0xa000, 0xbfff, MWA_RAM);
-		install_mem_read_handler (0, 0xa000, 0xbfff, MRA_RAM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0,MWA8_RAM);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, MRA8_RAM);
 	}
 	else
 	{
-		install_mem_write_handler (0, 0xa000, 0xbfff, MWA_NOP);
-		install_mem_read_handler (0, 0xa000, 0xbfff, MRA_ROM);
+		memory_install_write8_handler (0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0,MWA8_NOP);
+		memory_install_read8_handler (0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, MRA8_ROM);
 	}
 
 	cbm_serial_reset_write (0);
@@ -599,83 +607,70 @@ void vc20_init_machine (void)
 	via_0_ca1_w (0, vc20_via0_read_ca1(0) );
 }
 
-void vc20_shutdown_machine (void)
+static int vc20_rom_id(mess_image *img, mame_file *romfile)
 {
-}
-
-static int vc20_rom_id (int id)
-{
-	FILE *romfile;
 	unsigned char magic[] =
 	{0x41, 0x30, 0x20, 0xc3, 0xc2, 0xcd};	/* A0 CBM at 0xa004 (module offset 4) */
 	unsigned char buffer[sizeof (magic)];
-	char *cp;
+	const char *cp;
 	int retval;
 
-	logerror("vc20_rom_id %s\n", device_filename(IO_CARTSLOT,id));
-	if (!(romfile = (FILE*)image_fopen (IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, 0)))
-	{
-		logerror("rom %s not found\n", device_filename(IO_CARTSLOT,id));
-		return 0;
-	}
+	logerror("vc20_rom_id %s\n", image_filename(img));
 
 	retval = 0;
 
-	osd_fseek (romfile, 4, SEEK_SET);
-	osd_fread (romfile, buffer, sizeof (magic));
-	osd_fclose (romfile);
+	mame_fseek (romfile, 4, SEEK_SET);
+	mame_fread (romfile, buffer, sizeof (magic));
 
 	if (!memcmp (buffer, magic, sizeof (magic)))
 		retval = 1;
 
-	if ((cp = strrchr (device_filename(IO_CARTSLOT,id), '.')) != NULL)
+	cp = image_filetype(img);
+	if (cp)
 	{
-		if ((stricmp (cp + 1, "a0") == 0)
-			|| (stricmp (cp + 1, "20") == 0)
-			|| (stricmp (cp + 1, "40") == 0)
-			|| (stricmp (cp + 1, "60") == 0)
-			|| (stricmp (cp + 1, "bin") == 0)
-			|| (stricmp (cp + 1, "rom") == 0)
-			|| (stricmp (cp + 1, "prg") == 0))
+		if ((mame_stricmp (cp, "a0") == 0)
+			|| (mame_stricmp (cp, "20") == 0)
+			|| (mame_stricmp (cp, "40") == 0)
+			|| (mame_stricmp (cp, "60") == 0)
+			|| (mame_stricmp (cp, "bin") == 0)
+			|| (mame_stricmp (cp, "rom") == 0)
+			|| (mame_stricmp (cp, "prg") == 0))
 			retval = 1;
 	}
 
 		if (retval)
-			logerror("rom %s recognized\n", device_filename(IO_CARTSLOT,id));
+			logerror("rom %s recognized\n", image_filename(img));
 		else
-			logerror("rom %s not recognized\n", device_filename(IO_CARTSLOT,id));
+			logerror("rom %s not recognized\n", image_filename(img));
 
 	return retval;
 }
 
-int vc20_rom_load (int id)
+DEVICE_INIT(vc20_rom)
+{
+	vc20_memory_init();
+	return INIT_PASS;
+}
+
+DEVICE_LOAD(vc20_rom)
 {
 	UINT8 *mem = memory_region (REGION_CPU1);
-	FILE *fp;
-	int size, read;
-	char *cp;
+	int size, read_;
+	const char *cp;
 	int addr = 0;
 
-	vc20_memory_init();
-
-	if (device_filename(IO_CARTSLOT,id)==NULL) return 0;
-
-	if (!vc20_rom_id (id))
+	if (!vc20_rom_id(image, file))
 		return 1;
-	fp = (FILE*)image_fopen (IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, 0);
-	if (!fp)
-	{
-		logerror("%s file not found\n", device_filename(IO_CARTSLOT,id));
-		return 1;
-	}
+	mame_fseek (file, 0, SEEK_SET);
 
-	size = osd_fsize (fp);
+	size = mame_fsize (file);
 
-	if ((cp = strrchr (device_filename(IO_CARTSLOT,id), '.')) != NULL)
+	cp = image_filetype(image);
+	if (cp)
 	{
-		if ((cp[1] != 0) && (cp[2] == '0') && (cp[3] == 0))
+		if ((cp[0] != 0) && (cp[1] == '0') && (cp[2] == 0))
 		{
-			switch (toupper (cp[1]))
+			switch (toupper (cp[0]))
 			{
 			case 'A':
 				addr = 0xa000;
@@ -693,11 +688,11 @@ int vc20_rom_load (int id)
 		}
 		else
 		{
-			if (stricmp (cp, ".prg") == 0)
+			if (mame_stricmp (cp, "prg") == 0)
 			{
 				unsigned short in;
 
-				osd_fread_lsbfirst (fp, &in, 2);
+				mame_fread_lsbfirst (file, &in, 2);
 				logerror("rom prg %.4x\n", in);
 				addr = in;
 				size -= 2;
@@ -716,23 +711,15 @@ int vc20_rom_load (int id)
 		}
 	}
 
-	logerror("loading rom %s at %.4x size:%.4x\n",device_filename(IO_CARTSLOT,id), addr, size);
-	read = osd_fread (fp, mem + addr, size);
-	osd_fclose (fp);
-	if (read != size)
+	logerror("loading rom %s at %.4x size:%.4x\n",image_filename(image), addr, size);
+	read_ = mame_fread (file, mem + addr, size);
+	if (read_ != size)
 		return 1;
 	return 0;
 }
 
-
-int vc20_frame_interrupt (void)
+INTERRUPT_GEN( vc20_frame_interrupt )
 {
-	static int quickload = 0;
-
-	if (!quickload && QUICKLOAD)
-		cbm_quick_open (0, 0, vc20_memory);
-	quickload = QUICKLOAD;
-
 	via_0_ca1_w (0, vc20_via0_read_ca1 (0));
 	keyboard[0] = 0xff;
 	if (KEY_DEL) keyboard[0]&=~0x80;
@@ -817,6 +804,4 @@ int vc20_frame_interrupt (void)
 	vc20_tape_config (DATASSETTE, DATASSETTE_TONE);
 	vc20_tape_buttons (DATASSETTE_PLAY, DATASSETTE_RECORD, DATASSETTE_STOP);
 	set_led_status (1 /*KB_CAPSLOCK_FLAG */ , KEY_SHIFT_LOCK ? 1 : 0);
-
-	return ignore_interrupt ();
 }
