@@ -15,25 +15,23 @@
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
-
+#include "image.h"
 #include "includes/vtech2.h"
+#include "devices/cassette.h"
+#include "sound/speaker.h"
 
 /* public */
-int laser_latch = -1;
+int laser_latch;
 
 /* static */
-static UINT8 *mem = NULL;
-static int laser_bank_mask = 0x0000;	/* up to 16 4K banks supported */
-static int laser_bank[4] = {-1,-1,-1,-1};
-static int laser_video_bank = 0;
-
-static UINT8 *cassette_image = NULL;
+static UINT8 *mem;
+static int laser_bank_mask;	/* up to 16 4K banks supported */
+static int laser_bank[4];
+static int laser_video_bank;
 
 #define TRKSIZE_VZ	0x9a0	/* arbitrary (actually from analyzing format) */
 #define TRKSIZE_FM	3172	/* size of a standard FM mode track */
 
-static int flop_specified[2] = {0, 0};
-static void *laser_fdc_file[2] = {NULL, NULL};
 static UINT8 laser_track_x2[2] = {80, 80};
 static UINT8 laser_fdc_wrprot[2] = {0x80, 0x80};
 static UINT8 laser_fdc_status = 0;
@@ -51,22 +49,22 @@ static int laser_fdc_latch = 0;
 static void mwa_bank(int bank, int offs, int data);
 
 /* wrappers for bank #1 to #4 */
-static WRITE_HANDLER ( mwa_bank1 ) { mwa_bank(0,offset,data); }
-static WRITE_HANDLER ( mwa_bank2 ) { mwa_bank(1,offset,data); }
-static WRITE_HANDLER ( mwa_bank3 ) { mwa_bank(2,offset,data); }
-static WRITE_HANDLER ( mwa_bank4 ) { mwa_bank(3,offset,data); }
+static WRITE8_HANDLER ( mwa_bank1 ) { mwa_bank(0,offset,data); }
+static WRITE8_HANDLER ( mwa_bank2 ) { mwa_bank(1,offset,data); }
+static WRITE8_HANDLER ( mwa_bank3 ) { mwa_bank(2,offset,data); }
+static WRITE8_HANDLER ( mwa_bank4 ) { mwa_bank(3,offset,data); }
 
 /* read from banked memory (handle memory mapped i/o) */
 static int mra_bank(int bank, int offs);
 
 /* wrappers for bank #1 to #4 */
-static READ_HANDLER ( mra_bank1) { return mra_bank(0,offset); }
-static READ_HANDLER ( mra_bank2) { return mra_bank(1,offset); }
-static READ_HANDLER ( mra_bank3) { return mra_bank(2,offset); }
-static READ_HANDLER ( mra_bank4) { return mra_bank(3,offset); }
+static  READ8_HANDLER ( mra_bank1) { return mra_bank(0,offset); }
+static  READ8_HANDLER ( mra_bank2) { return mra_bank(1,offset); }
+static  READ8_HANDLER ( mra_bank3) { return mra_bank(2,offset); }
+static  READ8_HANDLER ( mra_bank4) { return mra_bank(3,offset); }
 
 /* read banked memory (handle memory mapped i/o) */
-static mem_read_handler mra_bank_soft[4] =
+static read8_handler mra_bank_soft[4] =
 {
     mra_bank1,  /* mapped in 0000-3fff */
     mra_bank2,  /* mapped in 4000-7fff */
@@ -75,7 +73,7 @@ static mem_read_handler mra_bank_soft[4] =
 };
 
 /* write banked memory (handle memory mapped i/o and videoram) */
-static mem_write_handler mwa_bank_soft[4] =
+static write8_handler mwa_bank_soft[4] =
 {
     mwa_bank1,  /* mapped in 0000-3fff */
     mwa_bank2,  /* mapped in 4000-7fff */
@@ -84,90 +82,83 @@ static mem_write_handler mwa_bank_soft[4] =
 };
 
 /* read banked memory (plain ROM/RAM) */
-static mem_read_handler mra_bank_hard[4] =
+static read8_handler mra_bank_hard[4] =
 {
-    MRA_BANK1,  /* mapped in 0000-3fff */
-    MRA_BANK2,  /* mapped in 4000-7fff */
-    MRA_BANK3,  /* mapped in 8000-bfff */
-    MRA_BANK4   /* mapped in c000-ffff */
+    MRA8_BANK1,  /* mapped in 0000-3fff */
+    MRA8_BANK2,  /* mapped in 4000-7fff */
+    MRA8_BANK3,  /* mapped in 8000-bfff */
+    MRA8_BANK4   /* mapped in c000-ffff */
 };
 
 /* write banked memory (plain ROM/RAM) */
-static mem_write_handler mwa_bank_hard[4] =
+static write8_handler mwa_bank_hard[4] =
 {
-    MWA_BANK1,  /* mapped in 0000-3fff */
-    MWA_BANK2,  /* mapped in 4000-7fff */
-    MWA_BANK3,  /* mapped in 8000-bfff */
-    MWA_BANK4   /* mapped in c000-ffff */
+    MWA8_BANK1,  /* mapped in 0000-3fff */
+    MWA8_BANK2,  /* mapped in 4000-7fff */
+    MWA8_BANK3,  /* mapped in 8000-bfff */
+    MWA8_BANK4   /* mapped in c000-ffff */
 };
 
-void init_laser(void)
+DRIVER_INIT(laser)
 {
     UINT8 *gfx = memory_region(REGION_GFX2);
     int i;
-    for (i = 0; i < 256; i++)
+
+	for (i = 0; i < 256; i++)
         gfx[i] = i;
-}
 
-void laser350_init_machine(void)
-{
+	laser_latch = -1;
     mem = memory_region(REGION_CPU1);
-	/* banks 0 to 3 only, optional ROM extension */
-	laser_bank_mask = 0xf00f;
-    laser_video_bank = 3;
-	videoram = mem + laser_video_bank * 0x04000;
-	logerror("laser350 init machine: bank mask $%04X, video %d [$%05X]\n", laser_bank_mask, laser_video_bank, laser_video_bank * 0x04000);
+
+	for (i = 0; i < sizeof(laser_bank) / sizeof(laser_bank[0]); i++)
+		laser_bank[i] = -1;
 }
 
-void laser500_init_machine(void)
-{
-    mem = memory_region(REGION_CPU1);
-	/* banks 0 to 2, and 4-7 only , optional ROM extension */
-	laser_bank_mask = 0xf0f7;
-    laser_video_bank = 7;
-    videoram = mem + laser_video_bank * 0x04000;
-	logerror("laser500 init machine: bank mask $%04X, video %d [$%05X]\n", laser_bank_mask, laser_video_bank, laser_video_bank * 0x04000);
-}
 
-void laser700_init_machine(void)
-{
-    mem = memory_region(REGION_CPU1);
-	/* all banks except #3 */
-	laser_bank_mask = 0xfff7;
-    laser_video_bank = 7;
-    videoram = mem + laser_video_bank * 0x04000;
-	logerror("laser700 init machine: bank mask $%04X, video %d [$%05X]\n", laser_bank_mask, laser_video_bank, laser_video_bank * 0x04000);
-}
 
-void laser_shutdown_machine(void)
+static void laser_machine_init(int bank_mask, int video_mask)
 {
     int i;
-    for( i = 0; i < 2; i++ )
-    {
-        if( laser_fdc_file[i] )
-            osd_fclose(laser_fdc_file[i]);
-        laser_fdc_file[i] = NULL;
-    }
+
+	laser_bank_mask = bank_mask;
+    laser_video_bank = video_mask;
+	videoram = mem + laser_video_bank * 0x04000;
+	logerror("laser_machine_init(): bank mask $%04X, video %d [$%05X]\n", laser_bank_mask, laser_video_bank, laser_video_bank * 0x04000);
+
+	for (i = 0; i < sizeof(laser_bank) / sizeof(laser_bank[0]); i++)
+		laser_bank_select_w(i, 0);
 }
 
-static WRITE_HANDLER ( mwa_empty )
+MACHINE_INIT( laser350 )
 {
-	/* empty */
+	/* banks 0 to 3 only, optional ROM extension */
+	laser_machine_init(0xf00f, 3);
 }
 
-static READ_HANDLER ( mra_empty )
+MACHINE_INIT( laser500 )
 {
-	return 0xff;
+	/* banks 0 to 2, and 4-7 only , optional ROM extension */
+	laser_machine_init(0xf0f7, 7);
 }
 
-WRITE_HANDLER( laser_bank_select_w )
+MACHINE_INIT( laser700 )
+{
+	/* all banks except #3 */
+	laser_machine_init(0xfff7, 7);
+}
+
+
+WRITE8_HANDLER( laser_bank_select_w )
 {
     static const char *bank_name[16] = {
         "ROM lo","ROM hi","MM I/O","Video RAM lo",
         "RAM #0","RAM #1","RAM #2","RAM #3",
         "RAM #4","RAM #5","RAM #6","RAM #7/Video RAM hi",
         "ext ROM #0","ext ROM #1","ext ROM #2","ext ROM #3"};
+	read8_handler read_handler;
+	write8_handler write_handler;
 
+	offset %= 4;
     data &= 15;
 
 	if( data != laser_bank[offset] )
@@ -178,36 +169,40 @@ WRITE_HANDLER( laser_bank_select_w )
         /* memory mapped I/O bank selected? */
 		if (data == 2)
 		{
-			memory_set_bankhandler_r(1+offset,0,mra_bank_soft[offset]);
-			memory_set_bankhandler_w(1+offset,0,mwa_bank_soft[offset]);
+			read_handler = mra_bank_soft[offset];
+			write_handler = mwa_bank_soft[offset];
 		}
 		else
 		{
-			cpu_setbank(offset+1, &mem[0x4000*laser_bank[offset]]);
+			memory_set_bankptr(offset+1, &mem[0x4000*laser_bank[offset]]);
 			if( laser_bank_mask & (1 << data) )
 			{
-				memory_set_bankhandler_r(1+offset,0,mra_bank_hard[offset]);
+				read_handler = mra_bank_hard[offset];
+				write_handler = mwa_bank_hard[offset];
+
 				/* video RAM bank selected? */
 				if( data == laser_video_bank )
 				{
 					logerror("select bank #%d VIDEO!\n", offset+1);
-                    memory_set_bankhandler_w(1+offset,0,mwa_bank_soft[offset]);
-				}
-				else
-				{
-					memory_set_bankhandler_w(1+offset,0,mwa_bank_hard[offset]);
 				}
 			}
 			else
 			{
 				logerror("select bank #%d MASKED!\n", offset+1);
-				memory_set_bankhandler_r(1+offset,0,mra_empty);
-				memory_set_bankhandler_w(1+offset,0,mwa_empty);
+				read_handler = return8_FF;
+				write_handler = MWA8_NOP;
 			}
 		}
+		memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, offset * 0x4000, offset * 0x4000 + 0x3fff, 0, 0, read_handler);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, offset * 0x4000, offset * 0x4000 + 0x3fff, 0, 0, write_handler);
     }
 }
 
+static mess_image *vtech2_cassette_image(void)
+{
+	return image_from_devtype_and_index(IO_CASSETTE, 0);
+}
+
 /*************************************************
  * memory mapped I/O read
  * bit  function
@@ -284,7 +279,7 @@ static int mra_bank(int bank, int offs)
 	}
 
     /* what's bit 7 good for? tape input maybe? */
-	level = device_input(IO_CASSETTE, 0);
+	level = cassette_input(vtech2_cassette_image()) * 65536.0;
 	if( level < level_old - 511 )
 		cassette_bit = 0x00;
 	if( level > level_old + 511 )
@@ -326,10 +321,6 @@ static void mwa_bank(int bank, int offs, int data)
                 schedule_full_refresh();
 			if ((data ^ laser_latch) & 0x01)
 				speaker_level_w(0, data & 1);
-#if 0
-            if ((data ^ laser_latch) & 0x06)
-				device_output(IO_CASSETTE, 0, data & 6);
-#endif
             laser_latch = data;
         }
         break;
@@ -350,251 +341,50 @@ static void mwa_bank(int bank, int offs, int data)
     }
 }
 
-int laser_rom_init(int id)
+DEVICE_LOAD( laser_cart )
 {
 	int size = 0;
-    void *file;
 
-	if (device_filename(IO_CARTSLOT,id) == NULL)
-		return INIT_PASS;
+	size = mame_fread(file, &mem[0x30000], 0x10000);
+	laser_bank_mask &= ~0xf000;
+	if( size > 0 )
+		laser_bank_mask |= 0x1000;
+	if( size > 0x4000 )
+		laser_bank_mask |= 0x2000;
+	if( size > 0x8000 )
+		laser_bank_mask |= 0x4000;
+	if( size > 0xc000 )
+		laser_bank_mask |= 0x8000;
 
-	file = image_fopen(IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-    if( file )
-    {
-		size = osd_fread(file, &mem[0x30000], 0x10000);
-        osd_fclose(file);
-		laser_bank_mask &= ~0xf000;
-		if( size > 0 )
-			laser_bank_mask |= 0x1000;
-		if( size > 0x4000 )
-			laser_bank_mask |= 0x2000;
-		if( size > 0x8000 )
-			laser_bank_mask |= 0x4000;
-		if( size > 0xc000 )
-			laser_bank_mask |= 0x8000;
-    }
-    if( size > 0 )
-        return INIT_PASS;
-    return INIT_FAIL;
+	return size > 0 ? INIT_PASS : INIT_FAIL;
 }
 
-void laser_rom_exit(int id)
+DEVICE_UNLOAD( laser_cart )
 {
 	laser_bank_mask &= ~0xf000;
 	/* wipe out the memory contents to be 100% sure */
 	memset(&mem[0x30000], 0xff, 0x10000);
 }
 
-#define LO	-20000
-#define HI	+20000
-
-#define BITSAMPLES	18
-#define BYTESAMPLES 8*BITSAMPLES
-#define SILENCE 8000
-
-static INT16 bit0[BITSAMPLES] =
+DEVICE_LOAD( laser_floppy )
 {
-	/* short cycle, long cycles */
-	HI,HI,HI,LO,LO,LO,
-	HI,HI,HI,HI,HI,HI,
-	LO,LO,LO,LO,LO,LO
-};
-
-static INT16 bit1[BITSAMPLES] =
-{
-	/* three short cycle */
-	HI,HI,HI,LO,LO,LO,
-	HI,HI,HI,LO,LO,LO,
-	HI,HI,HI,LO,LO,LO
-};
-
-
-static INT16 *fill_wave_bit(INT16 *buffer, int bit)
-{
-	int i;
-	if( bit )
-	{
-		for( i = 0; i < BITSAMPLES; i++ )
-			*buffer++ = bit1[i];
-    }
-	else
-	{
-		for( i = 0; i < BITSAMPLES; i++ )
-			*buffer++ = bit0[i];
-    }
-	return buffer;
-}
-
-
-static INT16 *fill_wave_byte(INT16 *buffer, int byte)
-{
-	buffer = fill_wave_bit(buffer, (byte >> 7) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 6) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 5) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 4) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 3) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 2) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 1) & 1);
-	buffer = fill_wave_bit(buffer, (byte >> 0) & 1);
-    return buffer;
-}
-
-static int fill_wave(INT16 *buffer, int length, UINT8 *code)
-{
-	static int nullbyte;
-
-    if( code == CODE_HEADER )
-    {
-		int i;
-
-        if( length < SILENCE )
-			return -1;
-		for( i = 0; i < SILENCE; i++ )
-			*buffer++ = 0;
-
-		nullbyte = 0;
-
-        return SILENCE;
-    }
-
-	if( code == CODE_TRAILER )
-    {
-		int i;
-
-        /* silence at the end */
-		for( i = 0; i < length; i++ )
-			*buffer++ = 0;
-        return length;
-    }
-
-    if( length < BYTESAMPLES )
-		return -1;
-
-	buffer = fill_wave_byte(buffer, *code);
-
-    if( !nullbyte && *code == 0 )
-	{
-		int i;
-		for( i = 0; i < 2*BITSAMPLES; i++ )
-			*buffer++ = LO;
-        nullbyte = 1;
-		return BYTESAMPLES + 2 * BITSAMPLES;
-	}
-
-    return BYTESAMPLES;
-}
-
-/*
-int laser_cassette_verify (UINT8 buff[])
-{
-	int i;
-
-	for( i = 0; i < 128; i++ )
-		if( buff[i] != 0x80 )
-			return INIT_FAIL;
-	for( i = 128; i < 128+5; i++ )
-		if( buff[i] != 0xfe )
-			return INIT_FAIL;
-	for( i = 128+5+1; i < 128+5+1+17; i++ )
-	{
-		if( buff[i] == 0x00 )
-			break;
-	}
-	if( i == 128+5+1+17 )
-		return 1;
-	if( buff[128+5] == 0xf0 )
-	{
-		logerror("vtech2_cassette_id: BASIC magic $%02X '%s' found\n", buff[128+5], buff+128+5+1);
-		return INIT_PASS;
-	}
-	if( buff[128+5] == 0xf1 )
-	{
-		logerror("vtech2_cassette_id: MCODE magic $%02X '%s' found\n", buff[128+5], buff+128+5+1);
-		return INIT_PASS;
-	}
-	return INIT_FAIL;
-}
-*/
-
-int laser_cassette_init(int id)
-{
-	void *file;
-	if (device_filename(IO_CASSETTE,id) == NULL)
-		return INIT_PASS;
-
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if( file )
-	{
-		struct wave_args wa = {0,};
-		wa.file = file;
-		wa.display = 1;
-		wa.fill_wave = fill_wave;
-		wa.smpfreq = 600*BITSAMPLES;
-		wa.header_samples = SILENCE;
-		wa.trailer_samples = SILENCE;
-		wa.chunk_size = 1;
-		wa.chunk_samples = BYTESAMPLES;
-		if( device_open(IO_CASSETTE,id,0,&wa) )
-			return INIT_FAIL;
-		return INIT_PASS;
-    }
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_RW_CREATE);
-	if( file )
-    {
-		struct wave_args wa = {0,};
-		wa.file = file;
-		wa.display = 1;
-		wa.fill_wave = fill_wave;
-		wa.smpfreq = 600*BITSAMPLES;
-		if( device_open(IO_CASSETTE,id,1,&wa) )
-			return INIT_FAIL;
-        return INIT_PASS;
-    }
-    return INIT_FAIL;
-}
-
-void laser_cassette_exit(int id)
-{
-	if( cassette_image )
-		free(cassette_image);
-	cassette_image = NULL;
-}
-
-int laser_floppy_init(int id)
-{
-	void *file;
 	UINT8 buff[32];
 
-	if (device_filename(IO_FLOPPY,id) == NULL)
-	{
-		flop_specified[id] = 0;
-		return INIT_PASS;
-	}
-	else
-		flop_specified[id] = 1;
-
-	file = image_fopen(IO_FLOPPY, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-    if( file )
-    {
-        osd_fread(file, buff, sizeof(buff));
-		osd_fclose(file);
-		if( memcmp(buff, "\x80\x80\x80\x80\x80\x80\x00\xfe\0xe7\0x18\0xc3\x00\x00\x00\x80\x80", 16) == 0 )
-			return INIT_PASS;
-	}
-	else
-	{
+	mame_fread(file, buff, sizeof(buff));
+	if (memcmp(buff, "\x80\x80\x80\x80\x80\x80\x00\xfe\0xe7\0x18\0xc3\x00\x00\x00\x80\x80", 16))
 		return INIT_FAIL;
-	}
 
 	return INIT_PASS;
 }
 
-void laser_floppy_exit(int id)
+static mame_file *laser_file(void)
 {
-    if( laser_fdc_file[id] )
-        osd_fclose(laser_fdc_file[id]);
-    laser_fdc_file[id] = NULL;
-	flop_specified[id] = 0;
+	mess_image *image;
+	mame_file *file;
+
+	image = image_from_devtype_and_index(IO_FLOPPY, laser_drive);
+	file = image_fp(image);
+	return file;
 }
 
 static void laser_get_track(void)
@@ -602,13 +392,13 @@ static void laser_get_track(void)
     sprintf(laser_frame_message, "#%d get track %02d", laser_drive, laser_track_x2[laser_drive]/2);
     laser_frame_time = 30;
     /* drive selected or and image file ok? */
-    if( laser_drive >= 0 && laser_fdc_file[laser_drive] != NULL )
+    if( laser_drive >= 0 && laser_file() != NULL )
     {
         int size, offs;
         size = TRKSIZE_VZ;
         offs = TRKSIZE_VZ * laser_track_x2[laser_drive]/2;
-        osd_fseek(laser_fdc_file[laser_drive], offs, SEEK_SET);
-        size = osd_fread(laser_fdc_file[laser_drive], laser_fdc_data, size);
+        mame_fseek(laser_file(), offs, SEEK_SET);
+        size = mame_fread(laser_file(), laser_fdc_data, size);
         logerror("get track @$%05x $%04x bytes\n", offs, size);
     }
     laser_fdc_offs = 0;
@@ -618,12 +408,12 @@ static void laser_get_track(void)
 static void laser_put_track(void)
 {
     /* drive selected and image file ok? */
-    if( laser_drive >= 0 && laser_fdc_file[laser_drive] != NULL )
+    if( laser_drive >= 0 && laser_file() != NULL )
     {
         int size, offs;
         offs = TRKSIZE_VZ * laser_track_x2[laser_drive]/2;
-        osd_fseek(laser_fdc_file[laser_drive], offs + laser_fdc_start, SEEK_SET);
-        size = osd_fwrite(laser_fdc_file[laser_drive], &laser_fdc_data[laser_fdc_start], laser_fdc_write);
+        mame_fseek(laser_file(), offs + laser_fdc_start, SEEK_SET);
+        size = mame_fwrite(laser_file(), &laser_fdc_data[laser_fdc_start], laser_fdc_write);
         logerror("put track @$%05X+$%X $%04X/$%04X bytes\n", offs, laser_fdc_start, size, laser_fdc_write);
     }
 }
@@ -633,7 +423,7 @@ static void laser_put_track(void)
 #define PHI2(n) (((n)>>2)&1)
 #define PHI3(n) (((n)>>3)&1)
 
-READ_HANDLER( laser_fdc_r )
+ READ8_HANDLER( laser_fdc_r )
 {
     int data = 0xff;
     switch( offset )
@@ -677,7 +467,7 @@ READ_HANDLER( laser_fdc_r )
     return data;
 }
 
-WRITE_HANDLER( laser_fdc_w )
+WRITE8_HANDLER( laser_fdc_w )
 {
     int drive;
 
