@@ -1,26 +1,177 @@
 /***************************************************************************
 
-  WD179X.c
+	wd179x.c
 
-  Functions to emulate a WD179x floppy disc controller
-
-  KT - Removed disk image code and replaced it with floppy drive functions.
-	   Any disc image is now useable with this code.
-	 - fixed write protect
+	Implementations of the Western Digitial 17xx and 19xx families of
+	floppy disk controllers
 
 
- TODO:
-	 - Multiple record read/write
-	 - What happens if a track is read that doesn't have any id's on it?
-	   (e.g. unformatted disc)
+	Kevin Thacker
+		- Removed disk image code and replaced it with floppy drive functions.
+		  Any disc image is now useable with this code.
+		- Fixed write protect
+				  
+	2005-Apr-16 P.Harvey-Smith:
+		- Increased the delay in wd179x_timed_read_sector_request and
+		  wd179x_timed_write_sector_request, to 40us to more closely match
+		  what happens on the real hardware, this has fixed the NitrOS9 boot
+		  problems.
+  
+	TODO:
+		- Multiple record read/write
+		- What happens if a track is read that doesn't have any id's on it?
+	     (e.g. unformatted disc)
+
 ***************************************************************************/
 
+
 #include "driver.h"
 #include "includes/wd179x.h"
-#include "includes/flopdrv.h"
+#include "devices/flopdrv.h"
 
-#define VERBOSE 1
-#define VERBOSE_DATA 0		/* This turns on and off the recording of each byte during read and write */
+
+/***************************************************************************
+
+	Parameters
+
+***************************************************************************/
+
+#define VERBOSE			0	/* General logging */
+#define VERBOSE_DATA	0	/* Logging of each byte during read and write */
+
+#define DELAY_ERROR		3
+#define DELAY_NOTREADY	1
+#define DELAY_DATADONE	3
+
+
+
+/***************************************************************************
+
+	Constants
+
+***************************************************************************/
+
+#define TYPE_I			1
+#define TYPE_II 		2
+#define TYPE_III		3
+#define TYPE_IV 		4
+
+#define FDC_STEP_RATE   0x03    /* Type I additional flags */
+#define FDC_STEP_VERIFY 0x04	/* verify track number */
+#define FDC_STEP_HDLOAD 0x08	/* load head */
+#define FDC_STEP_UPDATE 0x10	/* update track register */
+
+#define FDC_RESTORE 	0x00	/* Type I commands */
+#define FDC_SEEK		0x10
+#define FDC_STEP		0x20
+#define FDC_STEP_IN 	0x40
+#define FDC_STEP_OUT	0x60
+
+#define FDC_MASK_TYPE_I 		(FDC_STEP_HDLOAD|FDC_STEP_VERIFY|FDC_STEP_RATE)
+
+/* Type I commands status */
+#define STA_1_BUSY		0x01	/* controller is busy */
+#define STA_1_IPL		0x02	/* index pulse */
+#define STA_1_TRACK0	0x04	/* track 0 detected */
+#define STA_1_CRC_ERR	0x08	/* CRC error */
+#define STA_1_SEEK_ERR	0x10	/* seek error */
+#define STA_1_HD_LOADED 0x20	/* head loaded */
+#define STA_1_WRITE_PRO 0x40	/* floppy is write protected */
+#define STA_1_NOT_READY 0x80	/* controller not ready */
+
+/* Type II and III additional flags */
+#define FDC_DELETED_AM	0x01	/* read/write deleted address mark */
+#define FDC_SIDE_CMP_T	0x02	/* side compare track data */
+#define FDC_15MS_DELAY	0x04	/* delay 15ms before command */
+#define FDC_SIDE_CMP_S	0x08	/* side compare sector data */
+#define FDC_MULTI_REC	0x10	/* only for type II commands */
+
+/* Type II commands */
+#define FDC_READ_SEC	0x80	/* read sector */
+#define FDC_WRITE_SEC	0xA0	/* write sector */
+
+#define FDC_MASK_TYPE_II		(FDC_MULTI_REC|FDC_SIDE_CMP_S|FDC_15MS_DELAY|FDC_SIDE_CMP_T|FDC_DELETED_AM)
+
+/* Type II commands status */
+#define STA_2_BUSY		0x01
+#define STA_2_DRQ		0x02
+#define STA_2_LOST_DAT	0x04
+#define STA_2_CRC_ERR	0x08
+#define STA_2_REC_N_FND 0x10
+#define STA_2_REC_TYPE	0x20
+#define STA_2_WRITE_PRO 0x40
+#define STA_2_NOT_READY 0x80
+
+#define FDC_MASK_TYPE_III		(FDC_SIDE_CMP_S|FDC_15MS_DELAY|FDC_SIDE_CMP_T|FDC_DELETED_AM)
+
+/* Type III commands */
+#define FDC_READ_DAM	0xc0	/* read data address mark */
+#define FDC_READ_TRK	0xe0	/* read track */
+#define FDC_WRITE_TRK	0xf0	/* write track (format) */
+
+/* Type IV additional flags */
+#define FDC_IM0 		0x01	/* interrupt mode 0 */
+#define FDC_IM1 		0x02	/* interrupt mode 1 */
+#define FDC_IM2 		0x04	/* interrupt mode 2 */
+#define FDC_IM3 		0x08	/* interrupt mode 3 */
+
+#define FDC_MASK_TYPE_IV		(FDC_IM3|FDC_IM2|FDC_IM1|FDC_IM0)
+
+/* Type IV commands */
+#define FDC_FORCE_INT	0xd0	/* force interrupt */
+
+
+
+/***************************************************************************
+
+	Structures
+
+***************************************************************************/
+
+typedef struct
+{
+	void   (*callback)(int event);   /* callback for IRQ status */
+	DENSITY   density;				/* FM/MFM, single / double density */
+	wd179x_type_t type;
+	UINT8	track_reg;				/* value of track register */
+	UINT8	data;					/* value of data register */
+	UINT8	command;				/* last command written */
+	UINT8	command_type;			/* last command type */
+	UINT8	sector; 				/* current sector # */
+
+	UINT8	read_cmd;				/* last read command issued */
+	UINT8	write_cmd;				/* last write command issued */
+	INT8	direction;				/* last step direction */
+
+	UINT8	status; 				/* status register */
+	UINT8	status_drq; 			/* status register data request bit */
+	UINT8	status_ipl; 			/* status register toggle index pulse bit */
+	UINT8	busy_count; 			/* how long to keep busy bit set */
+
+	UINT8	buffer[6144];			/* I/O buffer (holds up to a whole track) */
+	UINT32	data_offset;			/* offset into I/O buffer */
+	INT32	data_count; 			/* transfer count from/into I/O buffer */
+
+	UINT8	*fmt_sector_data[256];	/* pointer to data after formatting a track */
+
+	UINT8	dam_list[256][4];		/* list of data address marks while formatting */
+	int 	dam_data[256];			/* offset to data inside buffer while formatting */
+	int 	dam_cnt;				/* valid number of entries in the dam_list */
+	UINT16	sector_length;			/* sector length (byte) */
+
+	UINT8	ddam;					/* ddam of sector found - used when reading */
+	UINT8	sector_data_id;
+	mame_timer	*timer, *timer_rs, *timer_ws;
+	int		data_direction;
+}	WD179X;
+
+
+
+/***************************************************************************
+
+	Read track stuff
+
+***************************************************************************/
 
 /* structure describing a double density track */
 #define TRKSIZE_DD		6144
@@ -66,41 +217,58 @@ static UINT8 track_SD[][2] = {
 };
 #endif
 
-static void wd179x_complete_command(WD179X *, int);
+
+
+/***************************************************************************
+
+	Prototypes
+
+***************************************************************************/
+
+static void wd179x_complete_command(WD179X *, int delay);
 static void wd179x_clear_data_request(void);
 static void wd179x_set_data_request(void);
 static void wd179x_timed_data_request(void);
 static void wd179x_set_irq(WD179X *);
-static void *busy_timer = NULL;
+static mame_timer *busy_timer = NULL;
 
 /* one wd controlling multiple drives */
 static WD179X wd;
+
 /* this is the drive currently selected */
-static UINT8 drv = 0;
+static UINT8 current_drive;
+
 /* this is the head currently selected */
 static UINT8 hd = 0;
 
+/**************************************************************************/
+
+static mess_image *wd179x_current_image(void)
+{
+	return image_from_devtype_and_index(IO_FLOPPY, current_drive);
+}
+
+
+
 /* use this to determine which drive is controlled by WD */
 void wd179x_set_drive(UINT8 drive)
 {
-#if VERBOSE
-	if( drive != drv )
-	logerror("wd179x_set_drive: $%02x\n", drive);
-#endif
-
-	drv = drive;
+	current_drive = drive;
 }
 
+
+
 void wd179x_set_side(UINT8 head)
 {
 #if VERBOSE
 	if( head != hd )
-	logerror("wd179x_set_side: $%02x\n", head);
+		logerror("wd179x_set_side: $%02x\n", head);
 #endif
-
 	hd = head;
 }
 
+
+
 void wd179x_set_density(DENSITY density)
 {
 	WD179X *w = &wd;
@@ -114,6 +282,7 @@ void wd179x_set_density(DENSITY density)
 }
 
 
+
 static void	wd179x_busy_callback(int dummy)
 {
 	WD179X *w = (WD179X *)dummy;
@@ -122,14 +291,12 @@ static void	wd179x_busy_callback(int dummy)
 	timer_reset(busy_timer, TIME_NEVER);
 }
 
+
+
 static void wd179x_set_busy(WD179X *w, double milliseconds)
 {
-	if (busy_timer)
-	{
-		timer_remove(busy_timer);
-	}
 	w->status |= STA_1_BUSY;
-	busy_timer = timer_set(TIME_IN_MSEC(milliseconds), (int)w, wd179x_busy_callback);
+	timer_adjust(busy_timer, TIME_IN_MSEC(milliseconds), (int)w, 0);
 }
 
 
@@ -138,49 +305,64 @@ static void wd179x_set_busy(WD179X *w, double milliseconds)
 
 static void wd179x_restore(WD179X *w)
 {
-		UINT8 step_counter = 255;
+	UINT8 step_counter;
+	
+	if (current_drive >= device_count(IO_FLOPPY))
+		return;
+
+	step_counter = 255;
 		
 #if 0
-		w->status |= STA_1_BUSY;
+	w->status |= STA_1_BUSY;
 #endif
 
-		/* setup step direction */
-		w->direction = -1;
+	/* setup step direction */
+	w->direction = -1;
 
-		w->command_type = TYPE_I;
+	w->command_type = TYPE_I;
 
-		/* reset busy count */
-		w->busy_count = 0;
+	/* reset busy count */
+	w->busy_count = 0;
 
+	if (image_slotexists(wd179x_current_image()))
+	{
 		/* keep stepping until track 0 is received or 255 steps have been done */
-		while (!(floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_HEAD_AT_TRACK_0)) && (step_counter!=0))
+		while (!(floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_HEAD_AT_TRACK_0)) && (step_counter!=0))
 		{
 			/* update time to simulate seek time busy signal */
 			w->busy_count++;
-			floppy_drive_seek(drv, w->direction);
+			floppy_drive_seek(wd179x_current_image(), w->direction);
 			step_counter--;
 		}
+	}
 
-		/* update track reg */
-		w->track_reg = 0;
+	/* update track reg */
+	w->track_reg = 0;
 #if 0
-		/* simulate seek time busy signal */
-		w->busy_count = 0;	/*w->busy_count * ((w->data & FDC_STEP_RATE) + 1); */
+	/* simulate seek time busy signal */
+	w->busy_count = 0;	/*w->busy_count * ((w->data & FDC_STEP_RATE) + 1); */
 	
-		/* when command completes set irq */
-		wd179x_set_irq(w);
+	/* when command completes set irq */
+	wd179x_set_irq(w);
 #endif
-		wd179x_set_busy(w,0.1);
-
+	wd179x_set_busy(w,0.1);
 }
 
-void	wd179x_reset(void)
+
+
+void wd179x_reset(void)
 {
 	wd179x_restore(&wd);
 }
 
 
-void wd179x_init(int type,void (*callback)(int))
+
+static void	wd179x_busy_callback(int dummy);
+static void	wd179x_misc_timer_callback(int code);
+static void	wd179x_read_sector_callback(int code);
+static void	wd179x_write_sector_callback(int code);
+
+void wd179x_init(wd179x_type_t type, void (*callback)(int))
 {
 	memset(&wd, 0, sizeof(WD179X));
 	wd.status = STA_1_TRACK0;
@@ -188,64 +370,22 @@ void wd179x_init(int type,void (*callback)(int))
 	wd.callback = callback;
 /*	wd.status_ipl = STA_1_IPL; */
 	wd.density = DEN_MFM_LO;
-	busy_timer = NULL;
+	busy_timer = mame_timer_alloc(wd179x_busy_callback);
+	wd.timer = mame_timer_alloc(wd179x_misc_timer_callback);
+	wd.timer_rs = mame_timer_alloc(wd179x_read_sector_callback);
+	wd.timer_ws = mame_timer_alloc(wd179x_write_sector_callback);
 
 	wd179x_reset();
-
-#if 0
-
-	for (i = 0; i < MAX_DRIVES; i++)
-	{
-		wd[i] = malloc(sizeof(WD179X));
-		if (!wd[i])
-		{
-			while (--i >= 0)
-			{
-				free(wd[i]);
-				wd[i] = 0;
-			}
-			return;
-		}
-		memset(wd[i], 0, sizeof(WD179X));
-		wd[i]->unit = 0;
-		wd[i]->tracks = 40;
-		wd[i]->heads = 1;
-		wd[i]->density = DEN_MFM_LO;
-		wd[i]->offset = 0;
-		wd[i]->first_sector_id = 0;
-		wd[i]->sec_per_track = 18;
-		wd[i]->sector_length = 256;
-		wd[i]->head = 0;
-		wd[i]->track = 0;
-		wd[i]->track_reg = 0;
-		wd[i]->direction = 1;
-		wd[i]->sector = 0;
-		wd[i]->data = 0;
-		wd[i]->status = (active) ? STA_1_TRACK0 : 0;
-		wd[i]->status_drq = 0;
-		wd[i]->status_ipl = 0;
-		wd[i]->busy_count = 0;
-		wd[i]->data_offset = 0;
-		wd[i]->data_count = 0;
-		wd[i]->image_name = 0;
-		wd[i]->image_size = 0;
-		wd[i]->dir_sector = 0;
-		wd[i]->dir_length = 0;
-		wd[i]->secmap = 0;
-		wd[i]->timer = NULL;
-		wd[i]->timer_rs = NULL;
-		wd[i]->timer_ws = NULL;
-	}
-#endif
 }
 
+
+
 static void write_track(WD179X * w)
 {
-
-
-
 }
 
+
+
 /* read an entire track */
 static void read_track(WD179X * w)
 {
@@ -343,7 +483,7 @@ static void read_track(WD179X * w)
 				pdst--; 	   /* go back one byte */
 				if (seek(w, t, h, s) == 0)
 				{
-					if (osd_fread(w->image_file, pdst, l) != l)
+					if (mame_fread(w->image_file, pdst, l) != l)
 					{
 						w->status = STA_2_CRC_ERR;
 						return;
@@ -370,7 +510,7 @@ static void read_track(WD179X * w)
 
 	w->data_count = (w->density) ? TRKSIZE_DD : TRKSIZE_SD;
 
-	floppy_drive_read_track_data_info_buffer( drv, hd, (char *)w->buffer, &(w->data_count) );
+	floppy_drive_read_track_data_info_buffer( wd179x_current_image(), hd, (char *)w->buffer, &(w->data_count) );
 	
 	w->data_offset = 0;
 
@@ -379,49 +519,7 @@ static void read_track(WD179X * w)
 	w->busy_count = 0;
 }
 
-/* currently a empty function - to be completed! */
-void	wd179x_exit(void)
-{
-	WD179X *w = &wd;
 
-	if (busy_timer!=NULL)
-	{
-		timer_remove(busy_timer);
-		busy_timer = NULL;
-	}
-
-	if (w->timer!=NULL)
-	{
-		timer_remove(w->timer);
-		w->timer = NULL;
-	}
-
-	if (w->timer_rs!=NULL)
-	{
-		timer_remove(w->timer_rs);
-		w->timer = NULL;
-	}
-
-	if (w->timer_ws!=NULL)
-	{
-		timer_remove(w->timer_ws);
-		w->timer_ws = NULL;
-	}
-}
-
-#if 0
-void wd179x_stop_drive(void)
-{
-	WD179X *w = &wd;
-
-	w->busy_count = 0;
-	w->status = 0;
-	w->status_drq = 0;
-	if (w->callback)
-		(*w->callback) (WD179X_DRQ_CLR);
-	w->status_ipl = 0;
-}
-#endif
 
 /* calculate CRC for data address marks or sector data */
 static void calc_crc(UINT16 * crc, UINT8 value)
@@ -446,6 +544,8 @@ static void calc_crc(UINT16 * crc, UINT8 value)
 	*crc = *crc ^ l;
 }
 
+
+
 /* read the next data address mark */
 static void wd179x_read_id(WD179X * w)
 {
@@ -454,7 +554,7 @@ static void wd179x_read_id(WD179X * w)
 	w->status &= ~(STA_2_CRC_ERR | STA_2_REC_N_FND);
 
 	/* get next id from disc */
-	if (floppy_drive_get_next_id(drv, hd, &id))
+	if (floppy_drive_get_next_id(wd179x_current_image(), hd, &id))
 	{
 		UINT16 crc = 0xffff;
 
@@ -495,11 +595,12 @@ static void wd179x_read_id(WD179X * w)
 		/*w->sector = w->track_reg; */
 		logerror("read id failed\n");
 
-		wd179x_complete_command(w, 1);
+		wd179x_complete_command(w, DELAY_ERROR);
 	}
 }
 
 
+
 static int wd179x_find_sector(WD179X *w)
 {
 	UINT8 revolution_count;
@@ -511,7 +612,7 @@ static int wd179x_find_sector(WD179X *w)
 
 	while (revolution_count!=4)
 	{
-		if (floppy_drive_get_next_id(drv, hd, &id))
+		if (floppy_drive_get_next_id(wd179x_current_image(), hd, &id))
 		{
 			/* compare track */
 			if (id.C == w->track_reg)
@@ -533,7 +634,7 @@ static int wd179x_find_sector(WD179X *w)
 		}
 
 		 /* index set? */
-		if (floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_INDEX))
+		if (floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_INDEX))
 		{
 			/* update revolution count */
 			revolution_count++;
@@ -546,11 +647,13 @@ static int wd179x_find_sector(WD179X *w)
 #if VERBOSE
 	logerror("track %d sector %d not found!\n", w->track_reg, w->sector);
 #endif
-	wd179x_complete_command(w, 1);
+	wd179x_complete_command(w, DELAY_ERROR);
 
 	return 0;
 }
 
+
+
 /* read a sector */
 static void wd179x_read_sector(WD179X *w)
 {
@@ -561,7 +664,7 @@ static void wd179x_read_sector(WD179X *w)
 		w->data_count = w->sector_length;
 
 		/* read data */
-		floppy_drive_read_sector_data(drv, hd, w->sector_data_id, (char *)w->buffer, w->sector_length);
+		floppy_drive_read_sector_data(wd179x_current_image(), hd, w->sector_data_id, (char *)w->buffer, w->sector_length);
 
 		wd179x_timed_data_request();
 
@@ -570,6 +673,8 @@ static void wd179x_read_sector(WD179X *w)
 	}
 }
 
+
+
 static void	wd179x_set_irq(WD179X *w)
 {
 	w->status &= ~STA_2_BUSY;
@@ -578,16 +683,40 @@ static void	wd179x_set_irq(WD179X *w)
 		(*w->callback) (WD179X_IRQ_SET);
 }
 
-static void wd179x_complete_command_callback(int dummy)
+
+
+/* 0=command callback; 1=data callback */
+enum
+{
+	MISCCALLBACK_COMMAND,
+	MISCCALLBACK_DATA
+};
+
+
+
+static void wd179x_misc_timer_callback(int callback_type)
 {
 	WD179X *w = &wd;
 
-	wd179x_set_irq(w);
+	switch(callback_type) {
+	case MISCCALLBACK_COMMAND:
+		/* command callback */
+		wd179x_set_irq(w);
+		break;
+
+	case MISCCALLBACK_DATA:
+		/* data callback */
+		/* ok, trigger data request now */
+		wd179x_set_data_request();
+		break;
+	}
 
 	/* stop it, but don't allow it to be free'd */
 	timer_reset(w->timer, TIME_NEVER); 
 }
 
+
+
 /* called on error, or when command is actually completed */
 /* KT - I have used a timer for systems that use interrupt driven transfers.
 A interrupt occurs after the last byte has been read. If it occurs at the time
@@ -607,17 +736,12 @@ static void wd179x_complete_command(WD179X *w, int delay)
 	usecs = floppy_drive_get_datarate_in_us(w->density);
 	usecs *= delay;
 
-	/* remove old timer if it exists */
-	if (w->timer!=NULL)
-	{
-		timer_remove(w->timer);
-		w->timer = NULL;
-	}
-
 	/* set new timer */
-	w->timer = timer_set(TIME_IN_USEC(usecs), 0, wd179x_complete_command_callback);
+	timer_adjust(w->timer, TIME_IN_USEC(usecs), MISCCALLBACK_COMMAND, 0);
 }
 
+
+
 static void wd179x_write_sector(WD179X *w)
 {
 	/* at this point, the disc is write enabled, and data
@@ -631,11 +755,12 @@ static void wd179x_write_sector(WD179X *w)
 		w->data_count = w->sector_length;
 
 		/* write data */
-		floppy_drive_write_sector_data(drv, hd, w->sector_data_id, (char *)w->buffer, w->sector_length,w->write_cmd & 0x01);
+		floppy_drive_write_sector_data(wd179x_current_image(), hd, w->sector_data_id, (char *)w->buffer, w->sector_length,w->write_cmd & 0x01);
 	}
 }
 
 
+
 /* verify the seek operation by looking for a id that has a matching track value */
 static void wd179x_verify_seek(WD179X *w)
 {
@@ -651,7 +776,7 @@ static void wd179x_verify_seek(WD179X *w)
 	/* must be found within 5 revolutions otherwise error */
 	while (revolution_count!=5)
 	{
-		if (floppy_drive_get_next_id(drv, hd, &id))
+		if (floppy_drive_get_next_id(wd179x_current_image(), hd, &id))
 		{
 			/* compare track */
 			if (id.C == w->track_reg)
@@ -662,7 +787,7 @@ static void wd179x_verify_seek(WD179X *w)
 		}
 
 		 /* index set? */
-		if (floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_INDEX))
+		if (floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_INDEX))
 		{
 			/* update revolution count */
 			revolution_count++;
@@ -675,6 +800,7 @@ static void wd179x_verify_seek(WD179X *w)
 }
 
 
+
 /* clear a data request */
 static void wd179x_clear_data_request(void)
 {
@@ -686,6 +812,8 @@ static void wd179x_clear_data_request(void)
 	w->status &= ~STA_2_DRQ;
 }
 
+
+
 /* set data request */
 static void wd179x_set_data_request(void)
 {
@@ -704,20 +832,9 @@ static void wd179x_set_data_request(void)
 	w->status |= STA_2_DRQ;
 }
 
-/* callback for data transfers */
-static void	wd179x_data_timer_callback(int code)
-{
-	WD179X *w = &wd;
 
-	/* ok, trigger data request now */
-	wd179x_set_data_request();
-
-	/* stop it, but don't allow it to be free'd */
-	timer_reset(w->timer, TIME_NEVER); 
-}
 
 /* callback to initiate read sector */
-
 static void	wd179x_read_sector_callback(int code)
 {
 	WD179X *w = &wd;
@@ -728,18 +845,18 @@ static void	wd179x_read_sector_callback(int code)
 	logerror("wd179x: Read Sector callback.\n");
 #endif
 
-	if (!floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_READY))
-		wd179x_complete_command(w, 1);
+	if (!floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_READY))
+		wd179x_complete_command(w, DELAY_NOTREADY);
 	else
 		wd179x_read_sector(w);
 
 	/* stop it, but don't allow it to be free'd */
-	if (w->timer_rs !=NULL)
-		timer_reset(w->timer_rs, TIME_NEVER); 
+	timer_reset(w->timer_rs, TIME_NEVER); 
 }
 
-/* callback to initiate write sector */
 
+
+/* callback to initiate write sector */
 static void	wd179x_write_sector_callback(int code)
 {
 	WD179X *w = &wd;
@@ -750,17 +867,17 @@ static void	wd179x_write_sector_callback(int code)
 	logerror("wd179x: Write Sector callback.\n");
 #endif
 
-	if (!floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_READY))
-		wd179x_complete_command(w, 1);
+	if (!floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_READY))
+		wd179x_complete_command(w, DELAY_NOTREADY);
 	else
 	{
 
 		/* drive write protected? */
-		if (floppy_drive_get_flag_state(drv,FLOPPY_DRIVE_DISK_WRITE_PROTECTED))
+		if (floppy_drive_get_flag_state(wd179x_current_image(),FLOPPY_DRIVE_DISK_WRITE_PROTECTED))
 		{
 			w->status |= STA_2_WRITE_PRO;
 
-			wd179x_complete_command(w, 1);
+			wd179x_complete_command(w, DELAY_ERROR);
 		}
 		else
 		{
@@ -780,10 +897,11 @@ static void	wd179x_write_sector_callback(int code)
 	}
 
 	/* stop it, but don't allow it to be free'd */
-	if (w->timer_ws !=NULL)
-		timer_reset(w->timer_ws, TIME_NEVER); 
+	timer_reset(w->timer_ws, TIME_NEVER); 
 }
 
+
+
 /* setup a timed data request - data request will be triggered in a few usecs time */
 static void wd179x_timed_data_request(void)
 {
@@ -792,58 +910,42 @@ static void wd179x_timed_data_request(void)
 
 	usecs = floppy_drive_get_datarate_in_us(w->density);
 
-	/* remove old timer if it exists */
-	if (w->timer!=NULL)
-	{
-		timer_remove(w->timer);
-		w->timer = NULL;
-	}
-
 	/* set new timer */
-	w->timer = timer_set(TIME_IN_USEC(usecs), 0, wd179x_data_timer_callback);
+	timer_adjust(w->timer, TIME_IN_USEC(usecs), MISCCALLBACK_DATA, 0);
 }
 
+
+
 /* setup a timed read sector - read sector will be triggered in a few usecs time */
 static void wd179x_timed_read_sector_request(void)
 {
 	int usecs;
 	WD179X *w = &wd;
 
-	usecs = 20; /* How long should we wait? How about 20 micro seconds? */
-
-	/* remove old timer if it exists */
-	if (w->timer_rs !=NULL)
-	{
-		timer_remove(w->timer_rs);
-		w->timer_rs = NULL;
-	}
+	usecs = 40; /* How long should we wait? How about 40 micro seconds? */
 
 	/* set new timer */
-	w->timer_rs = timer_set(TIME_IN_USEC(usecs), 0, wd179x_read_sector_callback);
+	timer_reset(w->timer_rs, TIME_IN_USEC(usecs));
 }
 
+
+
 /* setup a timed write sector - write sector will be triggered in a few usecs time */
 static void wd179x_timed_write_sector_request(void)
 {
 	int usecs;
 	WD179X *w = &wd;
 
-	usecs = 20; /* How long should we wait? How about 20 micro seconds? */
-
-	/* remove old timer if it exists */
-	if (w->timer_ws !=NULL)
-	{
-		timer_remove(w->timer_ws);
-		w->timer_ws = NULL;
-	}
+	usecs = 40; /* How long should we wait? How about 40 micro seconds? */
 
 	/* set new timer */
-	w->timer_ws = timer_set(TIME_IN_USEC(usecs), 0, wd179x_write_sector_callback);
+	timer_reset(w->timer_ws, TIME_IN_USEC(usecs));
 }
 
 
+
 /* read the FDC status register. This clears IRQ line too */
-READ_HANDLER ( wd179x_status_r )
+ READ8_HANDLER ( wd179x_status_r )
 {
 	WD179X *w = &wd;
 	int result = w->status;
@@ -861,7 +963,7 @@ READ_HANDLER ( wd179x_status_r )
 	{
 
 		/* if disc present toggle index pulse */
-		if (floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_DISK_INSERTED))
+		if (image_exists(wd179x_current_image()))
 		{
 			/* eventually toggle index pulse bit */
 			w->status ^= STA_1_IPL;
@@ -869,20 +971,20 @@ READ_HANDLER ( wd179x_status_r )
 
 		/* set track 0 state */
 		result &=~STA_1_TRACK0;
-		if (floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_HEAD_AT_TRACK_0))
+		if (floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_HEAD_AT_TRACK_0))
 			result |= STA_1_TRACK0;
 
-	/*	floppy_drive_set_ready_state(drv, 1,1); */
+	/*	floppy_drive_set_ready_state(wd179x_current_image(), 1,1); */
 		w->status &= ~STA_1_NOT_READY;
 		
 		if (w->type == WD_TYPE_179X)
 		{
-			if (!floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_READY))
+			if (!floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_READY))
 				w->status |= STA_1_NOT_READY;
 		}
 		else
 		{
-			if (floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_READY))
+			if (floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_READY))
 				w->status |= STA_1_NOT_READY;
 		}
 	}
@@ -899,8 +1001,10 @@ READ_HANDLER ( wd179x_status_r )
 	return result;
 }
 
+
+
 /* read the FDC track register */
-READ_HANDLER ( wd179x_track_r )
+ READ8_HANDLER ( wd179x_track_r )
 {
 	WD179X *w = &wd;
 
@@ -910,8 +1014,10 @@ READ_HANDLER ( wd179x_track_r )
 	return w->track_reg;
 }
 
+
+
 /* read the FDC sector register */
-READ_HANDLER ( wd179x_sector_r )
+ READ8_HANDLER ( wd179x_sector_r )
 {
 	WD179X *w = &wd;
 
@@ -921,8 +1027,10 @@ READ_HANDLER ( wd179x_sector_r )
 	return w->sector;
 }
 
+
+
 /* read the FDC data register */
-READ_HANDLER ( wd179x_data_r )
+ READ8_HANDLER ( wd179x_data_r )
 {
 	WD179X *w = &wd;
 
@@ -957,7 +1065,11 @@ READ_HANDLER ( wd179x_data_r )
 		/*	w->sector++; */
 			/* Delay the INTRQ 3 byte times becuase we need to read two CRC bytes and
 			   compare them with a calculated CRC */
-			wd179x_complete_command(w, 3);
+			wd179x_complete_command(w, DELAY_DATADONE);
+
+#if VERBOSE
+			logerror("wd179x_data_r(): data read completed\n");
+#endif
 		}
 		else
 		{
@@ -972,16 +1084,18 @@ READ_HANDLER ( wd179x_data_r )
 	return w->data;
 }
 
+
+
 /* write the FDC command register */
-WRITE_HANDLER ( wd179x_command_w )
+WRITE8_HANDLER ( wd179x_command_w )
 {
 	WD179X *w = &wd;
-
-	floppy_drive_set_motor_state(drv, 1);
-	floppy_drive_set_ready_state(drv, 1,0);
+	
+	floppy_drive_set_motor_state(wd179x_current_image(), 1);
+	floppy_drive_set_ready_state(wd179x_current_image(), 1,0);
 	/* also cleared by writing command */
 	if (w->callback)
-			(*w->callback) (WD179X_IRQ_CLR);
+		(*w->callback) (WD179X_IRQ_CLR);
 
 	/* clear write protected. On read sector, read track and read dam, write protected bit is clear */
 	w->status &= ~((1<<6) | (1<<5) | (1<<4));
@@ -1075,20 +1189,20 @@ WRITE_HANDLER ( wd179x_command_w )
 			w->status &= ~STA_2_LOST_DAT;
 			wd179x_clear_data_request();
 
-			if (!floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_READY))
+			if (!floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_READY))
             {
-				wd179x_complete_command(w, 1);
+				wd179x_complete_command(w, DELAY_NOTREADY);
             }
             else
             {
     
                 /* drive write protected? */
-                if (floppy_drive_get_flag_state(drv,FLOPPY_DRIVE_DISK_WRITE_PROTECTED))
+                if (floppy_drive_get_flag_state(wd179x_current_image(),FLOPPY_DRIVE_DISK_WRITE_PROTECTED))
                 {
                     /* yes */
                     w->status |= STA_2_WRITE_PRO;
                     /* quit command */
-                    wd179x_complete_command(w, 1);
+                    wd179x_complete_command(w, DELAY_ERROR);
                 }
                 else
                 {
@@ -1113,9 +1227,9 @@ WRITE_HANDLER ( wd179x_command_w )
 			w->status &= ~STA_2_LOST_DAT;
   			wd179x_clear_data_request();
 
-			if (!floppy_drive_get_flag_state(drv, FLOPPY_DRIVE_READY))
+			if (!floppy_drive_get_flag_state(wd179x_current_image(), FLOPPY_DRIVE_READY))
             {
-				wd179x_complete_command(w, 1);
+				wd179x_complete_command(w, DELAY_NOTREADY);
             }
             else
             {
@@ -1185,7 +1299,7 @@ WRITE_HANDLER ( wd179x_command_w )
 			/* update track reg */
 			w->track_reg += w->direction;
 
-			floppy_drive_seek(drv, w->direction);
+			floppy_drive_seek(wd179x_current_image(), w->direction);
 		}
 
 		/* simulate seek time busy signal */
@@ -1207,7 +1321,7 @@ WRITE_HANDLER ( wd179x_command_w )
 		/* simulate seek time busy signal */
 		w->busy_count = 0;	/*((data & FDC_STEP_RATE) + 1); */
 
-		floppy_drive_seek(drv, w->direction);
+		floppy_drive_seek(wd179x_current_image(), w->direction);
 
 		if (data & FDC_STEP_UPDATE)
 			w->track_reg += w->direction;
@@ -1230,7 +1344,7 @@ WRITE_HANDLER ( wd179x_command_w )
 		/* simulate seek time busy signal */
 		w->busy_count = 0;	/*((data & FDC_STEP_RATE) + 1); */
 
-		floppy_drive_seek(drv, w->direction);
+		floppy_drive_seek(wd179x_current_image(), w->direction);
 
 		if (data & FDC_STEP_UPDATE)
 			w->track_reg += w->direction;
@@ -1252,7 +1366,7 @@ WRITE_HANDLER ( wd179x_command_w )
 		w->busy_count = 0;	/*((data & FDC_STEP_RATE) + 1); */
 
 		/* for now only allows a single drive to be selected */
-		floppy_drive_seek(drv, w->direction);
+		floppy_drive_seek(wd179x_current_image(), w->direction);
 
 		if (data & FDC_STEP_UPDATE)
 			w->track_reg += w->direction;
@@ -1280,8 +1394,10 @@ WRITE_HANDLER ( wd179x_command_w )
 	}
 }
 
+
+
 /* write the FDC track register */
-WRITE_HANDLER ( wd179x_track_w )
+WRITE8_HANDLER ( wd179x_track_w )
 {
 	WD179X *w = &wd;
 	w->track_reg = data;
@@ -1291,8 +1407,10 @@ WRITE_HANDLER ( wd179x_track_w )
 #endif
 }
 
+
+
 /* write the FDC sector register */
-WRITE_HANDLER ( wd179x_sector_w )
+WRITE8_HANDLER ( wd179x_sector_w )
 {
 	WD179X *w = &wd;
 	w->sector = data;
@@ -1301,8 +1419,10 @@ WRITE_HANDLER ( wd179x_sector_w )
 #endif
 }
 
+
+
 /* write the FDC data register */
-WRITE_HANDLER ( wd179x_data_w )
+WRITE8_HANDLER ( wd179x_data_w )
 {
 	WD179X *w = &wd;
 
@@ -1327,7 +1447,7 @@ WRITE_HANDLER ( wd179x_data_w )
 			else
 				wd179x_write_sector(w);
 
-			wd179x_complete_command(w, 3);
+			wd179x_complete_command(w, DELAY_DATADONE);
 		}
 		else
 		{
@@ -1336,13 +1456,55 @@ WRITE_HANDLER ( wd179x_data_w )
 		}
 
 	}
-#if VERBOSE
 	else
 	{
+#if VERBOSE
 		logerror("wd179x_data_w $%02X\n", data);
-	}
 #endif
+	}
 	w->data = data;
 }
 
 
+
+ READ8_HANDLER( wd179x_r )
+{
+	UINT8 result = 0;
+
+	switch(offset % 4) {
+	case 0: 
+		result = wd179x_status_r(0);
+		break;
+	case 1: 
+		result = wd179x_track_r(0);
+		break;
+	case 2: 
+		result = wd179x_sector_r(0);
+		break;
+	case 3: 
+		result = wd179x_data_r(0);
+		break;
+	}
+	return result;
+}
+
+
+
+WRITE8_HANDLER( wd179x_w )
+{
+	switch(offset % 4) {
+	case 0:
+		wd179x_command_w(0, data);
+		break;
+	case 1:
+		wd179x_track_w(0, data);
+		break;
+	case 2:
+		wd179x_sector_w(0, data);
+		break;
+	case 3:
+		wd179x_data_w(0, data);
+		break;
+	}
+}
+
