@@ -84,7 +84,7 @@ static struct {
 
 } speech={ 0 };
 
-void c364_speech_timer(int arg)
+static void c364_speech_timer(int arg)
 {
 	if (!speech.playing) return;
 
@@ -93,12 +93,18 @@ void c364_speech_timer(int arg)
 	} else {
 		speech.endOfSample=
 				(memcmp(speech.sample.data,"\xff\xff\xff\xff\xff\xff",6)==0);
-		/*speech.endOfSample=true; */
-		speech.busy=false;
+		/*speech.endOfSample=TRUE; */
+		speech.busy=FALSE;
 	}
 }
 
-WRITE_HANDLER(c364_speech_w)
+void c364_speech_init(void)
+{
+	memset(&speech, 0, sizeof(speech));
+	speech.timer = timer_alloc(c364_speech_timer);
+}
+
+WRITE8_HANDLER(c364_speech_w)
 {
 	DBG_LOG (2, "364", ("port write %.2x %.2x\n", offset, data));
 	switch (offset) {
@@ -108,22 +114,19 @@ WRITE_HANDLER(c364_speech_w)
 			case 0:
 				switch (speech.command.data) {
 				case 9:case 0xb:
-					speech.playing=false;
+					speech.playing=FALSE;
 					break;
 				case 1: /* start */
-					speech.timer=timer_pulse(1.0/8000, 0, c364_speech_timer);
-					speech.playing=true;
-					speech.endOfSample=false;
+					timer_adjust(speech.timer, 0, 0, 1.0/8000);
+					speech.playing=TRUE;
+					speech.endOfSample=FALSE;
 					speech.sampleindex=0;
 					break;
 				case 2:
-					speech.endOfSample=false;
-					/*speech.busy=false; */
-					if (speech.timer) {
-						timer_remove(speech.timer);
-						speech.timer=0;
-					}
-					speech.playing=false;
+					speech.endOfSample=FALSE;
+					/*speech.busy=FALSE; */
+					timer_reset(speech.timer, TIME_NEVER);
+					speech.playing=FALSE;
 					break;
 				case 5: /* set rate (in next nibble) */
 					speech.command.state=1;
@@ -160,14 +163,14 @@ WRITE_HANDLER(c364_speech_w)
 							   speech.sample.data[5]));
 			speech.sample.index=0;
 			/*speech.endOfSample=false; */
-			speech.busy=true;
+			speech.busy=TRUE;
 			speech.state=0;
 		}
 		break;
 	}
 }
 
-READ_HANDLER(c364_speech_r)
+ READ8_HANDLER(c364_speech_r)
 {
 	int data=0xff;
 	switch (offset) {
