@@ -113,7 +113,7 @@ static int detect_super_chip(void)
 }
 
 
-static DEVICE_LOAD( a2600_cart )
+static int device_load_a2600_cart(mess_image *image, mame_file *file)
 {
 	cart_size = mame_fsize(file);
 
@@ -672,14 +672,23 @@ ROM_START( a2600 )
 ROM_END
 
 
-static void a2600_cartslot_getinfo(struct IODevice *dev)
+static void a2600_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "bin\0a26\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_a2600_cart;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+		case DEVINFO_INT_MUST_BE_LOADED:				info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_a2600_cart; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "bin,a26"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(a2600)
