@@ -40,34 +40,34 @@ icq3250a-d
  */
 
 #include "driver.h"
-
 #include "includes/comquest.h"
+#include "devices/cartslot.h"
 
-READ_HANDLER(comquest_read)
+static  READ8_HANDLER(comquest_read)
 {
 	UINT8 data=0;
 	logerror("comquest read %.4x %.2x\n",offset,data);
 	return data;
 }
 
-WRITE_HANDLER(comquest_write)
+static WRITE8_HANDLER(comquest_write)
 {
 	logerror("comquest read %.4x %.2x\n",offset,data);
 }
 
-static MEMORY_READ_START( comquest_readmem )
-/*	{ 0x0000, 0x7fff, MRA_BANK1 }, */
-	{ 0x0000, 0xffff, MRA_ROM },
-/*	{ 0x8000, 0xffff, MRA_RAM }, // batterie buffered */
-MEMORY_END
+static ADDRESS_MAP_START( comquest_readmem , ADDRESS_SPACE_PROGRAM, 8)
+/*	{ 0x0000, 0x7fff, MRA8_BANK1 }, */
+	AM_RANGE( 0x0000, 0xffff) AM_READ( MRA8_ROM )
+/*	{ 0x8000, 0xffff, MRA8_RAM }, // batterie buffered */
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( comquest_writemem )
-	{ 0x0000, 0x7fff, MWA_ROM },
-	{ 0x8000, 0xffff, MWA_RAM },
-MEMORY_END
+static ADDRESS_MAP_START( comquest_writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x7fff) AM_WRITE( MWA8_ROM )
+	AM_RANGE( 0x8000, 0xffff) AM_WRITE( MWA8_RAM )
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, r)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode) PORT_CODE(r)
 
 INPUT_PORTS_START( comquest )
 	PORT_START
@@ -171,7 +171,7 @@ INPUT_PORTS_START( comquest )
 
 INPUT_PORTS_END
 
-static struct GfxLayout comquest_charlayout =
+static gfx_layout comquest_charlayout =
 {
         8,8,
         256*8,                                    /* 256 characters */
@@ -202,113 +202,95 @@ static struct GfxLayout comquest_charlayout =
         8*8
 };
 
-static struct GfxDecodeInfo comquest_gfxdecodeinfo[] = {
+static gfx_decode comquest_gfxdecodeinfo[] = {
 	{ REGION_GFX1, 0x0000, &comquest_charlayout,                     0, 2 },
     { -1 } /* end of array */
 };
 
-static int comquest_frame_int(void)
+static unsigned char comquest_palette[] =
 {
-	return 0;
-}
-
-static unsigned char comquest_palette[2][3] =
-{
-	{ 0, 0, 0 },
-	{ 255,255,255 }
+	0, 0, 0,
+	255,255,255
 };
 
 static unsigned short comquest_colortable[1][2] = {
 	{ 0, 1 },
 };
 
-static void comquest_init_colors (unsigned char *sys_palette,
-							  unsigned short *sys_colortable,
-							  const unsigned char *color_prom)
+static PALETTE_INIT( comquest )
 {
-	memcpy (sys_palette, comquest_palette, sizeof (comquest_palette));
-	memcpy(sys_colortable, comquest_colortable,sizeof(comquest_colortable));
+	palette_set_colors(0, comquest_palette, sizeof(comquest_palette) / 3);
+	memcpy(colortable, comquest_colortable,sizeof(comquest_colortable));
 }
 
-static void comquest_machine_init(void)
+static MACHINE_INIT( comquest )
 {
 /*	UINT8 *mem=memory_region(REGION_USER1); */
-/*	cpu_setbank(1,mem+0x00000); */
+/*	memory_set_bankptr(1,mem+0x00000); */
 }
 
 UINT32 amask= 0xffff;
 
-static struct MachineDriver machine_driver_comquest =
-{
+
+static MACHINE_DRIVER_START( comquest )
 	/* basic machine hardware */
-	{
-		{
-			CPU_M6805,
-/*			CPU_HD63705, // instruction set looks like m6805/m6808 */
-/*			CPU_M68705, // instruction set looks like m6805/m6808 */
+	MDRV_CPU_ADD(M6805, 4000000)		/* 4000000? */
+	/*MDRV_CPU_ADD(HD63705, 4000000)	instruction set looks like m6805/m6808 */
+	/*MDRV_CPU_ADD(M68705, 4000000)	instruction set looks like m6805/m6808 */
+
 /*
-  8 bit bus, integrated io, serial io?,
+	8 bit bus, integrated io, serial io?,
 
-  starts at address zero?
+	starts at address zero?
 
-  not saturn, although very similar hardware compared to hp48g (build into big plastic case)
-  not sc61860, 62015?
-  not cdp1802
-  not tms9900?
-  not z80
-  not 6502, mitsubishi 740
-  not i86
-  not 6809
-  not 68008?
-  not tms32010
-  not t11
-  not arm
-  not 8039
-  not tms370
-  not lh5801
-  not fujitsu mb89150
-  not epson e0c88
+	not saturn, although very similar hardware compared to hp48g (build into big plastic case)
+	not sc61860, 62015?
+	not cdp1802
+	not tms9900?
+	not z80
+	not 6502, mitsubishi 740
+	not i86
+	not 6809
+	not 68008?
+	not tms32010
+	not t11
+	not arm
+	not 8039
+	not tms370
+	not lh5801
+	not fujitsu mb89150
+	not epson e0c88
 */
-			4000000, /*? */
-			comquest_readmem,comquest_writemem,0,0,
-			comquest_frame_int, 1,
-			0,0,
-			&amask
-        }
-	},
-	/* frames per second, VBL duration */
-	60, DEFAULT_60HZ_VBLANK_DURATION, /* lcd! */
-	1,				/* single CPU */
-	comquest_machine_init,
-	0,/*pc1401_machine_stop, */
 
-	/* 160 x 102 */
-	64*4, 128, { 0, 64*4 - 1, 0, 128 - 1},
-	comquest_gfxdecodeinfo,			   /* graphics decode info */
-	/* 16 out of 4096 */
-	sizeof (comquest_palette) / sizeof (comquest_palette[0]) ,
-	sizeof (comquest_colortable) / sizeof(comquest_colortable[0][0]),
-	comquest_init_colors,		/* convert color prom */
+	MDRV_CPU_PROGRAM_MAP(comquest_readmem,comquest_writemem)
+	MDRV_CPU_CONFIG( amask )
+	MDRV_FRAMES_PER_SECOND(LCD_FRAMES_PER_SECOND)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
 
-	VIDEO_TYPE_RASTER,	/* video flags */
-	0,						/* obsolete */
-    comquest_vh_start,
-	comquest_vh_stop,
-	comquest_vh_screenrefresh,
+	MDRV_MACHINE_INIT( comquest )
+
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(64*4, 128)	/* 160 x 102 */
+	MDRV_VISIBLE_AREA(0, 64*4-1, 0, 128-1)
+	MDRV_GFXDECODE( comquest_gfxdecodeinfo )
+	MDRV_PALETTE_LENGTH( sizeof(comquest_palette) / 3)
+	MDRV_COLORTABLE_LENGTH( sizeof(comquest_colortable) / sizeof(comquest_colortable[0][0]) )
+	MDRV_PALETTE_INIT( comquest )
+
+	MDRV_VIDEO_START( comquest )
+	MDRV_VIDEO_UPDATE( comquest )
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		/* unknown ? */
-		{ 0 }
-    }
-};
+	/* unknown ? */
+MACHINE_DRIVER_END
 
 ROM_START(comquest)
 /*	ROM_REGION(0x10000,REGION_CPU1,0) */
 /*	ROM_REGION(0x80000,REGION_USER1,0) */
 	ROM_REGION(0x100000,REGION_CPU1,0)
-	ROM_LOAD("comquest.bin", 0x00000, 0x80000, 0x2bf4b1a8)
+	ROM_LOAD("comquest.bin", 0x00000, 0x80000, CRC(2bf4b1a8) SHA1(8d1821cbde37cca2055b18df001438f7d138a8c1))
 /*
 000 +16kbyte graphics data?
 040 16kbyte code
@@ -335,51 +317,18 @@ ROM_START(comquest)
 
 /*	ROM_REGION(0x100,REGION_GFX1,0) */
 	ROM_REGION(0x80000,REGION_GFX1,0)
-	ROM_LOAD("comquest.bin", 0x00000, 0x80000, 0x2bf4b1a8)
+	ROM_LOAD("comquest.bin", 0x00000, 0x80000, CRC(2bf4b1a8) SHA1(8d1821cbde37cca2055b18df001438f7d138a8c1))
 ROM_END
 
-static const struct IODevice io_comquest[] = {
-#if 0
-	{
-		IO_CARTSLOT,					/* type */
-		1,								/* count */
-		"bin\0",						/* file extensions */
-		IO_RESET_ALL,							/* private */
-		0,
-		a2600_load_rom,					/* init */
-		NULL,							/* exit */
-		NULL,							/* info */
-		NULL,							/* open */
-		NULL,							/* close */
-		NULL,							/* status */
-		NULL,							/* seek */
-		NULL,							/* tell */
-		NULL,							/* input */
-		NULL,							/* output */
-		NULL,							/* input_chunk */
-		NULL							/* output_chunk */
-	},
-#endif
-    { IO_END }
-};
+SYSTEM_CONFIG_START(comquest)
+	/*CONFIG_DEVICE_CARTSLOT_REQ( 1, "bin\0", a2600_load_rom, NULL, NULL)*/
+SYSTEM_CONFIG_END
 
-void init_comquest(void)
-{
-/*	int i; */
-/*	UINT8 *gfx=memory_region(REGION_GFX1); */
-/*	for (i=0; i<256; i++) gfx[i]=i; */
-}
+/***************************************************************************
 
-/*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      MONITOR	COMPANY   FULLNAME */
-CONS( 19??, comquest, 0, 		comquest, comquest, comquest, "Data Concepts",  "Comquest Plus German")
+  Game driver(s)
 
-#ifdef RUNTIME_LOADER
-extern void comquest_runtime_loader_init(void)
-{
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"comquest")==0) drivers[i]=&driver_comquest;
-	}
-}
-#endif
+***************************************************************************/
 
+/*    YEAR  NAME      PARENT	COMPAT	MACHINE   INPUT     INIT	CONFIG		MONITOR	COMPANY   FULLNAME */
+CONS( 19??, comquest, 0, 		0,		comquest, comquest, 0,		comquest,	"Data Concepts",  "Comquest Plus German", 0)
