@@ -818,69 +818,129 @@ static const char *coco_floppy_getname(const struct IODevice *dev, int id, char
  *
  *************************************/
 
-static void coco_bitbanger_getinfo(struct IODevice *dev)
+static void coco_bitbanger_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* bitbanger port */
-	bitbanger_device_getinfo(dev, &coco_bitbanger_config);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_BITBANGER_CONFIG:				info->p = (void *) &coco_bitbanger_config; break;
+
+		default:										bitbanger_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
 
-static void coco_cassette_getinfo(struct IODevice *dev)
+static void coco_cassette_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cassette */
-	cassette_device_getinfo(dev, coco_cassette_formats, NULL,
-		CASSETTE_PLAY | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_CASSETTE_FORMATS:				info->p = (void *) coco_cassette_formats; break;
+
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_CASSETTE_DEFAULT_STATE:		info->i = CASSETTE_PLAY | CASSETTE_MOTOR_DISABLED | CASSETTE_SPEAKER_MUTED; break;
+
+		default:										cassette_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
 
-static void coco_floppy_getinfo(struct IODevice *dev)
+static void coco_floppy_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* floppy */
-	floppy_device_getinfo(dev, floppyoptions_coco);
-	dev->count = 4;
-	dev->name = coco_floppy_getname;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 4; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_GET_NAME:						info->name = coco_floppy_getname; break;
+		case DEVINFO_PTR_FLOPPY_OPTIONS:				info->p = (void *) floppyoptions_coco; break;
+
+		default:										floppy_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
 
-static void coco_cartslot_getinfo(struct IODevice *dev)
+static void coco_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "ccc\0rom\0";
-	dev->load = device_load_coco_rom;
-	dev->unload = device_unload_coco_rom;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_coco_rom; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_coco_rom; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "ccc,rom"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
 
-static void coco3_cartslot_getinfo(struct IODevice *dev)
+static void coco3_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "ccc\0rom\0";
-	dev->load = device_load_coco3_rom;
-	dev->unload = device_unload_coco3_rom;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_coco3_rom; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_coco3_rom; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "ccc,rom"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
 
-static void coco_snapshot_getinfo(struct IODevice *dev)
+static void coco_snapshot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	snapshot_device_getinfo(dev, snapshot_load_coco_pak, 0.00);
-	dev->file_extensions = "pak\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "pak"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_SNAPSHOT_LOAD:					info->f = (genf *) snapshot_load_coco_pak; break;
+
+		default:										snapshot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
 
-static void coco3_snapshot_getinfo(struct IODevice *dev)
+static void coco3_snapshot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	snapshot_device_getinfo(dev, snapshot_load_coco3_pak, 0.00);
-	dev->file_extensions = "pak\0";
+	switch(state)
+	{
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "pak"); break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_SNAPSHOT_LOAD:					info->f = (genf *) snapshot_load_coco3_pak; break;
+
+		default:										snapshot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 /*************************************
@@ -889,11 +949,16 @@ static void coco3_snapshot_getinfo(struct IODevice *dev)
 *
 **************************************/
 
-static void dragon_printer_getinfo(struct IODevice *dev)
+static void dragon_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer port */
-	printer_device_getinfo(dev);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
 
