@@ -76,61 +76,61 @@
 #define LOG(x)	/* x */
 #endif
 
-static MEMORY_READ_START ( readmem )
-	{ 0x0000, 0x03ff, MRA_RAM },
-	{ 0x1700, 0x173f, m6530_003_r },
-	{ 0x1740, 0x177f, m6530_002_r },
-	{ 0x1780, 0x17bf, MRA_RAM },
-	{ 0x17c0, 0x17ff, MRA_RAM },
-	{ 0x1800, 0x1bff, MRA_ROM },
-	{ 0x1c00, 0x1fff, MRA_ROM },
-	{ 0x2000, 0xffff, kim1_mirror_r },
-MEMORY_END
+static ADDRESS_MAP_START ( readmem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x03ff) AM_READ( MRA8_RAM )
+	AM_RANGE( 0x1700, 0x173f) AM_READ( m6530_003_r )
+	AM_RANGE( 0x1740, 0x177f) AM_READ( m6530_002_r )
+	AM_RANGE( 0x1780, 0x17bf) AM_READ( MRA8_RAM )
+	AM_RANGE( 0x17c0, 0x17ff) AM_READ( MRA8_RAM )
+	AM_RANGE( 0x1800, 0x1bff) AM_READ( MRA8_ROM )
+	AM_RANGE( 0x1c00, 0x1fff) AM_READ( MRA8_ROM )
+	AM_RANGE( 0x2000, 0xffff) AM_READ( kim1_mirror_r )
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( writemem )
-	{ 0x0000, 0x03ff, MWA_RAM },
-	{ 0x1700, 0x173f, m6530_003_w },
-	{ 0x1740, 0x177f, m6530_002_w },
-	{ 0x1780, 0x17bf, MWA_RAM },
-	{ 0x17c0, 0x17ff, MWA_RAM },
-	{ 0x1800, 0x1bff, MWA_ROM },
-	{ 0x1c00, 0x1fff, MWA_ROM },
-	{ 0x2000, 0xffff, kim1_mirror_w },
-MEMORY_END
+static ADDRESS_MAP_START( writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x03ff) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x1700, 0x173f) AM_WRITE( m6530_003_w )
+	AM_RANGE( 0x1740, 0x177f) AM_WRITE( m6530_002_w )
+	AM_RANGE( 0x1780, 0x17bf) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x17c0, 0x17ff) AM_WRITE( MWA8_RAM )
+	AM_RANGE( 0x1800, 0x1bff) AM_WRITE( MWA8_ROM )
+	AM_RANGE( 0x1c00, 0x1fff) AM_WRITE( MWA8_ROM )
+	AM_RANGE( 0x2000, 0xffff) AM_WRITE( kim1_mirror_w )
+ADDRESS_MAP_END
 
 INPUT_PORTS_START( kim1 )
 	PORT_START			/* IN0 keys row 0 */
 	PORT_BIT (0x80, 0x00, IPT_UNUSED )
-	PORT_BITX(0x40, 0x40, IPT_KEYBOARD, "0.6: 0",        KEYCODE_0,      IP_JOY_NONE )
-	PORT_BITX(0x20, 0x20, IPT_KEYBOARD, "0.5: 1",        KEYCODE_1,      IP_JOY_NONE )
-	PORT_BITX(0x10, 0x10, IPT_KEYBOARD, "0.4: 2",        KEYCODE_2,      IP_JOY_NONE )
-	PORT_BITX(0x08, 0x08, IPT_KEYBOARD, "0.3: 3",        KEYCODE_3,      IP_JOY_NONE )
-	PORT_BITX(0x04, 0x04, IPT_KEYBOARD, "0.2: 4",        KEYCODE_4,      IP_JOY_NONE )
-	PORT_BITX(0x02, 0x02, IPT_KEYBOARD, "0.1: 5",        KEYCODE_5,      IP_JOY_NONE )
-	PORT_BITX(0x01, 0x01, IPT_KEYBOARD, "0.0: 6",        KEYCODE_6,      IP_JOY_NONE )
+	PORT_BIT(0x40, 0x40, IPT_KEYBOARD) PORT_NAME("0.6: 0") PORT_CODE(KEYCODE_0)
+	PORT_BIT(0x20, 0x20, IPT_KEYBOARD) PORT_NAME("0.5: 1") PORT_CODE(KEYCODE_1)
+	PORT_BIT(0x10, 0x10, IPT_KEYBOARD) PORT_NAME("0.4: 2") PORT_CODE(KEYCODE_2)
+	PORT_BIT(0x08, 0x08, IPT_KEYBOARD) PORT_NAME("0.3: 3") PORT_CODE(KEYCODE_3)
+	PORT_BIT(0x04, 0x04, IPT_KEYBOARD) PORT_NAME("0.2: 4") PORT_CODE(KEYCODE_4)
+	PORT_BIT(0x02, 0x02, IPT_KEYBOARD) PORT_NAME("0.1: 5") PORT_CODE(KEYCODE_5)
+	PORT_BIT(0x01, 0x01, IPT_KEYBOARD) PORT_NAME("0.0: 6") PORT_CODE(KEYCODE_6)
 	PORT_START			/* IN1 keys row 1 */
 	PORT_BIT (0x80, 0x00, IPT_UNUSED )
-	PORT_BITX(0x40, 0x40, IPT_KEYBOARD, "1.6: 7",        KEYCODE_7,      IP_JOY_NONE )
-	PORT_BITX(0x20, 0x20, IPT_KEYBOARD, "1.5: 8",        KEYCODE_8,      IP_JOY_NONE )
-	PORT_BITX(0x10, 0x10, IPT_KEYBOARD, "1.4: 9",        KEYCODE_9,      IP_JOY_NONE )
-	PORT_BITX(0x08, 0x08, IPT_KEYBOARD, "1.3: A",        KEYCODE_A,      IP_JOY_NONE )
-	PORT_BITX(0x04, 0x04, IPT_KEYBOARD, "1.2: B",        KEYCODE_B,      IP_JOY_NONE )
-	PORT_BITX(0x02, 0x02, IPT_KEYBOARD, "1.1: C",        KEYCODE_C,      IP_JOY_NONE )
-	PORT_BITX(0x01, 0x01, IPT_KEYBOARD, "1.0: D",        KEYCODE_D,      IP_JOY_NONE )
+	PORT_BIT(0x40, 0x40, IPT_KEYBOARD) PORT_NAME("1.6: 7") PORT_CODE(KEYCODE_7)
+	PORT_BIT(0x20, 0x20, IPT_KEYBOARD) PORT_NAME("1.5: 8") PORT_CODE(KEYCODE_8)
+	PORT_BIT(0x10, 0x10, IPT_KEYBOARD) PORT_NAME("1.4: 9") PORT_CODE(KEYCODE_9)
+	PORT_BIT(0x08, 0x08, IPT_KEYBOARD) PORT_NAME("1.3: A") PORT_CODE(KEYCODE_A)
+	PORT_BIT(0x04, 0x04, IPT_KEYBOARD) PORT_NAME("1.2: B") PORT_CODE(KEYCODE_B)
+	PORT_BIT(0x02, 0x02, IPT_KEYBOARD) PORT_NAME("1.1: C") PORT_CODE(KEYCODE_C)
+	PORT_BIT(0x01, 0x01, IPT_KEYBOARD) PORT_NAME("1.0: D") PORT_CODE(KEYCODE_D)
 	PORT_START			/* IN2 keys row 2 */
 	PORT_BIT (0x80, 0x00, IPT_UNUSED )
-	PORT_BITX(0x40, 0x40, IPT_KEYBOARD, "2.6: E",        KEYCODE_E,      IP_JOY_NONE )
-	PORT_BITX(0x20, 0x20, IPT_KEYBOARD, "2.5: F",        KEYCODE_F,      IP_JOY_NONE )
-	PORT_BITX(0x10, 0x10, IPT_KEYBOARD, "2.4: AD (F1)",  KEYCODE_F1,     IP_JOY_NONE )
-	PORT_BITX(0x08, 0x08, IPT_KEYBOARD, "2.3: DA (F2)",  KEYCODE_F2,     IP_JOY_NONE )
-	PORT_BITX(0x04, 0x04, IPT_KEYBOARD, "2.2: +  (CR)",  KEYCODE_ENTER,  IP_JOY_NONE )
-	PORT_BITX(0x02, 0x02, IPT_KEYBOARD, "2.1: GO (F5)",  KEYCODE_F5,     IP_JOY_NONE )
-	PORT_BITX(0x01, 0x01, IPT_KEYBOARD, "2.0: PC (F6)",  KEYCODE_F6,     IP_JOY_NONE )
+	PORT_BIT(0x40, 0x40, IPT_KEYBOARD) PORT_NAME("2.6: E") PORT_CODE(KEYCODE_E)
+	PORT_BIT(0x20, 0x20, IPT_KEYBOARD) PORT_NAME("2.5: F") PORT_CODE(KEYCODE_F)
+	PORT_BIT(0x10, 0x10, IPT_KEYBOARD) PORT_NAME("2.4: AD (F1)") PORT_CODE(KEYCODE_F1)
+	PORT_BIT(0x08, 0x08, IPT_KEYBOARD) PORT_NAME("2.3: DA (F2)") PORT_CODE(KEYCODE_F2)
+	PORT_BIT(0x04, 0x04, IPT_KEYBOARD) PORT_NAME("2.2: +  (CR)") PORT_CODE(KEYCODE_ENTER)
+	PORT_BIT(0x02, 0x02, IPT_KEYBOARD) PORT_NAME("2.1: GO (F5)") PORT_CODE(KEYCODE_F5)
+	PORT_BIT(0x01, 0x01, IPT_KEYBOARD) PORT_NAME("2.0: PC (F6)") PORT_CODE(KEYCODE_F6)
 	PORT_START			/* IN3 STEP and RESET keys, MODE switch */
 	PORT_BIT (0x80, 0x00, IPT_UNUSED )
-	PORT_BITX(0x40, 0x40, IPT_KEYBOARD, "sw1: ST (F7)",  KEYCODE_F7,     IP_JOY_NONE )
-	PORT_BITX(0x20, 0x20, IPT_KEYBOARD, "sw2: RS (F3)",  KEYCODE_F3,     IP_JOY_NONE )
-	PORT_BITX(0x10, 0x10, IPT_DIPSWITCH_NAME | IPF_TOGGLE, "sw3: SS (NumLock)", KEYCODE_NUMLOCK, IP_JOY_NONE )
+	PORT_BIT(0x40, 0x40, IPT_KEYBOARD) PORT_NAME("sw1: ST (F7)") PORT_CODE(KEYCODE_F7)
+	PORT_BIT(0x20, 0x20, IPT_KEYBOARD) PORT_NAME("sw2: RS (F3)") PORT_CODE(KEYCODE_F3)
+	PORT_BIT(0x10, 0x10, IPT_DIPSWITCH_NAME) PORT_NAME("sw3: SS (NumLock)") PORT_CODE(KEYCODE_NUMLOCK) PORT_TOGGLE
 	PORT_DIPSETTING( 0x00, "single step")
 	PORT_DIPSETTING( 0x10, "run")
 	PORT_BIT (0x08, 0x00, IPT_UNUSED )
@@ -139,7 +139,7 @@ INPUT_PORTS_START( kim1 )
 	PORT_BIT (0x01, 0x00, IPT_UNUSED )
 INPUT_PORTS_END
 
-static struct GfxLayout led_layout =
+static gfx_layout led_layout =
 {
 	18, 24, 	/* 16 x 24 LED 7segment displays */
 	128,		/* 128 codes */
@@ -159,7 +159,7 @@ static struct GfxLayout led_layout =
 	24 * 24,	/* every LED code takes 32 times 18 (aligned 24) bit words */
 };
 
-static struct GfxLayout key_layout =
+static gfx_layout key_layout =
 {
 	24, 18, 	/* 24 * 18 keyboard icons */
 	24, 		/* 24  codes */
@@ -174,93 +174,58 @@ static struct GfxLayout key_layout =
 	18 * 24 * 2,	/* every icon takes 18 rows of 24 * 2 bits */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static gfx_decode gfxdecodeinfo[] =
 {
-	{ 1, 0, &led_layout, 0, 16 },
-	{ 2, 0, &key_layout, 16*2, 2 },
-MEMORY_END	 /* end of array */
-
-static struct DACinterface dac_interface =
-{
-	1,			/* number of DACs */
-	{ 100 } 	/* volume */
+	{ REGION_GFX1, 0, &led_layout, 0, 16 },
+	{ REGION_GFX2, 0, &key_layout, 16*2, 2 },
+	{ -1 } /* end of array */
 };
 
-static struct MachineDriver machine_driver_kim1 =
-{
+
+static MACHINE_DRIVER_START( kim1 )
 	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			1000000,	/* 1 MHz */
-			readmem,writemem,0,0,
-			kim1_interrupt, 1
-        }
-	},
-	/* frames per second, VBL duration */
-	60, DEFAULT_60HZ_VBLANK_DURATION,
-	1,				/* single CPU */
-	kim1_init_machine,
-	NULL,			/* stop machine */
+	MDRV_CPU_ADD_TAG("main", M6502, 1000000)        /* 1 MHz */
+	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_VBLANK_INT(kim1_interrupt, 1)
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
+
+	MDRV_MACHINE_INIT( kim1 )
 
 	/* video hardware (well, actually there was no video ;) */
-	600, 768, { 0, 600 - 1, 0, 768 - 1},
-	gfxdecodeinfo,
-	32768+21,				/* leave extra colors for the overlay */
-	256,
-	kim1_init_colors,		/* convert color prom */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(600, 768)
+	MDRV_VISIBLE_AREA(0, 600 - 1, 0, 768 - 1)
+	MDRV_GFXDECODE( gfxdecodeinfo )
+	MDRV_PALETTE_LENGTH(32768+21)
+	MDRV_COLORTABLE_LENGTH(256)
+	MDRV_PALETTE_INIT( kim1 )
 
-	VIDEO_TYPE_RASTER | VIDEO_SUPPORTS_DIRTY,	/* video flags */
-	0,						/* obsolete */
-	kim1_vh_start,
-	kim1_vh_stop,
-	kim1_vh_screenrefresh,
+	MDRV_VIDEO_START( kim1 )
+	MDRV_VIDEO_UPDATE( kim1 )
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-        {
-			SOUND_DAC,
-			&dac_interface
-		}
-    }
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+MACHINE_DRIVER_END
+
 
 ROM_START(kim1)
 	ROM_REGION(0x10000,REGION_CPU1,0)
-		ROM_LOAD("6530-003.bin",    0x1800, 0x0400, 0xa2a56502)
-		ROM_LOAD("6530-002.bin",    0x1c00, 0x0400, 0x2b08e923)
+		ROM_LOAD("6530-003.bin",    0x1800, 0x0400, CRC(a2a56502) SHA1(60b6e48f35fe4899e29166641bac3e81e3b9d220))
+		ROM_LOAD("6530-002.bin",    0x1c00, 0x0400, CRC(2b08e923) SHA1(054f7f6989af3a59462ffb0372b6f56f307b5362))
 	ROM_REGION(128 * 24 * 3,REGION_GFX1,0)
 		/* space filled with 7segement graphics by kim1_init_driver */
 	ROM_REGION( 24 * 18 * 3 * 2,REGION_GFX2,0)
 		/* space filled with key icons by kim1_init_driver */
 ROM_END
 
+SYSTEM_CONFIG_START(kim1)
+	CONFIG_DEVICE(kim1_cassette_getinfo)
+SYSTEM_CONFIG_END
 
-
-static const struct IODevice io_kim1[] = {
-    {
-		IO_CASSETTE,		/* type */
-        1,                  /* count */
-		"kim\0",            /* file extensions */
-		IO_RESET_ALL,		/* reset if file changed */
-        0,
-		kim1_cassette_init, /* init */
-		kim1_cassette_exit, /* exit */
-        NULL,               /* info */
-        NULL,               /* open */
-        NULL,               /* close */
-        NULL,               /* status */
-        NULL,               /* seek */
-		NULL,				/* tell */
-        NULL,               /* input */
-        NULL,               /* output */
-        NULL,               /* input_chunk */
-        NULL                /* output_chunk */
-    },
-    { IO_END }
-};
-
-/*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      COMPANY   FULLNAME */
-COMP( 1975, kim1,	  0, 		kim1,	  kim1, 	kim1,	  "MOS Technologies",  "KIM-1" )
-
+/*    YEAR  NAME      PARENT    COMPAT	MACHINE   INPUT     INIT      CONFIG  COMPANY   FULLNAME */
+COMP( 1975, kim1,	  0, 		0,		kim1,	  kim1, 	kim1,	  kim1,	  "MOS Technologies",  "KIM-1" , 0)
