@@ -532,10 +532,15 @@ static WRITE8_HANDLER ( mtx_trap_write )
 	}
 }
 
-static void mtx_printer_getinfo(struct IODevice *dev)
+static void mtx_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
-	printer_device_getinfo (dev);
-	dev->count = 1;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		default:										printer_device_getinfo(devclass, state, info); break;
+	}
 }
 
 static MACHINE_INIT( mtx512 )
