@@ -253,7 +253,7 @@ static MACHINE_STOP( snes )
 		snes_save_sram();
 }
 
-static DEVICE_LOAD(snes_cart)
+static int device_load_snes_cart(mess_image *image, mame_file *file)
 {
 	int i;
 	UINT16 totalblocks, readblocks;
@@ -504,14 +504,23 @@ static MACHINE_DRIVER_START( snespal )
 	MDRV_FRAMES_PER_SECOND(50)
 MACHINE_DRIVER_END
 
-static void snes_cartslot_getinfo(struct IODevice *dev)
+static void snes_cartslot_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "smc\0sfc\0fig\0swc\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_snes_cart;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+		case DEVINFO_INT_MUST_BE_LOADED:				info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_snes_cart; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "smc,sfc,fig,swc"); break;
+
+		default:										cartslot_device_getinfo(devclass, state, info); break;
+	}
 }
 
 SYSTEM_CONFIG_START(snes)
