@@ -28,24 +28,67 @@ internal expansion/cartridge port
 #include "machine/6522via.h"
 #include "cpu/m6502/m6502.h"
 
-static int ssystem3_frame_int(void);
-static void ssystem3_machine_init(void);
 
-static MEMORY_READ_START( ssystem3_readmem )
-	{ 0x0000, 0x03ff, MRA_RAM },
-	{ 0x6000, 0x600f, via_0_r },
-	{ 0xc000, 0xffff, MRA_ROM },
-MEMORY_END
 
-static MEMORY_WRITE_START( ssystem3_writemem )
-	{ 0x0000, 0x03ff, MWA_RAM },
+/*
+  port b
+   bit 0: ??
+
+    hi speed serial 1 
+   bit 1: output data
+   bit 2: output clock (hi data is taken)
+
+	bit 6: input clocks!?
+
+ */
+
+struct via6522_interface config=
+{
+	0,/*read8_handler in_a_func; */
+	0,/*read8_handler in_b_func; */
+	0,/*read8_handler in_ca1_func; */
+	0,/*read8_handler in_cb1_func; */
+	0,/*read8_handler in_ca2_func; */
+	0,/*read8_handler in_cb2_func; */
+	0,/*write8_handler out_a_func; */
+	0,/*write8_handler out_b_func; */
+	0,/*write8_handler out_ca2_func; */
+	0,/*write8_handler out_cb2_func; */
+	0,/*void (*irq_func)(int state); */
+};
+
+static DRIVER_INIT( ssystem3 )
+{
+	via_config(0,&config);
+}
+
+static INTERRUPT_GEN( ssystem3_frame_int )
+{
+	static int toggle=0;
+	via_set_input_b(0,toggle?0x40:0);
+	toggle^=0;
+}
+
+static MACHINE_INIT( ssystem3 )
+{
+	via_reset();
+}
+
+static ADDRESS_MAP_START( ssystem3_readmem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x03ff) AM_READ( MRA8_RAM )
+	AM_RANGE( 0x6000, 0x600f) AM_READ( via_0_r )
+	AM_RANGE( 0xc000, 0xffff) AM_READ( MRA8_ROM )
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( ssystem3_writemem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x03ff) AM_WRITE( MWA8_RAM )
 /* 0x4000, 0x40ff, lcd chip!? */
-	{ 0x6000, 0x600f, via_0_w },
-	{ 0xc000, 0xffff, MWA_ROM },
-MEMORY_END
+	AM_RANGE( 0x6000, 0x600f) AM_WRITE( via_0_w )
+	AM_RANGE( 0xc000, 0xffff) AM_WRITE( MWA8_ROM )
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, r)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode) PORT_CODE(r)
 
 INPUT_PORTS_START( ssystem3 )
 	PORT_START
@@ -83,48 +126,42 @@ DIPS_HELPER( 0x001, "NEW GAME", KEYCODE_F3, CODE_NONE) /* seams to be direct wir
 #endif
 INPUT_PORTS_END
 
-static struct DACinterface ssystem3_dac={ 1, {80}}; /* silence is golden */
 
-static struct MachineDriver machine_driver_ssystem3 =
-{
+
+static MACHINE_DRIVER_START( ssystem3 )
 	/* basic machine hardware */
-	{
-		{
-			CPU_M6502,
-			1000000,
-			ssystem3_readmem, ssystem3_writemem,0,0,
-			ssystem3_frame_int, 1,
-        }
-	},
-	/* frames per second, VBL duration */
-	60, DEFAULT_60HZ_VBLANK_DURATION, /* lcd! */
-	1,				/* single CPU */
-	ssystem3_machine_init,
-	0,/*pc1401_machine_stop, */
+	MDRV_CPU_ADD(M6502, 1000000)
+	MDRV_CPU_PROGRAM_MAP(ssystem3_readmem, ssystem3_writemem)
+	MDRV_CPU_VBLANK_INT(ssystem3_frame_int, 1)
+	MDRV_FRAMES_PER_SECOND(LCD_FRAMES_PER_SECOND)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
 
-	728, 437, { 0, 728 - 1, 0, 437 - 1},
-	0, 			   /* graphics decode info */
-	sizeof (ssystem3_palette) / sizeof (ssystem3_palette[0]) + 32768,
-	sizeof (ssystem3_colortable) / sizeof(ssystem3_colortable[0][0]),
-	ssystem3_init_colors,		/* convert color prom */
+	MDRV_MACHINE_INIT( ssystem3 )
 
-	VIDEO_TYPE_RASTER,	/* video flags */
-	0,						/* obsolete */
-    ssystem3_vh_start,
-	ssystem3_vh_stop,
-	ssystem3_vh_screenrefresh,
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(728, 437)
+	MDRV_VISIBLE_AREA(0, 728-1, 0, 437-1)
+	MDRV_PALETTE_LENGTH(242 + 32768)
+	MDRV_COLORTABLE_LENGTH(2)
+	MDRV_PALETTE_INIT( ssystem3 )
+
+	MDRV_VIDEO_START( ssystem3 )
+	MDRV_VIDEO_UPDATE( ssystem3 )
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{ SOUND_DAC, &ssystem3_dac }
-    }
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+MACHINE_DRIVER_END
+
 
 ROM_START(ssystem3)
 	ROM_REGION(0x10000,REGION_CPU1,0)
-	ROM_LOAD("ss3lrom", 0xc000, 0x1000, 0x9ea46ed3)
-	ROM_LOAD("ss3hrom", 0xf000, 0x1000, 0x52741e0b)
+	ROM_LOAD("ss3lrom", 0xc000, 0x1000, CRC(9ea46ed3))
+	ROM_LOAD("ss3hrom", 0xf000, 0x1000, CRC(52741e0b))
 	ROM_RELOAD(0xd000, 0x1000)
 /* 0xd450 reset,irq,nmi
 
@@ -133,66 +170,12 @@ ROM_START(ssystem3)
 
 ROM_END
 
-static const struct IODevice io_ssystem3[] = {
-    { IO_END }
-};
+/***************************************************************************
 
+  Game driver(s)
 
-/*
-  port b
-   bit 0: ??
+***************************************************************************/
 
-    hi speed serial 1 
-   bit 1: output data
-   bit 2: output clock (hi data is taken)
-
-	bit 6: input clocks!?
-
- */
-
-struct via6522_interface config=
-{
-	0,/*mem_read_handler in_a_func; */
-		0,/*mem_read_handler in_b_func; */
-		0,/*mem_read_handler in_ca1_func; */
-		0,/*mem_read_handler in_cb1_func; */
-		0,/*mem_read_handler in_ca2_func; */
-		0,/*mem_read_handler in_cb2_func; */
-		0,/*mem_write_handler out_a_func; */
-		0,/*mem_write_handler out_b_func; */
-		0,/*mem_write_handler out_ca2_func; */
-		0,/*mem_write_handler out_cb2_func; */
-		0,/*void (*irq_func)(int state); */
-};
-
-void init_ssystem3(void)
-{
-	via_config(0,&config);
-}
-
-static int ssystem3_frame_int(void)
-{
-	static int toggle=0;
-	via_set_input_b(0,toggle?0x40:0);
-	toggle^=0;
-	return ignore_interrupt();
-}
-
-static void ssystem3_machine_init(void)
-{
-	via_reset();
-}
-
-
-CONS( 1979,	ssystem3,	0, 		ssystem3,	ssystem3,	ssystem3,	  "NOVAG Industries Ltd.",  "Chess Champion Super System III") 
+/*	  YEAR	NAME	  PARENT	COMPAT	MACHINE   INPUT		INIT		CONFIG		COMPANY		FULLNAME */
+CONS( 1979,	ssystem3, 0, 		0,		ssystem3, ssystem3,	ssystem3,	NULL,		"NOVAG Industries Ltd.",  "Chess Champion Super System III", 0) 
 /*chess champion MK III in germany */
-
-#ifdef RUNTIME_LOADER
-extern void ssystem3_runtime_loader_init(void)
-{
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"ssystem3")==0) drivers[i]=&driver_ssystem3;
-	}
-}
-#endif
