@@ -424,43 +424,67 @@ ROM_START(tx0_8kw)
 		/* space filled with our font */
 ROM_END
 
-static void tx0_punchtape_getinfo(struct IODevice *dev)
+static void tx0_punchtape_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* punchtape */
-	dev->type = IO_PUNCHTAPE;
-	dev->count = 2;
-	dev->file_extensions = "tap\0rim\0";
-	dev->getdispositions = tx0_tape_get_open_mode;
-	dev->init = device_init_tx0_tape;
-	dev->load = device_load_tx0_tape;
-	dev->unload = device_unload_tx0_tape;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_PUNCHTAPE; break;
+		case DEVINFO_INT_COUNT:							info->i = 2; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_INIT:							info->init = device_init_tx0_tape; break;
+		case DEVINFO_PTR_LOAD:							info->load = device_load_tx0_tape; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_tx0_tape; break;
+		case DEVINFO_PTR_GET_DISPOSITIONS:				info->getdispositions = tx0_tape_get_open_mode; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "tap,rim"); break;
+	}
 }
 
-static void tx0_printer_getinfo(struct IODevice *dev)
+static void tx0_printer_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* printer */
-	dev->type = IO_PRINTER;
-	dev->count = 1;
-	dev->file_extensions = "typ\0";
-	dev->readable = 0;
-	dev->writeable = 1;
-	dev->creatable = 1;
-	dev->load = device_load_tx0_typewriter;
-	dev->unload = device_unload_tx0_typewriter;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_PRINTER; break;
+		case DEVINFO_INT_READABLE:						info->i = 0; break;
+		case DEVINFO_INT_WRITEABLE:						info->i = 1; break;
+		case DEVINFO_INT_CREATABLE:						info->i = 1; break;
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_LOAD:							info->load = device_load_tx0_typewriter; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_tx0_typewriter; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "typ"); break;
+	}
 }
 
-static void tx0_magtape_getinfo(struct IODevice *dev)
+static void tx0_magtape_getinfo(const device_class *devclass, UINT32 state, union devinfo *info)
 {
 	/* magtape */
-	dev->type = IO_CASSETTE;
-	dev->count = 1;
-	dev->file_extensions = "tap\0";
-	dev->readable = 1;
-	dev->writeable = 1;
-	dev->creatable = 0;
-	dev->init = device_init_tx0_magtape;
-	dev->load = device_load_tx0_magtape;
-	dev->unload = device_unload_tx0_magtape;
+	switch(state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TYPE:							info->i = IO_CASSETTE; break;
+		case DEVINFO_INT_READABLE:						info->i = 1; break;
+		case DEVINFO_INT_WRITEABLE:						info->i = 1; break;
+		case DEVINFO_INT_CREATABLE:						info->i = 0; break;
+		case DEVINFO_INT_COUNT:							info->i = 1; break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_PTR_INIT:							info->init = device_init_tx0_magtape; break;
+		case DEVINFO_PTR_LOAD:							info->load = device_load_tx0_magtape; break;
+		case DEVINFO_PTR_UNLOAD:						info->unload = device_unload_tx0_magtape; break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_FILE_EXTENSIONS:				strcpy(info->s = device_temp_str(), "tap"); break;
+	}
 }
 
 SYSTEM_CONFIG_START(tx0)
