@@ -15,32 +15,14 @@ static void apf_charproc(UINT8 c)
 	m6847_as_w(0,		(c & 0x080));	
 }
 
-#define APF_DUMP_RAM
-
-#ifdef APF_DUMP_RAM
-void apf_dump_ram(void)
-{
-	void *file;
-
-	file = osd_fopen(Machine->gamedrv->name, "apfram.bin", OSD_FILETYPE_NVRAM,OSD_FOPEN_WRITE);
-
-	if (file)
-	{
-		osd_fwrite(file, apf_video_ram, 0x0400);
-
-		/* close file */
-		osd_fclose(file);
-	}
-}
-#endif
 
 
-READ_HANDLER(apf_video_r)
+ READ8_HANDLER(apf_video_r)
 {
 	return apf_video_ram[offset];
 }
 
-WRITE_HANDLER(apf_video_w)
+WRITE8_HANDLER(apf_video_w)
 {
 	apf_video_ram[offset] = data;
 	m6847_touch_vram(offset);
@@ -48,9 +30,9 @@ WRITE_HANDLER(apf_video_w)
 	schedule_full_refresh();
 }
 
-extern int apf_ints;
+extern unsigned int apf_ints;
 
-WRITE_HANDLER(apf_vsync_int)
+static WRITE8_HANDLER(apf_vsync_int)
 {
 	if (data!=0)
 	{
@@ -64,12 +46,12 @@ WRITE_HANDLER(apf_vsync_int)
 	apf_update_ints();
 }
 
-int apf_vh_start(void)
+VIDEO_START( apf )
 {
 	struct m6847_init_params p;
 
 	/* allocate video memory ram */
-	apf_video_ram = (unsigned char *)malloc(0x0400);
+	apf_video_ram = (unsigned char *)auto_malloc(0x0400);
 
 	m6847_vh_normalparams(&p);
 	p.version = M6847_VERSION_ORIGINAL_NTSC;
@@ -78,23 +60,8 @@ int apf_vh_start(void)
 	p.charproc = apf_charproc;
 	p.fs_func = apf_vsync_int;
 
-	if (m6847_vh_start(&p))
+	if (video_start_m6847(&p))
 		return 1;
 
 	return (0);
 }
-
-void apf_vh_stop(void)
-{
-	apf_dump_ram();
-
-	/* free video memory ram */
-	if (apf_video_ram!=NULL)
-	{
-		free(apf_video_ram);
-		apf_video_ram = NULL;
-	}
-
-	m6847_vh_stop();
-}
-
