@@ -34,7 +34,7 @@ static int stylus_y;
 /* colour table filled in from avigo colour table*/
 static UINT32 stylus_color_table[3] = {0,0,0};
 
-static struct GfxLayout pointerlayout =
+static gfx_layout pointerlayout =
 {
 	8, 8,
 	1,
@@ -51,7 +51,7 @@ static UINT8 pointermask[] =
 	0xf0, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00	/* whitemask */
 };
 
-static struct GfxElement *stylus_pointer;
+static gfx_element *stylus_pointer;
 
 void	avigo_vh_set_stylus_marker_position(int x,int y)
 {
@@ -59,7 +59,7 @@ void	avigo_vh_set_stylus_marker_position(int x,int y)
 	stylus_y = y;
 }
 
-READ_HANDLER(avigo_vid_memory_r)
+ READ8_HANDLER(avigo_vid_memory_r)
 {
         unsigned char *ptr;
 
@@ -83,7 +83,7 @@ READ_HANDLER(avigo_vid_memory_r)
 		return ptr[0];
 }
 
-WRITE_HANDLER(avigo_vid_memory_w)
+WRITE8_HANDLER(avigo_vid_memory_w)
 {
 		if (offset==0)
 		{
@@ -122,37 +122,25 @@ WRITE_HANDLER(avigo_vid_memory_w)
         }
 }
 
-int avigo_vh_start(void)
+VIDEO_START( avigo )
 {
     /* current selected column to read/write */
     avigo_screen_column = 0;
 
     /* allocate video memory */
-    avigo_video_memory = malloc(((AVIGO_SCREEN_WIDTH>>3)*AVIGO_SCREEN_HEIGHT));
+    avigo_video_memory = auto_malloc(((AVIGO_SCREEN_WIDTH>>3)*AVIGO_SCREEN_HEIGHT));
 
 /*	if (avigo_backdrop)
 		backdrop_refresh(avigo_backdrop);
 */
-	stylus_pointer = decodegfx(pointermask, &pointerlayout);
+	Machine->gfx[0] = stylus_pointer = allocgfx(&pointerlayout);
+	decodegfx(stylus_pointer, pointermask, 0, 1);
 	stylus_pointer->colortable = stylus_color_table;
 	stylus_pointer->total_colors = 3;
 	stylus_color_table[1] = Machine->pens[0];
 	stylus_color_table[2] = Machine->pens[1]; 
 	return 0;
 }
-void    avigo_vh_stop(void)
-{
-    if (avigo_video_memory!=NULL)
-    {
-            free(avigo_video_memory);
-            avigo_video_memory = NULL;
-    }
-
-/*	if (avigo_backdrop)
-		artwork_free(&avigo_backdrop);
-*/
-	freegfx(stylus_pointer);
-}
 
 /* two colours */
 static unsigned short avigo_colour_table[AVIGO_NUM_COLOURS] =
@@ -169,13 +157,12 @@ static unsigned char avigo_palette[AVIGO_NUM_COLOURS * 3] =
 
 
 /* Initialise the palette */
-void avigo_init_palette(unsigned char *sys_palette, unsigned short *sys_colortable, const unsigned char *color_prom)
+PALETTE_INIT( avigo )
 {
 /*	char *backdrop_name;
     int used = 2; */
-    memcpy(sys_palette, avigo_palette, sizeof (avigo_palette));
-    memcpy(sys_colortable, avigo_colour_table, sizeof (avigo_colour_table));
-
+	palette_set_colors(0, avigo_palette, sizeof(avigo_palette) / 3);
+    memcpy(colortable, avigo_colour_table, sizeof (avigo_colour_table));
 
 	/* load backdrop */
 #if 0
@@ -218,13 +205,13 @@ unsigned int avigo_ad_y;
   Do NOT call osd_update_display() from this function,
   it will be called by the main emulation engine.
 ***************************************************************************/
-void avigo_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( avigo )
 {
     int y;
     int b;
     int x;
     int pens[2];
-	struct rectangle r;
+	rectangle r;
 
 	/* draw avigo display */
     pens[0] = Machine->pens[0];
@@ -237,7 +224,7 @@ void avigo_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
         unsigned char *line_ptr = avigo_video_memory +  (y*(AVIGO_SCREEN_WIDTH>>3));
 		
         x = 0;
-        for (by=AVIGO_SCREEN_WIDTH>>3; by>=0; by--)
+        for (by=((AVIGO_SCREEN_WIDTH>>3)-1); by>=0; by--)
         {
 			int px;
             unsigned char byte;
@@ -271,7 +258,7 @@ void avigo_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 
 		char	avigo_text[256];
 		sprintf(avigo_text,"X: %03x Y: %03x",avigo_ad_x, avigo_ad_y);
-		ui_text(bitmap, avigo_text, 0, 200);
+		ui_draw_text(avigo_text, 0, 200);
 
 	}
 	{
@@ -285,7 +272,7 @@ void avigo_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 
 
 		sprintf(avigo_text,"Xb: %02x Yb: %02x zb: %02x ab:%02x bb:%02x",xb, yb,zb,ab,bb);
-		ui_text(bitmap, avigo_text, 0, 216+16);
+		ui_draw_text(avigo_text, 0, 216+16);
 
 	}
 }
