@@ -4,12 +4,12 @@
 
 #include "includes/hp48.h"
 
-unsigned char hp48_palette[248][3] =
+static unsigned char hp48_palette[] =
 {
-	{ 49,70,64 }, /*background */
-	{ 40,35,55 }, /*symbol color */
-	{ 49,72,73 }, /*lcd light */
-	{ 37,42,64 }, /*lcd dark */
+	49,70,64,	/* background */
+	40,35,55,	/* symbol color */
+	49,72,73,	/* lcd light */
+	37,42,64	/* lcd dark */
 };
 
 /* 32 contrast steps */
@@ -51,45 +51,38 @@ unsigned short hp48_colortable[0x20][2] = {
 	{ 2, 3 }
 };
 
-void hp48_init_colors (unsigned char *sys_palette,
-						  unsigned short *sys_colortable,
-						  const unsigned char *color_prom)
+PALETTE_INIT( hp48 )
 {
-	memcpy (sys_palette, hp48_palette, sizeof (hp48_palette));
-	memcpy(sys_colortable,hp48_colortable,sizeof(hp48_colortable));
+	palette_set_colors(0, hp48_palette, sizeof(hp48_palette) / 3);
+	memcpy(colortable,hp48_colortable,sizeof(hp48_colortable));
 }
 
-
-int hp48_vh_start(void)
+VIDEO_START( hp48 )
 {
     videoram_size = 6 * 2 + 24;
     videoram = (UINT8*) auto_malloc (videoram_size);
 	if (!videoram)
         return 1;
 
+#if 0
 	{
 		char backdrop_name[200];
 	    /* try to load a backdrop for the machine */
 		sprintf (backdrop_name, "%s.png", Machine->gamedrv->name);
 		backdrop_load(backdrop_name, 8);
 	}
+#endif
 
-	return generic_vh_start();
+	return video_start_generic();
 }
 
-void hp48_vh_stop(void)
-{
-	generic_vh_stop();
-}
-
-static void hp48_draw_special(struct mame_bitmap *bitmap,int x, int y, const char *figure, int color)
+static void hp48_draw_special(mame_bitmap *bitmap,int x, int y, const char *figure, int color)
 {
 	int j, xi=0;
 	for (j=0; figure[j]; j++) {
 		switch (figure[j]) {
 		case '1': 
 			plot_pixel(bitmap, x+xi, y, color);
-			osd_mark_dirty(x+xi,y,x+xi,y);
 			xi++;
 			break;
 		case ' ': 
@@ -106,7 +99,7 @@ static void hp48_draw_special(struct mame_bitmap *bitmap,int x, int y, const cha
 
 #define LCD_LINES (hp48_hardware.data[0x28]|((hp48_hardware.data[0x29]&3)<<4)
 
-static const char *orange={ 
+static const char *hp48_orange={ 
 	"11111111111\r"
 	"111 1111111\r"
 	"11  1111111\r"
@@ -114,7 +107,7 @@ static const char *orange={
 	"11  11111 1\r"
 	"111 11111 1\r"
 	"111111111 1"
-}, *blue= {
+}, *hp48_blue= {
 	"11111111111\r"
 	"1111111 111\r"
 	"1111111  11\r"
@@ -122,7 +115,7 @@ static const char *orange={
 	"1 11111  11\r"
 	"1 11111 111\r"
 	"1 111111111"
-}, *alpha= {
+}, *hp48_alpha= {
 	"          1\r"
 	"   11111 1\r"
 	"  1     1\r"
@@ -130,7 +123,7 @@ static const char *orange={
 	" 1      1\r"
 	" 1     11\r"
 	"  11111  1"
-}, *alarm= {
+}, *hp48_alarm= {
 	"  1       1\r"
 	" 1  1   1  1\r"
 	"1  1  1  1  1\r"
@@ -138,7 +131,7 @@ static const char *orange={
 	"1  1  1  1  1\r"
 	" 1  1   1  1\r"
 	"  1       1"
-}, *busy= {
+}, *hp48_busy= {
 	"11111111\r"
 	" 1    1\r"
 	"  1  1\r"
@@ -146,7 +139,7 @@ static const char *orange={
 	"  1  1\r"
 	" 1    1\r"
 	"11111111"
-}, *transmit={
+}, *hp48_transmit={
 	" 11\r"
 	"1  1   1\r"
 	"    1   1\r"
@@ -167,7 +160,7 @@ static const char *orange={
 #define LCD_LINE_OFFSET (hp48_hardware.data[0x25]|(hp48_hardware.data[0x26]<<4)\
 		|(hp48_hardware.data[0x27]<<8))
 
-void hp48_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( hp48 )
 {
 	int x, y, i;
 	int color[2];
@@ -178,31 +171,27 @@ void hp48_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh)
 /*    color[0] = Machine->pens[1]; */
 	color[1] = Machine->pens[1];
 
-    if (full_refresh)
-    {
-		osd_mark_dirty (0, 0, bitmap->width, bitmap->height);
-    }
 
 	for (y=0,i=LCD_BASE_ADDRESS; y<64; y+=8, i+=LCD_LINE_OFFSET) {
 		for (x=0; x<131; x++) {
 			drawgfx(bitmap, Machine->gfx[0], 
-					cpu_readmem20(i+x),
+					program_read_byte(i+x),
 					contrast,0,0,
 					x*2+RIGHT,y*2+DOWN,
 					0, TRANSPARENCY_NONE,0);
 		}
 	}
 
-	hp48_draw_special(bitmap,RIGHT+12,DOWN-13,orange,
+	hp48_draw_special(bitmap,RIGHT+12,DOWN-13,hp48_orange,
 					  hp48_hardware.data[0xb]&1?color[1]:color[0]);
-	hp48_draw_special(bitmap,RIGHT+57,DOWN-13,blue,
+	hp48_draw_special(bitmap,RIGHT+57,DOWN-13,hp48_blue,
 					  hp48_hardware.data[0xb]&2?color[1]:color[0]);
-	hp48_draw_special(bitmap,RIGHT+102,DOWN-13,alpha,
+	hp48_draw_special(bitmap,RIGHT+102,DOWN-13,hp48_alpha,
 					  hp48_hardware.data[0xb]&4?color[1]:color[0]);
-	hp48_draw_special(bitmap,RIGHT+147,DOWN-13,alarm,
+	hp48_draw_special(bitmap,RIGHT+147,DOWN-13,hp48_alarm,
 					  hp48_hardware.data[0xb]&8?color[1]:color[0]);
-	hp48_draw_special(bitmap,RIGHT+192,DOWN-13,busy,
+	hp48_draw_special(bitmap,RIGHT+192,DOWN-13,hp48_busy,
 					  hp48_hardware.data[0xc]&1?color[1]:color[0]);
-	hp48_draw_special(bitmap,RIGHT+237,DOWN-13,transmit,
+	hp48_draw_special(bitmap,RIGHT+237,DOWN-13,hp48_transmit,
 					  hp48_hardware.data[0xc]&2?color[1]:color[0]);
 }
