@@ -13,30 +13,34 @@
 #include "m6847.h"
 #include "state.h"
 #include "vidhrdw/generic.h"
-#include "includes/rstrbits.h"
-#include "includes/rstrtrck.h"
+#include "videomap.h"
 
 /* The "Back doors" are declared here */
 #include "includes/dragon.h"
 
 #ifdef MAME_DEBUG
-#define LOG_FS	0
-#define LOG_HS	0
+#define LOG_FS			0
+#define LOG_HS			0
+#define LOG_INTERRUPT	0
 #else /* !MAME_DEBUG */
-#define LOG_FS	0
-#define LOG_HS	0
+#define LOG_FS			0
+#define LOG_HS			0
+#define LOG_INTERRUPT	0
 #endif /* MAME_DEBUG */
 
-static void m6847_rastertrack_newscreen(struct rastertrack_vvars *vvars, struct rastertrack_hvars *hvars);
-static void m6847_rastertrack_getvideomode(struct rastertrack_hvars *hvars);
-
-struct m6847_state {
+struct m6847_state
+{
 	struct m6847_init_params initparams;
 	int modebits;
 	int videooffset;
 	int latched_videooffset;
-	int rowsize;
+	int rowheight;
 	int fs, hs;
+	mame_timer *hs_timer1;
+	mame_timer *hs_timer2;
+	mame_timer *hs_timer_actual;
+	mame_timer *fs_timer;
+	mame_timer *fs_timer_actual;
 };
 
 static struct m6847_state the_state;
@@ -56,8 +60,6 @@ enum {
 
 #define LOG_M6847 0
 
-static UINT8 *game_palette;
-
 static unsigned char palette[] = {
 	0x00,0x00,0x00, /* BLACK */
 	0x00,0xff,0x00, /* GREEN */
@@ -852,57 +854,357 @@ void m6847_vh_normalparams(struct m6847_init_params *params)
 	params->artifactdipswitch = -1;
 }
 
-void m6847_vh_init_palette(unsigned char *sys_palette, unsigned short *sys_colortable,const unsigned char *color_prom)
+static void mix_colors(UINT8 *dest, const double *val, const UINT8 *c0, const UINT8 *c1)
+{
+	double v;
+	int i;
+
+	for (i = 0; i < 3; i++) {
+		v = (c0[i] * (1.0 - val[i])) + (c1[i] * val[i]);
+		dest[i] = (UINT8) (v + 0.5);
+	}
+}
+
+static void setup_artifact_palette(int destcolor, UINT16 c0, UINT16 c1,
+	const double *colorfactors, int numfactors, int reverse)
+{
+	int i, ii;
+	UINT8 rgb0[3];
+	UINT8 rgb1[3];
+	UINT8 rgbdest[3];
+
+	palette_get_color(c0, &rgb0[0], &rgb0[1], &rgb0[2]);
+	palette_get_color(c1, &rgb1[0], &rgb1[1], &rgb1[2]);
+
+	for (i = 0; i < numfactors; i++) {
+		ii = i;
+		if (reverse)
+			ii ^= 1;
+
+		mix_colors(rgbdest, &colorfactors[ii * 3], rgb0, rgb1);
+		palette_set_color(destcolor + i, rgbdest[0], rgbdest[1], rgbdest[2]);
+	}
+}
+
+static PALETTE_INIT( m6847 )
 {
 	assert((sizeof(artifactfactors) / (sizeof(artifactfactors[0]) * 3)) == M6847_ARTIFACT_COLOR_COUNT);
 
-	memcpy(sys_palette, palette, sizeof(palette));
+	palette_set_colors(0, palette, sizeof(palette) / 3);
 
-	setup_artifact_palette(sys_palette, sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*0),
+	setup_artifact_palette(sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*0),
 		0, 1, artifactfactors, M6847_ARTIFACT_COLOR_COUNT, 0);
-	setup_artifact_palette(sys_palette, sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*1),
+	setup_artifact_palette(sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*1),
 		0, 1, artifactfactors, M6847_ARTIFACT_COLOR_COUNT, 1);
-	setup_artifact_palette(sys_palette, sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*2),
+	setup_artifact_palette(sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*2),
 		0, 5, artifactfactors, M6847_ARTIFACT_COLOR_COUNT, 0);
-	setup_artifact_palette(sys_palette, sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*3),
+	setup_artifact_palette(sizeof(palette) / (sizeof(palette[0])*3) + (M6847_ARTIFACT_COLOR_COUNT*3),
 		0, 5, artifactfactors, M6847_ARTIFACT_COLOR_COUNT, 1);
-
-	/* I'm taking advantage about how 'sys_palette' will be valid for the
-	 * entire emulation; check src/palette.c for details
-	 */
-	game_palette = sys_palette;
 }
 
-static struct rastertrack_interface m6847_rastertrack_intf =
+UINT8 internal_m6847_charproc(UINT32 c, UINT16 *charpalette, const UINT16 *metapalette, int row, int skew)
 {
-	263,
-	m6847_rastertrack_newscreen,
-	NULL,
-	internal_m6847_rastertrack_endcontent,
-	m6847_rastertrack_getvideomode,
-	0
+	int fgc, bgc;
+	const UINT8 *character;
+
+	/* give the host machine a chance to pull our strings */
+	the_state.initparams.charproc(c & 0xff);
+
+	if (the_state.modebits & M6847_MODEBIT_AS) {
+		/* semigraphics */
+		bgc = 8;
+
+		if ((the_state.modebits & M6847_MODEBIT_INTEXT) &&  (!m6847_is_t1(the_state.initparams.version)) ) {
+			/* semigraphics 6 */
+			character = &fontdata8x12[(96 + (c & 0x3f)) * 12];
+			fgc = ((c >> 6) & 0x3);
+			if (the_state.modebits & M6847_MODEBIT_CSS)
+				fgc += 4;
+		}
+		else {
+			/* Semigraphics 4 */
+			bgc = 8;
+			fgc = (c >> 4) & 0x7;
+			character = &fontdata8x12[(160 + (c & 0x0f)) * 12];
+		}
+
+	}
+	else {
+		/* Text */
+		fgc = (the_state.modebits & M6847_MODEBIT_CSS) ? 15 : 13;
+
+		/* Inverse the character, if appropriate */
+		if (the_state.modebits & M6847_MODEBIT_INV)
+			fgc ^= 1;
+
+		if ((the_state.initparams.version == M6847_VERSION_M6847T1_PAL) || (the_state.initparams.version == M6847_VERSION_M6847T1_NTSC) ) {
+			/* M6847T1 specific features */
+
+			/* Lowercase */
+			if ((the_state.modebits & M6847_MODEBIT_GM0) && ((c & 0xff) < 0x20))
+				c += 0x40;
+			else
+				c &= 0x3f;
+
+			/* Inverse (The following was verified in Rainbow Magazine 12/86) */
+			if (the_state.modebits & M6847_MODEBIT_GM1)
+				fgc ^= 1;
+		}
+		else {
+			c &= 0x3f;
+		}
+		character = &fontdata8x12[(c & 0x7f) * 12 + skew];
+		bgc = fgc ^ 1;
+	}
+
+	assert(((character >= fontdata8x12) && (character < (fontdata8x12 + sizeof(pal_round_fontdata8x12)))));
+
+	charpalette[0] = metapalette[bgc];
+	charpalette[1] = metapalette[fgc];
+	return character[row];
+}
+
+static UINT16 m6847_metapalette[] = { 1, 2, 3, 4, 5, 6, 7, 8, 0, 1, 0, 5, 9, 10, 11, 12};
+
+static UINT8 m6847_charproc(UINT32 c, UINT16 *charpalette, int row)
+{
+	return internal_m6847_charproc(c, charpalette, m6847_metapalette, row, 0);
+}
+
+void internal_m6847_frame_callback(struct videomap_framecallback_info *info, int offset, int border_top, int rows)
+{
+	/* keep track of the video offset so we can handle dirty buffers */
+	the_state.latched_videooffset = the_state.videooffset;
+
+	/* now fill in the struct */
+	info->video_base = the_state.videooffset + offset;
+	info->bordertop_scanlines = border_top;
+	info->visible_scanlines = rows;
+	if (the_state.modebits & M6847_MODEBIT_AG)
+	{
+		if (the_state.modebits & M6847_MODEBIT_GM0)
+			info->pitch = ((the_state.modebits & (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) == (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) ? 32 : 16;
+		else
+			info->pitch = ((the_state.modebits & (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) != 0) ? 32 : 16;
+	}
+	else
+	{
+		info->pitch = 32;
+	}
+}
+
+static void m6847_frame_callback(struct videomap_framecallback_info *info)
+{
+	internal_m6847_frame_callback(info, 0, 13+25, 192);
+}
+
+static UINT16 artifactcorrection[128] = {
+	 0,  0,		 0,	 0,		 0,  6,		 0,	 2,
+	 5,  7,		 5,	 7,		 1,  3,		 1, 11,
+	 8,  6,		 8, 14,		 8,  9,		 8,	 9,
+	 4,  4,		 4, 15,		12, 12,		12, 15,
+
+	 5, 13,		 5, 13,		13,  0,		13,	 2,
+	10, 10,		10, 10,		10, 15,		10, 11,
+	 3,  1,		 3,	 1,		15,  9,		15,	 9,
+	11, 11,		11, 11,		15, 15,		15, 15,
+
+	14,  0,		14,	 0,		14,  6,		14,	 2,
+	 0,  7,		 0,	 7,		 1,  3,		 1, 11,
+	 9,  6,		 9, 14,		 9,  9,		 9,	 9,
+	15,  4,		15, 15,		12, 12,		12, 15,
+
+	 2, 13,		 2, 13,		 2,  0,		 2,	 2,
+	10, 10,		10, 10,		10, 15,		10, 11,
+	12,  1,		12,	 1,		12,  9,		12,	 9,
+	15, 11,		15, 11,		15, 15,		15, 15
 };
 
-int internal_m6847_vh_start(const struct m6847_init_params *params, struct rastertrack_interface *intf, int dirtyramsize)
+static int get_artifact_value(void)
 {
-	struct rastertrack_initvars vars;
+	return (the_state.initparams.artifactdipswitch == -1) ? 0 : (readinputport(the_state.initparams.artifactdipswitch) & 3);
+}
+
+void internal_m6847_line_callback(struct videomap_linecallback_info *info, const UINT16 *metapalette,
+	struct internal_m6847_linecallback_interface *intf)
+{
+	int i;
+	int artifact_value, artifact_mode;
+	int metapalette_pos;
+	int palettebase;
+	UINT8 myrgb[3];
+	UINT8 rgb0[3];
+	UINT8 rgb1[3];
+	static UINT16 artifact_metapalette[128];
+
+	info->visible_columns = 256 * intf->width_factor;
+	info->scanlines_per_row = the_state.rowheight;
+	info->borderleft_columns = (Machine->drv->screen_width - info->visible_columns) / 2;
+	info->border_value = 0xff;
+	info->text_modulo = 12;
+
+	if (the_state.modebits & M6847_MODEBIT_AG)
+	{
+		if (the_state.modebits & M6847_MODEBIT_GM0)
+		{
+			/* resolution modes */
+			info->grid_width = ((the_state.modebits & (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) == (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) ? 256 : 128;
+			info->grid_depth = 1;
+
+			artifact_value = get_artifact_value();
+
+			if (artifact_value && (info->grid_width == 256))
+			{
+				/* arifacting */
+				metapalette_pos = -1;
+				info->flags = VIDEOMAP_FLAGS_ARTIFACT;
+				info->metapalette = artifact_metapalette;
+
+				/* figure out which mode we need to use */
+				artifact_mode = (artifact_value >= 2) ? 0 : 1;
+				if (the_state.modebits & M6847_MODEBIT_CSS)
+					artifact_mode += 2;
+
+				/* do we have a dynamic palette */
+				if (intf->setup_dynamic_artifact_palette)
+				{
+					palettebase = intf->setup_dynamic_artifact_palette(artifact_mode, rgb0, rgb1);
+					for (i = 0; i < M6847_ARTIFACT_COLOR_COUNT; i++)
+					{
+						mix_colors(myrgb, &artifactfactors[(i ^ (artifact_mode & 1)) * 3], rgb0, rgb1);
+						palette_set_color(palettebase + i, myrgb[0], myrgb[1], myrgb[2]);
+					}
+				}
+
+				/* set up the arifact metapalette */
+				assert(sizeof(artifactcorrection) == sizeof(artifact_metapalette));
+				for (i = 0; i < (sizeof(artifactcorrection) / sizeof(artifactcorrection[0])); i++)
+					artifact_metapalette[i] = intf->calculate_artifact_color(artifactcorrection[i], artifact_mode);
+			}
+			else
+			{
+				if (the_state.modebits & M6847_MODEBIT_CSS)
+					metapalette_pos = 10;
+				else
+					metapalette_pos = 8;
+			}
+		}
+		else
+		{
+			/* color modes */
+			info->grid_width = (the_state.modebits & (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) ? 128 : 64;
+			info->grid_depth = 2;
+			if (the_state.modebits & M6847_MODEBIT_CSS)
+				metapalette_pos = 4;
+			else
+				metapalette_pos = 0;
+		}
+		if (metapalette_pos >= 0)
+			info->metapalette = &metapalette[metapalette_pos];
+	}
+	else
+	{
+		/* text/semigraphic modes */
+		info->grid_width = 32;
+		info->grid_depth = 8;
+		info->charproc = intf->charproc;
+	}
+}
+
+static UINT16 m6847_calculate_artifact_color(UINT16 metacolor, int artifact_mode)
+{
+	UINT16 result, artifact_base;
+
+	switch(metacolor)
+	{
+	case 0:
+		result = 0;
+		break;
+	case 15:
+		result = (artifact_mode & 2) ? 5 : 1;
+		break;
+	default:
+		artifact_base = (sizeof(palette) / (sizeof(palette[0])*3)) + (artifact_mode * M6847_ARTIFACT_COLOR_COUNT);
+		result = artifact_base + metacolor - 1;
+		break;					
+	}
+	return result;
+}
+
+static struct internal_m6847_linecallback_interface m6847_linecallback_interface =
+{
+	1,
+	m6847_charproc,
+	m6847_calculate_artifact_color,
+	NULL
+};
+
+static void m6847_line_callback(struct videomap_linecallback_info *info)
+{
+	internal_m6847_line_callback(info, m6847_metapalette, &m6847_linecallback_interface);
+}
+
+static UINT16 internal_m6847_get_border_color_callback(void)
+{
+	UINT16 pen = 0;
+
+	switch(m6847_get_bordercolor()) {
+	case M6847_BORDERCOLOR_BLACK:
+		pen = 0;
+		break;
+	case M6847_BORDERCOLOR_GREEN:
+		pen = 1;
+		break;
+	case M6847_BORDERCOLOR_WHITE:
+		pen = 5;
+		break;
+	case M6847_BORDERCOLOR_ORANGE:
+		pen = 12;
+		break;
+	}
+	return pen;
+}
+
+static struct videomap_interface m6847_videomap_interface =
+{
+	VIDEOMAP_FLAGS_MEMORY8 | VIDEOMAP_FLAGS_BUFFERVIDEO,
+	m6847_frame_callback,
+	m6847_line_callback,
+	internal_m6847_get_border_color_callback
+};
+
+static void hs_set(int val);
+static void hs_set_actual(int val);
+static void fs_set(int val);
+static void fs_set_actual(int val);
+
+int internal_video_start_m6847(const struct m6847_init_params *params, const struct videomap_interface *videointf, int dirtyramsize)
+{
+	struct videomap_config cfg;
 
 	the_state.initparams = *params;
 	the_state.modebits = 0;
-	the_state.videooffset = 0;
+	the_state.videooffset = params->initial_video_offset % params->ramsize;
 	the_state.latched_videooffset = 0;
-	the_state.rowsize = 12;
+	the_state.rowheight = 12;
 	the_state.fs = 1;
 	the_state.hs = 1;
 
+	the_state.hs_timer1 = timer_alloc(hs_set);
+	the_state.hs_timer2 = timer_alloc(hs_set);
+	the_state.hs_timer_actual = timer_alloc(hs_set_actual);
+	the_state.fs_timer = timer_alloc(fs_set);
+	the_state.fs_timer_actual = timer_alloc(fs_set_actual);
+
 	videoram_size = dirtyramsize;
-	if (generic_vh_start())
+	if (video_start_generic())
 		return 1;
 
-	vars.intf = intf;
-	vars.vram = params->ram;
-	vars.vramwrap = params->ramsize;
-	rastertrack_init(&vars);
+	cfg.intf = videointf;
+	cfg.videoram = params->ram;
+	cfg.videoram_windowsize = params->ramsize;
+	cfg.dirtybuffer = dirtybuffer;
+	videomap_init(&cfg);
 
 	/* The following code sets up which font to use.			*/
 	switch( params->version )
@@ -930,11 +1232,11 @@ int internal_m6847_vh_start(const struct m6847_init_params *params, struct raste
 	return 0;
 }
 
-int m6847_vh_start(const struct m6847_init_params *params)
+int video_start_m6847(const struct m6847_init_params *params)
 {
 	int result;
 
-	result = internal_m6847_vh_start(params, &m6847_rastertrack_intf, MAX_VRAM);
+	result = internal_video_start_m6847(params, &m6847_videomap_interface, MAX_VRAM);
 	if (result)
 		return result;
 
@@ -942,11 +1244,6 @@ int m6847_vh_start(const struct m6847_init_params *params)
 	return 0;
 }
 
-void m6847_vh_stop(void)
-{
-	generic_vh_stop();
-}
-
 /* --------------------------------------------------
  * Timing
  *
@@ -998,8 +1295,9 @@ void m6847_vh_stop(void)
  * instructions up, this delay is an attempt to delay the interrupts and allow
  * the program to see fs change before the interrupt handler is invoked
  */
+/*
 struct callback_info {
-	mem_write_handler callback;
+	write8_handler callback;
 	int value;
 };
 
@@ -1008,15 +1306,19 @@ static void do_invoke(int ci_int)
 	struct callback_info *ci;
 	ci = (struct callback_info *) ci_int;
 	ci->callback(0, ci->value);
-	free(ci);
 }
 
-static void invoke_callback(mem_write_handler callback, double delay, int value)
+static void invoke_callback(write8_handler callback, double delay, int value)
 {
+	static int index_ = 0;
+	static struct callback_info callback_buf[32];
+
 	struct callback_info *ci;
 
 	if (callback) {
-		ci = (struct callback_info *) malloc(sizeof(struct callback_info));
+		index_ %= sizeof(callback_buf) / sizeof(callback_buf[0]);
+
+		ci = &callback_buf[index_++];
 		if (!ci)
 			return;
 		ci->callback = callback;
@@ -1030,9 +1332,8 @@ static void hs_fall(int dummy)
 	the_state.hs = 0;
 	invoke_callback(the_state.initparams.hs_func, the_state.initparams.callback_delay, the_state.hs);
 
-#if LOG_HS
-	logerror("hs_fall(): hs=0 time=%g\n", timer_get_time());
-#endif
+	if (LOG_HS)
+		logerror("hs_fall(): hs=0 time=%g\n", timer_get_time());
 }
 
 static void hs_rise(int dummy)
@@ -1040,9 +1341,8 @@ static void hs_rise(int dummy)
 	the_state.hs = 1;
 	invoke_callback(the_state.initparams.hs_func, the_state.initparams.callback_delay, the_state.hs);
 
-#if LOG_HS
-	logerror("hs_rise(): hs=1 time=%g\n", timer_get_time());
-#endif
+	if (LOG_HS)
+		logerror("hs_rise(): hs=1 time=%g\n", timer_get_time());
 }
 
 static void fs_fall(int dummy)
@@ -1050,9 +1350,8 @@ static void fs_fall(int dummy)
 	the_state.fs = 0;
 	invoke_callback(the_state.initparams.fs_func, the_state.initparams.callback_delay, the_state.fs);
 
-#if LOG_FS
-	logerror("fs_fall(): fs=0 time=%g\n", timer_get_time());
-#endif
+	if (LOG_FS)
+		logerror("fs_fall(): fs=0 scanline=%d horzbeampos=%d time=%g\n", cpu_getscanline(), cpu_gethorzbeampos(), timer_get_time());
 }
 
 static void fs_rise(int dummy)
@@ -1060,21 +1359,99 @@ static void fs_rise(int dummy)
 	the_state.fs = 1;
 	invoke_callback(the_state.initparams.fs_func, the_state.initparams.callback_delay, the_state.fs);
 
-#if LOG_FS
-	logerror("fs_rise(): fs=1 time=%g\n", timer_get_time());
-#endif
+	if (LOG_FS)
+		logerror("fs_rise(): fs=1 scanline=%d horzbeampos=%d time=%g\n", cpu_getscanline(), cpu_gethorzbeampos(), timer_get_time());
+}
+*/
+
+static void hs_set_actual(int val)
+{
+	the_state.initparams.hs_func(0, val);
 }
 
-void internal_m6847_rastertrack_endcontent(void)
+static void hs_set(int val)
 {
-	timer_set(DFS_F, 0, fs_fall);
+	the_state.hs = val;
+	if (the_state.initparams.hs_func)
+		timer_adjust(the_state.hs_timer_actual, the_state.initparams.callback_delay, val, 0);
+
+	if (LOG_HS)
+		logerror("hs_set(): hs=%d scanline=%d horzbeampos=%d time=%g\n", val, cpu_getscanline(), cpu_gethorzbeampos(), timer_get_time());
 }
 
-int m6847_vh_interrupt(void)
+static void fs_set_actual(int val)
 {
-	timer_set(DHS_F, 0, hs_fall);
-	timer_set(DHS_R + (TIME_IN_HZ(3588545.0) * 16.5), 0, hs_rise);
-	return rastertrack_hblank();
+	the_state.initparams.fs_func(0, val);
+}
+
+static void fs_set(int val)
+{
+	the_state.fs = val;
+	if (the_state.initparams.fs_func)
+		timer_adjust(the_state.fs_timer_actual, the_state.initparams.callback_delay, val, 0);
+
+	if (LOG_FS)
+		logerror("fs_set(): fs=%d scanline=%d horzbeampos=%d time=%g\n", val, cpu_getscanline(), cpu_gethorzbeampos(), timer_get_time());
+}
+
+
+int internal_m6847_getadjustedscanline(void)
+{
+	int scanline;
+	int horzbeampos;
+
+	scanline = cpu_getscanline();
+	horzbeampos = cpu_gethorzbeampos();
+
+	/* adjust scanline because things seem to behave weird here */
+	if ((horzbeampos + (Machine->drv->screen_width / 4)) < Machine->drv->screen_width)
+	{
+		if (scanline == 0)
+			scanline = Machine->drv->screen_height-1;
+		else
+			scanline--;
+	}
+	return scanline;
+}
+
+void internal_m6847_vh_interrupt(int scanline, int rise_scanline, int fall_scanline)
+{
+	int new_fs;
+
+	if (LOG_INTERRUPT)
+		logerror("internal_m6847_vh_interrupt(): scanline=%d horzbeampos=%d\n", scanline, cpu_gethorzbeampos());
+
+	/* vsync interrupt */
+	if (rise_scanline > fall_scanline)
+	{
+		if (scanline >= rise_scanline)
+			new_fs = 1;
+		else if (scanline >= fall_scanline)
+			new_fs = 0;
+		else
+			new_fs = 1;
+	}
+	else
+	{
+		if (scanline >= fall_scanline)
+			new_fs = 0;
+		else if (scanline >= rise_scanline)
+			new_fs = 1;
+		else
+			new_fs = 0;
+	}
+
+	if ((new_fs && !the_state.fs) || (!new_fs && the_state.fs))
+		timer_adjust(the_state.fs_timer, DFS_R, new_fs, 0);
+
+	/* hsync interrupt */
+	timer_adjust(the_state.hs_timer1, DHS_F, 0, 0);
+	timer_adjust(the_state.hs_timer2, DHS_R + (TIME_IN_HZ(3588545.0) * 16.5), 1, 0);
+}
+
+INTERRUPT_GEN( m6847_vh_interrupt )
+{
+	internal_m6847_vh_interrupt(internal_m6847_getadjustedscanline(), 0, 13+25+192);
 }
 
 /* --------------------------------------------------
@@ -1086,187 +1463,6 @@ void m6847_set_ram_size(int ramsize)
 	the_state.initparams.ramsize = ramsize;
 }
 
-static UINT8 *mapper_alphanumeric(UINT8 *mem, int param, int *fg, int *bg, int *attr)
-{
-	UINT8 b;
-	UINT8 *character;
-	int bgc = 0, fgc = 0;
-
-	b = *mem;
-
-	/* Give the host machine a chance to pull our strings */
-	the_state.initparams.charproc(b);
-
-	if (the_state.modebits & M6847_MODEBIT_AS) {
-		/* Semigraphics */
-		bgc = 8;
-
-		if ((the_state.modebits & M6847_MODEBIT_INTEXT) &&  (!m6847_is_t1(the_state.initparams.version)) ) {
-			/* Semigraphics 6 */
-			character = &fontdata8x12[(96 + (b & 0x3f)) * 12];
-			fgc = ((b >> 6) & 0x3);
-			if (the_state.modebits & M6847_MODEBIT_CSS)
-				fgc += 4;
-		}
-		else {
-			/* Semigraphics 4 */
-			switch(b & 0x0f) {
-			case 0:
-				bgc = 8;
-				character = NULL;
-				break;
-			case 15:
-				bgc = (b >> 4) & 0x7;
-				character = NULL;
-				break;
-			default:
-				bgc = 8;
-				fgc = (b >> 4) & 0x7;
-				character = &fontdata8x12[(160 + (b & 0x0f)) * 12];
-				break;
-			}
-		}
-
-	}
-	else {
-		/* Text */
-		fgc = (the_state.modebits & M6847_MODEBIT_CSS) ? 15 : 13;
-
-		/* Inverse the character, if appropriate */
-		if (the_state.modebits & M6847_MODEBIT_INV)
-			fgc ^= 1;
-
-		if ((the_state.initparams.version == M6847_VERSION_M6847T1_PAL) || (the_state.initparams.version == M6847_VERSION_M6847T1_NTSC) ) {
-			/* M6847T1 specific features */
-
-			/* Lowercase */
-			if ((the_state.modebits & M6847_MODEBIT_GM0) && (b < 0x20))
-				b += 0x40;
-			else
-				b &= 0x3f;
-
-			/* Inverse (The following was verified in Rainbow Magazine 12/86) */
-			if (the_state.modebits & M6847_MODEBIT_GM1)
-				fgc ^= 1;
-		}
-		else {
-			b &= 0x3f;
-		}
-
-
-		if (b == 0x20) {
-			character = NULL;
-		}
-		else {
-			character = &fontdata8x12[b * 12];
-			if (param)
-				character += 1;	/* Skew up */
-		}
-		bgc = fgc ^ 1;
-	}
-
-	*bg = bgc;
-	*fg = fgc;
-	return character;
-}
-
-/* This is a refresh function used by the Dragon/CoCo as well as the CoCo 3 when in lo-res
- * mode.  Internally, it treats the colors like a CoCo 3 and uses the pens array to
- * translate those colors to the proper palette.
- *
- * video_vmode
- *     bit 4	1=graphics, 0=text
- *     bit 3    resolution high bit
- *     bit 2    resolution low bit
- *     bit 1    1=b/w graphics, 0=color graphics
- *     bit 0	color set
- */
-void internal_m6847_rastertrack_getvideomode(struct rastertrack_hvars *hvars,
-	UINT32 *pens, int skew_up, int border_pen, int wf,
-	int artifact_value, int artifact_palettebase,
-	void (*getcolorrgb)(int c, UINT8 *red, UINT8 *green, UINT8 *blue))
-{
-	hvars->mode.height = 192 / the_state.rowsize;
-	hvars->mode.offset = 0;
-	hvars->frame_width = 256 * wf;
-	hvars->frame_height = 192;
-	hvars->border_pen = Machine->pens[border_pen];
-
-	if (the_state.modebits & M6847_MODEBIT_AG)
-	{
-		hvars->mode.flags = RASTERBITS_FLAG_GRAPHICS;
-		hvars->mode.flags = RASTERBITS_FLAG_GRAPHICS;
-
-		if (the_state.modebits & M6847_MODEBIT_GM0)
-		{
-			/* Resolution modes */
-			hvars->mode.bytesperrow = ((the_state.modebits & (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) == (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) ? 32 : 16;
-			hvars->mode.width = hvars->mode.bytesperrow * 8;
-			hvars->mode.depth = 1;
-			if (the_state.modebits & M6847_MODEBIT_CSS) {
-				hvars->mode.pens[0] = pens[10];
-				hvars->mode.pens[1] = pens[11];
-			}
-			else {
-				hvars->mode.pens[0] = pens[8];
-				hvars->mode.pens[1] = pens[9];
-			}
-
-			if (artifact_value && (hvars->mode.bytesperrow == 32)) {
-				/* I am here because we are doing PMODE 4 artifact colors */
-
-				hvars->mode.flags |= RASTERBITS_FLAG_ARTIFACT;
-				if (artifact_palettebase < 0) {
-					hvars->mode.u.artifact.flags = RASTERBITS_ARTIFACT_STATICPALLETTE;
-					hvars->mode.u.artifact.u.staticpalette = game_palette;
-				}
-				else {
-					hvars->mode.u.artifact.flags = RASTERBITS_ARTIFACT_DYNAMICPALETTE;
-					hvars->mode.u.artifact.u.dynamicpalettebase = artifact_palettebase;
-				}
-
-				if (artifact_value >= 2)
-					hvars->mode.u.artifact.flags |= RASTERBITS_ARTIFACT_REVERSE;
-
-				hvars->mode.u.artifact.colorfactors = artifactfactors;
-				hvars->mode.u.artifact.numfactors = M6847_ARTIFACT_COLOR_COUNT;
-				hvars->mode.u.artifact.getcolorrgb = getcolorrgb;
-			}
-		}
-		else
-		{
-			/* Color modes */
-			hvars->mode.bytesperrow = ((the_state.modebits & (M6847_MODEBIT_GM2|M6847_MODEBIT_GM1)) != 0) ? 32 : 16;
-			hvars->mode.width = hvars->mode.bytesperrow * 4;
-			hvars->mode.depth = 2;
-			if (the_state.modebits & M6847_MODEBIT_CSS) {
-				hvars->mode.pens[0] = pens[4];
-				hvars->mode.pens[1] = pens[5];
-				hvars->mode.pens[2] = pens[6];
-				hvars->mode.pens[3] = pens[7];
-			}
-			else {
-				hvars->mode.pens[0] = pens[0];
-				hvars->mode.pens[1] = pens[1];
-				hvars->mode.pens[2] = pens[2];
-				hvars->mode.pens[3] = pens[3];
-			}
-		}
-	}
-	else
-	{
-		hvars->mode.flags = RASTERBITS_FLAG_TEXT | RASTERBITS_FLAG_TEXTMODULO;
-		hvars->mode.bytesperrow = 32;
-		hvars->mode.width = 32;
-		hvars->mode.depth = 8;
-		memcpy(hvars->mode.pens, pens, sizeof(hvars->mode.pens));
-		hvars->mode.u.text.mapper = mapper_alphanumeric;
-		hvars->mode.u.text.mapper_param = skew_up;
-		hvars->mode.u.text.fontheight = 12;
-		hvars->mode.u.text.underlinepos = -1;
-	}
-}
-
 int m6847_get_bordercolor(void)
 {
 	int bordercolor;
@@ -1293,63 +1489,29 @@ int m6847_get_bordercolor(void)
 	return bordercolor;
 }
 
-static int m6847_bordercolor(void)
-{
-	int pen = 0;
-
-	switch(m6847_get_bordercolor()) {
-	case M6847_BORDERCOLOR_BLACK:
-		pen = 0;
-		break;
-	case M6847_BORDERCOLOR_GREEN:
-		pen = 1;
-		break;
-	case M6847_BORDERCOLOR_WHITE:
-		pen = 5;
-		break;
-	case M6847_BORDERCOLOR_ORANGE:
-		pen = 12;
-		break;
-	}
-	return pen;
-}
-
-static void m6847_rastertrack_getvideomode(struct rastertrack_hvars *hvars)
+void internal_video_update_m6847(int screen, mame_bitmap *bitmap, const rectangle *cliprect, int *do_skip)
 {
+	static int last_artifact_value = 0;
 	int artifact_value;
-	static UINT32 m6847_metapalette[] = {
-		1, 2, 3, 4, 5, 6, 7, 8, 0, 1, 0, 5, 9, 10, 11, 12
-	};
+	int mode_with_arifact = M6847_MODEBIT_AG|M6847_MODEBIT_GM2|M6847_MODEBIT_GM1|M6847_MODEBIT_GM0;
 
-	artifact_value = (the_state.initparams.artifactdipswitch == -1) ? 0 : (readinputport(the_state.initparams.artifactdipswitch) & 3);
-	internal_m6847_rastertrack_getvideomode(hvars, m6847_metapalette, 0, m6847_bordercolor(), 1, artifact_value, -1, NULL);
-}
-
-void internal_m6847_rastertrack_newscreen(struct rastertrack_vvars *vvars, struct rastertrack_hvars *hvars,
-	int border_top, int rows, int baseoffset, int use_m6847_offset, void (*getvideomode)(struct rastertrack_hvars *))
-{
-	timer_set(DFS_R, 0, fs_rise);
-
-	the_state.latched_videooffset = the_state.videooffset;
-
-	if (vvars) {
-		vvars->bordertop = border_top;
-		vvars->rows = rows;
-		vvars->baseaddress = (use_m6847_offset ? the_state.latched_videooffset : 0) + baseoffset;
-	}
-	if (hvars) {
-		getvideomode(hvars);
+	/* this code is needed so we can detect changes in the artifact dip switch */
+	if ((the_state.modebits & mode_with_arifact) == mode_with_arifact)
+	{
+		artifact_value = get_artifact_value();
+		if (artifact_value != last_artifact_value)
+		{
+			last_artifact_value = artifact_value;
+			videomap_invalidate_lineinfo();
+		}
 	}
+
+	video_update_videomap(screen, bitmap, cliprect, do_skip);
 }
 
-static void m6847_rastertrack_newscreen(struct rastertrack_vvars *vvars, struct rastertrack_hvars *hvars)
+static VIDEO_UPDATE( m6847 )
 {
-	internal_m6847_rastertrack_newscreen(vvars, hvars, 38, 192, 0, TRUE, m6847_rastertrack_getvideomode);
-}
-
-void m6847_vh_update(struct mame_bitmap *bitmap, int full_refresh)
-{
-	rastertrack_refresh(bitmap, full_refresh);
+	internal_video_update_m6847(screen, bitmap, cliprect, do_skip);
 }
 
 int m6847_is_t1(int version)
@@ -1369,14 +1531,14 @@ int m6847_is_t1(int version)
 
 void m6847_set_video_offset(int offset)
 {
-#if LOG_M6847
-	logerror("m6847_set_video_offset(): offset=$%04x\n", offset);
-#endif
+	if (LOG_M6847)
+		logerror("m6847_set_video_offset(): offset=$%04x\n", offset);
 
 	offset %= the_state.initparams.ramsize;
-	if (offset != the_state.videooffset) {
+	if (offset != the_state.videooffset)
+	{
 		the_state.videooffset = offset;
-		schedule_full_refresh();
+		videomap_invalidate_frameinfo();
 	}
 }
 
@@ -1396,9 +1558,9 @@ void m6847_touch_vram(int offset)
 
 void m6847_set_row_height(int rowheight)
 {
-	if (rowheight != the_state.rowsize) {
-		the_state.rowsize = rowheight;
-		rastertrack_touchvideomode();
+	if (rowheight != the_state.rowheight) {
+		the_state.rowheight = rowheight;
+		videomap_invalidate_lineinfo();
 	}
 }
 
@@ -1416,16 +1578,27 @@ void m6847_set_cannonical_row_height(void)
 	m6847_set_row_height(rowheight);
 }
 
-READ_HANDLER( m6847_ag_r )		{ return (the_state.modebits & M6847_MODEBIT_AG) ? 1 : 0; }
-READ_HANDLER( m6847_as_r )		{ return (the_state.modebits & M6847_MODEBIT_AS) ? 1 : 0; }
-READ_HANDLER( m6847_intext_r )	{ return (the_state.modebits & M6847_MODEBIT_INTEXT) ? 1 : 0; }
-READ_HANDLER( m6847_inv_r )		{ return (the_state.modebits & M6847_MODEBIT_INV) ? 1 : 0; }
-READ_HANDLER( m6847_css_r )		{ return (the_state.modebits & M6847_MODEBIT_CSS) ? 1 : 0; }
-READ_HANDLER( m6847_gm2_r )		{ return (the_state.modebits & M6847_MODEBIT_GM2) ? 1 : 0; }
-READ_HANDLER( m6847_gm1_r )		{ return (the_state.modebits & M6847_MODEBIT_GM1) ? 1 : 0; }
-READ_HANDLER( m6847_gm0_r )		{ return (the_state.modebits & M6847_MODEBIT_GM0) ? 1 : 0; }
-READ_HANDLER( m6847_fs_r )		{ return the_state.fs; }
-READ_HANDLER( m6847_hs_r )		{ return the_state.hs; }
+void mdrv_m6847(machine_config *machine, int (*video_start_proc)(void), int is_pal)
+{
+	MDRV_VIDEO_ATTRIBUTES(M6847_VIDEO_TYPE)
+	MDRV_SCREEN_SIZE(M6847_SCREEN_WIDTH, M6847_SCREEN_HEIGHT)
+	MDRV_VISIBLE_AREA(0,319,11,250)
+	MDRV_PALETTE_LENGTH(M6847_TOTAL_COLORS)
+	MDRV_PALETTE_INIT(m6847)
+	MDRV_VIDEO_START(proc)
+	MDRV_VIDEO_UPDATE(m6847)
+}
+
+ READ8_HANDLER( m6847_ag_r )		{ return (the_state.modebits & M6847_MODEBIT_AG) ? 1 : 0; }
+ READ8_HANDLER( m6847_as_r )		{ return (the_state.modebits & M6847_MODEBIT_AS) ? 1 : 0; }
+ READ8_HANDLER( m6847_intext_r )	{ return (the_state.modebits & M6847_MODEBIT_INTEXT) ? 1 : 0; }
+ READ8_HANDLER( m6847_inv_r )		{ return (the_state.modebits & M6847_MODEBIT_INV) ? 1 : 0; }
+ READ8_HANDLER( m6847_css_r )		{ return (the_state.modebits & M6847_MODEBIT_CSS) ? 1 : 0; }
+ READ8_HANDLER( m6847_gm2_r )		{ return (the_state.modebits & M6847_MODEBIT_GM2) ? 1 : 0; }
+ READ8_HANDLER( m6847_gm1_r )		{ return (the_state.modebits & M6847_MODEBIT_GM1) ? 1 : 0; }
+ READ8_HANDLER( m6847_gm0_r )		{ return (the_state.modebits & M6847_MODEBIT_GM0) ? 1 : 0; }
+ READ8_HANDLER( m6847_fs_r )		{ return the_state.fs; }
+ READ8_HANDLER( m6847_hs_r )		{ return the_state.hs; }
 
 static void write_modebits(int data, int mask, int causesrefresh)
 {
@@ -1436,18 +1609,22 @@ static void write_modebits(int data, int mask, int causesrefresh)
 	else
 		newmodebits = the_state.modebits & ~mask;
 
-	if (newmodebits != the_state.modebits) {
+	if (newmodebits != the_state.modebits)
+	{
 		the_state.modebits = newmodebits;
 		if (causesrefresh)
-			rastertrack_touchvideomode();
+		{
+			videomap_invalidate_lineinfo();
+			videomap_invalidate_border();
+		}
 	}
 }
 
-WRITE_HANDLER( m6847_ag_w )		{ write_modebits(data, M6847_MODEBIT_AG, 1); }
-WRITE_HANDLER( m6847_as_w )		{ write_modebits(data, M6847_MODEBIT_AS, 0); }
-WRITE_HANDLER( m6847_intext_w )	{ write_modebits(data, M6847_MODEBIT_INTEXT, 0); }
-WRITE_HANDLER( m6847_inv_w )	{ write_modebits(data, M6847_MODEBIT_INV, 0); }
-WRITE_HANDLER( m6847_css_w )	{ write_modebits(data, M6847_MODEBIT_CSS, 1); }
-WRITE_HANDLER( m6847_gm2_w )	{ write_modebits(data, M6847_MODEBIT_GM2, 1); }
-WRITE_HANDLER( m6847_gm1_w )	{ write_modebits(data, M6847_MODEBIT_GM1, 1); }
-WRITE_HANDLER( m6847_gm0_w )	{ write_modebits(data, M6847_MODEBIT_GM0, 1); }
+WRITE8_HANDLER( m6847_ag_w )		{ write_modebits(data, M6847_MODEBIT_AG, 1); }
+WRITE8_HANDLER( m6847_as_w )		{ write_modebits(data, M6847_MODEBIT_AS, 0); }
+WRITE8_HANDLER( m6847_intext_w )	{ write_modebits(data, M6847_MODEBIT_INTEXT, 0); }
+WRITE8_HANDLER( m6847_inv_w )	{ write_modebits(data, M6847_MODEBIT_INV, 0); }
+WRITE8_HANDLER( m6847_css_w )	{ write_modebits(data, M6847_MODEBIT_CSS, 1); }
+WRITE8_HANDLER( m6847_gm2_w )	{ write_modebits(data, M6847_MODEBIT_GM2, 1); }
+WRITE8_HANDLER( m6847_gm1_w )	{ write_modebits(data, M6847_MODEBIT_GM1, 1); }
+WRITE8_HANDLER( m6847_gm0_w )	{ write_modebits(data, M6847_MODEBIT_GM0, 1); }
