@@ -8,6 +8,7 @@
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "includes/mbee.h"
 
 typedef struct {		 /* CRTC 6545 */
 	UINT8 horizontal_total;
@@ -53,92 +54,94 @@ int mbee_frame_counter;
 UINT8 *pcgram;
 
 /* from mess/systems/microbee.c */
-extern struct GfxLayout mbee_charlayout;
+extern gfx_layout mbee_charlayout;
 
 
-void mbee_pcg_color_latch_w(int offs, int data)
+WRITE8_HANDLER ( mbee_pcg_color_latch_w )
 {
 	logerror("mbee pcg_color_latch_w $%02X\n", data);
 	mbee_pcg_color_latch = data;
 }
 
-int mbee_pcg_color_latch_r(int offs)
+ READ8_HANDLER ( mbee_pcg_color_latch_r )
 {
 	int data = mbee_pcg_color_latch;
 	logerror("mbee pcg_color_latch_r $%02X\n", data);
 	return data;
 }
 
-void mbee_videoram_w(int offs, int data)
+WRITE8_HANDLER ( mbee_videoram_w )
 {
-    if( videoram[offs] != data )
+    if( videoram[offset] != data )
 	{
-		logerror("mbee videoram [$%04X] <- $%02X\n",offs,data);
-		videoram[offs] = data;
-		dirtybuffer[offs] = 1;
+		logerror("mbee videoram [$%04X] <- $%02X\n", offset, data);
+		videoram[offset] = data;
+		colorram[offset] = 2;
+		dirtybuffer[offset] = 1;
 	}
 }
 
-int mbee_videoram_r(int offs)
+ READ8_HANDLER ( mbee_videoram_r )
 {
 	int data;
 	if( m6545_video_bank & 0x01 )
 	{
-		data = pcgram[offs];
-		logerror("mbee pcgram [$%04X] -> $%02X\n",offs,data);
+		data = pcgram[offset];
+		logerror("mbee pcgram [$%04X] -> $%02X\n", offset, data);
 	}
 	else
 	{
-		data = videoram[offs];
-		logerror("mbee videoram [$%04X] -> $%02X\n",offs,data);
+		data = videoram[offset];
+		logerror("mbee videoram [$%04X] -> $%02X\n", offset, data);
     }
     return data;
 }
 
-void mbee_pcg_color_w(int offs, int data)
+WRITE8_HANDLER ( mbee_pcg_color_w )
 {
 	if( (m6545_video_bank & 0x01) || (mbee_pcg_color_latch & 0x40) == 0 )
 	{
-		if( pcgram[0x0800+offs] != data )
+		if( pcgram[0x0800+offset] != data )
         {
-            int chr = 0x80 + offs / 16;
+            int chr = 0x80 + offset / 16;
+			int i;
 
-            logerror("mbee pcgram  [$%04X] <- $%02X\n",offs,data);
-            pcgram[0x0800+offs] = data;
+            logerror("mbee pcgram  [$%04X] <- $%02X\n", offset, data);
+            pcgram[0x0800+offset] = data;
             /* decode character graphics again */
             decodechar(Machine->gfx[0], chr, pcgram, &mbee_charlayout);
 
             /* mark all visible characters with that code dirty */
-            for( offs = 0; offs < videoram_size; offs++ )
+            for( i = 0; i < videoram_size; i++ )
             {
-                if( videoram[offs] == chr )
-                    dirtybuffer[offs] = 1;
+                if( videoram[i] == chr )
+                    dirtybuffer[i] = 1;
             }
         }
     }
 	else
 	{
-		if( colorram[offs] != data )
+		if( colorram[offset] != data )
         {
-            logerror("colorram [$%04X] <- $%02X\n",offs,data);
-            colorram[offs] = data;
-            dirtybuffer[offs] = 1;
+            logerror("colorram [$%04X] <- $%02X\n", offset, data);
+            colorram[offset] = data;
+            dirtybuffer[offset] = 1;
         }
 	}
 }
 
-int mbee_pcg_color_r(int offs)
+ READ8_HANDLER ( mbee_pcg_color_r )
 {
 	int data;
 
 	if( mbee_pcg_color_latch & 0x40 )
-        data = colorram[offs];
+        data = colorram[offset];
 	else
-		data = pcgram[0x0800+offs];
+		data = pcgram[0x0800+offset];
     return data;
 }
 
-int keyboard_matrix_r(int offs)
+static int keyboard_matrix_r(int offs)
 {
 	int port = (offs >> 7) & 7;
 	int bit = (offs >> 4) & 7;
@@ -201,33 +204,33 @@ static void m6545_offset_xy(void)
 	logerror("6545 offset x:%d  y:%d\n", off_x, off_y);
 }
 
-int mbee_color_bank_r(int offs)
+ READ8_HANDLER ( mbee_color_bank_r )
 {
 	int data = m6545_color_bank;
 	logerror("6545 color_bank_r $%02X\n", data);
 	return data;
 }
 
-void mbee_color_bank_w(int offs, int data)
+WRITE8_HANDLER ( mbee_color_bank_w )
 {
 	logerror("6545 color_bank_w $%02X\n", data);
 	m6545_color_bank = data;
 }
 
-int mbee_video_bank_r(int offs)
+ READ8_HANDLER ( mbee_video_bank_r )
 {
 	int data = m6545_video_bank;
 	logerror("6545 video_bank_r $%02X\n", data);
 	return data;
 }
 
-void mbee_video_bank_w(int offs, int data)
+WRITE8_HANDLER ( mbee_video_bank_w )
 {
 	logerror("6545 video_bank_w $%02X\n", data);
     m6545_video_bank = data;
 }
 
-void m6545_update_strobe(int param)
+static void m6545_update_strobe(int param)
 {
 	int data;
     data = keyboard_matrix_r(param);
@@ -238,7 +241,7 @@ void m6545_update_strobe(int param)
 	}
 }
 
-int m6545_status_r(int offs)
+ READ8_HANDLER ( m6545_status_r )
 {
 	int data = 0, y = cpu_getscanline();
 
@@ -253,7 +256,7 @@ int m6545_status_r(int offs)
     return data;
 }
 
-int m6545_data_r(int offs)
+ READ8_HANDLER ( m6545_data_r )
 {
 	int addr, data = 0;
 
@@ -328,12 +331,12 @@ int m6545_data_r(int offs)
 	return data;
 }
 
-void m6545_index_w(int offs, int data)
+WRITE8_HANDLER ( m6545_index_w )
 {
 	crt.idx = data & 0x1f;
 }
 
-void m6545_data_w(int offs, int data)
+WRITE8_HANDLER ( m6545_data_w )
 {
 	int addr;
 
@@ -491,9 +494,9 @@ void m6545_data_w(int offs, int data)
     }
 }
 
-int mbee_vh_start(void)
+VIDEO_START( mbee )
 {
-    if( generic_vh_start() )
+    if( video_start_generic() )
 		return 1;
 	pcgram = memory_region(REGION_CPU1)+0xf000;
 	videoram = memory_region(REGION_GFX1)+0x0000;
@@ -503,14 +506,10 @@ int mbee_vh_start(void)
     return 0;
 }
 
-void mbee_vh_stop(void)
+VIDEO_UPDATE( mbee )
 {
-	generic_vh_stop();
-}
-
-void mbee_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
-{
-	int offs, cursor;
+	int offs, cursor, screen_;
+	int full_refresh = 1;
 
 	if( mbee_frame_counter > 0 )
 	{
@@ -518,19 +517,13 @@ void mbee_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 			full_refresh = 1;
 		else
 		{
-			/* I know this is ugly, but it happens only once
-			 * after a new message is sprintf()ed into the string :)
-			 */
-            while( strlen(mbee_frame_message) < 128 )
-				strcat(mbee_frame_message, " ");
-			ui_text(bitmap, mbee_frame_message, 0, Machine->uiheight - 10);
+			ui_popup("%s", mbee_frame_message);
 		}
     }
 
     if( full_refresh )
 	{
 		memset(dirtybuffer, 1, videoram_size);
-        fillbitmap(bitmap, Machine->pens[0], &Machine->visible_area);
 	}
 
 	for( offs = 0x000; offs < 0x380; offs += 0x10 )
@@ -538,14 +531,15 @@ void mbee_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 
 	framecnt++;
 
-    cursor = crt.cursor_address_hi * 256 + crt.cursor_address_lo;
-	for( offs = 0; offs < crt.horizontal_displayed * crt.vertical_displayed; offs++ )
+	cursor = crt.cursor_address_hi * 256 + crt.cursor_address_lo;
+	screen_ = crt.screen_address_hi * 256 + crt.screen_address_lo;
+	for( offs = screen_; offs < crt.horizontal_displayed * crt.vertical_displayed + screen_; offs++ )
 	{
 		if( dirtybuffer[offs] )
 		{
 			int sx, sy, code, color;
-			sy = off_y + (offs / crt.horizontal_displayed) * (crt.scan_lines + 1);
-			sx = (off_x + (offs % crt.horizontal_displayed)) * 8;
+			sy = off_y + ((offs - screen_) / crt.horizontal_displayed) * (crt.scan_lines + 1);
+			sx = (off_x + ((offs - screen_) % crt.horizontal_displayed)) * 8;
 			code = videoram[offs];
 			color = colorram[offs];
 			drawgfx( bitmap,Machine->gfx[0],code,color,0,0,sx,sy,
