@@ -18,37 +18,38 @@
    light back / grid colors
    black, blue, green, light green, red, violet, orange, light grey */
 
-UINT8 odyssey2_colors[24][3]={
-  /* Background,Grid Dim */
-  { 0x00,0x00,0x00 },
-  { 0x00,0x00,0xFF },   /* Blue */
-  { 0x00,0x80,0x00 },   /* DK Green */
-  { 0xff,0x9b,0x60 },
-  { 0xCC,0x00,0x00 },   /* Red */
-  { 0xa9,0x80,0xff },
-  { 0x82,0xfd,0xdb },
-  { 0xFF,0xFF,0xFF },
+UINT8 odyssey2_colors[] =
+{
+	/* Background,Grid Dim */
+	0x00,0x00,0x00,
+	0x00,0x00,0xFF,   /* Blue */
+	0x00,0x80,0x00,   /* DK Green */
+	0xff,0x9b,0x60,
+	0xCC,0x00,0x00,   /* Red */
+	0xa9,0x80,0xff,
+	0x82,0xfd,0xdb,
+	0xFF,0xFF,0xFF,
 
-  /* Background,Grid Bright */
+	/* Background,Grid Bright */
 
-  { 0x80,0x80,0x80 },
-  { 0x50,0xAE,0xFF },   /* Blue */
-  { 0x00,0xFF,0x00 },   /* Dk Green */
-  { 0x82,0xfb,0xdb },   /* Lt Grey */
-  { 0xEC,0x02,0x60 },   /* Red */
-  { 0xa9,0x80,0xff },   /* Violet */
-  { 0xff,0x9b,0x60 },   /* Orange */
-  { 0xFF,0xFF,0xFF },
+	0x80,0x80,0x80,
+	0x50,0xAE,0xFF,   /* Blue */
+	0x00,0xFF,0x00,   /* Dk Green */
+	0x82,0xfb,0xdb,   /* Lt Grey */
+	0xEC,0x02,0x60,   /* Red */
+	0xa9,0x80,0xff,   /* Violet */
+	0xff,0x9b,0x60,   /* Orange */
+	0xFF,0xFF,0xFF,
 
-  /* Character,Sprite colors */
-  { 0x71,0x71,0x71 },   /* Dark Grey */
-  { 0xFF,0x80,0x80 },   /* Red */
-  { 0x00,0xC0,0x00 },   /* Green */
-  { 0xff,0x9b,0x60 },   /* Orange */
-  { 0x50,0xAE,0xFF },   /* Blue */
-  { 0xa9,0x80,0xff },   /* Violet */
-  { 0x82,0xfb,0xdb },   /* Lt Grey */
-  { 0xff,0xff,0xff }    /* White */
+	/* Character,Sprite colors */
+	0x71,0x71,0x71,   /* Dark Grey */
+	0xFF,0x80,0x80,   /* Red */
+	0x00,0xC0,0x00,   /* Green */
+	0xff,0x9b,0x60,   /* Orange */
+	0x50,0xAE,0xFF,   /* Blue */
+	0xa9,0x80,0xff,   /* Violet */
+	0x82,0xfb,0xdb,   /* Lt Grey */
+	0xff,0xff,0xff    /* White */
 };
 
 UINT8 o2_shape[0x40][8]={
@@ -154,20 +155,24 @@ union {
 static UINT8 collision;
 static int line;
 static double line_time;
+static UINT32 o2_snd_shift[2];
 
 /***************************************************************************
 
   Start the video hardware emulation.
 
 ***************************************************************************/
-int odyssey2_vh_start(void)
+VIDEO_START( odyssey2 )
 {
-    odyssey2_vh_hpos = 0;
-	odyssey2_display = (UINT8 *)malloc(8 * 8 * 256);
+	o2_snd_shift[0] = Machine->sample_rate / 983;
+	o2_snd_shift[1] = Machine->sample_rate / 3933;
+
+	odyssey2_vh_hpos = 0;
+	odyssey2_display = (UINT8 *) auto_malloc(8 * 8 * 256);
 	if( !odyssey2_display )
 		return 1;
 	memset(odyssey2_display, 0, 8 * 8 * 256);
-    return 0;
+	return 0;
 }
 
 /***************************************************************************
@@ -176,21 +181,14 @@ int odyssey2_vh_start(void)
 
 ***************************************************************************/
 
-void odyssey2_vh_init_palette(unsigned char *game_palette, unsigned short *game_colortable,const unsigned char *color_prom)
+PALETTE_INIT( odyssey2 )
 {
-    game_colortable[0] = 0;
-    game_colortable[1] = 1;
-    memcpy (game_palette, odyssey2_colors, sizeof(odyssey2_colors));
+	palette_set_colors(0, odyssey2_colors, sizeof(odyssey2_colors) / 3);
+	colortable[0] = 0;
+	colortable[1] = 1;
 }
 
-void odyssey2_vh_stop(void)
-{
-	if( odyssey2_display )
-		free(odyssey2_display);
-	odyssey2_display = NULL;
-}
-
-extern READ_HANDLER ( odyssey2_video_r )
+extern  READ8_HANDLER ( odyssey2_video_r )
 {
     UINT8 data=0;
     int h;
@@ -211,55 +209,60 @@ extern READ_HANDLER ( odyssey2_video_r )
     return data;
 }
 
-extern WRITE_HANDLER ( odyssey2_video_w )
+extern WRITE8_HANDLER ( odyssey2_video_w )
 {
-    o2_vdc.reg[offset]=data;
+	/* Update the sound */
+	if( offset >= 0xa7 && offset <= 0xaa )
+		stream_update( odyssey2_sh_channel, 0 );
+
+	o2_vdc.reg[offset]=data;
 }
 
-extern READ_HANDLER ( odyssey2_t1_r )
+extern  READ8_HANDLER ( odyssey2_t1_r )
 {
-/*    static bool t=FALSE; */
     static int t=FALSE;
     t=!t;
     return t;
 }
 
-int odyssey2_line(void)
+INTERRUPT_GEN( odyssey2_line )
 {
-    line_time=timer_get_time();
-    line=(line+1)%262;
+    line_time = timer_get_time();
+    line = (line + 1) % 262;
+
     switch (line) {
     case 252:
-	cpu_set_irq_line(0, 1, ASSERT_LINE); /*vsync?? */
-	break;
+		cpunum_set_input_line(0, 0, ASSERT_LINE); /* vsync?? */
+		break;
     case 253:
-	cpu_set_irq_line(0, 1, CLEAR_LINE); /*vsync?? */
-	break;
+		cpunum_set_input_line(0, 0, CLEAR_LINE); /* vsync?? */
+		break;
     }
-    return 0;
 }
 
 INLINE void odyssey2_draw_box(UINT8 bg[][320], int x, int y, int width, int height, UINT8 color)
 {
     int x1,y1;
-    for (y1=0; y1<height; y1++) {
-	for (x1=0; x1<width; x1++) {
-	    bg[y+y1][x+x1]|=color;
-	}
+    for (y1 = 0; y1 < height; y1++)
+	{
+		for (x1 = 0; x1 < width; x1++)
+			bg[y+y1][x+x1] |= color;
     }
 }
 
 INLINE void odyssey2_draw(UINT8 bg[][320], UINT8 code, int x, int y, int scale_x, int scale_y, UINT8 color)
 {
     int m,x1,y1;
-    for (m=0x80; m>0; m>>=1, x+=scale_x) {
-	if (code&m) {
-	    for (y1=0; y1<scale_y; y1++) {
-		for (x1=0; x1<scale_x; x1++) {
-		    bg[y+y1][x+x1]|=color;
+    for (m=0x80; m>0; m>>=1, x+=scale_x)
+	{
+		if (code & m)
+		{
+			for (y1=0; y1<scale_y; y1++)
+			{
+				for (x1 = 0; x1 < scale_x; x1++)
+					bg[y+y1][x+x1] |= color;
+			}
 		}
-	    }
-	}
     }
 }
 
@@ -267,18 +270,20 @@ INLINE void odyssey2_draw(UINT8 bg[][320], UINT8 code, int x, int y, int scale_x
 INLINE void odyssey2_draw_sprite(UINT8 bg[][320], UINT8 code, int x, int y, int scale_x, int scale_y, UINT8 color)
 {
     int m,x1,y1;
-    for (m=1; m<=0x80; m<<=1, x+=scale_x) {
-	if (code&m) {
-	    for (y1=0; y1<scale_y; y1++) {
-		for (x1=0; x1<scale_x; x1++) {
-		    bg[y+y1][x+x1]|=color;
+    for (m=1; m<=0x80; m<<=1, x+=scale_x)
+	{
+		if (code & m)
+		{
+			for (y1=0; y1<scale_y; y1++)
+			{
+				for (x1 = 0; x1 < scale_x; x1++)
+					bg[y+y1][x+x1] |= color;
+			}
 		}
-	    }
-	}
     }
 }
 
-INLINE void odyssey2_draw_char(struct mame_bitmap *bitmap, UINT8 bg[][320], int x, int y, int ptr, int color)
+INLINE void odyssey2_draw_char(mame_bitmap *bitmap, UINT8 bg[][320], int x, int y, int ptr, int color)
 {
     int n, i;
     int offset=ptr|((color&1)<<8);
@@ -305,111 +310,156 @@ INLINE void odyssey2_draw_char(struct mame_bitmap *bitmap, UINT8 bg[][320], int
 
 ***************************************************************************/
 
-void odyssey2_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( odyssey2 )
 {
-    int i, j, x, y;
-    int color;
-    UINT8 bg[300][320]= { { 0 } };
+	int i, j, x, y;
+	int color;
+	UINT8 bg[300][320]= { { 0 } };
 
-    assert(bitmap->width<=ARRAY_LENGTH(bg[0])
-	   && bitmap->height<=ARRAY_LENGTH(bg));
+	assert(bitmap->width<=ARRAY_LENGTH(bg[0])
+		&& bitmap->height<=ARRAY_LENGTH(bg));
 
-    plot_box(bitmap, 0, 0, bitmap->width, bitmap->height, Machine->pens[(o2_vdc.s.color>>3)&0x7]);
-    if (o2_vdc.s.control&8) {
-	/* grid 8 points right compared to characters, sprites */
+	plot_box(bitmap, 0, 0, bitmap->width, bitmap->height, Machine->pens[(o2_vdc.s.color>>3)&0x7]);
+	if (o2_vdc.s.control & 8)
+	{
+		/* grid 8 points right compared to characters, sprites */
 #define WIDTH 16
 #define HEIGHT 24
-	int w=2;
-	color=o2_vdc.s.color&7;
-	color|=(o2_vdc.s.color>>3)&8;
-	for (i=0, x=0; x<9; x++, i++) {
-	    for (j=1, y=0; y<9; y++, j<<=1) {
-		if ( ((j<=0x80)&&(o2_vdc.s.hgrid[0][i]&j))
-		     ||((j>0x80)&&(o2_vdc.s.hgrid[1][i]&1)) ) {
-		    odyssey2_draw_box(bg,8+x*WIDTH,24+y*HEIGHT, WIDTH,3, 0x20);
-		    plot_box(bitmap,8+x*WIDTH,24+y*HEIGHT,WIDTH,3,Machine->pens[color]);
+		int w=2;
+		color=o2_vdc.s.color&7;
+		color|=(o2_vdc.s.color>>3)&8;
+		for (i=0, x=0; x<9; x++, i++) {
+			for (j=1, y=0; y<9; y++, j<<=1) {
+				if ( ((j<=0x80)&&(o2_vdc.s.hgrid[0][i]&j))
+						||((j>0x80)&&(o2_vdc.s.hgrid[1][i]&1)) )
+				{
+					odyssey2_draw_box(bg,8+x*WIDTH,24+y*HEIGHT, WIDTH,3, 0x20);
+					plot_box(bitmap,8+x*WIDTH,24+y*HEIGHT,WIDTH,3,Machine->pens[color]);
+				}
+		    }
 		}
-	    }
-	}
-	if (o2_vdc.s.control&0x80) w=WIDTH;
-	for (i=0, x=0; x<10; x++, i++) {
-	    for (j=1, y=0; y<8; y++, j<<=1) {
-		if (o2_vdc.s.vgrid[i]&j) {
-		    odyssey2_draw_box(bg,8+x*WIDTH,24+y*HEIGHT,w,HEIGHT, 0x10);
-		    plot_box(bitmap,8+x*WIDTH,24+y*HEIGHT,w,HEIGHT,Machine->pens[color]);
+		if (o2_vdc.s.control&0x80) w=WIDTH;
+		for (i=0, x=0; x<10; x++, i++) {
+			for (j=1, y=0; y<8; y++, j<<=1)
+			{
+				if (o2_vdc.s.vgrid[i]&j) {
+				    odyssey2_draw_box(bg,8+x*WIDTH,24+y*HEIGHT,w,HEIGHT, 0x10);
+				    plot_box(bitmap,8+x*WIDTH,24+y*HEIGHT,w,HEIGHT,Machine->pens[color]);
+				}
+			}
 		}
-	    }
-	}
     }
-    if (o2_vdc.s.control&0x20) {
-	for (i=0; i<ARRAY_LENGTH(o2_vdc.s.foreground); i++) {
-	    odyssey2_draw_char(bitmap,bg,
-			       o2_vdc.s.foreground[i].x, o2_vdc.s.foreground[i].y,
-			       o2_vdc.s.foreground[i].ptr, o2_vdc.s.foreground[i].color);
-	}
-	for (i=0; i<ARRAY_LENGTH(o2_vdc.s.quad); i++) {
-	    x=o2_vdc.s.quad[i].single[0].x;
-	    for (j=0; j<ARRAY_LENGTH(o2_vdc.s.quad[0].single); j++, x+=2*8) {
-		odyssey2_draw_char(bitmap,bg,
-				   x, y=o2_vdc.s.quad[i].single[0].y,
-				   o2_vdc.s.quad[i].single[j].ptr, o2_vdc.s.quad[i].single[j].color);
-	    }
-	}
-	for (i=0; i<ARRAY_LENGTH(o2_vdc.s.sprites); i++) {
-	    Machine->gfx[0]->colortable[1]=Machine->pens[16+((o2_vdc.s.sprites[i].color>>3)&7)];
-	    y=o2_vdc.s.sprites[i].y;
-	    x=o2_vdc.s.sprites[i].x;
-	    for (j=0; j<8; j++) {
-		if (o2_vdc.s.sprites[i].color&4) {
-		    if (y+4*j>=bitmap->height) break;
-		    odyssey2_draw_sprite(bg, o2_vdc.s.shape[i][j], x, y+j*4, 2, 4, 1<<i);
-		    drawgfxzoom(bitmap, Machine->gfx[1], o2_vdc.s.shape[i][j],0,
-				0,0,x,y+j*4,
-				0, TRANSPARENCY_PEN,0,0x20000, 0x40000);
-		} else {
-		    if (y+j*2>=bitmap->height) break;
-		    odyssey2_draw_sprite(bg, o2_vdc.s.shape[i][j], x, y+j*2, 1, 2, 1<<i);
-		    drawgfxzoom(bitmap, Machine->gfx[1], o2_vdc.s.shape[i][j],0,
-				0,0,x,y+j*2,
-				0, TRANSPARENCY_PEN,0, 0x10000, 0x20000);
+    if (o2_vdc.s.control&0x20)
+	{
+		for (i=0; i<ARRAY_LENGTH(o2_vdc.s.foreground); i++) {
+			odyssey2_draw_char(bitmap,bg,
+				o2_vdc.s.foreground[i].x, o2_vdc.s.foreground[i].y,
+				o2_vdc.s.foreground[i].ptr, o2_vdc.s.foreground[i].color);
 		}
-	    }
-	}
-    }
-    collision=0;
-/*    for (y=0; y<bitmap->height; y++) { */
-/*	for (x=0; x<bitmap->width; x++) { */
-    for (y=0; y<200; y++) {
-	for (x=0; x<200; x++) {
-	    switch (bg[y][x]) {
-	    case 0: case 1: case 2: case 4: case 8:
-	    case 0x10: case 0x20: case 0x80:
-		break;
-	    default:
-		if (bg[y][x]&o2_vdc.s.collision) {
-		    collision|=bg[y][x];
+		for (i=0; i<ARRAY_LENGTH(o2_vdc.s.quad); i++)
+		{
+			x=o2_vdc.s.quad[i].single[0].x;
+			for (j=0; j<ARRAY_LENGTH(o2_vdc.s.quad[0].single); j++, x+=2*8)
+			{
+				odyssey2_draw_char(bitmap,bg,
+					x, y=o2_vdc.s.quad[i].single[0].y,
+					o2_vdc.s.quad[i].single[j].ptr, o2_vdc.s.quad[i].single[j].color);
+			}
+		}
+		for (i=0; i<ARRAY_LENGTH(o2_vdc.s.sprites); i++)
+		{
+			Machine->gfx[0]->colortable[1]=Machine->pens[16+((o2_vdc.s.sprites[i].color>>3)&7)];
+			y=o2_vdc.s.sprites[i].y;
+			x=o2_vdc.s.sprites[i].x;
+			for (j=0; j<8; j++)
+			{
+				if (o2_vdc.s.sprites[i].color&4)
+				{
+					if (y+4*j>=bitmap->height) break;
+					odyssey2_draw_sprite(bg, o2_vdc.s.shape[i][j], x, y+j*4, 2, 4, 1<<i);
+					drawgfxzoom(bitmap, Machine->gfx[1], o2_vdc.s.shape[i][j],0,
+						0,0,x,y+j*4,
+						0, TRANSPARENCY_PEN,0,0x20000, 0x40000);
+				}
+				else
+				{
+					if (y+j*2>=bitmap->height) break;
+					odyssey2_draw_sprite(bg, o2_vdc.s.shape[i][j], x, y+j*2, 1, 2, 1<<i);
+					drawgfxzoom(bitmap, Machine->gfx[1], o2_vdc.s.shape[i][j],0,
+						0,0,x,y+j*2,
+						0, TRANSPARENCY_PEN,0, 0x10000, 0x20000);
+				}
+			}
 		}
-	    }
 	}
-    }
+	collision=0;
+/*	for (y=0; y<bitmap->height; y++) { */
+/*		for (x=0; x<bitmap->width; x++) { */
+	for (y=0; y<300; y++)
+	{
+		for (x=0; x<320; x++)
+		{
+			switch (bg[y][x]) {
+			case 0: case 1: case 2: case 4: case 8:
+			case 0x10: case 0x20: case 0x80:
+				break;
 
-#if 0
-    char str[0x40];
-    for (i=0; i<4; i++) {
-	snprintf(str, sizeof(str), "%.2x:%.2x %.2x",
-		 o2_vdc.s.sprites[i].x,
-		 o2_vdc.s.sprites[i].y,
-		 o2_vdc.s.sprites[i].color);
-	ui_text(bitmap, str, 160, i*8);
-    }
-    snprintf(str, sizeof(str), "%.2x %.2x",
-	     o2_vdc.s.collision,
-	     collision);
-    ui_text(bitmap, str, 160, i*8);
-
-
-#endif
-    return;
+			default:
+				if (bg[y][x]&o2_vdc.s.collision)
+				{
+				    collision|=bg[y][x]&(~o2_vdc.s.collision);
+				}
+				break;
+			}
+		}
+	}
 }
 
+void odyssey2_sh_update( void *param,stream_sample_t **inputs, stream_sample_t **_buffer,int length )
+{
+	static UINT32 signal;
+	static UINT16 count = 0;
+	int ii;
+	int period;
+	stream_sample_t *buffer = _buffer[0];
 
+	/* Generate the signal */
+	signal = o2_vdc.s.shift3 | (o2_vdc.s.shift2 << 8) | (o2_vdc.s.shift1 << 16);
+
+	if( o2_vdc.s.sound & 0x80 )	/* Sound is enabled */
+	{
+		for( ii = 0; ii < length; ii++, buffer++ )
+		{
+			*buffer = 0;
+			*buffer = signal & 0x1;
+			period = (o2_vdc.s.sound & 0x20) ? 11 : 44;
+			if( ++count >= period )
+			{
+				count = 0;
+				signal >>= 1;
+				/* Loop sound */
+				if( o2_vdc.s.sound & 0x40 )
+				{
+					signal |= *buffer << 23;
+				}
+			}
+
+			/* Throw an interrupt if enabled */
+			if( o2_vdc.s.control & 0x4 )
+			{
+				cpunum_set_input_line(0, 1, HOLD_LINE); /* Is this right? */
+			}
+
+			/* Adjust volume */
+			*buffer *= o2_vdc.s.sound & 0xf;
+			/* Pump the volume up */
+			*buffer <<= 10;
+		}
+	}
+	else
+	{
+		/* Sound disabled, so clear the buffer */
+		for( ii = 0; ii < length; ii++, buffer++ )
+			*buffer = 0;
+	}
+}
