@@ -1,6 +1,6 @@
 /***************************************************************************
 
-  $Id: pc8801.c,v 1.8 2001/11/16 05:02:58 npwoods Exp $
+  $Id: pc8801.c,v 1.15 2005/08/31 01:22:09 npwoods Exp $
 
 ***************************************************************************/
 
@@ -25,31 +25,36 @@ static int dmac_FL;
 static UINT16 dmac_addr[3],dmac_size[3];
 static UINT8 dmac_flag,dmac_status;
 
-static enum {
-  noblink_underline,
-  blink_underline,
-  noblink_block,
-  blink_block
+enum
+{
+	noblink_underline,
+	blink_underline,
+	noblink_block,
+	blink_block
 } cursor_mode;
 
-static enum {
-  parameter0,
-  parameter1,
-  parameter2,
-  parameter3,
-  parameter4,
-  cursorx,
-  cursory,
-  lpenx,
-  lpeny,
-  other
+enum
+{
+	parameter0,
+	parameter1,
+	parameter2,
+	parameter3,
+	parameter4,
+	cursorx,
+	cursory,
+	lpenx,
+	lpeny,
+	other
 } crtc_state;
 
-typedef enum {
-  GRAPH_NO,
-  GRAPH_200_COL,
-  GRAPH_200_BW,
-  GRAPH_400_BW} GMODE;
+typedef enum
+{
+	GRAPH_NO,
+	GRAPH_200_COL,
+	GRAPH_200_BW,
+	GRAPH_400_BW
+} GMODE;
+
 static GMODE gmode=GRAPH_NO;
 static int disp_plane[3];
 
@@ -70,7 +75,7 @@ static int disp_plane[3];
 
 static char *graph_dirty=NULL;
 static unsigned short *attr_tmp=NULL,*attr_old=NULL,*text_old=NULL;
-static struct mame_bitmap *wbm1,*wbm2;
+static mame_bitmap *wbm1,*wbm2;
 
 #define TRAM(x,y) (pc88sr_is_highspeed ? \
 	pc88sr_textRAM[(dmac_addr[2]+(x)+(y)*120)&0xfff] : \
@@ -82,76 +87,39 @@ static struct mame_bitmap *wbm1,*wbm2;
 
 void pc8801_video_init (int hireso)
 {
-  if ((wbm1 = bitmap_alloc(Machine->drv->screen_width,
-			   Machine->drv->screen_height)) == 0) return;
-  if ((wbm2 = bitmap_alloc(Machine->drv->screen_width,
-			   Machine->drv->screen_height)) == 0) return;
-  pc8801_is_24KHz=hireso;
-  crtcON=0;
-  textON=1;
+	wbm1 = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
+	wbm2 = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
+	pc8801_is_24KHz=hireso;
+	crtcON=0;
+	textON=1;
 
-  dmac_FL=0;
-  dmac_addr[0]=dmac_size[0]=0;
-  dmac_addr[1]=dmac_size[1]=0;
-  dmac_addr[2]=dmac_size[2]=0;
-  dmac_flag=dmac_status=0;
+	dmac_FL=0;
+	dmac_addr[0]=dmac_size[0]=0;
+	dmac_addr[1]=dmac_size[1]=0;
+	dmac_addr[2]=dmac_size[2]=0;
+	dmac_flag=dmac_status=0;
 
-  if(gVRAM==NULL) {
-    if((gVRAM = (UINT8*)malloc (0xc000))==NULL) {
-      {
-       	logerror ("pc8801: out of memory!\n");
-	return;
-      }
-    }
-  }
-  memset(gVRAM,0,0xc000);
-  if(pc88sr_textRAM==NULL) {
-    if((pc88sr_textRAM = (UINT8*)malloc (0x1000))==NULL) {
-      {
-	logerror ("pc8801: out of memory!\n");
-        return;
-      }
-    }
-  }
-  memset(pc88sr_textRAM,0,0x1000);
-  if(attr_tmp==NULL) {
-    if((attr_tmp = malloc (sizeof(unsigned short)*80*25))==NULL) {
-      {
-       	logerror ("pc8801: out of memory!\n");
-	return;
-      }
-    }
-  }
-  if(attr_old==NULL) {
-    if((attr_old = malloc (sizeof(unsigned short)*80*100))==NULL) {
-      {
-       	logerror ("pc8801: out of memory!\n");
-	return;
-      }
-    }
-  }
-  if(text_old==NULL) {
-    if((text_old = malloc (sizeof(unsigned short)*80*100))==NULL) {
-      {
-       	logerror ("pc8801: out of memory!\n");
-	return;
-      }
-    }
-  }
-  if(graph_dirty==NULL) {
-    if((graph_dirty = malloc (80*100))==NULL) {
-      {
-       	logerror ("pc8801: out of memory!\n");
-	return;
-      }
-    }
-  }
-  selected_vram=0;
-  ALUON=0;
-  analog_palette=0;
+	gVRAM = (UINT8*) auto_malloc(0xc000);
+	pc88sr_textRAM = (UINT8*) auto_malloc(0x1000);
+	attr_tmp = auto_malloc(sizeof(unsigned short)*80*25);
+	attr_old = auto_malloc(sizeof(unsigned short)*80*100);
+	text_old = auto_malloc(sizeof(unsigned short)*80*100);
+	graph_dirty = auto_malloc(80*100);
+
+	if (!wbm1 || !wbm2 || !gVRAM || !pc88sr_textRAM || !attr_tmp || !attr_old || !text_old || !graph_dirty)
+	{
+		logerror ("pc8801: out of memory!\n");
+		return;
+	}
+
+	memset(gVRAM,0,0xc000);
+	memset(pc88sr_textRAM,0,0x1000);
+	selected_vram=0;
+	ALUON=0;
+	analog_palette=0;
 }
 
-static WRITE_HANDLER(write_gvram)
+static WRITE8_HANDLER(write_gvram)
 {
   int x,y;
 
@@ -175,14 +143,16 @@ static WRITE_HANDLER(write_gvram)
   }
 }
 
+/* NPW 8-Feb-2004 - This pseudo template stuff is an abomination.  Whomever wrote this should be shot */
+
 #define VVV \
 	XXX(0) \
 	XXX(1) \
 	XXX(2)
 
 #define XXX(n) \
-static WRITE_HANDLER(write_gvram##n##_bank5){write_gvram(offset+0x4000*n,data);} \
-static WRITE_HANDLER(write_gvram##n##_bank6){write_gvram(offset+0x4000*n+0x3000,data);}
+static WRITE8_HANDLER(write_gvram##n##_bank5){write_gvram(offset+0x4000*n,data);} \
+static WRITE8_HANDLER(write_gvram##n##_bank6){write_gvram(offset+0x4000*n+0x3000,data);}
 	VVV
 #undef XXX
 
@@ -203,7 +173,7 @@ static WRITE_HANDLER(write_gvram##n##_bank6){write_gvram(offset+0x4000*n+0x3000,
 	XXX(3)
 
 #define XXX(x) \
-static READ_HANDLER(read_gvram_alu##x) \
+static  READ8_HANDLER(read_gvram_alu##x) \
 { \
   ALU_save0 = gVRAM[offset+0x0000]; \
   ALU_save1 = gVRAM[offset+0x4000]; \
@@ -213,14 +183,14 @@ static READ_HANDLER(read_gvram_alu##x) \
     (x & 2 ? gVRAM[offset+0x4000] : ~gVRAM[offset+0x4000]) & \
     (x & 4 ? gVRAM[offset+0x8000] : ~gVRAM[offset+0x8000]); \
 } \
-static READ_HANDLER(read_gvram_alu##x##_bank5){return read_gvram_alu##x(offset);} \
-static READ_HANDLER(read_gvram_alu##x##_bank6){return read_gvram_alu##x(offset+0x3000);}
+static  READ8_HANDLER(read_gvram_alu##x##_bank5){return read_gvram_alu##x(offset);} \
+static  READ8_HANDLER(read_gvram_alu##x##_bank6){return read_gvram_alu##x(offset+0x3000);}
 
 YYY
 
 #undef XXX
 
-static WRITE_HANDLER(write_gvram_alu0)
+static WRITE8_HANDLER(write_gvram_alu0)
 {
 #define WWW(x) \
   switch(ALU1&(0x11<<x)) { \
@@ -243,18 +213,18 @@ static WRITE_HANDLER(write_gvram_alu0)
 
 #undef WWW
 }
-static WRITE_HANDLER(write_gvram_alu1)
+static WRITE8_HANDLER(write_gvram_alu1)
 {
   write_gvram(offset+0x0000 , ALU_save0);
   write_gvram(offset+0x4000 , ALU_save1);
   write_gvram(offset+0x8000 , ALU_save2);
 }
-static WRITE_HANDLER(write_gvram_alu2){write_gvram(offset+0x0000,ALU_save1);}
-static WRITE_HANDLER(write_gvram_alu3){write_gvram(offset+0x4000,ALU_save0);}
+static WRITE8_HANDLER(write_gvram_alu2){write_gvram(offset+0x0000,ALU_save1);}
+static WRITE8_HANDLER(write_gvram_alu3){write_gvram(offset+0x4000,ALU_save0);}
 
 #define XXX(x) \
-static WRITE_HANDLER(write_gvram_alu##x##_bank5){write_gvram_alu##x(offset,data);} \
-static WRITE_HANDLER(write_gvram_alu##x##_bank6){write_gvram_alu##x(offset+0x3000,data);}
+static WRITE8_HANDLER(write_gvram_alu##x##_bank5){write_gvram_alu##x(offset,data);} \
+static WRITE8_HANDLER(write_gvram_alu##x##_bank6){write_gvram_alu##x(offset+0x3000,data);}
 
 ZZZ
 
@@ -262,6 +232,9 @@ ZZZ
 
 int is_pc8801_vram_select(void)
 {
+	read8_handler rh5 = NULL, rh6 = NULL;
+	write8_handler wh5 = NULL, wh6 = NULL;
+
   if(ALUON) {
     /* ALU mode */
     if(ALU2&0x80) {
@@ -269,8 +242,8 @@ int is_pc8801_vram_select(void)
       switch(ALU2&0x07) {
 #define XXX(x) \
       case x: \
-	memory_set_bankhandler_r(5, 0, read_gvram_alu##x##_bank5); \
-	memory_set_bankhandler_r(6, 0, read_gvram_alu##x##_bank6); \
+	rh5 = read_gvram_alu##x##_bank5; \
+	rh6 = read_gvram_alu##x##_bank6; \
 	break;
 
 	YYY
@@ -281,8 +254,8 @@ int is_pc8801_vram_select(void)
       switch(ALU2&0x30) {
 #define XXX(x) \
       case x<<4: \
-	memory_set_bankhandler_w(5, 0, write_gvram_alu##x##_bank5); \
-	memory_set_bankhandler_w(6, 0, write_gvram_alu##x##_bank6); \
+	wh5 = write_gvram_alu##x##_bank5; \
+	wh6 = write_gvram_alu##x##_bank6; \
 	break;
 
 	ZZZ
@@ -299,12 +272,12 @@ int is_pc8801_vram_select(void)
     switch(selected_vram) {
 #define XXX(n) \
     case (n+1): \
-      memory_set_bankhandler_r(5, 0, MRA_BANK5); \
-      memory_set_bankhandler_r(6, 0, MRA_BANK6); \
-      memory_set_bankhandler_w(5, 0, write_gvram##n##_bank5); \
-      memory_set_bankhandler_w(6, 0, write_gvram##n##_bank6); \
-      cpu_setbank(5, gVRAM + 0x4000*n ); \
-      cpu_setbank(6, gVRAM + 0x4000*n + 0x3000 ); \
+      rh5 = MRA8_BANK5; \
+      rh6 = MRA8_BANK6; \
+      wh5 = write_gvram##n##_bank5; \
+      wh6 = write_gvram##n##_bank6; \
+      memory_set_bankptr(5, gVRAM + 0x4000*n ); \
+      memory_set_bankptr(6, gVRAM + 0x4000*n + 0x3000 ); \
       return 1;
 
       VVV
@@ -316,16 +289,22 @@ int is_pc8801_vram_select(void)
       return 0; /* MAIN RAM */
     }
   }
+
+  
+	if (rh5) memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xc000, 0xefff, 0, 0, rh5);
+	if (wh5) memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xefff, 0, 0, wh5);
+	if (rh6) memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xf000, 0xffff, 0, 0, rh6);
+	if (wh6) memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xf000, 0xffff, 0, 0, wh6);
 }
 
-WRITE_HANDLER(pc88sr_disp_32)
+WRITE8_HANDLER(pc88sr_disp_32)
 {
   analog_palette=((data & 0x20) != 0x00);
   ALUON=((data & 0x40) != 0x00);
   pc8801_update_bank();
 }
 
-WRITE_HANDLER(pc88sr_ALU)
+WRITE8_HANDLER(pc88sr_ALU)
 {
   switch(offset) {
   case 0:
@@ -338,7 +317,7 @@ WRITE_HANDLER(pc88sr_ALU)
   pc8801_update_bank();
 }
 
-WRITE_HANDLER(pc8801_vramsel)
+WRITE8_HANDLER(pc8801_vramsel)
 {
   if(offset==3) {
     selected_vram=0;
@@ -348,7 +327,7 @@ WRITE_HANDLER(pc8801_vramsel)
   pc8801_update_bank();
 }
 
-READ_HANDLER(pc8801_vramtest)
+ READ8_HANDLER(pc8801_vramtest)
 {
   switch(selected_vram) {
   case 1: return 0xf9;
@@ -358,15 +337,18 @@ READ_HANDLER(pc8801_vramtest)
   }
 }
 
-int pc8801_vh_start(void){return 0;}
-void pc8801_vh_exit(void){}
+VIDEO_START( pc8801 )
+{
+	return 0;
+}
 
 #define BLOCK_YSIZE (pc8801_is_24KHz ? 4 : 2)
 
-void pc8801_vh_refresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( pc8801 )
 {
   int x,y,attr_new,text_new,i,a,tx,ty,oy,gx,gy,ct,cg;
   static int blink_count;
+  int full_refresh = 1;
 
   blink_count=(blink_count+1)%(blink_period*4);
   /* attribute expand */
@@ -412,7 +394,8 @@ void pc8801_vh_refresh(struct mame_bitmap *bitmap,int full_refresh)
   }
 
   /* display draw */
-  for(y=0;y<100;y++) {
+  for(y=0;y<100;y++)
+  {
     ty=y/(100/text_height);
     oy=y%(100/text_height);
     for(x=0;x<80;x++) {
@@ -615,27 +598,32 @@ void pc8801_vh_refresh(struct mame_bitmap *bitmap,int full_refresh)
 	     &Machine->visible_area,TRANSPARENCY_NONE,0);
 }
 
-void pc8801_init_palette (unsigned char *sys_palette,
-			  unsigned short *sys_colortable,
-			  const unsigned char *color_prom)
+PALETTE_INIT( pc8801 )
 {
-  int i;
+	int i;
 
-  memset(sys_palette,0,3*8);	/* for graphics */
-  /* for text */
-  for(i=0;i<8;i++) {
-    sys_palette[(i+8)*3+0] = (i & 2) ? 0xff : 0x00;
-    sys_palette[(i+8)*3+1] = (i & 4) ? 0xff : 0x00;
-    sys_palette[(i+8)*3+2] = (i & 1) ? 0xff : 0x00;
-    sys_colortable[i*2+0] = 0;
-    sys_colortable[i*2+1] = i+8;
-    sys_colortable[(i+8)*2+0] = i+8;
-    sys_colortable[(i+8)*2+1] = 0;
-  }
-  memset(sys_palette+3*16,0,3*2);	/* for background and scanline */
+	for (i = 0; i < 8; i++)
+		palette_set_color(i, 0, 0, 0);	/* for graphics */
+
+	/* for text */
+	for (i = 0; i < 8; i++)
+	{
+		palette_set_color(i+8,
+			(i & 2) ? 0xff : 0x00,
+			(i & 4) ? 0xff : 0x00,
+			(i & 1) ? 0xff : 0x00);
+		colortable[i*2+0] = 0;
+		colortable[i*2+1] = i+8;
+		colortable[(i+8)*2+0] = i+8;
+		colortable[(i+8)*2+1] = 0;
+	}
+
+	/* for background and scanline */
+	palette_set_color(16, 0, 0, 0);
+	palette_set_color(17, 0, 0, 0);
 }
 
-WRITE_HANDLER(pc8801_crtc_write)
+WRITE8_HANDLER(pc8801_crtc_write)
 {
   if(offset==1) {
     /* command */
@@ -766,7 +754,7 @@ WRITE_HANDLER(pc8801_crtc_write)
   }
 }
 
-READ_HANDLER(pc8801_crtc_read)
+ READ8_HANDLER(pc8801_crtc_read)
 {
   if(offset==0) {
     /* light pen point */
@@ -787,7 +775,7 @@ READ_HANDLER(pc8801_crtc_read)
   }
 }
 
-WRITE_HANDLER(pc8801_dmac_write)
+WRITE8_HANDLER(pc8801_dmac_write)
 {
   switch(offset) {
   case 8:
@@ -823,7 +811,7 @@ WRITE_HANDLER(pc8801_dmac_write)
   }
 }
 
-READ_HANDLER(pc8801_dmac_read)
+ READ8_HANDLER(pc8801_dmac_read)
 {
   switch(offset) {
   case 8:
@@ -854,12 +842,12 @@ READ_HANDLER(pc8801_dmac_read)
   return 0;
 }
 
-WRITE_HANDLER(pc88sr_disp_30)
+WRITE8_HANDLER(pc88sr_disp_30)
 {
   text_width=((data&0x01)==0x00) ? 40 : 80;
 }
 
-WRITE_HANDLER(pc88sr_disp_31)
+WRITE8_HANDLER(pc88sr_disp_31)
 {
   GMODE gmode_new;
 
@@ -888,7 +876,7 @@ WRITE_HANDLER(pc88sr_disp_31)
   }
 }
 
-WRITE_HANDLER(pc8801_palette_out)
+WRITE8_HANDLER(pc8801_palette_out)
 {
   int palno;
   int i;
