@@ -3,14 +3,18 @@
   IBM PC junior
   Tandy 1000 Graphics Adapter (T1T) section
 
+  Note that in the IBM PC Junior world, the term 'vga' is not the 'vga' that
+  most people think of
+
 ***************************************************************************/
+
 #include "vidhrdw/generic.h"
 
 #include "includes/crtc6845.h"
-#include "includes/pc_cga.h" /* cga monitor palette */
-#include "includes/pc_aga.h" /*europc charset */
-#include "includes/pc_t1t.h"
-#include "includes/state.h"
+#include "vidhrdw/pc_cga.h" /* cga monitor palette */
+#include "vidhrdw/pc_aga.h" /*europc charset */
+#include "vidhrdw/pc_t1t.h"
+#include "mscommon.h"
 
 #define VERBOSE_T1T 1		/* T1T (Tandy 1000 Graphics Adapter) */
 
@@ -21,13 +25,24 @@
 #define T1T_LOG(n,m,a)
 #endif
 
-/*
-  vga is used in this document for a special video gate array
-  not identical to the famous graphics adapter!
-*/
+/***************************************************************************
 
+	Static declarations
 
-unsigned short pcjr_colortable[] = {
+***************************************************************************/
+
+static PALETTE_INIT( pcjr );
+static VIDEO_START( pc_t1t );
+static pc_video_update_proc pc_t1t_choosevideomode(int *width, int *height, struct crtc6845 *crtc);
+
+/***************************************************************************
+
+	MachineDriver stuff
+
+**************************************************************************/
+
+static unsigned short pcjr_colortable[] =
+{
      0, 0, 0, 1, 0, 2, 0, 3, 0, 4, 0, 5, 0, 6, 0, 7, 0, 8, 0, 9, 0,10, 0,11, 0,12, 0,13, 0,14, 0,15,
      1, 0, 1, 1, 1, 2, 1, 3, 1, 4, 1, 5, 1, 6, 1, 7, 1, 8, 1, 9, 1,10, 1,11, 1,12, 1,13, 1,14, 1,15,
      2, 0, 2, 1, 2, 2, 2, 3, 2, 4, 2, 5, 2, 6, 2, 7, 2, 8, 2, 9, 2,10, 2,11, 2,12, 2,13, 2,14, 2,15,
@@ -55,7 +70,7 @@ unsigned short pcjr_colortable[] = {
 	 0,1,2,3, 4,5,6,7, 8,9,0xa,0xb, 0xc,0xd,0xe,0xf
 };
 
-static struct GfxLayout t1t_gfxlayout_4bpp =
+static gfx_layout t1t_gfxlayout_4bpp =
 {
 	2,1,					/* 8 x 32 graphics */
     256,                    /* 256 codes */
@@ -68,25 +83,70 @@ static struct GfxLayout t1t_gfxlayout_4bpp =
 	1*8 					/* every code takes 1 byte */
 };
 
-struct GfxDecodeInfo t1t_gfxdecodeinfo[] =
+static gfx_layout t1t_charlayout =
 {
-	{ 1, 0x0000, &europc_cga_charlayout,		  0,			 256 },	/* single width */
-	{ 1, 0x1000, &CGA_gfxlayout_1bpp,	  256*2,		  16 },	/* 640x400 1bpp gfx */
-    { 1, 0x1000, &CGA_gfxlayout_2bpp,     256*2+16*2,      4 },  /* 320x200 2bpp gfx */
-	{ 1, 0x1000, &t1t_gfxlayout_4bpp,	  256*2+16*2+2*4, 16 },	/* 160x200 4bpp gfx */
+	8,8,					/* 8 x 8 characters */
+    128,                    /* 128 characters */
+    1,                      /* 1 bits per pixel */
+    { 0 },                  /* no bitplanes; 1 bit per pixel */
+    /* x offsets */
+    { 0,1,2,3,4,5,6,7 },
+    /* y offsets */
+	{ 0*8,1*8,2*8,3*8,
+	  4*8,5*8,6*8,7*8 },
+    8*8                     /* every char takes 8 bytes */
+};
+
+static gfx_decode t1000hx_gfxdecodeinfo[] =
+{
+	{ 0, 0xffa6e, &t1t_charlayout,			0,				128 },	/* single width */
+	{ 0, 0xfc0a8, &t1t_charlayout,			0,				128 },	/* single width */
+	{ REGION_GFX1,  0x1000, &t1t_gfxlayout_4bpp,		256*2+16*2+2*4,	16 },	/* 160x200 4bpp gfx */
     { -1 } /* end of array */
 };
 
-/* Initialise the cga palette */
-void pcjr_init_palette(unsigned char *sys_palette, unsigned short *sys_colortable,const unsigned char *color_prom)
+static gfx_decode t1000sx_gfxdecodeinfo[] =
 {
-	memcpy(sys_palette,cga_palette,sizeof(cga_palette));
-	memcpy(sys_colortable,pcjr_colortable,sizeof(pcjr_colortable));
+	{ 0, 0xffa6e, &t1t_charlayout,			0,				128 },	/* single width */
+	{ 0, 0xf40a3, &t1t_charlayout,			0,				128 },	/* single width */
+	{ REGION_GFX1,  0x1000, &t1t_gfxlayout_4bpp,		256*2+16*2+2*4,	16 },	/* 160x200 4bpp gfx */
+    { -1 } /* end of array */
+};
+
+MACHINE_DRIVER_START( pcvideo_t1000hx )
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(80*8, 25*9)
+	MDRV_VISIBLE_AREA(0,80*8-1, 0,25*9-1)
+	MDRV_GFXDECODE(t1000hx_gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(sizeof(cga_palette) / sizeof(cga_palette[0]))
+	MDRV_COLORTABLE_LENGTH(sizeof(pcjr_colortable) / sizeof(pcjr_colortable[0]))
+	MDRV_PALETTE_INIT(pcjr)
+
+	MDRV_VIDEO_START(pc_t1t)
+	MDRV_VIDEO_UPDATE(pc_video)
+MACHINE_DRIVER_END
+
+MACHINE_DRIVER_START( pcvideo_t1000sx )
+	MDRV_IMPORT_FROM( pcvideo_t1000hx )
+	MDRV_GFXDECODE( t1000sx_gfxdecodeinfo )
+MACHINE_DRIVER_END
+
+/***************************************************************************
+
+	Methods
+
+***************************************************************************/
+
+/* Initialise the cga palette */
+static PALETTE_INIT( pcjr )
+{
+	int i;
+	for(i = 0; i < (sizeof(cga_palette) / 3); i++)
+		palette_set_color(i, cga_palette[i][0], cga_palette[i][1], cga_palette[i][2]);
+	memcpy(colortable, pcjr_colortable, sizeof(pcjr_colortable));
 }
 
 static struct { 
-	struct _CRTC6845 *crtc;
-
 	UINT8 mode_control, color_select;
 	UINT8 status;
 
@@ -118,7 +178,7 @@ static struct {
    so are in graphics mode 2 or 4 of such banks distinquished
    by line */
 
-extern void pc_t1t_reset(void)
+void pc_t1t_reset(void)
 {
 	videoram=NULL;
 	pcjr.bank=0;
@@ -128,7 +188,7 @@ extern void pc_t1t_reset(void)
 /***************************************************************************
   Mark all text positions with attribute bit 7 set dirty
  ***************************************************************************/
-void pc_t1t_blink_textcolors(int on)
+static void pc_t1t_blink_textcolors(int on)
 {
 	int i, offs, size;
 
@@ -136,59 +196,44 @@ void pc_t1t_blink_textcolors(int on)
 	if (pcjr.pc_blink == on) return;
 
     pcjr.pc_blink = on;
-	offs = (crtc6845_get_start(pcjr.crtc)* 2) % videoram_size;
-	size = crtc6845_get_char_columns(pcjr.crtc)*crtc6845_get_char_lines(pcjr.crtc);
+	offs = (crtc6845_get_start(crtc6845)* 2) % videoram_size;
+	size = crtc6845_get_char_columns(crtc6845) * crtc6845_get_char_lines(crtc6845);
 
-	for (i = 0; i < size; i++)
+	if (dirtybuffer)
 	{
-		if (videoram[offs+1] & 0x80)
-			dirtybuffer[offs+1] = 1;
-		if( (offs += 2) == videoram_size )
-			offs = 0;
-    }
+		for (i = 0; i < size; i++)
+		{
+			if (videoram[offs+1] & 0x80)
+				dirtybuffer[offs+1] = 1;
+			if( (offs += 2) == videoram_size )
+				offs = 0;
+		}
+	}
 }
 
-extern void pc_t1t_timer(void)
+void pc_t1t_timer(void)
 {
-	if( ((++pcjr.pc_framecnt & 63) == 63) ) {
+	if( ((++pcjr.pc_framecnt & 63) == 63) )
+	{
 		pc_t1t_blink_textcolors(pcjr.pc_framecnt&64);
 	}
 }
 
-void pc_t1t_cursor(CRTC6845_CURSOR *cursor)
+static void pc_t1t_cursor(struct crtc6845_cursor *cursor)
 {
-	dirtybuffer[cursor->pos*2]=1;
+	if (dirtybuffer)
+		dirtybuffer[cursor->pos*2] = 1;
 }
 
-static CRTC6845_CONFIG config= { 14318180 /*?*/, pc_t1t_cursor };
+static struct crtc6845_config config= { 14318180 /*?*/, pc_t1t_cursor };
 
 
-int pc_t1t_vh_start(void)
+static VIDEO_START( pc_t1t )
 {
-	videoram_size = 0x8000;
-
-	pcjr.crtc=crtc6845;
-	crtc6845_init(pcjr.crtc, &config);
-
-    return generic_vh_start();
+	return pc_video_start(&config, pc_t1t_choosevideomode, 0x8000) ? INIT_PASS : INIT_FAIL;
 }
 
-void pc_t1t_vh_stop(void)
-{
-    generic_vh_stop();
-}
-
-WRITE_HANDLER ( pc_t1t_videoram_w )
-{
-	if( !videoram )
-		return;
-	if( videoram[offset] == data )
-		return;
-	videoram[offset] = data;
-	dirtybuffer[offset] = 1;
-}
-
-READ_HANDLER ( pc_t1t_videoram_r )
+ READ8_HANDLER ( pc_t1t_videoram_r )
 {
 	int data = 0xff;
 	if( videoram )
@@ -199,7 +244,7 @@ READ_HANDLER ( pc_t1t_videoram_r )
 /*
  * 3d8 rW	T1T mode control register (see #P138)
  */
-void pc_t1t_mode_control_w(int data)
+static void pc_t1t_mode_control_w(int data)
 {
 	T1T_LOG(1,"T1T_mode_control_w",("$%02x: colums %d, gfx %d, hires %d, blink %d\n", \
 		data, (data&1)?80:40, (data>>1)&1, (data>>4)&1, (data>>5)&1));
@@ -208,7 +253,7 @@ void pc_t1t_mode_control_w(int data)
 	pcjr.mode_control = data;
 }
 
-int pc_t1t_mode_control_r(void)
+static int pc_t1t_mode_control_r(void)
 {
     int data = pcjr.mode_control;
     return data;
@@ -217,7 +262,7 @@ int pc_t1t_mode_control_r(void)
 /*
  * 3d9 ?W	color select register on color adapter
  */
-void pc_t1t_color_select_w(int data)
+static void pc_t1t_color_select_w(int data)
 {
 	T1T_LOG(1,"T1T_color_select_w",("$%02x\n", data));
 	if (pcjr.color_select == data)
@@ -226,7 +271,7 @@ void pc_t1t_color_select_w(int data)
 	pcjr.full_refresh=1;
 }
 
-int pc_t1t_color_select_r(void)
+static int pc_t1t_color_select_r(void)
 {
 	int data = pcjr.color_select;
 	T1T_LOG(1,"T1T_color_select_r",("$%02x\n", data));
@@ -248,7 +293,7 @@ int pc_t1t_color_select_r(void)
  *      =1  memory access without interfering with display
  *      (Genoa SuperEGA) horizontal or vertical retrace
  */
-int pc_t1t_status_r(void)
+static int pc_t1t_status_r(void)
 {
     int data = (input_port_0_r(0) & 0x08) | pcjr.status;
     pcjr.status ^= 0x01;
@@ -258,7 +303,7 @@ int pc_t1t_status_r(void)
 /*
  * 3db -W	light pen strobe reset (on any value)
  */
-void pc_t1t_lightpen_strobe_w(int data)
+static void pc_t1t_lightpen_strobe_w(int data)
 {
 	T1T_LOG(1,"T1T_lightpen_strobe_w",("$%02x\n", data));
 /*	pc_port[0x3db] = data; */
@@ -269,13 +314,13 @@ void pc_t1t_lightpen_strobe_w(int data)
  * 3da -W	(mono EGA/mono VGA) feature control register
  *			(see PORT 03DAh-W for details; VGA, see PORT 03CAh-R)
  */
-void pc_t1t_vga_index_w(int data)
+static void pc_t1t_vga_index_w(int data)
 {
 	T1T_LOG(1,"T1T_vga_index_w",("$%02x\n", data));
 	pcjr.reg.index = data;
 }
 
-void pc_t1t_vga_data_w(int data)
+static void pc_t1t_vga_data_w(int data)
 {
     pcjr.reg.data[pcjr.reg.index] = data;
 
@@ -310,7 +355,7 @@ void pc_t1t_vga_data_w(int data)
     }
 }
 
-int pc_t1t_vga_data_r(void)
+static int pc_t1t_vga_data_r(void)
 {
 	int data = pcjr.reg.data[pcjr.reg.index];
 
@@ -353,7 +398,7 @@ int pc_t1t_vga_data_r(void)
  *	   6-7	Display mode. 0: Text, 1: 16K graphics mode (4,5,6,8)
  *			2: 32K graphics mode (9,Ah)
  */
-void pc_t1t_bank_w(int data)
+static void pc_t1t_bank_w(int data)
 {
 	if (pcjr.bank != data)
 	{
@@ -374,12 +419,13 @@ void pc_t1t_bank_w(int data)
 #endif
         videoram = &memory_region(REGION_CPU1)[vram];
 		pcjr.displayram = &memory_region(REGION_CPU1)[dram];
-        memset(dirtybuffer, 1, videoram_size);
+        if (dirtybuffer)
+			memset(dirtybuffer, 1, videoram_size);
 		T1T_LOG(1,"t1t_bank_w",("$%02x: display ram $%05x, video ram $%05x\n", data, dram, vram));
 	}
 }
 
-int pc_t1t_bank_r(void)
+static int pc_t1t_bank_r(void)
 {
 	int data = pcjr.bank;
     T1T_LOG(1,"t1t_bank_r",("$%02x\n", data));
@@ -393,15 +439,15 @@ int pc_t1t_bank_r(void)
  *
  *************************************************************************/
 
-WRITE_HANDLER ( pc_T1T_w )
+WRITE8_HANDLER ( pc_T1T_w )
 {
 	switch( offset )
 	{
 		case 0: case 2: case 4: case 6:
-			crtc6845_port_w(pcjr.crtc,0,data);
+			crtc6845_port_w(crtc6845,0,data);
 			break;
 		case 1: case 3: case 5: case 7:
-			crtc6845_port_w(pcjr.crtc,1,data);
+			crtc6845_port_w(crtc6845,1,data);
 			break;
 		case 8:
 			pc_t1t_mode_control_w(data);
@@ -428,111 +474,156 @@ WRITE_HANDLER ( pc_T1T_w )
     }
 }
 
-READ_HANDLER ( pc_T1T_r )
+ READ8_HANDLER ( pc_T1T_r )
 {
 	int data = 0xff;
 	switch( offset )
 	{
 		case 0: case 2: case 4: case 6:
-			data=crtc6845_port_r(pcjr.crtc,0);
+			data = crtc6845_port_r(crtc6845,0);
 			break;
+
 		case 1: case 3: case 5: case 7:
-			data=crtc6845_port_r(pcjr.crtc,1);
+			data = crtc6845_port_r(crtc6845,1);
 			break;
+
 		case 8:
 			data = pc_t1t_mode_control_r();
 			break;
+
 		case 9:
 			data = pc_t1t_color_select_r();
 			break;
+
 		case 10:
 			data = pc_t1t_status_r();
 			break;
+
 		case 11:
 			/* -W lightpen strobe reset */
 			break;
+
 		case 12:
-			break;
 		case 13:
             break;
+
 		case 14:
 			data = pc_t1t_vga_data_r();
             break;
+
         case 15:
 			data = pc_t1t_bank_r();
+			break;
     }
 	return data;
 }
 
+/***************************************************************************
+  Plot single text character
+***************************************************************************/
+
+static void t1t_plot_char(mame_bitmap *bitmap, const rectangle *r, UINT8 ch, UINT8 attr)
+{
+	int width;
+	int height;
+	int bgcolor;
+	gfx_element *gfx;
+
+	gfx = Machine->gfx[ch & 0x80 ? 1 : 0];
+	drawgfx(bitmap, gfx, ch & 0x7f, attr, 
+			0, 0, r->min_x, r->min_y, r, TRANSPARENCY_NONE, 0);
+
+	height = r->max_y - r->min_y + 1;
+	width = r->max_x - r->min_x + 1;
+
+	if (height > 8)
+	{
+		bgcolor = gfx->colortable[gfx->color_granularity * (attr % gfx->total_colors)];
+		plot_box(bitmap, r->min_x, r->min_y + 8, width, height - 8, bgcolor);
+	}
+}
+
+
+
 /***************************************************************************
   Draw text mode with 40x25 characters (default) with high intensity bg.
 ***************************************************************************/
-static void t1t_text_inten(struct mame_bitmap *bitmap)
+
+static void t1t_text_inten(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int sx, sy;
-	int	offs = crtc6845_get_start(pcjr.crtc)*2;
-	int lines = crtc6845_get_char_lines(pcjr.crtc);
-	int height = crtc6845_get_char_height(pcjr.crtc);
-	int columns = crtc6845_get_char_columns(pcjr.crtc);
-	struct rectangle r;
-	CRTC6845_CURSOR cursor;
+	int	offs = crtc6845_get_start(crtc)*2;
+	int lines = crtc6845_get_char_lines(crtc);
+	int height = crtc6845_get_char_height(crtc);
+	int columns = crtc6845_get_char_columns(crtc);
+	rectangle r;
+	struct crtc6845_cursor cursor;
 
-	crtc6845_time(pcjr.crtc);
-	crtc6845_get_cursor(pcjr.crtc, &cursor);
+	crtc6845_time(crtc);
+	crtc6845_get_cursor(crtc, &cursor);
 
 	for (sy=0, r.min_y=0, r.max_y=height-1; sy<lines; sy++, r.min_y+=height,r.max_y+=height) {
 
 		for (sx=0, r.min_x=0, r.max_x=7; sx<columns; 
-			 sx++, offs=(offs+2)&0x3fff, r.min_x+=8, r.max_x+=8) {
-			if (dirtybuffer[offs] || dirtybuffer[offs+1]) {
+			 sx++, offs=(offs+2)&0x3fff, r.min_x+=8, r.max_x+=8)
+		{
+			if (!dirtybuffer || dirtybuffer[offs] || dirtybuffer[offs+1])
+			{
+				UINT8 ch = pcjr.displayram[offs];
+				UINT8 attr = pcjr.displayram[offs + 1];
 				
-				drawgfx(bitmap, Machine->gfx[0], pcjr.displayram[offs], pcjr.displayram[offs+1], 
-						0,0,r.min_x,r.min_y,&r,TRANSPARENCY_NONE,0);
+				t1t_plot_char(bitmap, &r, ch, attr);
 
-/*				if ((cursor.on)&&(offs==cursor.pos*2)) { */
-				if (cursor.on&&(pcjr.pc_framecnt&32)&&(offs==cursor.pos*2)) {
-					int k=height-cursor.top;
-					struct rectangle rect2=r;
-					rect2.min_y+=cursor.top; 
-					if (cursor.bottom<height) k=cursor.bottom-cursor.top+1;
+				if (cursor.on && (pcjr.pc_framecnt & 32) && (offs == cursor.pos * 2))
+				{
+					int k = height - cursor.top;
+					rectangle rect2 = r;
+					rect2.min_y += cursor.top; 
+					if (cursor.bottom<height)
+						k=cursor.bottom-cursor.top+1;
 
 					if (k>0)
-						plot_box(Machine->scrbitmap, r.min_x, 
-								 r.min_y+cursor.top, 
-								 8, k, Machine->pens[7]);
+						plot_box(bitmap, r.min_x, 
+									r.min_y+cursor.top, 
+									8, k, Machine->pens[7]);
 				}
 
-				dirtybuffer[offs]=dirtybuffer[offs+1]=0;
+				if (dirtybuffer)
+					dirtybuffer[offs] = dirtybuffer[offs + 1] = 0;
 			}
 		}
 	}
 }
 
+
+
 /***************************************************************************
   Draw text mode with 40x25 characters (default) and blinking colors.
 ***************************************************************************/
-static void t1t_text_blink(struct mame_bitmap *bitmap)
+
+static void t1t_text_blink(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int sx, sy;
-	int	offs = crtc6845_get_start(pcjr.crtc)*2;
-	int lines = crtc6845_get_char_lines(pcjr.crtc);
-	int height = crtc6845_get_char_height(pcjr.crtc);
-	int columns = crtc6845_get_char_columns(pcjr.crtc);
-	struct rectangle r;
-	CRTC6845_CURSOR cursor;
+	int	offs = crtc6845_get_start(crtc)*2;
+	int lines = crtc6845_get_char_lines(crtc);
+	int height = crtc6845_get_char_height(crtc);
+	int columns = crtc6845_get_char_columns(crtc);
+	rectangle r;
+	struct crtc6845_cursor cursor;
 
-	crtc6845_time(pcjr.crtc);
-	crtc6845_get_cursor(pcjr.crtc, &cursor);
-
-	for (sy=0, r.min_y=0, r.max_y=height-1; sy<lines; sy++, r.min_y+=height,r.max_y+=height) {
+	crtc6845_time(crtc);
+	crtc6845_get_cursor(crtc, &cursor);
 
+	for (sy=0, r.min_y=0, r.max_y=height-1; sy<lines; sy++, r.min_y+=height,r.max_y+=height)
+	{
 		for (sx=0, r.min_x=0, r.max_x=7; sx<columns; 
-			 sx++, offs=(offs+2)&0x3fff, r.min_x+=8, r.max_x+=8) {
-
-			if (dirtybuffer[offs] || dirtybuffer[offs+1]) {
-				
-				int attr = pcjr.displayram[offs+1];
-				
+			sx++, offs=(offs+2)&0x3fff, r.min_x+=8, r.max_x+=8)
+		{
+			if (!dirtybuffer || dirtybuffer[offs] || dirtybuffer[offs+1])
+			{
+				UINT8 ch = pcjr.displayram[offs + 0];
+				UINT8 attr = pcjr.displayram[offs + 1];
+					
 				if (attr & 0x80)	/* blinking ? */
 				{
 					if (pcjr.pc_blink)
@@ -541,99 +632,64 @@ static void t1t_text_blink(struct mame_bitmap *bitmap)
 						attr = attr & 0x7f;
 				}
 
-				drawgfx(bitmap, Machine->gfx[0], pcjr.displayram[offs], attr, 
-						0,0,r.min_x,r.min_y,&r,TRANSPARENCY_NONE,0);
+				t1t_plot_char(bitmap, &r, ch, attr);
 
-/*				if ((cursor.on)&&(offs==cursor.pos*2)) { */
-				if (cursor.on&&(pcjr.pc_framecnt&32)&&(offs==cursor.pos*2)) {
-					int k=height-cursor.top;
-					struct rectangle rect2=r;
-					rect2.min_y+=cursor.top; 
-					if (cursor.bottom<height) k=cursor.bottom-cursor.top+1;
+				if (cursor.on&& (pcjr.pc_framecnt & 32) && (offs == cursor.pos * 2))
+				{
+					int k = height-cursor.top;
+					rectangle rect2 = r;
+					rect2.min_y += cursor.top;
+
+					if (cursor.bottom < height)
+						k = cursor.bottom - cursor.top + 1;
 
 					if (k>0)
-						plot_box(Machine->scrbitmap, r.min_x, 
-								 r.min_y+cursor.top, 
-								 8, k, Machine->pens[7]);
+						plot_box(bitmap, r.min_x, 
+							r.min_y+cursor.top, 
+							8, k, Machine->pens[7]);
 				}
 
-				dirtybuffer[offs]=dirtybuffer[offs+1]=0;
+				if (dirtybuffer)
+					dirtybuffer[offs] = dirtybuffer[offs + 1] = 0;
 			}
 		}
 	}
 }
 
+
+
 /***************************************************************************
   Draw graphics mode with 320x200 pixels (default) with 2 bits/pixel.
   The cell size is 2x1 (double width pixels, 1 scanline is the real
   default but up to 32 are possible).
   Even scanlines are from T1T_base + 0x0000, odd from T1T_base + 0x2000
 ***************************************************************************/
-static void t1t_gfx_2bpp(struct mame_bitmap *bitmap)
+
+static void t1t_gfx_2bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
-	int i, sx, sy, sh;
-	int	offs = crtc6845_get_start(pcjr.crtc)*2;
-	int lines = crtc6845_get_char_lines(pcjr.crtc);
-	int height = crtc6845_get_char_height(pcjr.crtc);
-	int columns = crtc6845_get_char_columns(pcjr.crtc)*2;
+	static const UINT16 palette[] =
+	{
+		0, 10, 12, 14,
+		0, 11, 13, 15
+	};
 
-	for (sy=0; sy<lines; sy++,offs=(offs+columns)&0x1fff) {
-
-		for (sh=0; sh<height; sh++) { 
-			switch (sh&3) {
-			case 0: /* char line 0 used as a12 line in graphic mode */
-				for (i=offs, sx=0; sx<columns; sx++, i=(i+1)&0x1fff) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[2], pcjr.displayram[i], (pcjr.color_select&0x20?1:0),
-								0,0,sx*4,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			case 1:
-				for (i=offs|0x2000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x2000) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[2], pcjr.displayram[i], (pcjr.color_select&0x20?1:0),
-								0,0,sx*4,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			case 2:
-				for (i=offs|0x4000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x4000) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[2], pcjr.displayram[i], (pcjr.color_select&0x20?1:0),
-								0,0,sx*4,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			case 3:
-				for (i=offs|0x6000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x6000) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[2], pcjr.displayram[i], (pcjr.color_select&0x20?1:0),
-								0,0,sx*4,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			}
-		}
-	}
+	pc_render_gfx_2bpp(bitmap, crtc, pcjr.displayram, &palette[pcjr.color_select ? 4 : 0], 2);
 }
 
+
+
 /***************************************************************************
   Draw graphics mode with 640x200 pixels (default).
   The cell size is 1x1 (1 scanline is the real default)
   Even scanlines are from T1T_base + 0x0000, odd from T1T_base + 0x2000
 ***************************************************************************/
-static void t1t_gfx_1bpp(struct mame_bitmap *bitmap)
+static void t1t_gfx_1bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
 	int i, sx, sy, sh;
-	int	offs = crtc6845_get_start(pcjr.crtc)*2;
-	int lines = crtc6845_get_char_lines(pcjr.crtc);
-	int height = crtc6845_get_char_height(pcjr.crtc);
-	int columns = crtc6845_get_char_columns(pcjr.crtc)*2;
+	int	offs = crtc6845_get_start(crtc)*2;
+	int lines = crtc6845_get_char_lines(crtc);
+	int height = crtc6845_get_char_height(crtc);
+	int columns = crtc6845_get_char_columns(crtc)*2;
 
 	for (sy=0; sy<lines; sy++,offs=(offs+columns)&0x1fff) {
 
@@ -641,7 +697,7 @@ static void t1t_gfx_1bpp(struct mame_bitmap *bitmap)
 			if (!(sh&1)) { /* char line 0 used as a12 line in graphic mode */
 				for (i=offs, sx=0; sx<columns; sx++, i=(i+1)&0x1fff) {
 					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[1], pcjr.displayram[i], pcjr.color_select&0xf, 0,0,sx*8,sy*height+sh,
+						drawgfx(bitmap, Machine->gfx[2], pcjr.displayram[i], pcjr.color_select&0xf, 0,0,sx*8,sy*height+sh,
 								0,TRANSPARENCY_NONE,0);
 						dirtybuffer[i]=0;
 					}
@@ -649,7 +705,7 @@ static void t1t_gfx_1bpp(struct mame_bitmap *bitmap)
 			} else {
 				for (i=offs|0x2000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x2000) {
 					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[1], pcjr.displayram[i], pcjr.color_select&0xf, 0,0,sx*8,sy*height+sh,
+						drawgfx(bitmap, Machine->gfx[2], pcjr.displayram[i], pcjr.color_select&0xf, 0,0,sx*8,sy*height+sh,
 								0,TRANSPARENCY_NONE,0);
 						dirtybuffer[i]=0;
 					}
@@ -659,6 +715,8 @@ static void t1t_gfx_1bpp(struct mame_bitmap *bitmap)
 	}
 }
 
+
+
 /***************************************************************************
   Draw graphics mode with 160x200 pixels (default) and 4 bits/pixel.
   The cell size is 4x1 (quadruple width pixels, 1 scanline is the real
@@ -666,138 +724,72 @@ static void t1t_gfx_1bpp(struct mame_bitmap *bitmap)
   Scanlines (scanline % 4) are from CGA_base + 0x0000,
   CGA_base + 0x2000
 ***************************************************************************/
-static void t1t_gfx_4bpp(struct mame_bitmap *bitmap)
+
+static void t1t_gfx_4bpp(mame_bitmap *bitmap, struct crtc6845 *crtc)
 {
-	int i, sx, sy, sh;
-	int	offs = crtc6845_get_start(pcjr.crtc)*2;
-	int lines = crtc6845_get_char_lines(pcjr.crtc);
-	int height = crtc6845_get_char_height(pcjr.crtc);
-	int columns = crtc6845_get_char_columns(pcjr.crtc)*2;
-
-	for (sy=0; sy<lines; sy++,offs=(offs+columns)&0x1fff) {
-
-		for (sh=0; sh<height; sh++) { 
-			switch (sh&3) {
-			case 0: /* char line 0 used as a12 line in graphic mode */
-				for (i=offs, sx=0; sx<columns; sx++, i=(i+1)&0x1fff) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[3], pcjr.displayram[i], 0,
-								0,0,sx*2,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			case 1:
-				for (i=offs|0x2000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x2000) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[3], pcjr.displayram[i], 0,
-								0,0,sx*2,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			case 2:
-				for (i=offs|0x4000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x4000) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[3], pcjr.displayram[i], 0,
-								0,0,sx*2,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			case 3:
-				for (i=offs|0x6000, sx=0; sx<columns; sx++, i=((i+1)&0x1fff)|0x6000) {
-					if (dirtybuffer[i]) {
-						drawgfx(bitmap, Machine->gfx[3], pcjr.displayram[i], 0,
-								0,0,sx*2,sy*height+sh, 0,TRANSPARENCY_NONE,0);
-						dirtybuffer[i]=0;
-					}
-				}
-				break;
-			}
-		}
-	}
+	pc_render_gfx_4bpp(bitmap, crtc, pcjr.displayram, NULL, 4);
 }
 
+
+
 /***************************************************************************
-  Draw the game screen in the given mame_bitmap.
-  Do NOT call osd_update_display() from this function,
-  it will be called by the main emulation engine.
+  Choose the appropriate video mode
 ***************************************************************************/
-void pc_t1t_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+
+static pc_video_update_proc pc_t1t_choosevideomode(int *width, int *height, struct crtc6845 *crtc)
 {
-	static int video_active = 0;
-	static int width=0, height=0;
-	int w,h;
+	int xfactor = 8;
+	int yfactor = 1;
+	pc_video_update_proc proc = NULL;
 
-	if (!pcjr.displayram) return;
+	switch( pcjr.mode_control & 0x3b ) {
+	case 0x08:
+	case 0x09:
+		proc = t1t_text_inten;
+		break;
 
-    /* draw entire scrbitmap because of usrintrf functions
-	   called osd_clearbitmap or attr change / scanline change */
-	if( crtc6845_do_full_refresh(pcjr.crtc)||pcjr.full_refresh||full_refresh )
-	{
-		pcjr.full_refresh=0;
-		memset(dirtybuffer, 1, videoram_size);
-		fillbitmap(bitmap, Machine->pens[0], &Machine->visible_area);
-		video_active = 0;
+	case 0x28:
+	case 0x29:
+		proc = t1t_text_blink;
+		break;
+
+    case 0x0a: case 0x0b: case 0x2a: case 0x2b:
+		switch (pcjr.bank & 0xc0) {
+		case 0x00:	/* hmm.. text in graphics? */
+		case 0x40:
+			proc = t1t_gfx_2bpp;
+			break;
+
+		case 0x80:
+			proc = t1t_gfx_4bpp;
+			xfactor = 4;
+			break;
+
+		case 0xc0:
+			proc = t1t_gfx_4bpp;
+			xfactor = 4;
+			break;
+		}
+		break;
+
+	case 0x18: case 0x19: case 0x1a: case 0x1b:
+	case 0x38: case 0x39: case 0x3a: case 0x3b:
+		switch (pcjr.bank & 0xc0) {
+		case 0x00:	/* hmm.. text in graphics? */
+		case 0x40:
+			proc = t1t_gfx_1bpp;
+			xfactor = 16;
+			break;
+
+		case 0x80:
+		case 0xc0:
+			proc = t1t_gfx_2bpp;
+			break;
+        }
+		break;
     }
 
-	w=crtc6845_get_char_columns(pcjr.crtc)*8;
-	h=crtc6845_get_char_height(pcjr.crtc)*crtc6845_get_char_lines(pcjr.crtc);
-	switch( pcjr.mode_control & 0x3b )	/* text and gfx modes */
-	{
-		case 0x08:
-			video_active = 10;
-			t1t_text_inten(bitmap); /* column */
-			break;
-		case 0x09:
-			video_active = 10;
-			t1t_text_inten(bitmap);
-			break;
-		case 0x28:
-			video_active = 10;
-			t1t_text_blink(bitmap); /* 40 column */
-			break;
-		case 0x29:
-			video_active = 10;
-			t1t_text_blink(bitmap);
-			break;
-        case 0x0a: case 0x0b: case 0x2a: case 0x2b:
-			video_active = 10;
-			switch (pcjr.bank & 0xc0)
-			{
-			case 0x00:	/* hmm.. text in graphics? */
-			case 0x40: t1t_gfx_2bpp(bitmap); break;
-			case 0x80: t1t_gfx_4bpp(bitmap);w/=2; break; /*160 */
-			case 0xc0: t1t_gfx_4bpp(bitmap);w/=2; break; /*320 */
-			}
-			break;
-		case 0x18: case 0x19: case 0x1a: case 0x1b:
-		case 0x38: case 0x39: case 0x3a: case 0x3b:
-			video_active = 10;
-			switch (pcjr.bank & 0xc0)
-			{
-			case 0x00:	/* hmm.. text in graphics? */
-			case 0x40: t1t_gfx_1bpp(bitmap);w*=2; break;
-			case 0x80:
-			case 0xc0: t1t_gfx_2bpp(bitmap); break; /*640 */
-            }
-			break;
-
-        default:
-			if( video_active && --video_active == 0 )
-				fillbitmap(bitmap, Machine->pens[0], &Machine->visible_area);
-    }
-
-	if ( (width!=w)||(height!=h) ) {
-		width=w;
-		height=h;
-		if (width>Machine->visible_area.max_x) width=Machine->visible_area.max_x+1;
-		if (height>Machine->visible_area.max_y) height=Machine->visible_area.max_y+1;
-		if ((width>100)&&(height>100))
-			osd_set_visible_area(0,width-1,0, height-1);
-		else logerror("video %d %d\n",width, height);
-	}
-
-/*	state_display(bitmap); */
+	*width *= xfactor;
+	*height *= yfactor;
+	return proc;
 }
