@@ -356,6 +356,8 @@ Video part
 #include <stdio.h>
 #include "osd_cpu.h"
 #include "driver.h"
+#include "utils.h"
+#include "sound/custom.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
@@ -471,9 +473,7 @@ unsigned char ted7360_palette[] =
 
 struct CustomSound_interface ted7360_sound_interface =
 {
-	ted7360_custom_start,
-	ted7360_custom_stop,
-	ted7360_custom_update
+	ted7360_custom_start
 };
 
 UINT8 ted7360[0x20] =
@@ -483,10 +483,11 @@ bool ted7360_pal;
 bool ted7360_rom;
 
 static int lines;
-static void *timer1 = 0, *timer2 = 0, *timer3 = 0;
-static bool cursor1 = false;
-static mem_read_handler vic_dma_read;
-static mem_read_handler vic_dma_read_rom;
+static int timer1_active, timer2_active, timer3_active;
+static mame_timer *timer1, *timer2, *timer3;
+static int cursor1 = FALSE;
+static read8_handler vic_dma_read;
+static read8_handler vic_dma_read_rom;
 static int chargenaddr, bitmapaddr, videoaddr;
 
 static int x_begin, x_end;
@@ -494,14 +495,14 @@ static int y_begin, y_end;
 
 static UINT16 c16_bitmap[2], bitmapmulti[4], mono[2], monoinversed[2], multi[4], ecmcolor[2], colors[5];
 
-static struct mame_bitmap *ted7360_bitmap;	/* Machine->scrbitmap for speedup */
+static mame_bitmap *ted7360_bitmap;
 static int rasterline = 0, lastline = 0;
 static double rastertime;
 static void ted7360_drawlines (int first, int last);
 
 static UINT32 cursorcolortable[2] =
 {0};
-static struct GfxLayout cursorlayout =
+static gfx_layout cursorlayout =
 {
 	8, 8,
 	1,
@@ -514,17 +515,23 @@ static struct GfxLayout cursorlayout =
 
 static UINT8 cursormask[] =
 {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
-static struct GfxElement *cursorelement;
+static gfx_element *cursorelement;
+
+static void ted7360_timer_timeout (int which);
 
 void ted7360_init (int pal)
 {
 	ted7360_pal = pal;
 	lines = TED7360_LINES;
 	chargenaddr = bitmapaddr = videoaddr = 0;
+	timer1_active = timer2_active = timer3_active = 0;
+	timer1 = timer_alloc(ted7360_timer_timeout);
+	timer2 = timer_alloc(ted7360_timer_timeout);
+	timer3 = timer_alloc(ted7360_timer_timeout);
 }
 
-void ted7360_set_dma (mem_read_handler dma_read,
-					  mem_read_handler dma_read_rom)
+void ted7360_set_dma (read8_handler dma_read,
+					  read8_handler dma_read_rom)
 {
 	vic_dma_read = dma_read;
 	vic_dma_read_rom = dma_read_rom;
@@ -571,37 +578,39 @@ static void ted7360_timer_timeout (int which)
 	{
 	case 1:
 	    /* prooved by digisound of several intros like eoroidpro */
-		timer1 = timer_set (TEDTIME_IN_CYCLES (TIMER1), 1, ted7360_timer_timeout);
+		timer_adjust(timer1, TEDTIME_IN_CYCLES (TIMER1), 1, 0);
+		timer1_active = 1;
 		ted7360_set_interrupt (8);
 		break;
 	case 2:
-		timer2 = timer_set (TEDTIME_IN_CYCLES (0x10000), 2, ted7360_timer_timeout);
+		timer_adjust(timer2, TEDTIME_IN_CYCLES (0x10000), 2, 0);
+		timer2_active = 1;
 		ted7360_set_interrupt (0x10);
 		break;
 	case 3:
-		timer3 = timer_set (TEDTIME_IN_CYCLES (0x10000), 3, ted7360_timer_timeout);
+		timer_adjust(timer3, TEDTIME_IN_CYCLES (0x10000), 3, 0);
+		timer3_active = 1;
 		ted7360_set_interrupt (0x40);
 		break;
 	}
 }
 
-int ted7360_frame_interrupt (void)
+INTERRUPT_GEN( ted7360_frame_interrupt )
 {
 	static int count;
 
 	if ((ted7360[0x1f] & 0xf) >= 0x0f)
 	{
 /*  if (count>=CURSORRATE) { */
-		cursor1 ^= true;
+		cursor1 ^= TRUE;
 		ted7360[0x1f] &= ~0xf;
 		count = 0;
 	}
 	else
 		ted7360[0x1f]++;
-	return ignore_interrupt ();
 }
 
-WRITE_HANDLER ( ted7360_port_w )
+WRITE8_HANDLER ( ted7360_port_w )
 {
 	int old;
 
@@ -623,51 +632,45 @@ WRITE_HANDLER ( ted7360_port_w )
 	{
 	case 0:						   /* stop timer 1 */
 		ted7360[offset] = data;
-		if (timer1)
+		if (timer1_active)
 		{
 			ted7360[1] = TEDTIME_TO_CYCLES (timer_timeleft (timer1)) >> 8;
-			timer_remove (timer1);
-			timer1 = 0;
+			timer_reset(timer1, TIME_NEVER);
+			timer1_active = 0;
 		}
 		break;
 	case 1:						   /* start timer 1 */
 		ted7360[offset] = data;
-		if (!timer1)
-			timer1 = timer_set (TEDTIME_IN_CYCLES (TIMER1), 1, ted7360_timer_timeout);
-		else
-			timer_reset (timer1, TEDTIME_IN_CYCLES (TIMER1));
+		timer_adjust(timer1, TEDTIME_IN_CYCLES (TIMER1), 1, 0);
+		timer1_active = 1;
 		break;
 	case 2:						   /* stop timer 2 */
 		ted7360[offset] = data;
-		if (timer2)
+		if (timer2_active)
 		{
 			ted7360[3] = TEDTIME_TO_CYCLES (timer_timeleft (timer2)) >> 8;
-			timer_remove (timer2);
-			timer2 = 0;
+			timer_reset(timer2, TIME_NEVER);
+			timer2_active = 0;
 		}
 		break;
 	case 3:						   /* start timer 2 */
 		ted7360[offset] = data;
-		if (!timer2)
-			timer2 = timer_set (TEDTIME_IN_CYCLES (TIMER2), 2, ted7360_timer_timeout);
-		else
-			timer_reset (timer2, TEDTIME_IN_CYCLES (TIMER2));
+		timer_adjust(timer2, TEDTIME_IN_CYCLES (TIMER2), 2, 0);
+		timer2_active = 1;
 		break;
 	case 4:						   /* stop timer 3 */
 		ted7360[offset] = data;
-		if (timer3)
+		if (timer3_active)
 		{
 			ted7360[5] = TEDTIME_TO_CYCLES (timer_timeleft (timer3)) >> 8;
-			timer_remove (timer3);
-			timer3 = 0;
+			timer_reset(timer3, TIME_NEVER);
+			timer3_active = 0;
 		}
 		break;
 	case 5:						   /* start timer 3 */
 		ted7360[offset] = data;
-		if (!timer3)
-			timer3 = timer_set (TEDTIME_IN_CYCLES (TIMER3), 3, ted7360_timer_timeout);
-		else
-			timer_reset (timer3, TEDTIME_IN_CYCLES (TIMER3));
+		timer_adjust(timer3, TEDTIME_IN_CYCLES (TIMER3), 3, 0);
+		timer3_active = 1;
 		break;
 	case 6:
 		if (ted7360[offset] != data)
@@ -837,7 +840,7 @@ WRITE_HANDLER ( ted7360_port_w )
 	}
 }
 
-READ_HANDLER ( ted7360_port_r )
+ READ8_HANDLER ( ted7360_port_r )
 {
 	int val = 0;
 
@@ -928,17 +931,18 @@ READ_HANDLER ( ted7360_port_r )
 	return val;
 }
 
-int ted7360_vh_start (void)
+VIDEO_START( ted7360 )
 {
-	cursorelement = decodegfx (cursormask, &cursorlayout);
+	cursorelement = allocgfx(&cursorlayout);
+	decodegfx(cursorelement, cursormask, 0, 1);
 	cursorelement->colortable = cursorcolortable;
 	cursorcolortable[1] = Machine->pens[1];
 	cursorelement->total_colors = 2;
-	ted7360_bitmap = Machine->scrbitmap;
+	ted7360_bitmap = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
 	return 0;
 }
 
-void ted7360_vh_stop (void)
+VIDEO_STOP( ted7360 )
 {
 	freegfx (cursorelement);
 }
@@ -948,41 +952,20 @@ static void ted7360_draw_character (int ybegin, int yend, int ch, int yoff, int
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			if (INROM)
-				code = vic_dma_read_rom (chargenaddr + ch * 8 + y);
-			else
-				code = vic_dma_read (chargenaddr + ch * 8 + y);
-			ted7360_bitmap->line[y + yoff][xoff] = color[code >> 7];
-			ted7360_bitmap->line[y + yoff][1 + xoff] = color[(code >> 6) & 1];
-			ted7360_bitmap->line[y + yoff][2 + xoff] = color[(code >> 5) & 1];
-			ted7360_bitmap->line[y + yoff][3 + xoff] = color[(code >> 4) & 1];
-			ted7360_bitmap->line[y + yoff][4 + xoff] = color[(code >> 3) & 1];
-			ted7360_bitmap->line[y + yoff][5 + xoff] = color[(code >> 2) & 1];
-			ted7360_bitmap->line[y + yoff][6 + xoff] = color[(code >> 1) & 1];
-			ted7360_bitmap->line[y + yoff][7 + xoff] = color[code & 1];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			if (INROM)
-				code = vic_dma_read_rom (chargenaddr + ch * 8 + y);
-			else
-				code = vic_dma_read (chargenaddr + ch * 8 + y);
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff) = color[code >> 7];
-			*((short *) ted7360_bitmap->line[y + yoff] + 1 + xoff) = color[(code >> 6) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 2 + xoff) = color[(code >> 5) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 3 + xoff) = color[(code >> 4) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 4 + xoff) = color[(code >> 3) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 5 + xoff) = color[(code >> 2) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 6 + xoff) = color[(code >> 1) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 7 + xoff) = color[code & 1];
-		}
+		if (INROM)
+			code = vic_dma_read_rom (chargenaddr + ch * 8 + y);
+		else
+			code = vic_dma_read (chargenaddr + ch * 8 + y);
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff) = color[code >> 7];
+		*((short *) ted7360_bitmap->line[y + yoff] + 1 + xoff) = color[(code >> 6) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 2 + xoff) = color[(code >> 5) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 3 + xoff) = color[(code >> 4) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 4 + xoff) = color[(code >> 3) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 5 + xoff) = color[(code >> 2) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 6 + xoff) = color[(code >> 1) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 7 + xoff) = color[code & 1];
 	}
 }
 
@@ -991,41 +974,20 @@ static void ted7360_draw_character_multi (int ybegin, int yend, int ch, int yoff
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			if (INROM)
-				code = vic_dma_read_rom (chargenaddr + ch * 8 + y);
-			else
-				code = vic_dma_read (chargenaddr + ch * 8 + y);
-			ted7360_bitmap->line[y + yoff][xoff] =
-				ted7360_bitmap->line[y + yoff][xoff + 1] = multi[code >> 6];
-			ted7360_bitmap->line[y + yoff][xoff + 2] =
-				ted7360_bitmap->line[y + yoff][xoff + 3] = multi[(code >> 4) & 3];
-			ted7360_bitmap->line[y + yoff][xoff + 4] =
-				ted7360_bitmap->line[y + yoff][xoff + 5] = multi[(code >> 2) & 3];
-			ted7360_bitmap->line[y + yoff][xoff + 6] =
-				ted7360_bitmap->line[y + yoff][xoff + 7] = multi[code & 3];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			if (INROM)
-				code = vic_dma_read_rom (chargenaddr + ch * 8 + y);
-			else
-				code = vic_dma_read (chargenaddr + ch * 8 + y);
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 1) = multi[code >> 6];
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 2) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 3) = multi[(code >> 4) & 3];
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 4) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 5) = multi[(code >> 2) & 3];
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 6) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 7) = multi[code & 3];
-		}
+		if (INROM)
+			code = vic_dma_read_rom (chargenaddr + ch * 8 + y);
+		else
+			code = vic_dma_read (chargenaddr + ch * 8 + y);
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 1) = multi[code >> 6];
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff + 2) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 3) = multi[(code >> 4) & 3];
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff + 4) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 5) = multi[(code >> 2) & 3];
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff + 6) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 7) = multi[code & 3];
 	}
 }
 
@@ -1034,35 +996,17 @@ static void ted7360_draw_bitmap (int ybegin, int yend,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read (bitmapaddr + ch * 8 + y);
-			ted7360_bitmap->line[y + yoff][xoff] = c16_bitmap[code >> 7];
-			ted7360_bitmap->line[y + yoff][1 + xoff] = c16_bitmap[(code >> 6) & 1];
-			ted7360_bitmap->line[y + yoff][2 + xoff] = c16_bitmap[(code >> 5) & 1];
-			ted7360_bitmap->line[y + yoff][3 + xoff] = c16_bitmap[(code >> 4) & 1];
-			ted7360_bitmap->line[y + yoff][4 + xoff] = c16_bitmap[(code >> 3) & 1];
-			ted7360_bitmap->line[y + yoff][5 + xoff] = c16_bitmap[(code >> 2) & 1];
-			ted7360_bitmap->line[y + yoff][6 + xoff] = c16_bitmap[(code >> 1) & 1];
-			ted7360_bitmap->line[y + yoff][7 + xoff] = c16_bitmap[code & 1];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read (bitmapaddr + ch * 8 + y);
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff) = c16_bitmap[code >> 7];
-			*((short *) ted7360_bitmap->line[y + yoff] + 1 + xoff) = c16_bitmap[(code >> 6) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 2 + xoff) = c16_bitmap[(code >> 5) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 3 + xoff) = c16_bitmap[(code >> 4) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 4 + xoff) = c16_bitmap[(code >> 3) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 5 + xoff) = c16_bitmap[(code >> 2) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 6 + xoff) = c16_bitmap[(code >> 1) & 1];
-			*((short *) ted7360_bitmap->line[y + yoff] + 7 + xoff) = c16_bitmap[code & 1];
-		}
+		code = vic_dma_read (bitmapaddr + ch * 8 + y);
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff) = c16_bitmap[code >> 7];
+		*((short *) ted7360_bitmap->line[y + yoff] + 1 + xoff) = c16_bitmap[(code >> 6) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 2 + xoff) = c16_bitmap[(code >> 5) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 3 + xoff) = c16_bitmap[(code >> 4) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 4 + xoff) = c16_bitmap[(code >> 3) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 5 + xoff) = c16_bitmap[(code >> 2) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 6 + xoff) = c16_bitmap[(code >> 1) & 1];
+		*((short *) ted7360_bitmap->line[y + yoff] + 7 + xoff) = c16_bitmap[code & 1];
 	}
 }
 
@@ -1071,35 +1015,17 @@ static void ted7360_draw_bitmap_multi (int ybegin, int yend,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read (bitmapaddr + ch * 8 + y);
-			ted7360_bitmap->line[y + yoff][xoff] =
-				ted7360_bitmap->line[y + yoff][xoff + 1] = bitmapmulti[code >> 6];
-			ted7360_bitmap->line[y + yoff][xoff + 2] =
-				ted7360_bitmap->line[y + yoff][xoff + 3] = bitmapmulti[(code >> 4) & 3];
-			ted7360_bitmap->line[y + yoff][xoff + 4] =
-				ted7360_bitmap->line[y + yoff][xoff + 5] = bitmapmulti[(code >> 2) & 3];
-			ted7360_bitmap->line[y + yoff][xoff + 6] =
-				ted7360_bitmap->line[y + yoff][xoff + 7] = bitmapmulti[code & 3];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read (bitmapaddr + ch * 8 + y);
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 1) = bitmapmulti[code >> 6];
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 2) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 3) = bitmapmulti[(code >> 4) & 3];
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 4) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 5) = bitmapmulti[(code >> 2) & 3];
-			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 6) =
-				*((short *) ted7360_bitmap->line[y + yoff] + xoff + 7) = bitmapmulti[code & 3];
-		}
+		code = vic_dma_read (bitmapaddr + ch * 8 + y);
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 1) = bitmapmulti[code >> 6];
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff + 2) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 3) = bitmapmulti[(code >> 4) & 3];
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff + 4) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 5) = bitmapmulti[(code >> 2) & 3];
+		*((short *) ted7360_bitmap->line[y + yoff] + xoff + 6) =
+			*((short *) ted7360_bitmap->line[y + yoff] + xoff + 7) = bitmapmulti[code & 3];
 	}
 }
 
@@ -1108,234 +1034,173 @@ static void ted7360_draw_cursor (int ybegin, int yend, int yoff, int xoff,
 {
 	int y;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			memset (ted7360_bitmap->line[yoff + y] + xoff, color, 8);
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			memset16 ((short *) ted7360_bitmap->line[yoff + y] + xoff, color, 8);
-		}
+		memset16 ((short *) ted7360_bitmap->line[yoff + y] + xoff, color, 8);
 	}
 }
 
 static void ted7360_drawlines (int first, int last)
 {
-    int line, vline, end;
-    int attr, ch, c1, c2, ecm;
-    int offs, yoff, xoff, ybegin, yend, xbegin, xend;
-    int i;
-    
-    lastline = last;
-    
-    if (osd_skip_this_frame ())
-	return;
-    
-    /* top part of display not rastered */
-    first -= TED7360_YPOS;
-    last -= TED7360_YPOS;
-    if ((first >= last) || (last <= 0))
-	return;
-    if (first < 0)
-	first = 0;
-    
-    if (!SCREENON)
-    {
-/*	if (Machine->color_depth == 8)
+	int line, vline, end;
+	int attr, ch, c1, c2, ecm;
+	int offs, yoff, xoff, ybegin, yend, xbegin, xend;
+	int i;
+
+	lastline = last;
+
+	if (osd_skip_this_frame ())
+		return;
+
+	/* top part of display not rastered */
+	first -= TED7360_YPOS;
+	last -= TED7360_YPOS;
+	if ((first >= last) || (last <= 0))
+		return;
+	if (first < 0)
+		first = 0;
+
+	if (!SCREENON)
 	{
-	    for (line = first; (line < last) && (line < ted7360_bitmap->height); line++)
-		memset (ted7360_bitmap->line[line], Machine->pens[0], ted7360_bitmap->width);
+		for (line = first; (line < last) && (line < ted7360_bitmap->height); line++)
+			memset16 (ted7360_bitmap->line[line], Machine->pens[0], ted7360_bitmap->width);
+		return;
+	}
+
+	if (COLUMNS40)
+		xbegin = XPOS, xend = xbegin + 320;
+	else
+		xbegin = XPOS + 7, xend = xbegin + 304;
+
+	if (last < y_begin)
+		end = last;
+	else
+		end = y_begin + YPOS;
+	{
+		for (line = first; line < end; line++)
+			memset16 (ted7360_bitmap->line[line], Machine->pens[FRAMECOLOR],
+				ted7360_bitmap->width);
+	}
+	if (LINES25)
+	{
+		vline = line - y_begin - YPOS;
 	}
 	else
-*/	{
-	    for (line = first; (line < last) && (line < ted7360_bitmap->height); line++)
-		memset16 (ted7360_bitmap->line[line], Machine->pens[0], ted7360_bitmap->width);
+	{
+		vline = line - y_begin - YPOS + 8 - VERTICALPOS;
 	}
-	return;
-    }
-    
-    if (COLUMNS40)
-	xbegin = XPOS, xend = xbegin + 320;
-    else
-	xbegin = XPOS + 7, xend = xbegin + 304;
-    
-    if (last < y_begin)
-	end = last;
-    else
-	end = y_begin + YPOS;
-/*    if (Machine->color_depth == 8)
-    {
-	for (line = first; line < end; line++)
-	    memset (ted7360_bitmap->line[line], Machine->pens[FRAMECOLOR],
-		    ted7360_bitmap->width);
-    }
-    else
-*/   {
-	for (line = first; line < end; line++)
-	    memset16 (ted7360_bitmap->line[line], Machine->pens[FRAMECOLOR],
-		      ted7360_bitmap->width);
-    }
-    if (LINES25)
-    {
-	vline = line - y_begin - YPOS;
-    }
-    else
-    {
-	vline = line - y_begin - YPOS + 8 - VERTICALPOS;
-    }
-    if (last < y_end + YPOS)
-	end = last;
-    else
-	end = y_end + YPOS;
-    for (; line < end; vline = (vline + 8) & ~7, line = line + 1 + yend - ybegin)
-    {
-	offs = (vline >> 3) * 40;
-	ybegin = vline & 7;
-	yoff = line - ybegin;
-	yend = (yoff + 7 < end) ? 7 : (end - yoff - 1);
+	if (last < y_end + YPOS)
+		end = last;
+	else
+		end = y_end + YPOS;
+	for (; line < end; vline = (vline + 8) & ~7, line = line + 1 + yend - ybegin)
+	{
+		offs = (vline >> 3) * 40;
+		ybegin = vline & 7;
+		yoff = line - ybegin;
+		yend = (yoff + 7 < end) ? 7 : (end - yoff - 1);
 		/* rendering 39 characters */
-	/* left and right borders are overwritten later */
-	
-	for (xoff = x_begin + XPOS; xoff < x_end + XPOS; xoff += 8, offs++)
-	{
-	    if (HIRESON)
-	    {
-		ch = vic_dma_read ((videoaddr | 0x400) + offs);
-		attr = vic_dma_read (((videoaddr) + offs));
-		c1 = ((ch >> 4) & 0xf) | (attr << 4);
-		c2 = (ch & 0xf) | (attr & 0x70);
-		bitmapmulti[1] = c16_bitmap[1] = Machine->pens[c1 & 0x7f];
-		bitmapmulti[2] = c16_bitmap[0] = Machine->pens[c2 & 0x7f];
-		if (MULTICOLORON)
-		{
-		    ted7360_draw_bitmap_multi (ybegin, yend, offs, yoff, xoff);
-		}
-		else
-		{
-		    ted7360_draw_bitmap (ybegin, yend, offs, yoff, xoff);
-		}
-	    }
-	    else
-	    {
-		ch = vic_dma_read ((videoaddr | 0x400) + offs);
-		attr = vic_dma_read (((videoaddr) + offs));
-		/* levente harsfalvi's docu says cursor off in ecm and multicolor */
-		if (ECMON) {
-		    /* hardware reverse off */
-		    ecm = ch >> 6;
-		    ecmcolor[0] = colors[ecm];
-		    ecmcolor[1] = Machine->pens[attr & 0x7f];
-		    ted7360_draw_character (ybegin, yend, ch & ~0xC0, yoff, xoff, ecmcolor);
-		} else if (MULTICOLORON) {
-		    /* hardware reverse off */
-		    if (attr & 8) {
-			multi[3] = Machine->pens[attr & 0x77];
-			ted7360_draw_character_multi (ybegin, yend, ch, yoff, xoff);
-		    } else {
-			mono[1] = Machine->pens[attr & 0x7f];
-			ted7360_draw_character (ybegin, yend, ch, yoff, xoff,
-						mono);
-		    }
-		} else if (cursor1 && (offs == CURSOR1POS)) {
-#ifndef GFX
-		    ted7360_draw_cursor (ybegin, yend, yoff, xoff,
-					 Machine->pens[attr & 0x7f]);
-#else
-		    drawgfx (ted7360_bitmap, cursorelement, 0, Machine->pens[attr & 0x7f], 0, 0,
-			     xoff, yoff, 0, TRANSPARENCY_NONE, 0);
-#endif
-		} else if (REVERSEON && (ch & 0x80)) {
-		    monoinversed[0] = Machine->pens[attr & 0x7f];
-		    if (cursor1 && (attr & 0x80))
-			ted7360_draw_cursor (ybegin, yend, yoff, xoff, monoinversed[0]);
-		    else
-			ted7360_draw_character (ybegin, yend, ch & ~0x80, yoff, xoff,
-						monoinversed);
-		}
-		else
-		{
-		    mono[1] = Machine->pens[attr & 0x7f];
-		    if (cursor1 && (attr & 0x80))
-			ted7360_draw_cursor (ybegin, yend, yoff, xoff, mono[0]);
-		    else
-			ted7360_draw_character (ybegin, yend, ch, yoff, xoff, mono);
-		}
-	    }
-	}
-/*	if (Machine->color_depth == 8)
-	{
-	    for (i = ybegin; i <= yend; i++)
-	    {
-		memset (ted7360_bitmap->line[yoff + i], Machine->pens[FRAMECOLOR], xbegin);
-		memset (ted7360_bitmap->line[yoff + i] + xend, Machine->pens[FRAMECOLOR],
-			ted7360_bitmap->width - xend);
-	    }
-	}
-	else
-*/	{
-	    for (i = ybegin; i <= yend; i++)
-	    {
-		memset16 (ted7360_bitmap->line[yoff + i], Machine->pens[FRAMECOLOR],
-			  xbegin);
-		memset16 ((short *) ted7360_bitmap->line[yoff + i] + xend,
-			  Machine->pens[FRAMECOLOR], ted7360_bitmap->width - xend);
-	    }
-	}
-    }
-    if (last < ted7360_bitmap->height)
-	end = last;
-    else
-	end = ted7360_bitmap->height;
-/*    if (Machine->color_depth == 8)
-    {
-	for (; line < end; line++)
-	    memset (ted7360_bitmap->line[line], Machine->pens[FRAMECOLOR],
-		    ted7360_bitmap->width);
-    }
-    else
-*/    {
-	for (; line < end; line++)
-	    memset16 (ted7360_bitmap->line[line], Machine->pens[FRAMECOLOR],
-		      ted7360_bitmap->width);
-    }
-}
+		/* left and right borders are overwritten later */
 
-static void ted7360_draw_text (struct mame_bitmap *bitmap, char *text, int *y)
-{
-	int x, x0, y1t, width = (Machine->visible_area.max_x -
-							 Machine->visible_area.min_x) / Machine->uifont->width;
-
-	if (text[0] != 0)
-	{
-		x = strlen (text);
-		*y -= Machine->uifont->height * ((x + width - 1) / width);
-		y1t = *y + Machine->uifont->height;
-		x = 0;
-		while (text[x])
+		for (xoff = x_begin + XPOS; xoff < x_end + XPOS; xoff += 8, offs++)
 		{
-			for (x0 = Machine->visible_area.min_x;
-				 text[x] && (x0 < Machine->visible_area.max_x -
-							 Machine->uifont->width);
-				 x++, x0 += Machine->uifont->width)
+			if (HIRESON)
 			{
-				drawgfx (bitmap, Machine->uifont, text[x], 0, 0, 0, x0, y1t, 0,
-						 TRANSPARENCY_NONE, 0);
+				ch = vic_dma_read ((videoaddr | 0x400) + offs);
+				attr = vic_dma_read (((videoaddr) + offs));
+				c1 = ((ch >> 4) & 0xf) | (attr << 4);
+				c2 = (ch & 0xf) | (attr & 0x70);
+				bitmapmulti[1] = c16_bitmap[1] = Machine->pens[c1 & 0x7f];
+				bitmapmulti[2] = c16_bitmap[0] = Machine->pens[c2 & 0x7f];
+				if (MULTICOLORON)
+				{
+					ted7360_draw_bitmap_multi (ybegin, yend, offs, yoff, xoff);
+				}
+				else
+				{
+					ted7360_draw_bitmap (ybegin, yend, offs, yoff, xoff);
+				}
+			}
+			else
+			{
+				ch = vic_dma_read ((videoaddr | 0x400) + offs);
+				attr = vic_dma_read (((videoaddr) + offs));
+				/* levente harsfalvi's docu says cursor off in ecm and multicolor */
+				if (ECMON)
+				{
+					/* hardware reverse off */
+					ecm = ch >> 6;
+					ecmcolor[0] = colors[ecm];
+					ecmcolor[1] = Machine->pens[attr & 0x7f];
+					ted7360_draw_character (ybegin, yend, ch & ~0xC0, yoff, xoff, ecmcolor);
+				}
+				else if (MULTICOLORON)
+				{
+					/* hardware reverse off */
+					if (attr & 8)
+					{
+						multi[3] = Machine->pens[attr & 0x77];
+						ted7360_draw_character_multi (ybegin, yend, ch, yoff, xoff);
+					}
+					else
+					{
+						mono[1] = Machine->pens[attr & 0x7f];
+						ted7360_draw_character (ybegin, yend, ch, yoff, xoff, mono);
+					}
+				}
+				else if (cursor1 && (offs == CURSOR1POS))
+				{
+#ifndef GFX
+					ted7360_draw_cursor (ybegin, yend, yoff, xoff,
+							Machine->pens[attr & 0x7f]);
+#else
+					drawgfx (ted7360_bitmap, cursorelement, 0, Machine->pens[attr & 0x7f], 0, 0,
+						xoff, yoff, 0, TRANSPARENCY_NONE, 0);
+#endif
+				}
+				else if (REVERSEON && (ch & 0x80))
+				{
+					monoinversed[0] = Machine->pens[attr & 0x7f];
+					if (cursor1 && (attr & 0x80))
+						ted7360_draw_cursor (ybegin, yend, yoff, xoff, monoinversed[0]);
+					else
+						ted7360_draw_character (ybegin, yend, ch & ~0x80, yoff, xoff,
+							monoinversed);
+				}
+				else
+				{
+					mono[1] = Machine->pens[attr & 0x7f];
+					if (cursor1 && (attr & 0x80))
+						ted7360_draw_cursor (ybegin, yend, yoff, xoff, mono[0]);
+					else
+						ted7360_draw_character (ybegin, yend, ch, yoff, xoff, mono);
+				}
 			}
-			y1t += Machine->uifont->height;
 		}
+
+		for (i = ybegin; i <= yend; i++)
+		{
+			memset16 (ted7360_bitmap->line[yoff + i], Machine->pens[FRAMECOLOR],
+				xbegin);
+			memset16 ((short *) ted7360_bitmap->line[yoff + i] + xend,
+				Machine->pens[FRAMECOLOR], ted7360_bitmap->width - xend);
+		}
+	}
+
+    if (last < ted7360_bitmap->height)
+		end = last;
+    else
+		end = ted7360_bitmap->height;
+
+	for (; line < end; line++)
+	{
+		memset16 (ted7360_bitmap->line[line], Machine->pens[FRAMECOLOR],
+			ted7360_bitmap->width);
 	}
 }
 
-int ted7360_raster_interrupt (void)
+INTERRUPT_GEN( ted7360_raster_interrupt )
 {
-	int y;
-	char text[70];
-
 	rasterline++;
 	rastertime = timer_get_time ();
 	if (rasterline >= lines)
@@ -1343,31 +1208,15 @@ int ted7360_raster_interrupt (void)
 		rasterline = 0;
 		ted7360_drawlines (lastline, TED7360_LINES);
 		lastline = 0;
-
-		y = Machine->visible_area.max_y + 1 - Machine->uifont->height;
-
-		vc20_tape_status (text, sizeof (text));
-		ted7360_draw_text (ted7360_bitmap, text, &y);
-
-		if (REAL_C1551) {
-			vc1541_drive_status (text, sizeof (text));
-			ted7360_draw_text (ted7360_bitmap, text, &y);
-		}
-
-		cbm_drive_0_status (text, sizeof (text));
-		ted7360_draw_text (ted7360_bitmap, text, &y);
-
-		cbm_drive_1_status (text, sizeof (text));
-		ted7360_draw_text (ted7360_bitmap, text, &y);
 	}
 	if (rasterline == C16_2_RASTERLINE (RASTERLINE))
 	{
 		ted7360_drawlines (lastline, rasterline);
 		ted7360_set_interrupt (2);
 	}
-	return ignore_interrupt ();
 }
 
-void ted7360_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( ted7360 )
 {
+	copybitmap(bitmap, ted7360_bitmap, 0, 0, 0, 0, cliprect, TRANSPARENCY_NONE, 0);
 }
