@@ -16,18 +16,18 @@
 
 int v9938_init (int, int, void (*callback)(int));
 void v9938_reset (void);
-void v9938_exit (void);
-void v9958_init_palette (unsigned char *, unsigned short *,const unsigned char *);
-void v9938_init_palette (unsigned char *, unsigned short *,const unsigned char *);
 int v9938_interrupt (void);
-void v9938_refresh (struct mame_bitmap *, int);
+VIDEO_UPDATE( v9938 );
 void v9938_set_sprite_limit (int);
 void v9938_set_resolution (int);
 
-WRITE_HANDLER (v9938_palette_w);
-WRITE_HANDLER (v9938_vram_w);
-READ_HANDLER (v9938_vram_r);
-WRITE_HANDLER (v9938_command_w);
-READ_HANDLER (v9938_status_r);
-WRITE_HANDLER (v9938_register_w);
- 
+extern PALETTE_INIT( v9938 );
+extern PALETTE_INIT( v9958 );
+extern WRITE8_HANDLER( v9938_palette_w );
+extern WRITE8_HANDLER( v9938_vram_w );
+extern  READ8_HANDLER( v9938_vram_r );
+extern WRITE8_HANDLER( v9938_command_w );
+extern  READ8_HANDLER( v9938_status_r );
+extern WRITE8_HANDLER( v9938_register_w );
+
+void v9938_update_mouse_state(int mx_delta, int my_delta, int button_state);
