@@ -23,7 +23,7 @@ static struct {
 	int palette_dirty;
 } vic3;
 
-WRITE_HANDLER( vic3_palette_w )
+WRITE8_HANDLER( vic3_palette_w )
 {
 	if (offset<0x100) vic3.palette[offset].red=data;
 	else if (offset<0x200) vic3.palette[offset&0xff].green=data;
@@ -38,17 +38,17 @@ extern void vic4567_init (int pal, int (*dma_read) (int),
 	memset(&vic2, 0, sizeof(vic2));
 
 	vic2.lines = VIC2_LINES;
-	vic2.vic3=true;
+	vic2.vic3 = TRUE;
 
 	vic2.dma_read = dma_read;
 	vic2.dma_read_color = dma_read_color;
 	vic2.interrupt = irq;
 	vic2.pal = pal;
 	vic2.port_changed = param_port_changed;
-	vic2.on = true;
+	vic2.on = TRUE;
 }
 
-WRITE_HANDLER ( vic3_port_w )
+WRITE8_HANDLER ( vic3_port_w )
 {
 	DBG_LOG (2, "vic write", ("%.2x:%.2x\n", offset, data));
 	offset &= 0x7f;
@@ -76,8 +76,8 @@ WRITE_HANDLER ( vic3_port_w )
 		break;
 	case 0x31:
 		vic2.reg[offset] = data;
-		if (data&0x40) timer_set_overclock(0,1.0);
-		else timer_set_overclock(0, 1.0/3.5);
+		if (data&0x40) cpunum_set_clockscale(0,1.0);
+		else cpunum_set_clockscale(0, 1.0/3.5);
 		break;
 	case 0x32:
 	case 0x33:
@@ -112,7 +112,7 @@ WRITE_HANDLER ( vic3_port_w )
 	}
 }
 
-READ_HANDLER ( vic3_port_r )
+ READ8_HANDLER ( vic3_port_r )
 {
 	int val = 0;
 	offset &= 0x7f;
@@ -193,16 +193,8 @@ static void vic3_drawlines (int first, int last)
 
 	if (!SCREENON)
 	{
-/*		if (Machine->color_depth == 8)
-		{
-			for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
-				memset (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
-		}
-		else
-*/		{
-			for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
-				memset16 (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
-		}
+		for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
+			memset16 (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
 		return;
 	}
 	if (COLUMNS40)
@@ -214,18 +206,13 @@ static void vic3_drawlines (int first, int last)
 		end = last;
 	else
 		end = vic2.y_begin + YPOS;
-/*	if (Machine->color_depth == 8)
+
+	for (line = first; line < end; line++)
 	{
-		for (line = first; line < end; line++)
-			memset (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					vic2.bitmap->width);
-	}
-	else
-*/	{
-		for (line = first; line < end; line++)
-			memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					  vic2.bitmap->width);
+		memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
+			vic2.bitmap->width);
 	}
+
 	if (LINES25)
 	{
 		vline = line - vic2.y_begin - YPOS;
@@ -348,41 +335,24 @@ static void vic3_drawlines (int first, int last)
 				memset (vic2.sprites[i].paintedline, 0, sizeof (vic2.sprites[i].paintedline));
 			}
 		}
-/*		if (Machine->color_depth == 8)
+
+		for (i = ybegin; i <= yend; i++)
 		{
-			for (i = ybegin; i <= yend; i++)
-			{
-				memset (vic2.bitmap->line[yoff + i], Machine->pens[FRAMECOLOR], xbegin);
-				memset (vic2.bitmap->line[yoff + i] + xend, Machine->pens[FRAMECOLOR],
-						vic2.bitmap->width - xend);
-			}
-		}
-		else
-*/		{
-			for (i = ybegin; i <= yend; i++)
-			{
-				memset16 (vic2.bitmap->line[yoff + i], Machine->pens[FRAMECOLOR],
-						  xbegin);
-				memset16 ((short *) vic2.bitmap->line[yoff + i] + xend,
-						  Machine->pens[FRAMECOLOR], vic2.bitmap->width - xend);
-			}
+			memset16 (vic2.bitmap->line[yoff + i], Machine->pens[FRAMECOLOR],
+						xbegin);
+			memset16 ((short *) vic2.bitmap->line[yoff + i] + xend,
+						Machine->pens[FRAMECOLOR], vic2.bitmap->width - xend);
 		}
 	}
 	if (last < vic2.bitmap->height)
 		end = last;
 	else
 		end = vic2.bitmap->height;
-/*	if (Machine->color_depth == 8)
+
+	for (; line < end; line++)
 	{
-		for (; line < end; line++)
-			memset (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					vic2.bitmap->width);
-	}
-	else
-*/	{
-		for (; line < end; line++)
-			memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
-					  vic2.bitmap->width);
+		memset16 (vic2.bitmap->line[line], Machine->pens[FRAMECOLOR],
+			vic2.bitmap->width);
 	}
 }
 
@@ -548,7 +518,7 @@ INLINE void vic3_draw_block(int x, int y, UINT8 colors[8])
     }
 
 #define VIC3_ADDR(a) VIC3_BITPLANE_IADDR(a)
-void vic3_interlace_draw_block(int x, int y, int offset)
+static void vic3_interlace_draw_block(int x, int y, int offset)
 {
 	int colors[8]={0};
 	int i, p;
@@ -617,7 +587,7 @@ void vic3_interlace_draw_block(int x, int y, int offset)
 
 #undef VIC3_ADDR
 #define VIC3_ADDR(a) VIC3_BITPLANE_ADDR(a)
-void vic3_draw_block(int x, int y, int offset)
+static void vic3_draw_block(int x, int y, int offset)
 {
 	int colors[8]={0};
 	int i, p;
@@ -685,14 +655,14 @@ void vic3_draw_block(int x, int y, int offset)
 }
 #endif
 
-void vic3_draw_bitplanes(void)
+static void vic3_draw_bitplanes(void)
 {
 	static int interlace=0;
 	int x, y, y1s, offset;
 #ifndef OPTIMIZE
 	UINT8 colors[8];
 #endif
-	struct rectangle vis;
+	rectangle vis;
 
 	if (VIC3_LINES==400) { /* interlaced! */
 		for ( y1s=0, offset=0; y1s<400; y1s+=16) {
@@ -731,36 +701,37 @@ void vic3_draw_bitplanes(void)
 		}
 	}
 	if (XPOS>0) {
-		vis.min_x=0;
-		vis.max_x=XPOS-1;
-		vis.min_y=0;
-		vis.max_y=Machine->uiheight-1;
+		vis.min_x = 0;
+		vis.max_x = XPOS-1;
+		vis.min_y = 0;
+		vis.max_y = Machine->visible_area.max_y;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
 	if (XPOS+VIC3_BITPLANES_WIDTH<Machine->visible_area.max_x) {
-		vis.min_x=XPOS+VIC3_BITPLANES_WIDTH;
-		vis.max_x=Machine->uiwidth-1;
-		vis.min_y=0;
-		vis.max_y=Machine->uiheight-1;
+		vis.min_x = XPOS+VIC3_BITPLANES_WIDTH;
+		vis.max_x = Machine->visible_area.max_x;
+		vis.min_y = 0;
+		vis.max_y = Machine->visible_area.max_y;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
-	if (YPOS>0) {
-		vis.min_y=0;
-		vis.max_y=YPOS-1;
-		vis.min_x=0;
-		vis.max_x=Machine->uiwidth-1;
+	if (YPOS>0)
+	{
+		vis.min_y = 0;
+		vis.max_y = YPOS-1;
+		vis.min_x = 0;
+		vis.max_x = Machine->visible_area.max_x;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
 	if (YPOS+VIC3_LINES<Machine->visible_area.max_y) {
-		vis.min_y=YPOS+VIC3_LINES;
-		vis.max_y=Machine->uiheight-1;
-		vis.min_x=0;
-		vis.max_x=Machine->uiwidth-1;
+		vis.min_y = YPOS+VIC3_LINES;
+		vis.max_y = Machine->visible_area.max_y;
+		vis.min_x = 0;
+		vis.max_x = Machine->visible_area.max_x;
 		fillbitmap(vic2.bitmap, Machine->pens[FRAMECOLOR],&vis);
 	}
 }
 
-int vic3_raster_irq (void)
+INTERRUPT_GEN( vic3_raster_irq )
 {
 	static int columns=640, raws=200;
 	int new_columns, new_raws;
@@ -800,7 +771,7 @@ int vic3_raster_irq (void)
 		if ((new_columns!=columns)||(new_raws!=raws)) {
 			raws=new_raws;
 			columns=new_columns;
-			osd_set_visible_area(0,columns+16-1,0, raws+16-1);
+			set_visible_area(0,columns+16-1,0, raws+16-1);
 		}
 		if (VIC3_BITPLANES) {
 			if (!osd_skip_this_frame ()) vic3_draw_bitplanes();
@@ -815,7 +786,7 @@ int vic3_raster_irq (void)
 			double tme = 0.0;
 
 			/* lightpen timer starten */
-			vic2.lightpentimer = timer_set (tme, 1, vic2_timer_timeout);
+			timer_set (tme, 1, vic2_timer_timeout);
 		}
 		/*state_display(vic2.bitmap); */
 	}
@@ -825,6 +796,5 @@ int vic3_raster_irq (void)
 			vic2_drawlines (vic2.lastline, vic2.rasterline);
 		vic2_set_interrupt (1);
 	}
-	return ignore_interrupt();
 }
 
