@@ -8,6 +8,8 @@
 #include <stdio.h>
 #include "osd_cpu.h"
 #include "driver.h"
+#include "utils.h"
+#include "sound/custom.h"
 
 #define VERBOSE_DBG 0
 #include "includes/cbm.h"
@@ -37,9 +39,7 @@ unsigned char vic6560_palette[] =
 
 struct CustomSound_interface vic6560_sound_interface =
 {
-	vic6560_custom_start,
-	vic6560_custom_stop,
-	vic6560_custom_update
+	vic6560_custom_start
 };
 
 UINT8 vic6560[16];
@@ -89,7 +89,7 @@ UINT8 vic6560[16];
 
 bool vic6560_pal;
 
-static struct mame_bitmap *vic6560_bitmap;
+static mame_bitmap *vic6560_bitmap;
 static int rasterline = 0, lastline = 0;
 static void vic6560_drawlines (int start, int last);
 
@@ -111,7 +111,7 @@ static UINT16 mono[2], monoinverted[2], multi[4], multiinverted[4];
 /* transparent, white, black */
 static UINT32 pointercolortable[3] =
 {0};
-static struct GfxLayout pointerlayout =
+static gfx_layout pointerlayout =
 {
 	8, 8,
 	1,
@@ -128,7 +128,7 @@ static UINT8 pointermask[] =
 	0xf0, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00	/* whitemask */
 };
 
-static struct GfxElement *pointerelement;
+static gfx_element *pointerelement;
 
 static void vic656x_init (void)
 {
@@ -140,7 +140,7 @@ static void vic656x_init (void)
 
 void vic6560_init (int (*dma_read) (int), int (*dma_read_color) (int))
 {
-	vic6560_pal = false;
+	vic6560_pal = FALSE;
 	vic_dma_read = dma_read;
 	vic_dma_read_color = dma_read_color;
 	vic656x_init ();
@@ -148,30 +148,32 @@ void vic6560_init (int (*dma_read) (int), int (*dma_read_color) (int))
 
 void vic6561_init (int (*dma_read) (int), int (*dma_read_color) (int))
 {
-	vic6560_pal = true;
+	vic6560_pal = TRUE;
 	vic_dma_read = dma_read;
 	vic_dma_read_color = dma_read_color;
 	vic656x_init ();
 }
-int vic6560_vh_start (void)
+
+VIDEO_START( vic6560 )
 {
 	black = Machine->pens[0];
 	white = Machine->pens[1];
-	pointerelement = decodegfx (pointermask, &pointerlayout);
+	pointerelement = allocgfx(&pointerlayout);
+	decodegfx(pointerelement, pointermask, 0, 1);
 	pointerelement->colortable = pointercolortable;
 	pointercolortable[1] = Machine->pens[1];
 	pointercolortable[2] = Machine->pens[0];
 	pointerelement->total_colors = 3;
-	vic6560_bitmap = Machine->scrbitmap;
+	vic6560_bitmap = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
 	return 0;
 }
 
-void vic6560_vh_stop (void)
+VIDEO_STOP( vic6560 )
 {
 	freegfx (pointerelement);
 }
 
-WRITE_HANDLER ( vic6560_port_w )
+WRITE8_HANDLER ( vic6560_port_w )
 {
 	DBG_LOG (1, "vic6560_port_w", (errorlog, "%.4x:%.2x\n", offset, data));
 	switch (offset)
@@ -237,7 +239,7 @@ WRITE_HANDLER ( vic6560_port_w )
 	}
 }
 
-READ_HANDLER ( vic6560_port_r )
+ READ8_HANDLER ( vic6560_port_r )
 {
 	static double lightpenreadtime = 0.0;
 	int val;
@@ -281,7 +283,7 @@ READ_HANDLER ( vic6560_port_r )
 	return val;
 }
 
-static int DOCLIP (struct rectangle *r1, const struct rectangle *r2)
+static int DOCLIP (rectangle *r1, const rectangle *r2)
 {
 	if (r1->min_x > r2->max_x)
 		return 0;
@@ -308,35 +310,17 @@ static void vic6560_draw_character (int ybegin, int yend,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read ((chargenaddr + ch * charheight + y) & 0x3fff);
-			vic6560_bitmap->line[y + yoff][xoff] = color[code >> 7];
-			vic6560_bitmap->line[y + yoff][xoff + 1] = color[(code >> 6) & 1];
-			vic6560_bitmap->line[y + yoff][xoff + 2] = color[(code >> 5) & 1];
-			vic6560_bitmap->line[y + yoff][xoff + 3] = color[(code >> 4) & 1];
-			vic6560_bitmap->line[y + yoff][xoff + 4] = color[(code >> 3) & 1];
-			vic6560_bitmap->line[y + yoff][xoff + 5] = color[(code >> 2) & 1];
-			vic6560_bitmap->line[y + yoff][xoff + 6] = color[(code >> 1) & 1];
-			vic6560_bitmap->line[y + yoff][xoff + 7] = color[code & 1];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read ((chargenaddr + ch * charheight + y) & 0x3fff);
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff) = color[code >> 7];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 1) = color[(code >> 6) & 1];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 2) = color[(code >> 5) & 1];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 3) = color[(code >> 4) & 1];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 4) = color[(code >> 3) & 1];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 5) = color[(code >> 2) & 1];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 6) = color[(code >> 1) & 1];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 7) = color[code & 1];
-		}
+		code = vic_dma_read ((chargenaddr + ch * charheight + y) & 0x3fff);
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff) = color[code >> 7];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 1) = color[(code >> 6) & 1];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 2) = color[(code >> 5) & 1];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 3) = color[(code >> 4) & 1];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 4) = color[(code >> 3) & 1];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 5) = color[(code >> 2) & 1];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 6) = color[(code >> 1) & 1];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 7) = color[code & 1];
 	}
 }
 
@@ -345,42 +329,24 @@ static void vic6560_draw_character_multi (int ybegin, int yend,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read ((chargenaddr + ch * charheight + y) & 0x3fff);
-			vic6560_bitmap->line[y + yoff][xoff + 1] =
-				vic6560_bitmap->line[y + yoff][xoff] = color[code >> 6];
-			vic6560_bitmap->line[y + yoff][xoff + 3] =
-				vic6560_bitmap->line[y + yoff][xoff + 2] = color[(code >> 4) & 3];
-			vic6560_bitmap->line[y + yoff][xoff + 5] =
-				vic6560_bitmap->line[y + yoff][xoff + 4] = color[(code >> 2) & 3];
-			vic6560_bitmap->line[y + yoff][xoff + 7] =
-				vic6560_bitmap->line[y + yoff][xoff + 6] = color[code & 3];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic_dma_read ((chargenaddr + ch * charheight + y) & 0x3fff);
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 1) =
-				*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff) = color[code >> 6];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 3) =
-				*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 2) = color[(code >> 4) & 3];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 5) =
-				*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 4) = color[(code >> 2) & 3];
-			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 7) =
-				*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 6) = color[code & 3];
-		}
+		code = vic_dma_read ((chargenaddr + ch * charheight + y) & 0x3fff);
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 1) =
+			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff) = color[code >> 6];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 3) =
+			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 2) = color[(code >> 4) & 3];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 5) =
+			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 4) = color[(code >> 2) & 3];
+		*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 7) =
+			*((UINT16 *) vic6560_bitmap->line[y + yoff] + xoff + 6) = color[code & 3];
 	}
 }
 
 
 #ifndef GFX
-INLINE void vic6560_draw_pointer (struct mame_bitmap *bitmap,
-								  struct rectangle *visible, int xoff, int yoff)
+INLINE void vic6560_draw_pointer (mame_bitmap *bitmap,
+								  rectangle *visible, int xoff, int yoff)
 {
 	/* this is a a static graphical object */
 	/* should be easy to convert to gfx_element!? */
@@ -390,30 +356,14 @@ INLINE void vic6560_draw_pointer (struct mame_bitmap *bitmap,
 	{0xf0, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00};
 	int i, j, y, x;
 
-/*	if (Machine->color_depth == 8)
+	for (y = visible->min_y, j = yoff; y <= visible->max_y; y++, j++)
 	{
-		for (y = visible->min_y, j = yoff; y <= visible->max_y; y++, j++)
+		for (x = visible->min_x, i = xoff; x <= visible->max_x; x++, i++)
 		{
-			for (x = visible->min_x, i = xoff; x <= visible->max_x; x++, i++)
-			{
-				if ((blackmask[j] << i) & 0x80)
-					bitmap->line[y][x] = black;
-				else if ((whitemask[j] << (i & ~1)) & 0x80)
-					bitmap->line[y][x] = white;
-			}
-		}
-	}
-	else
-*/	{
-		for (y = visible->min_y, j = yoff; y <= visible->max_y; y++, j++)
-		{
-			for (x = visible->min_x, i = xoff; x <= visible->max_x; x++, i++)
-			{
-				if ((blackmask[j] << i) & 0x80)
-					*((UINT16 *) bitmap->line[y] + x) = black;
-				else if ((whitemask[j] << (i & ~1)) & 0x80)
-					*((UINT16 *) bitmap->line[y] + x) = white;
-			}
+			if ((blackmask[j] << i) & 0x80)
+				*((UINT16 *) bitmap->line[y] + x) = black;
+			else if ((whitemask[j] << (i & ~1)) & 0x80)
+				*((UINT16 *) bitmap->line[y] + x) = white;
 		}
 	}
 }
@@ -429,20 +379,11 @@ static void vic6560_drawlines (int first, int last)
 	if (first >= last)
 		return;
 
-/*	if (Machine->color_depth == 8)
+	for (line = first; (line < ypos) && (line < last); line++)
 	{
-		for (line = first; (line < ypos) && (line < last); line++)
-		{
-			memset (vic6560_bitmap->line[line], framecolor, vic656x_xsize);
-		}
-	}
-	else
-*/	{
-		for (line = first; (line < ypos) && (line < last); line++)
-		{
-			memset16 (vic6560_bitmap->line[line], framecolor, vic656x_xsize);
-		}
+		memset16 (vic6560_bitmap->line[line], framecolor, vic656x_xsize);
 	}
+
 	for (vline = line - ypos; (line < last) && (line < ypos + ysize);)
 	{
 		if (matrix8x16)
@@ -462,16 +403,8 @@ static void vic6560_drawlines (int first, int last)
 
 		if (xpos > 0)
 		{
-/*			if (Machine->color_depth == 8)
-			{
-				for (i = ybegin; i <= yend; i++)
-					memset (vic6560_bitmap->line[yoff + i], framecolor, xpos);
-			}
-			else
-*/			{
-				for (i = ybegin; i <= yend; i++)
-					memset16 (vic6560_bitmap->line[yoff + i], framecolor, xpos);
-			}
+			for (i = ybegin; i <= yend; i++)
+				memset16 (vic6560_bitmap->line[yoff + i], framecolor, xpos);
 		}
 		for (xoff = xpos; (xoff < xpos + xsize) && (xoff < vic656x_xsize); xoff += 8, offs++)
 		{
@@ -507,17 +440,10 @@ static void vic6560_drawlines (int first, int last)
 		}
 		if (xoff < vic656x_xsize)
 		{
-/*			if (Machine->color_depth == 8)
+			for (i = ybegin; i <= yend; i++)
 			{
-				for (i = ybegin; i <= yend; i++)
-					memset (vic6560_bitmap->line[yoff + i] + xoff, framecolor,
-							vic656x_xsize - xoff);
-			}
-			else
-*/			{
-				for (i = ybegin; i <= yend; i++)
-					memset16 ((UINT16 *) vic6560_bitmap->line[yoff + i] + xoff,
-							  framecolor, vic656x_xsize - xoff);
+				memset16 ((UINT16 *) vic6560_bitmap->line[yoff + i] + xoff,
+					framecolor, vic656x_xsize - xoff);
 			}
 		}
 		if (matrix8x16)
@@ -531,53 +457,16 @@ static void vic6560_drawlines (int first, int last)
 			line = vline + ypos;
 		}
 	}
-/*	if (Machine->color_depth == 8)
+
+	for (; line < last; line++)
 	{
-		for (; line < last; line++)
-		{
-			memset (vic6560_bitmap->line[line], framecolor, vic656x_xsize);
-		}
-	}
-	else
-*/	{
-		for (; line < last; line++)
-		{
-			memset16 (vic6560_bitmap->line[line], framecolor, vic656x_xsize);
-		}
+		memset16 (vic6560_bitmap->line[line], framecolor, vic656x_xsize);
 	}
 }
 
-static void vic6560_draw_text (struct mame_bitmap *bitmap, char *text, int *y)
+INTERRUPT_GEN( vic656x_raster_interrupt )
 {
-	int x, x0, y1v, width = (Machine->visible_area.max_x -
-							 Machine->visible_area.min_x) / Machine->uifont->width;
-
-	if (text[0] != 0)
-	{
-		x = strlen (text);
-		*y -= Machine->uifont->height * ((x + width - 1) / width);
-		y1v = *y + Machine->uifont->height;
-		x = 0;
-		while (text[x])
-		{
-			for (x0 = Machine->visible_area.min_x;
-				 text[x] && (x0 < Machine->visible_area.max_x -
-							 Machine->uifont->width);
-				 x++, x0 += Machine->uifont->width)
-			{
-				drawgfx (bitmap, Machine->uifont, text[x], 0, 0, 0, x0, y1v, 0,
-						 TRANSPARENCY_NONE, 0);
-			}
-			y1v += Machine->uifont->height;
-		}
-	}
-}
-
-int vic656x_raster_interrupt (void)
-{
-	struct rectangle r;
-	int y;
-	char text[50];
+	rectangle r;
 
 	rasterline++;
 	if (rasterline >= vic656x_lines)
@@ -596,7 +485,6 @@ int vic656x_raster_interrupt (void)
 
 			if (DOCLIP (&r, &Machine->visible_area))
 			{
-				osd_mark_dirty (r.min_x, r.min_y, r.max_x, r.max_y);
 #ifndef GFX
 				vic6560_draw_pointer (vic6560_bitmap, &r,
 									  r.min_x - (LIGHTPEN_X_VALUE + VIC656X_MAME_XPOS - 1),
@@ -607,23 +495,10 @@ int vic656x_raster_interrupt (void)
 #endif
 			}
 		}
-		y = Machine->visible_area.max_y + 1 - Machine->uifont->height;
-
-		vc20_tape_status (text, sizeof (text));
-		vic6560_draw_text (vic6560_bitmap, text, &y);
-#ifdef VC1541
-		vc1541_drive_status (text, sizeof (text));
-#else
-		cbm_drive_0_status (text, sizeof (text));
-#endif
-		vic6560_draw_text (vic6560_bitmap, text, &y);
-
-		cbm_drive_1_status (text, sizeof (text));
-		vic6560_draw_text (vic6560_bitmap, text, &y);
 	}
-	return ignore_interrupt ();
 }
 
-void vic6560_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( vic6560 )
 {
+	copybitmap(bitmap, vic6560_bitmap, 0, 0, 0, 0, cliprect, TRANSPARENCY_NONE, 0);
 }
