@@ -60,7 +60,8 @@
 #include "osd_cpu.h"
 #include "driver.h"
 #include "vidhrdw/generic.h"
-#include "includes/state.h"
+#include "mscommon.h"
+#include "utils.h"
 
 
 #define VERBOSE_DBG 1
@@ -181,11 +182,10 @@ static struct {
 	void (*port_changed)(int);
 
 	int lines;
-	void *lightpentimer;
 
 	int chargenaddr, videoaddr;
 
-	struct mame_bitmap *bitmap;		   /* Machine->scrbitmap for speedup */
+	mame_bitmap *bitmap;
 	int x_begin, x_end;
 	int y_begin, y_end;
 
@@ -253,7 +253,7 @@ void vic6567_init (int chip_vic2e, int pal,
 	vic2.interrupt = irq;
 	vic2.vic2e = chip_vic2e;
 	vic2.pal = pal;
-	vic2.on = true;
+	vic2.on = TRUE;
 }
 
 void vic2_set_rastering(int onoff)
@@ -330,12 +330,11 @@ static void vic2_timer_timeout (int which)
 	}
 }
 
-int vic2_frame_interrupt (void)
+INTERRUPT_GEN( vic2_frame_interrupt )
 {
-	return ignore_interrupt ();
 }
 
-WRITE_HANDLER ( vic2_port_w )
+WRITE8_HANDLER ( vic2_port_w )
 {
 	DBG_LOG (2, "vic write", ("%.2x:%.2x\n", offset, data));
 	offset &= 0x3f;
@@ -562,7 +561,7 @@ WRITE_HANDLER ( vic2_port_w )
 	}
 }
 
-READ_HANDLER ( vic2_port_r )
+READ8_HANDLER ( vic2_port_r )
 {
 	int val = 0;
 	offset &= 0x3f;
@@ -650,21 +649,21 @@ READ_HANDLER ( vic2_port_r )
 	return val;
 }
 
-int vic2_vh_start (void)
+VIDEO_START( vic2 )
 {
 	int i;
 
-	vic2.bitmap = Machine->scrbitmap;
+	vic2.bitmap = auto_bitmap_alloc(Machine->drv->screen_width, Machine->drv->screen_height);
 
 	if (vic2.vic3) {
-		vic2.screen[0] = (UINT8*)malloc (sizeof (UINT8) * 216 * 656 / 8);
+		vic2.screen[0] = (UINT8*)auto_malloc (sizeof (UINT8) * 216 * 656 / 8);
 
 		if (!vic2.screen[0])
 			return 1;
 		for (i = 1; i < 216; i++)
 			vic2.screen[i] = vic2.screen[i - 1] + 656 / 8;
 	} else {
-		vic2.screen[0] = (UINT8*)malloc (sizeof (UINT8) * 216 * 336 / 8);
+		vic2.screen[0] = (UINT8*)auto_malloc (sizeof (UINT8) * 216 * 336 / 8);
 
 		if (!vic2.screen[0])
 			return 1;
@@ -739,47 +738,23 @@ int vic2_vh_start (void)
 	return 0;
 }
 
-void vic2_vh_stop (void)
-{
-	free (vic2.screen[0]);
-}
-
 static void vic2_draw_character (int ybegin, int yend, int ch,
 								 int yoff, int xoff, UINT16 *color)
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read (vic2.chargenaddr + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = code;
-			vic2.bitmap->line[y + yoff][xoff] = color[code >> 7];
-			vic2.bitmap->line[y + yoff][1 + xoff] = color[(code >> 6) & 1];
-			vic2.bitmap->line[y + yoff][2 + xoff] = color[(code >> 5) & 1];
-			vic2.bitmap->line[y + yoff][3 + xoff] = color[(code >> 4) & 1];
-			vic2.bitmap->line[y + yoff][4 + xoff] = color[(code >> 3) & 1];
-			vic2.bitmap->line[y + yoff][5 + xoff] = color[(code >> 2) & 1];
-			vic2.bitmap->line[y + yoff][6 + xoff] = color[(code >> 1) & 1];
-			vic2.bitmap->line[y + yoff][7 + xoff] = color[code & 1];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read (vic2.chargenaddr + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = code;
-			*((short *) vic2.bitmap->line[y + yoff] + xoff) = color[code >> 7];
-			*((short *) vic2.bitmap->line[y + yoff] + 1 + xoff) = color[(code >> 6) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 2 + xoff) = color[(code >> 5) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 3 + xoff) = color[(code >> 4) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 4 + xoff) = color[(code >> 3) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 5 + xoff) = color[(code >> 2) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 6 + xoff) = color[(code >> 1) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 7 + xoff) = color[code & 1];
-		}
+		code = vic2.dma_read (vic2.chargenaddr + ch * 8 + y);
+		vic2.screen[y + yoff][xoff >> 3] = code;
+		*((short *) vic2.bitmap->line[y + yoff] + xoff) = color[code >> 7];
+		*((short *) vic2.bitmap->line[y + yoff] + 1 + xoff) = color[(code >> 6) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 2 + xoff) = color[(code >> 5) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 3 + xoff) = color[(code >> 4) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 4 + xoff) = color[(code >> 3) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 5 + xoff) = color[(code >> 2) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 6 + xoff) = color[(code >> 1) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 7 + xoff) = color[code & 1];
 	}
 }
 
@@ -788,37 +763,18 @@ static void vic2_draw_character_multi (int ybegin, int yend, int ch,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read (vic2.chargenaddr + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = vic2.foreground[code];
-			vic2.bitmap->line[y + yoff][xoff] =
-				vic2.bitmap->line[y + yoff][xoff + 1] = vic2.multi[code >> 6];
-			vic2.bitmap->line[y + yoff][xoff + 2] =
-				vic2.bitmap->line[y + yoff][xoff + 3] = vic2.multi[(code >> 4) & 3];
-			vic2.bitmap->line[y + yoff][xoff + 4] =
-				vic2.bitmap->line[y + yoff][xoff + 5] = vic2.multi[(code >> 2) & 3];
-			vic2.bitmap->line[y + yoff][xoff + 6] =
-				vic2.bitmap->line[y + yoff][xoff + 7] = vic2.multi[code & 3];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read (vic2.chargenaddr + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = vic2.foreground[code];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 1) = vic2.multi[code >> 6];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff + 2) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 3) = vic2.multi[(code >> 4) & 3];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff + 4) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 5) = vic2.multi[(code >> 2) & 3];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff + 6) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 7) = vic2.multi[code & 3];
-		}
+		code = vic2.dma_read (vic2.chargenaddr + ch * 8 + y);
+		vic2.screen[y + yoff][xoff >> 3] = vic2.foreground[code];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 1) = vic2.multi[code >> 6];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff + 2) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 3) = vic2.multi[(code >> 4) & 3];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff + 4) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 5) = vic2.multi[(code >> 2) & 3];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff + 6) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 7) = vic2.multi[code & 3];
 	}
 }
 
@@ -827,37 +783,18 @@ static void vic2_draw_bitmap (int ybegin, int yend,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read ((vic2.chargenaddr&0x2000) + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = code;
-			vic2.bitmap->line[y + yoff][xoff] = vic2.c64_bitmap[code >> 7];
-			vic2.bitmap->line[y + yoff][1 + xoff] = vic2.c64_bitmap[(code >> 6) & 1];
-			vic2.bitmap->line[y + yoff][2 + xoff] = vic2.c64_bitmap[(code >> 5) & 1];
-			vic2.bitmap->line[y + yoff][3 + xoff] = vic2.c64_bitmap[(code >> 4) & 1];
-			vic2.bitmap->line[y + yoff][4 + xoff] = vic2.c64_bitmap[(code >> 3) & 1];
-			vic2.bitmap->line[y + yoff][5 + xoff] = vic2.c64_bitmap[(code >> 2) & 1];
-			vic2.bitmap->line[y + yoff][6 + xoff] = vic2.c64_bitmap[(code >> 1) & 1];
-			vic2.bitmap->line[y + yoff][7 + xoff] = vic2.c64_bitmap[code & 1];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read ((vic2.chargenaddr&0x2000) + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = code;
-			*((short *) vic2.bitmap->line[y + yoff] + xoff) = vic2.c64_bitmap[code >> 7];
-			*((short *) vic2.bitmap->line[y + yoff] + 1 + xoff) = vic2.c64_bitmap[(code >> 6) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 2 + xoff) = vic2.c64_bitmap[(code >> 5) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 3 + xoff) = vic2.c64_bitmap[(code >> 4) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 4 + xoff) = vic2.c64_bitmap[(code >> 3) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 5 + xoff) = vic2.c64_bitmap[(code >> 2) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 6 + xoff) = vic2.c64_bitmap[(code >> 1) & 1];
-			*((short *) vic2.bitmap->line[y + yoff] + 7 + xoff) = vic2.c64_bitmap[code & 1];
-		}
+		code = vic2.dma_read ((vic2.chargenaddr&0x2000) + ch * 8 + y);
+		vic2.screen[y + yoff][xoff >> 3] = code;
+		*((short *) vic2.bitmap->line[y + yoff] + xoff) = vic2.c64_bitmap[code >> 7];
+		*((short *) vic2.bitmap->line[y + yoff] + 1 + xoff) = vic2.c64_bitmap[(code >> 6) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 2 + xoff) = vic2.c64_bitmap[(code >> 5) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 3 + xoff) = vic2.c64_bitmap[(code >> 4) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 4 + xoff) = vic2.c64_bitmap[(code >> 3) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 5 + xoff) = vic2.c64_bitmap[(code >> 2) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 6 + xoff) = vic2.c64_bitmap[(code >> 1) & 1];
+		*((short *) vic2.bitmap->line[y + yoff] + 7 + xoff) = vic2.c64_bitmap[code & 1];
 	}
 }
 
@@ -866,37 +803,18 @@ static void vic2_draw_bitmap_multi (int ybegin, int yend,
 {
 	int y, code;
 
-/*	if (Machine->color_depth == 8)
+	for (y = ybegin; y <= yend; y++)
 	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read ((vic2.chargenaddr&0x2000)+ ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = vic2.foreground[code];
-			vic2.bitmap->line[y + yoff][xoff] =
-				vic2.bitmap->line[y + yoff][xoff + 1] = vic2.bitmapmulti[code >> 6];
-			vic2.bitmap->line[y + yoff][xoff + 2] =
-				vic2.bitmap->line[y + yoff][xoff + 3] = vic2.bitmapmulti[(code >> 4) & 3];
-			vic2.bitmap->line[y + yoff][xoff + 4] =
-				vic2.bitmap->line[y + yoff][xoff + 5] = vic2.bitmapmulti[(code >> 2) & 3];
-			vic2.bitmap->line[y + yoff][xoff + 6] =
-				vic2.bitmap->line[y + yoff][xoff + 7] = vic2.bitmapmulti[code & 3];
-		}
-	}
-	else
-*/	{
-		for (y = ybegin; y <= yend; y++)
-		{
-			code = vic2.dma_read ((vic2.chargenaddr&0x2000) + ch * 8 + y);
-			vic2.screen[y + yoff][xoff >> 3] = vic2.foreground[code];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 1) = vic2.bitmapmulti[code >> 6];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff + 2) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 3) = vic2.bitmapmulti[(code >> 4) & 3];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff + 4) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 5) = vic2.bitmapmulti[(code >> 2) & 3];
-			*((short *) vic2.bitmap->line[y + yoff] + xoff + 6) =
-				*((short *) vic2.bitmap->line[y + yoff] + xoff + 7) = vic2.bitmapmulti[code & 3];
-		}
+		code = vic2.dma_read ((vic2.chargenaddr&0x2000) + ch * 8 + y);
+		vic2.screen[y + yoff][xoff >> 3] = vic2.foreground[code];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 1) = vic2.bitmapmulti[code >> 6];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff + 2) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 3) = vic2.bitmapmulti[(code >> 4) & 3];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff + 4) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 5) = vic2.bitmapmulti[(code >> 2) & 3];
+		*((short *) vic2.bitmap->line[y + yoff] + xoff + 6) =
+			*((short *) vic2.bitmap->line[y + yoff] + xoff + 7) = vic2.bitmapmulti[code & 3];
 	}
 }
 
@@ -907,53 +825,26 @@ static void vic2_draw_sprite_code_multi (int y, int xbegin,
 
 	if ((y < YPOS) || (y >= 208) || (xbegin <= 1) || (xbegin >= 328))
 		return;
-/*	if (Machine->color_depth == 8)
+
+	for (x = 0, mask = 0xc0, shift = 6; x < 8; x += 2, mask >>= 2, shift -= 2)
 	{
-		for (x = 0, mask = 0xc0, shift = 6; x < 8; x += 2, mask >>= 2, shift -= 2)
+		if (code & mask)
 		{
-			if (code & mask)
+			switch ((prior & mask) >> shift)
 			{
-				switch ((prior & mask) >> shift)
-				{
-				case 1:
-					vic2.bitmap->line[y][xbegin + x + 1] =
-						vic2.spritemulti[(code >> shift) & 3];
-					break;
-				case 2:
-					vic2.bitmap->line[y][xbegin + x] =
-						vic2.spritemulti[(code >> shift) & 3];
-					break;
-				case 3:
-					vic2.bitmap->line[y][xbegin + x] =
-						vic2.bitmap->line[y][xbegin + x + 1] =
-						vic2.spritemulti[(code >> shift) & 3];
-					break;
-				}
-			}
-		}
-	}
-	else
-*/	{
-		for (x = 0, mask = 0xc0, shift = 6; x < 8; x += 2, mask >>= 2, shift -= 2)
-		{
-			if (code & mask)
-			{
-				switch ((prior & mask) >> shift)
-				{
-				case 1:
+			case 1:
+				((short *) vic2.bitmap->line[y])[xbegin + x + 1] =
+					vic2.spritemulti[(code >> shift) & 3];
+				break;
+			case 2:
+				((short *) vic2.bitmap->line[y])[xbegin + x] =
+					vic2.spritemulti[(code >> shift) & 3];
+				break;
+			case 3:
+				((short *) vic2.bitmap->line[y])[xbegin + x] =
 					((short *) vic2.bitmap->line[y])[xbegin + x + 1] =
-						vic2.spritemulti[(code >> shift) & 3];
-					break;
-				case 2:
-					((short *) vic2.bitmap->line[y])[xbegin + x] =
-						vic2.spritemulti[(code >> shift) & 3];
-					break;
-				case 3:
-					((short *) vic2.bitmap->line[y])[xbegin + x] =
-						((short *) vic2.bitmap->line[y])[xbegin + x + 1] =
-						vic2.spritemulti[(code >> shift) & 3];
-					break;
-				}
+					vic2.spritemulti[(code >> shift) & 3];
+				break;
 			}
 		}
 	}
@@ -965,24 +856,12 @@ static void vic2_draw_sprite_code (int y, int xbegin, int code, int color)
 
 	if ((y < YPOS) || (y >= 208) || (xbegin <= 1) || (xbegin >= 328))
 		return;
-/*	if (Machine->color_depth == 8)
+
+	for (x = 0, mask = 0x80; x < 8; x++, mask >>= 1)
 	{
-		for (x = 0, mask = 0x80; x < 8; x++, mask >>= 1)
+		if (code & mask)
 		{
-			if (code & mask)
-			{
-				vic2.bitmap->line[y][xbegin + x] = color;
-			}
-		}
-	}
-	else
-*/	{
-		for (x = 0, mask = 0x80; x < 8; x++, mask >>= 1)
-		{
-			if (code & mask)
-			{
-				((short *) vic2.bitmap->line[y])[xbegin + x] = color;
-			}
+			((short *) vic2.bitmap->line[y])[xbegin + x] = color;
 		}
 	}
 }
@@ -1265,16 +1144,8 @@ static void vic2_drawlines (int first, int last)
 
 	if (!SCREENON)
 	{
-/*		if (Machine->color_depth == 8)
-		{
-			for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
-				memset (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
-		}
-		else
-*/		{
-			for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
-				memset16 (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
-		}
+		for (line = first; (line < last) && (line < vic2.bitmap->height); line++)
+			memset16 (vic2.bitmap->line[line], Machine->pens[0], vic2.bitmap->width);
 		return;
 	}
 
@@ -1440,7 +1311,7 @@ static void vic2_drawlines (int first, int last)
 
 #include "vic4567.c"
 
-int vic2_raster_irq (void)
+INTERRUPT_GEN( vic2_raster_irq )
 {
 	int i;
 
@@ -1458,9 +1329,8 @@ int vic2_raster_irq (void)
 			double tme = 0.0;
 
 			/* lightpen timer starten */
-			vic2.lightpentimer = timer_set (tme, 1, vic2_timer_timeout);
+			timer_set (tme, 1, vic2_timer_timeout);
 		}
-		/*state_display(vic2.bitmap); */
 	}
 	if (vic2.rasterline == C64_2_RASTERLINE (RASTERLINE))
 	{
@@ -1468,25 +1338,26 @@ int vic2_raster_irq (void)
 			vic2_drawlines (vic2.lastline, vic2.rasterline);
 		vic2_set_interrupt (1);
 	}
-	return ignore_interrupt();
 }
 
-void vic2_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( vic2 )
 {
-#if 0
-    char text[40];
-    int i, y;
-    for (y=0, i=0; i<8; i++) {
-	if (SPRITEON(i)) {
-	    sprintf(text,"%d x:%d y:%d",i,
-		    SPRITE_X_POS(i), SPRITE_Y_POS(i) );
-
-	    ui_text(bitmap,text,0,y);
-	    y+=8;
-	}
-    }
-#endif
-	state_display(bitmap);
+	if (vic2.on)
+		copybitmap(bitmap, vic2.bitmap, 0, 0, 0, 0, cliprect, TRANSPARENCY_NONE, 0);
 }
 
+static PALETTE_INIT( vic2 )
+{
+	palette_set_colors(0, vic2_palette, sizeof(vic2_palette) / 3);
+}
+
+MACHINE_DRIVER_START( vh_vic2 )
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(336, 216)
+	MDRV_VISIBLE_AREA(0, 336 - 1, 0, 216 - 1)
+	MDRV_PALETTE_INIT( vic2 )
+	MDRV_PALETTE_LENGTH(sizeof (vic2_palette) / sizeof (vic2_palette[0]) / 3)
+	MDRV_VIDEO_START( vic2 )
+	MDRV_VIDEO_UPDATE( vic2 )
+MACHINE_DRIVER_END
 
