@@ -48,22 +48,15 @@ int laser_frame_time = 0;
 static int laser_bg_mode = 0;
 static int laser_two_color = 0;
 
-int laser_vh_start(void)
+VIDEO_START( laser )
 {
 	videoram_size = 0x04000;
-	dirtybuffer = (UINT8*)malloc(videoram_size);
+	dirtybuffer = (UINT8*) auto_malloc(videoram_size);
 	if (!dirtybuffer)
 		return 1;
 	return 0;
 }
 
-void laser_vh_stop(void)
-{
-	if (dirtybuffer)
-		free(dirtybuffer);
-	dirtybuffer = NULL;
-}
-
 static int offs_2[192] = {
 	0x0000,0x0800,0x1000,0x1800,0x2000,0x2800,0x3000,0x3800,
 	0x0100,0x0900,0x1100,0x1900,0x2100,0x2900,0x3100,0x3900,
@@ -133,13 +126,14 @@ static int offs_0[96] = {
 	0x26a0,0x2ea0,0x36a0,0x3ea0,0x27a0,0x2fa0,0x37a0,0x3fa0
 };
 
-void laser_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( laser )
 {
 	int offs, x, y;
+	int full_refresh = 1;
 
     if( full_refresh )
 	{
-		fillbitmap(Machine->scrbitmap, Machine->pens[(laser_bg_mode >> 4) & 15], &Machine->visible_area);
+		fillbitmap(bitmap, Machine->pens[(laser_bg_mode >> 4) & 15], &Machine->visible_area);
 		memset(dirtybuffer, 1, videoram_size);
     }
 
@@ -347,14 +341,11 @@ void laser_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 
 	if( laser_frame_time > 0 )
 	{
-		ui_text(bitmap, laser_frame_message, 2, Machine->visible_area.max_y - 9);
-		/* if the message timed out, clear it on the next frame */
-		if( --laser_frame_time == 0 )
-			schedule_full_refresh();
+		ui_popup("%s", laser_frame_message);
 	}
 }
 
-WRITE_HANDLER( laser_bg_mode_w )
+WRITE8_HANDLER( laser_bg_mode_w )
 {
     if (laser_bg_mode != data)
     {
@@ -364,7 +355,7 @@ WRITE_HANDLER( laser_bg_mode_w )
     }
 }
 
-WRITE_HANDLER( laser_two_color_w )
+WRITE8_HANDLER( laser_two_color_w )
 {
 	if (laser_two_color != data)
 	{
