@@ -2,6 +2,9 @@
 
     CHD compression frontend
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #include "osd_cpu.h"
@@ -241,6 +244,24 @@ static void error(void)
 
 
 
+/*-------------------------------------------------
+    osd_die - error hook for assertions
+-------------------------------------------------*/
+
+void CLIB_DECL osd_die(const char *text,...)
+{
+	va_list arg;
+
+	/* standard vfprintf stuff here */
+	va_start(arg, text);
+	vfprintf(stderr, text, arg);
+	va_end(arg);
+
+	exit(-1);
+}
+
+
+
 /*-------------------------------------------------
     special_chd_init - set up a CHD file as a
     "fake" raw file for input
@@ -1957,10 +1978,10 @@ static chd_interface_file *chdman_open(const char *filename, const char *mode)
 			if (buf)
 			{
 				/*
-				 * Calling setbuf makes -createhd and -merge run 5 - 10x faster 
-				 * on * Linux with the GNU C Library, and it shouldn't hurt 
-				 * performance on other platforms (verified on Mac OS X).
-				 */
+                 * Calling setbuf makes -createhd and -merge run 5 - 10x faster
+                 * on * Linux with the GNU C Library, and it shouldn't hurt
+                 * performance on other platforms (verified on Mac OS X).
+                 */
 				setbuf(file, buf);
 			}
 
