@@ -15,6 +15,7 @@ enum {
 	PARAM_RM,			/* 16 or 32-bit memory or register */
 	PARAM_RM8,			/* 8-bit memory or register */
 	PARAM_RM16,			/* 16-bit memory or register */
+	PARAM_M64,			/* 64-bit memory */
 	PARAM_I8,			/* 8-bit signed immediate */
 	PARAM_I16,			/* 16-bit signed immediate */
 	PARAM_UI8,			/* 8-bit unsigned immediate */
@@ -91,7 +92,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"add",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"add",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"add",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"add",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"add",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"add",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"push    es",		0,				0,					0,					0				},
 	{"pop     es",		0,				0,					0,					0				},
@@ -99,7 +100,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"or",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"or",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"or",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"or",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"or",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"or",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"push    cs",		0,				0,					0,					0				},
 	{"two_byte",		TWO_BYTE,		0,					0,					0				},
@@ -108,7 +109,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"adc",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"adc",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"adc",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"adc",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"adc",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"adc",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"push    ss",		0,				0,					0,					0				},
 	{"pop     ss",		0,				0,					0,					0				},
@@ -116,7 +117,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"sbb",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"sbb",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"sbb",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"sbb",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"sbb",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"sbb",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"push    ds",		0,				0,					0,					0				},
 	{"pop     ds",		0,				0,					0,					0				},
@@ -125,7 +126,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"and",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"and",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"and",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"and",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"and",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"and",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"seg_es",			SEG_ES,			0,					0,					0				},
 	{"daa",				0,				0,					0,					0				},
@@ -142,7 +143,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"xor",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"xor",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"xor",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"xor",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"xor",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"xor",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"seg_ss",			SEG_SS,			0,					0,					0				},
 	{"aaa",				0,				0,					0,					0				},
@@ -150,7 +151,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"cmp",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"cmp",				MODRM,			PARAM_REG8,			PARAM_RM8,			0				},
 	{"cmp",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"cmp",				0,				PARAM_AL,			PARAM_I8,			0				},
+	{"cmp",				0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"cmp",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"seg_ds",			SEG_DS,			0,					0,					0				},
 	{"aas",				0,				0,					0,					0				},
@@ -265,7 +266,7 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"movsw\0movsd",	VAR_NAME,		0,					0,					0				},
 	{"cmpsb",			0,				0,					0,					0				},
 	{"cmpsw\0cmpsd",	VAR_NAME,		0,					0,					0				},
-	{"test",			0,				PARAM_AL,			PARAM_I8,			0				},
+	{"test",			0,				PARAM_AL,			PARAM_UI8,			0				},
 	{"test",			0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"stosb",			0,				0,					0,					0				},
 	{"stosw\0stosd",	VAR_NAME,		0,					0,					0				},
@@ -274,14 +275,14 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"scasb",			0,				0,					0,					0				},
 	{"scasw\0scasd",	VAR_NAME,		0,					0,					0				},
 	/* 0xb0 */
-	{"mov",				0,				PARAM_AL,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_CL,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_DL,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_BL,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_AH,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_CH,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_DH,			PARAM_I8,			0				},
-	{"mov",				0,				PARAM_BH,			PARAM_I8,			0				},
+	{"mov",				0,				PARAM_AL,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_CL,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_DL,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_BL,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_AH,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_CH,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_DH,			PARAM_UI8,			0				},
+	{"mov",				0,				PARAM_BH,			PARAM_UI8,			0				},
 	{"mov",				0,				PARAM_EAX,			PARAM_IMM,			0				},
 	{"mov",				0,				PARAM_ECX,			PARAM_IMM,			0				},
 	{"mov",				0,				PARAM_EDX,			PARAM_IMM,			0				},
@@ -297,9 +298,9 @@ static const I386_OPCODE i386_opcode_table1[256] =
 	{"ret",				0,				0,					0,					0,				DASMFLAG_STEP_OUT},
 	{"les",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
 	{"lds",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
-	{"mov",				MODRM,			PARAM_RM8,			PARAM_I8,			0				},
+	{"mov",				MODRM,			PARAM_RM8,			PARAM_UI8,			0				},
 	{"mov",				MODRM,			PARAM_RM,			PARAM_IMM,			0				},
-	{"enter",			0,				PARAM_I16,			PARAM_I8,			0				},
+	{"enter",			0,				PARAM_I16,			PARAM_UI8,			0				},
 	{"leave",			0,				0,					0,					0				},
 	{"retf",			0,				PARAM_I16,			0,					0,				DASMFLAG_STEP_OUT},
 	{"retf",			0,				0,					0,					0,				DASMFLAG_STEP_OUT},
@@ -550,8 +551,8 @@ static const I386_OPCODE i386_opcode_table2[256] =
 	{"???",				0,				0,					0,					0				},
 	{"imul",			MODRM,			PARAM_REG,			PARAM_RM,			0				},
 	/* 0xb0 */
-	{"???",				0,				0,					0,					0				},
-	{"???",				0,				0,					0,					0				},
+	{"cmpxchg",			MODRM,			PARAM_RM8,			PARAM_REG,			0				},
+	{"cmpxchg",			MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"lss",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
 	{"btr",				MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"lfs",				MODRM,			PARAM_REG,			PARAM_RM,			0				},
@@ -567,14 +568,14 @@ static const I386_OPCODE i386_opcode_table2[256] =
 	{"movsx",			MODRM,			PARAM_REG,			PARAM_RM8,			0				},
 	{"movsx",			MODRM,			PARAM_REG,			PARAM_RM16,			0				},
 	/* 0xc0 */
+	{"xadd",			MODRM,			PARAM_RM8,			PARAM_REG,			0				},
+	{"xadd",			MODRM,			PARAM_RM,			PARAM_REG,			0				},
 	{"???",				0,				0,					0,					0				},
 	{"???",				0,				0,					0,					0				},
 	{"???",				0,				0,					0,					0				},
 	{"???",				0,				0,					0,					0				},
 	{"???",				0,				0,					0,					0				},
-	{"???",				0,				0,					0,					0				},
-	{"???",				0,				0,					0,					0				},
-	{"???",				0,				0,					0,					0				},
+	{"cmpxchg8b",		MODRM,			PARAM_M64,			0,					0				},
 	{"???",				0,				0,					0,					0				},
 	{"???",				0,				0,					0,					0				},
 	{"???",				0,				0,					0,					0				},
@@ -1089,7 +1090,7 @@ static const I386_OPCODE group0F01_table[8] =
 	{"smsw",			0,				PARAM_RM,			0,					0				},
 	{"???",				0,				0,					0,					0				},
 	{"lmsw",			0,				PARAM_RM,			0,					0				},
-	{"???",				0,				0,					0,					0				}
+	{"invlpg",			0,				PARAM_RM,			0,					0				}
 };
 
 static const I386_OPCODE group0FBA_table[8] =
@@ -1417,6 +1418,15 @@ static char* handle_param(char* s, UINT32 param)
 			}
 			break;
 
+		case PARAM_M64:
+			if( modrm >= 0xc0 ) {
+				s += sprintf( s, "???" );
+			} else {
+				s += sprintf( s, "qword ptr " );
+				s += sprintf( s, "%s", modrm_string );
+			}
+			break;
+
 		case PARAM_I8:
 			i8 = FETCHD();
 			s += sprintf( s, "%s", shexstring((INT8)i8, 0, FALSE) );
