@@ -1,24 +1,24 @@
 /*****************************************************************************
  *
- *	 m65ce02.c
- *	 Portable 65ce02 emulator V1.0beta3
+ *   m65ce02.c
+ *   Portable 65ce02 emulator V1.0beta3
  *
- *	 Copyright (c) 2000 Peter Trauner, all rights reserved
+ *   Copyright (c) 2000 Peter Trauner, all rights reserved
  *   documentation preliminary databook
- *	 documentation by michael steil mist@c64.org
- *	 available at ftp://ftp.funet.fi/pub/cbm/c65
+ *   documentation by michael steil mist@c64.org
+ *   available at ftp://ftp.funet.fi/pub/cbm/c65
  *
- *	 - This source code is released as freeware for non-commercial purposes.
- *	 - You are free to use and redistribute this code in modified or
- *	   unmodified form, provided you list me in the credits.
- *	 - If you modify this source code, you must add a notice to each modified
- *	   source file that it has been changed.  If you're a nice person, you
- *	   will clearly mark each change too.  :)
- *	 - If you wish to use this for commercial purposes, please contact me at
- *	   pullmoll@t-online.de
- *	 - The author of this copywritten work reserves the right to change the
- *	   terms of its usage and license at any time, including retroactively
- *	 - This entire notice must remain in the source code.
+ *   - This source code is released as freeware for non-commercial purposes.
+ *   - You are free to use and redistribute this code in modified or
+ *     unmodified form, provided you list me in the credits.
+ *   - If you modify this source code, you must add a notice to each modified
+ *     source file that it has been changed.  If you're a nice person, you
+ *     will clearly mark each change too.  :)
+ *   - If you wish to use this for commercial purposes, please contact me at
+ *     pullmoll@t-online.de
+ *   - The author of this copywritten work reserves the right to change the
+ *     terms of its usage and license at any time, including retroactively
+ *   - This entire notice must remain in the source code.
  *
  *****************************************************************************/
 /* 4. February 2000 PeT fixed relative word operand */
@@ -55,16 +55,6 @@
 #define LOG(x)
 #endif
 
-#ifdef RUNTIME_LOADER
-struct cpu_interface
-m65ce02_interface=
-CPU0(M65CE02,  m65ce02,  1,  0,1.00,M65CE02_INT_NONE,  M65CE02_INT_IRQ,M65CE02_INT_NMI,8, 16,     0,16,LE,1, 3);
-
-extern void m65ce02_runtime_loader_init(void)
-{
-	cpuintf[CPU_M65CE02]=m65ce02_interface;
-}
-#endif
 
 /* Layout of the registers in the debugger */
 static UINT8 m65ce02_reg_layout[] = {
@@ -134,7 +124,7 @@ void m65ce02_reset (void *param)
 	m65ce02.after_cli = 0;		/* pending IRQ and last insn cleared I */
 	m65ce02.irq_callback = NULL;
 
-	change_pc16(PCD);
+	change_pc(PCD);
 }
 
 void m65ce02_exit(void)
@@ -154,7 +144,7 @@ void m65ce02_set_context (void *src)
 	if( src )
 	{
 		m65ce02 = *(m65ce02_Regs*)src;
-		change_pc16(PCD);
+		change_pc(PCD);
 	}
 }
 
@@ -177,13 +167,6 @@ unsigned m65ce02_get_reg (int regnum)
 		case M65CE02_NMI_STATE: return m65ce02.nmi_state;
 		case M65CE02_IRQ_STATE: return m65ce02.irq_state;
 		case REG_PREVIOUSPC: return m65ce02.ppc.w.l;
-		default:
-			if( regnum <= REG_SP_CONTENTS )
-			{
-				unsigned offset = S + 2 * (REG_SP_CONTENTS - regnum);
-				if( offset < 0x1ff )
-					return RDMEM( offset ) | ( RDMEM( offset + 1 ) << 8 );
-			}
 	}
 	return 0;
 }
@@ -192,7 +175,7 @@ void m65ce02_set_reg (int regnum, unsigned val)
 {
 	switch( regnum )
 	{
-		case REG_PC: PCW = val; change_pc16(PCD); break;
+		case REG_PC: PCW = val; change_pc(PCD); break;
 		case M65CE02_PC: m65ce02.pc.w.l = val; break;
 		case REG_SP: S = val; break;
 		case M65CE02_S: m65ce02.sp.w.l = val; break;
@@ -204,18 +187,8 @@ void m65ce02_set_reg (int regnum, unsigned val)
 		case M65CE02_B: m65ce02.zp.b.h = val; break;
 		case M65CE02_EA: m65ce02.ea.w.l = val; break;
 		case M65CE02_ZP: m65ce02.zp.b.l = val; break;
-		case M65CE02_NMI_STATE: m65ce02_set_irq_line( IRQ_LINE_NMI, val ); break;
+		case M65CE02_NMI_STATE: m65ce02_set_irq_line( INPUT_LINE_NMI, val ); break;
 		case M65CE02_IRQ_STATE: m65ce02_set_irq_line( 0, val ); break;
-		default:
-			if( regnum <= REG_SP_CONTENTS )
-			{
-				unsigned offset = S + 2 * (REG_SP_CONTENTS - regnum);
-				if( offset < 0x1ff )
-				{
-					WRMEM( offset, val & 0xfff );
-					WRMEM( offset + 1, (val >> 8) & 0xff );
-				}
-			}
 	}
 }
 
@@ -234,7 +207,7 @@ INLINE void m65ce02_take_irq(void)
 		LOG(("M65ce02#%d takes IRQ ($%04x)\n", cpu_getactivecpu(), PCD));
 		/* call back the cpuintrf to let it clear the line */
 		if (m65ce02.irq_callback) (*m65ce02.irq_callback)(0);
-		change_pc16(PCD);
+		change_pc(PCD);
 	}
 	m65ce02.pending_irq = 0;
 }
@@ -243,7 +216,7 @@ int m65ce02_execute(int cycles)
 {
 	m65ce02_ICount = cycles;
 
-	change_pc16(PCD);
+	change_pc(PCD);
 
 	do
 	{
@@ -285,7 +258,7 @@ int m65ce02_execute(int cycles)
 
 void m65ce02_set_irq_line(int irqline, int state)
 {
-	if (irqline == IRQ_LINE_NMI)
+	if (irqline == INPUT_LINE_NMI)
 	{
 		if (m65ce02.nmi_state == state) return;
 		m65ce02.nmi_state = state;
@@ -301,7 +274,7 @@ void m65ce02_set_irq_line(int irqline, int state)
 			PCL = RDMEM(EAD);
 			PCH = RDMEM(EAD+1);
 			LOG(("M65ce02#%d takes NMI ($%04x)\n", cpu_getactivecpu(), PCD));
-			change_pc16(PCD);
+			change_pc(PCD);
 		}
 	}
 	else
