@@ -3,7 +3,7 @@
 
 /* 6809dasm.c - a 6809 opcode disassembler */
 /* Version 1.4 1-MAR-95 */
-/* Copyright  1995 Sean Riddle */
+/* Copyright 1995 Sean Riddle */
 
 /* thanks to Franklin Bowen for bug fixes, ideas */
 
@@ -23,11 +23,6 @@
 #include "mamedbg.h"
 #include "m6809.h"
 
-#ifndef TRUE
-#define TRUE	-1
-#define FALSE	0
-#endif
-
 typedef struct {                /* opcode structure */
    UINT8	opcode; 			/* 8-bit opcode value */
    UINT8	numoperands;
@@ -36,47 +31,30 @@ typedef struct {                /* opcode structure */
    UINT8	size;				/* access size */
    UINT8	access; 			/* access mode */
    UINT8	numcycles;			/* number of cycles - not used */
+   unsigned flags;				/* disassembly flags */
 } opcodeinfo;
 
-/* 6809 ADDRESSING MODES */
-enum M6809_ADDRESSING_MODES {
+/* 6809/6309 ADDRESSING MODES */
+enum M6809_ADDRESSING_MODES
+{
 	INH,
 	DIR,
+	DIR_IM,
 	IND,
 	REL,
 	EXT,
 	IMM,
+	IMM_RR,
+	IMM_BW,
+	IMM_TFM,
 	LREL,
-	PG2,						/* PAGE SWITCHES -	Page 2 */
-	PG3 						/*					Page 3 */
+	PG2,						/* PAGE SWITCHES -  Page 2 */
+	PG3 						/*                  Page 3 */
 };
 
-/* number of opcodes in each page */
-#define NUMPG1OPS 223
-#define NUMPG2OPS 38
-#define NUMPG3OPS 9
-
-int numops[3] =
-{
-   NUMPG1OPS,NUMPG2OPS,NUMPG3OPS,
-};
-
-#if 0
-static char modenames[9][14] = {
-   "inherent",
-   "direct",
-   "indexed",
-   "relative",
-   "extended",
-   "immediate",
-   "long relative",
-   "page 2",
-   "page 3",
-};
-#endif
 
 /* page 1 ops */
-static opcodeinfo pg1opcodes[NUMPG1OPS] =
+static const opcodeinfo m6809_pg1opcodes[] =
 {
 	{  0,1,"NEG",     DIR, EA_UINT8, EA_ZPG_RDWR,  6},
 	{  3,1,"COM",     DIR, EA_UINT8, EA_ZPG_RDWR,  6},
@@ -96,13 +74,13 @@ static opcodeinfo pg1opcodes[NUMPG1OPS] =
 	{ 18,0,"NOP",     INH, 0,        0,            2},
 	{ 19,0,"SYNC",    INH, 0,        0,            4},
 	{ 22,2,"LBRA",    LREL,EA_INT16, EA_REL_PC,    5},
-	{ 23,2,"LBSR",    LREL,EA_INT16, EA_REL_PC,    9},
+	{ 23,2,"LBSR",    LREL,EA_INT16, EA_REL_PC,    9, DASMFLAG_STEP_OVER},
 	{ 25,0,"DAA",     INH, 0,        0,            2},
 	{ 26,1,"ORCC",    IMM, 0,        0,            3},
 	{ 28,1,"ANDCC",   IMM, 0,        0,            3},
 	{ 29,0,"SEX",     INH, 0,        0,            2},
-	{ 30,1,"EXG",     IMM, 0,        0,            8},
-	{ 31,1,"TFR",     IMM, 0,        0,            6},
+	{ 30,1,"EXG",     IMM_RR, 0,        0,            8},
+	{ 31,1,"TFR",     IMM_RR, 0,        0,            6},
 
 	{ 32,1,"BRA",     REL, EA_INT8,  EA_REL_PC,    3},
 	{ 33,1,"BRN",     REL, EA_INT8,  EA_REL_PC,    3},
@@ -198,7 +176,7 @@ static opcodeinfo pg1opcodes[NUMPG1OPS] =
 	{138,1,"ORA",     IMM, EA_UINT8, EA_VALUE,     2},
 	{139,1,"ADDA",    IMM, EA_UINT8, EA_VALUE,     2},
 	{140,2,"CMPX",    IMM, EA_UINT16,EA_VALUE,     4},
-	{141,1,"BSR",     REL, EA_INT8,  EA_REL_PC,    7},
+	{141,1,"BSR",     REL, EA_INT8,  EA_REL_PC,    7, DASMFLAG_STEP_OVER},
 	{142,2,"LDX",     IMM, EA_UINT16,EA_VALUE,     3},
 
 	{144,1,"SUBA",    DIR, EA_UINT8, EA_ZPG_RD,    4},
@@ -214,7 +192,7 @@ static opcodeinfo pg1opcodes[NUMPG1OPS] =
 	{154,1,"ORA",     DIR, EA_UINT8, EA_ZPG_RD,    4},
 	{155,1,"ADDA",    DIR, EA_UINT8, EA_ZPG_RD,    4},
 	{156,1,"CMPX",    DIR, EA_UINT16,EA_ZPG_RD,    6},
-	{157,1,"JSR",     DIR, EA_UINT8, EA_ABS_PC,    7},
+	{157,1,"JSR",     DIR, EA_UINT8, EA_ABS_PC,    7, DASMFLAG_STEP_OVER},
 	{158,1,"LDX",     DIR, EA_UINT16,EA_ZPG_RD,    5},
 	{159,1,"STX",     DIR, EA_UINT16,EA_ZPG_WR,    5},
 
@@ -231,7 +209,7 @@ static opcodeinfo pg1opcodes[NUMPG1OPS] =
 	{170,1,"ORA",     IND, EA_UINT8, EA_MEM_RD,    4},
 	{171,1,"ADDA",    IND, EA_UINT8, EA_MEM_RD,    4},
 	{172,1,"CMPX",    IND, EA_UINT16,EA_MEM_RD,    6},
-	{173,1,"JSR",     IND, EA_UINT8, EA_ABS_PC,    7},
+	{173,1,"JSR",     IND, EA_UINT8, EA_ABS_PC,    7, DASMFLAG_STEP_OVER},
 	{174,1,"LDX",     IND, EA_UINT16,EA_MEM_RD,    5},
 	{175,1,"STX",     IND, EA_UINT16,EA_MEM_WR,    5},
 
@@ -248,7 +226,7 @@ static opcodeinfo pg1opcodes[NUMPG1OPS] =
 	{186,2,"ORA",     EXT, EA_UINT8, EA_MEM_RD,    5},
 	{187,2,"ADDA",    EXT, EA_UINT8, EA_MEM_RD,    5},
 	{188,2,"CMPX",    EXT, EA_UINT16,EA_MEM_RD,    7},
-	{189,2,"JSR",     EXT, EA_UINT8, EA_ABS_PC,    8},
+	{189,2,"JSR",     EXT, EA_UINT8, EA_ABS_PC,    8, DASMFLAG_STEP_OVER},
 	{190,2,"LDX",     EXT, EA_UINT16,EA_MEM_RD,    6},
 	{191,2,"STX",     EXT, EA_UINT16,EA_MEM_WR,    6},
 
@@ -319,7 +297,7 @@ static opcodeinfo pg1opcodes[NUMPG1OPS] =
 };
 
 /* page 2 ops 10xx*/
-static opcodeinfo pg2opcodes[NUMPG2OPS] =
+static const opcodeinfo m6809_pg2opcodes[] =
 {
 	{ 33,3,"LBRN",    LREL,EA_INT16, EA_REL_PC,    5},
 	{ 34,3,"LBHI",    LREL,EA_INT16, EA_REL_PC,    5},
@@ -362,7 +340,7 @@ static opcodeinfo pg2opcodes[NUMPG2OPS] =
 };
 
 /* page 3 ops 11xx */
-static opcodeinfo pg3opcodes[NUMPG3OPS] =
+static const opcodeinfo m6809_pg3opcodes[] =
 {
 	{ 63,1,"SWI3",    INH, 0,        0,           20},
 	{131,3,"CMPU",    IMM, EA_UINT16,EA_VALUE,     5},
@@ -375,43 +353,59 @@ static opcodeinfo pg3opcodes[NUMPG3OPS] =
 	{188,3,"CMPS",    EXT, EA_UINT16,EA_MEM_RD,    8},
 };
 
-static opcodeinfo *pgpointers[3] =
+static const opcodeinfo *m6809_pgpointers[3] =
 {
-   pg1opcodes,pg2opcodes,pg3opcodes,
+	m6809_pg1opcodes, m6809_pg2opcodes, m6809_pg3opcodes
 };
 
-static const UINT8 regid_6809[5] = {
-	M6809_X, M6809_Y, M6809_U, M6809_S, M6809_PC
+static const int m6809_numops[3] =
+{
+	sizeof(m6809_pg1opcodes) / sizeof(m6809_pg1opcodes[0]),
+	sizeof(m6809_pg2opcodes) / sizeof(m6809_pg2opcodes[0]),
+	sizeof(m6809_pg3opcodes) / sizeof(m6809_pg3opcodes[0])
 };
 
-static const char *regs_6809[5] = {
-	"X","Y","U","S","PC"
-};
+static const char *regs_6809[5] = { "X","Y","U","S","PC" };
 
-static const char *teregs[16] = {
+static const char *btwRegs[5] = { "CC", "A", "B", "inv" };
+
+static const char *teregs_6809[16] =
+{
 	"D","X","Y","U","S","PC","inv","inv",
 	"A","B","CC","DP","inv","inv","inv","inv"
 };
 
-static char *hexstring (int address)
-{
-	static char labtemp[10];
-	sprintf (labtemp, "$%04hX", address);
-	return labtemp;
-}
+static const char *tfmregs[16] = {
+	"D","X","Y","U","S","inv","inv","inv",
+	"inv","inv","inv","inv","inv","inv","inv","inv"
+};
 
-unsigned Dasm6809 (char *buffer, unsigned pc)
+static const char *tfm_s[] = { "%s+,%s+", "%s-,%s-", "%s+,%s", "%s,%s+" };
+
+offs_t m6809_dasm(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes)
 {
-	int i, j, k, page, opcode, numoperands, mode, size, access;
-	UINT8 operandarray[4];
-	const char *sym1, *sym2;
-	int rel, pb, offset, reg, pb2;
+	int i, k, page = 0, opcode, numoperands, mode, size, access;
+	const UINT8 *operandarray;
+	const char *sym1;
+	int rel, pb, offset = 0, reg, pb2;
 	unsigned ea = 0;
     int p = 0;
+	unsigned flags;
+	const int *numops;
+	const opcodeinfo **pgpointers;
+	const opcodeinfo *pg1opcodes;
+	const char **regs;
+	const char **teregs;
+
+	numops = m6809_numops;
+	pgpointers = m6809_pgpointers;
+	pg1opcodes = pgpointers[0];
+	regs = regs_6809;
+	teregs = teregs_6809;
 
 	*buffer = '\0';
 
-    opcode = cpu_readop(pc+(p++));
+	opcode = oprom[p++];
 	for( i = 0; i < numops[0]; i++ )
 		if (pg1opcodes[i].opcode == opcode)
 			break;
@@ -420,7 +414,7 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 	{
 		if( pg1opcodes[i].mode >= PG2 )
 		{
-			opcode = cpu_readop(pc+(p++));
+			opcode = oprom[p++];
 			page = pg1opcodes[i].mode - PG2 + 1;          /* get page # */
 			for( k = 0; k < numops[page]; k++ )
 				if (opcode == pgpointers[page][k].opcode)
@@ -429,11 +423,12 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 			if( k != numops[page] )
 			{	/* opcode found */
 				numoperands = pgpointers[page][k].numoperands - 1;
-				for (j = 0; j < numoperands; j++)
-					operandarray[j] = cpu_readop_arg(pc+(p++));
+				operandarray = &opram[p];
+				p += numoperands;
 				mode = pgpointers[page][k].mode;
 				size = pgpointers[page][k].size;
 				access = pgpointers[page][k].access;
+				flags = pgpointers[page][k].flags;
 				buffer += sprintf (buffer, "%-6s", pgpointers[page][k].name);
 			 }
 			 else
@@ -445,11 +440,12 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 		else
 		{	/* page 1 opcode */
 			numoperands = pg1opcodes[i].numoperands;
-			for( j = 0; j < numoperands; j++ )
-				operandarray[j] = cpu_readop_arg(pc+(p++));
+			operandarray = &opram[p];
+			p += numoperands;
 			mode = pg1opcodes[i].mode;
 			size = pg1opcodes[i].size;
 			access = pg1opcodes[i].access;
+			flags = pg1opcodes[i].flags;
 			buffer += sprintf (buffer, "%-6s", pg1opcodes[i].name);
 		}
 	}
@@ -459,13 +455,10 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 		return 1;
 	}
 
-	pc += p;
-
-	if( opcode != 0x1f && opcode != 0x1e )
-	{
 		if( mode == IMM )
 			buffer += sprintf (buffer, "#");
-	}
+
+	pc += p;
 
 	switch (mode)
 	{
@@ -488,33 +481,29 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 		if( pb2 == 0x88 || pb2 == 0x8c )
 		{	/* 8-bit offset */
 
-			/* KW 11/05/98 Fix of indirect opcodes		*/
-			offset = (INT8)cpu_readop_arg(pc);
+			/* KW 11/05/98 Fix of indirect opcodes      */
+			offset = (INT8) opram[p];
 			p++;
 			if( pb == 0x8c ) reg = 4;
 			if( (pb & 0x90) == 0x90 ) buffer += sprintf (buffer, "[");
 			if( pb == 0x8c )
 			{
 				sym1 = set_ea_info(1, pc, (INT8)offset, EA_REL_PC);
-				ea = (pc + (INT8)offset + cpu_get_reg(regid_6809[reg])) & 0xffff;
-				buffer += sprintf (buffer, "%s,%s", sym1, regs_6809[reg]);
+				buffer += sprintf (buffer, "%s,%s", sym1, regs[reg]);
 			}
 			else
 			{
 				sym1 = set_ea_info(1, offset, EA_INT8, EA_VALUE);
-				ea = (cpu_get_reg(regid_6809[reg]) + offset) & 0xffff;
-				buffer += sprintf (buffer, "%s,%s", sym1, regs_6809[reg]);
+				buffer += sprintf (buffer, "%s,%s", sym1, regs[reg]);
 			}
-/*			  if( pb == 0x8c ) */
-/*				  buffer += sprintf (buffer, " ; ($%04X)", offset + pc); */
 		}
 		else
 		if( pb2 == 0x89 || pb2 == 0x8d || pb2 == 0x8f )
 		{	/* 16-bit */
 
-			/* KW 11/05/98 Fix of indirect opcodes		*/
+			/* KW 11/05/98 Fix of indirect opcodes      */
 
-			offset = (INT16)( (cpu_readop_arg(pc) << 8) + cpu_readop_arg(pc+1) );
+			offset = (INT16)( (opram[p+0] << 8) + opram[p+1] );
 			p += 2;
 
 			if( pb == 0x8d )
@@ -530,56 +519,45 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 			if( pb2 == 0x8f )
 			{
 				sym1 = set_ea_info(1, offset, EA_INT16, EA_VALUE);
-				ea = offset;
                 buffer += sprintf (buffer, "%s", sym1);
 			}
 			else
 			{
 				sym1 = set_ea_info(1, offset, EA_INT16, EA_VALUE);
-				ea = (cpu_get_reg(regid_6809[reg]) + offset) & 0xffff;
-                buffer += sprintf (buffer, "%s,%s", sym1, regs_6809[reg]);
+				buffer += sprintf (buffer, "%s,%s", sym1, regs[reg]);
 			}
-/*			  if( pb == 0x8d ) */
-/*				  buffer += sprintf (buffer, " ; ($%04X)", offset + pc); */
 		}
 		else
 		if( pb & 0x80 )
 		{
 			if( (pb & 0x90) == 0x90 )
 				buffer += sprintf (buffer, "[");
+
 			switch( pb & 0x8f )
 			{
 			case 0x80:
-				ea = cpu_get_reg(regid_6809[reg]);
-				buffer += sprintf (buffer, ",%s+", regs_6809[reg]);
+				buffer += sprintf (buffer, ",%s+", regs[reg]);
 				break;
 			case 0x81:
-				ea = cpu_get_reg(regid_6809[reg]);
-                buffer += sprintf (buffer, ",%s++", regs_6809[reg]);
+				buffer += sprintf (buffer, ",%s++", regs[reg]);
 				break;
 			case 0x82:
-				ea = cpu_get_reg(regid_6809[reg]);
-                buffer += sprintf (buffer, ",-%s", regs_6809[reg]);
+				buffer += sprintf (buffer, ",-%s", regs[reg]);
 				break;
 			case 0x83:
-				ea = cpu_get_reg(regid_6809[reg]);
-                buffer += sprintf (buffer, ",--%s", regs_6809[reg]);
+				buffer += sprintf (buffer, ",--%s", regs[reg]);
 				break;
 			case 0x84:
-				ea = cpu_get_reg(regid_6809[reg]);
-                buffer += sprintf (buffer, ",%s", regs_6809[reg]);
+				buffer += sprintf (buffer, ",%s", regs[reg]);
 				break;
 			case 0x85:
-				ea = (cpu_get_reg(regid_6809[reg]) + (INT8) cpu_get_reg(M6809_B)) & 0xffff;
-                buffer += sprintf (buffer, "B,%s", regs_6809[reg]);
+				buffer += sprintf (buffer, "B,%s", regs[reg]);
 				break;
 			case 0x86:
-				ea = (cpu_get_reg(regid_6809[reg]) + (INT8) cpu_get_reg(M6809_A)) & 0xffff;
-                buffer += sprintf (buffer, "A,%s", regs_6809[reg]);
+				buffer += sprintf (buffer, "A,%s", regs[reg]);
 				break;
 			case 0x8b:
-				ea = (cpu_get_reg(regid_6809[reg]) + (cpu_get_reg(M6809_A) << 8) + cpu_get_reg(M6809_B)) & 0xffff;
-                buffer += sprintf (buffer, "D,%s", regs_6809[reg]);
+				buffer += sprintf (buffer, "D,%s", regs[reg]);
 				break;
 			}
 		}
@@ -588,23 +566,54 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 			offset = pb & 0x1f;
 			if (offset > 15)
 				offset = offset - 32;
-			buffer += sprintf (buffer, "%s,%s", hexstring (offset), regs_6809[reg]);
+			buffer += sprintf (buffer, "$%04hX,%s", (unsigned short) offset, regs[reg]);
 		}
 		/* indirect */
 		if( (pb & 0x90) == 0x90 )
 		{
-			ea = ( cpu_readmem16( ea ) << 8 ) + cpu_readmem16( (ea+1) & 0xffff );
             buffer += sprintf (buffer, "]");
 		}
-		sym2 = set_ea_info(0, ea, size, access);
         break;
 
-	default:
-		if( opcode == 0x1f || opcode == 0x1e )
-		{	/* TFR/EXG */
+	case IMM_RR:	  /* immediate register-register */
 			buffer += sprintf (buffer, "%s,%s", teregs[ (operandarray[0] >> 4) & 0xf], teregs[operandarray[0] & 0xf]);
-		}
-		else
+		break;
+
+	case IMM_BW:	  /* bitwise operations (6309 only) */
+		/* Decode register */
+		pb = operandarray[0];
+
+		buffer += sprintf (buffer, "%s", btwRegs[ ((pb & 0xc0) >> 6) ]);
+		buffer += sprintf (buffer, ",");
+		buffer += sprintf (buffer, "%d", ((pb & 0x38) >> 3) );
+		buffer += sprintf (buffer, ",");
+		buffer += sprintf (buffer, "%d", (pb & 0x07) );
+		buffer += sprintf (buffer, ",");
+
+		/* print zero page access */
+		ea = operandarray[1];
+		sym1 = set_ea_info(0, ea, size, access );
+		buffer += sprintf (buffer, "%s", sym1 );
+		break;
+
+	case IMM_TFM:	  /* transfer from memory (6309 only) */
+		buffer += sprintf (buffer, tfm_s[opcode & 0x07], tfmregs[ (operandarray[0] >> 4) & 0xf], tfmregs[operandarray[0] & 0xf]);
+		break;
+
+	case DIR_IM:	  /* direct in memory (6309 only) */
+		buffer += sprintf (buffer, "#");
+		ea = operandarray[0];
+		sym1 = set_ea_info(0, ea, EA_UINT8, EA_VALUE );
+		buffer += sprintf (buffer, "%s", sym1 );
+
+		buffer += sprintf (buffer, ",");
+
+		ea = operandarray[1];
+		sym1 = set_ea_info(0, ea, size, access );
+		buffer += sprintf (buffer, "%s", sym1 );
+		break;
+
+	default:
 		if( opcode == 0x34 || opcode == 0x36 )
 		{	/* PUSH */
 			pb2 = operandarray[0];
@@ -643,7 +652,7 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 			if( pb2 & 0x02 )
 			{
 				if( pb2 & 0xfc ) buffer += sprintf (buffer, ",");
-                strcat (buffer, "A");
+				buffer += sprintf (buffer, "A");
 			}
 			if( pb2 & 0x01 )
 			{
@@ -701,6 +710,27 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 		}
 		else
 		{
+			if ( numoperands == 4)
+			{
+				ea = (operandarray[0] << 24) + (operandarray[1] << 16) + (operandarray[2] << 8) + operandarray[3];
+				sym1 = set_ea_info(0, ea, size, access );
+				buffer += sprintf (buffer, "%s", sym1 );
+			}
+			else
+			if ( numoperands == 3)
+			{
+				buffer += sprintf (buffer, "#");
+				ea = operandarray[0];
+				sym1 = set_ea_info(0, ea, EA_INT8, EA_VALUE );
+				buffer += sprintf (buffer, "%s", sym1 );
+
+				buffer += sprintf (buffer, ",");
+
+				ea = (operandarray[1] << 8) + operandarray[2];
+				sym1 = set_ea_info(0, ea, size, access );
+				buffer += sprintf (buffer, "%s", sym1 );
+			}
+			else
 			if( numoperands == 2 )
 			{
 				ea = (operandarray[0] << 8) + operandarray[1];
@@ -718,7 +748,8 @@ unsigned Dasm6809 (char *buffer, unsigned pc)
 		break;
 	}
 
-	return p;
+	return p | flags | DASMFLAG_SUPPORTED;
 }
 
 #endif
+
