@@ -90,6 +90,10 @@
 #define LOG(x)
 #endif
 
+#ifdef MAME_DEBUG
+extern offs_t m6809_dasm(char *buffer, offs_t pc, UINT8 *oprom, UINT8 *opram, int bytes);
+#endif
+
 
 static UINT8 m6809_reg_layout[] = {
 	M6809_PC, M6809_S, M6809_CC, M6809_A, M6809_B, M6809_X, -1,
@@ -520,16 +524,6 @@ static void set_irq_line(int irqline, int state)
 	}
 }
 
-static offs_t m6809_dasm(char *buffer, offs_t pc)
-{
-#ifdef MAME_DEBUG
-    return Dasm6809(buffer,pc);
-#else
-	sprintf( buffer, "$%02X", cpu_readop(pc) );
-	return 1;
-#endif
-}
-
 /* includes the static function prototypes and the master opcode table */
 #include "6809tbl.c"
 
@@ -1201,7 +1195,9 @@ void m6809_get_info(UINT32 state, union cpuinfo *info)
 		case CPUINFO_PTR_EXIT:							info->exit = m6809_exit;					break;
 		case CPUINFO_PTR_EXECUTE:						info->execute = m6809_execute;				break;
 		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = m6809_dasm;					break;
+#ifdef MAME_DEBUG
+		case CPUINFO_PTR_DISASSEMBLE_NEW:				info->disassemble_new = m6809_dasm;					break;
+#endif /* MAME_DEBUG */
 		case CPUINFO_PTR_IRQ_CALLBACK:					info->irqcallback = m6809.irq_callback;			break;
 		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &m6809_ICount;				break;
 		case CPUINFO_PTR_REGISTER_LAYOUT:				info->p = m6809_reg_layout;				break;
