@@ -8,7 +8,7 @@
  *   when an overflow occurs
  *
  * Unimplemented opcodes:
- * LDTASK, ROTC, STTASK, UPDATE, UPDPTE
+ * ROTC, UPDATE, UPDPTE
  */
 
 UINT32 f12Op1, f12Op2;
@@ -82,7 +82,7 @@ UINT8 if12;
 /* writing to the second operand. */
 void F12DecodeFirstOperand(UINT32 (*DecodeOp1)(void), UINT8 dim1)
 {
-	if12 = MemRead8(PC + 1);
+	if12 = OpRead8(PC + 1);
 
 	/* Check if F1 or F2 */
 	if (if12 & 0x80)
@@ -183,7 +183,7 @@ void F12WriteSecondOperand(UINT8 dim2)
 /* Decode both format 1/2 operands */
 void F12DecodeOperands(UINT32 (*DecodeOp1)(void), UINT8 dim1, UINT32 (*DecodeOp2)(void), UINT8 dim2)
 {
-	UINT8 _if12 = MemRead8(PC + 1);
+	UINT8 _if12 = OpRead8(PC + 1);
 
 	/* Check if F1 or F2 */
 	if (_if12 & 0x80)
@@ -414,6 +414,7 @@ UINT32 opCALL(void) /* TRUSTED */
 	SP -= 4;
 	MemWrite32(SP, PC + amLength1 + amLength2 + 2);
 	PC = f12Op1;
+	ChangePC(PC);
 
 	return 0;
 }
@@ -456,29 +457,31 @@ UINT32 opCHKAE(void)
 
 UINT32 opCHLVL(void)
 {
+	UINT32 oldPSW;
+
 	F12DecodeOperands(ReadAM,0,ReadAM,0);
 
 	if (f12Op1>3)
 	{
-		messagebox("Illegal data field on opCHLVL\n");
-		F12END();
+		osd_die("Illegal data field on opCHLVL, PC=%x\n", PC);
 	}
 
-	UPDATEPSW();
+	oldPSW = v60_update_psw_for_exception(0, f12Op1);
 
 	SP -= 4;
 	MemWrite32(SP,f12Op2);
 
 	SP -= 4;
-	MemWrite32(SP,0x1800 + f12Op1*0x100);
+	MemWrite32(SP,EXCEPTION_CODE_AND_SIZE(0x1800 + f12Op1*0x100, 8));
 
 	SP -= 4;
-	MemWrite32(SP,PSW);
+	MemWrite32(SP,oldPSW);
 
 	SP -= 4;
 	MemWrite32(SP,PC + amLength1 + amLength2 + 2);
 
 	PC = GETINTVECT(24+f12Op1);
+	ChangePC(PC);
 
 	return 0;
 }
@@ -539,7 +542,8 @@ UINT32 opDIVB(void) /* TRUSTED */
 	F12LOADOP2BYTE();
 
 	_OV = ((appb == 0x80) && (f12Op1==0xFF));
-	if (f12Op1 && !_OV) appb=((*(INT8*)&appb) / ((INT8)(f12Op1&0xFF)));
+	if (f12Op1 && !_OV)
+		appb= (INT8)appb / (INT8)f12Op1;
 	_Z = (appb == 0);
 	_S = ((appb & 0x80)!=0);
 
@@ -555,7 +559,8 @@ UINT32 opDIVH(void) /* TRUSTED */
 	F12LOADOP2HALF();
 
 	_OV = ((apph == 0x8000) && (f12Op1==0xFFFF));
-	if (f12Op1 && !_OV)	apph=((*(INT16*)&apph) / ((INT16)(f12Op1&0xFFFF)));
+	if (f12Op1 && !_OV)
+		apph = (INT16)apph / (INT16)f12Op1;
 	_Z = (apph == 0);
 	_S = ((apph & 0x8000)!=0);
 
@@ -571,7 +576,8 @@ UINT32 opDIVW(void) /* TRUSTED */
 	F12LOADOP2WORD();
 
 	_OV = ((appw == 0x80000000) && (f12Op1==0xFFFFFFFF));
-	if (f12Op1 && !_OV)	appw=((*(INT32*)&appw) / (*(INT32*)&f12Op1));
+	if (f12Op1 && !_OV)
+		appw = (INT32)appw / (INT32)f12Op1;
 	_Z = (appw == 0);
 	_S = ((appw & 0x80000000)!=0);
 
@@ -581,7 +587,7 @@ UINT32 opDIVW(void) /* TRUSTED */
 
 UINT32 opDIVX(void)
 {
-	INT32 a,b;
+	UINT32 a,b;
 	INT64 dv;
 
 	F12DecodeOperands(ReadAM,2,ReadAMAddress,3);
@@ -597,10 +603,10 @@ UINT32 opDIVX(void)
 		b=MemRead32(f12Op2+4);
 	}
 
-	dv = (INT64)(((INT64)b<<32) | (INT64)a);
+	dv = ((UINT64)b<<32) | ((UINT64)a);
 
-	a = (INT32)(dv / (INT64)f12Op1);
-	b = (INT32)(dv % (INT64)f12Op1);
+	a = dv / (INT64)((INT32)f12Op1);
+	b = dv % (INT64)((INT32)f12Op1);
 
 	_S = ((a & 0x80000000)!=0);
 	_Z = (a == 0);
@@ -736,13 +742,57 @@ UINT32 opLDPR(void)
 	F12DecodeOperands(ReadAMAddress,2,ReadAM,2);
 	if (f12Op2 >= 0 && f12Op2 <= 28)
 	{
-		if (f12Flag1)
+	  if (f12Flag1 &&(!(OpRead8(PC + 1)&0x80 && OpRead8(PC + 2)==0xf4 ) ))
 			v60.reg[f12Op2 + 36] = v60.reg[f12Op1];
 		else
 			v60.reg[f12Op2 + 36] = f12Op1;
 	}
 	else
-		messagebox("Invalid operand on LDPR\n");
+	{
+		osd_die("Invalid operand on LDPR PC=%x\n", PC);
+	}
+	F12END();
+}
+
+UINT32 opLDTASK(void)
+{
+	int i;
+	F12DecodeOperands(ReadAMAddress,2,ReadAM,2);
+
+	v60WritePSW(v60ReadPSW() & 0xefffffff);
+
+	TR = f12Op2;
+
+	TKCW = MemRead32(f12Op2);
+	f12Op2 += 4;
+	if(SYCW & 0x100) {
+		L0SP = MemRead32(f12Op2);
+		f12Op2 += 4;
+	}
+	if(SYCW & 0x200) {
+		L1SP = MemRead32(f12Op2);
+		f12Op2 += 4;
+	}
+	if(SYCW & 0x400) {
+		L2SP = MemRead32(f12Op2);
+		f12Op2 += 4;
+	}
+	if(SYCW & 0x800) {
+		L3SP = MemRead32(f12Op2);
+		f12Op2 += 4;
+	}
+
+	v60ReloadStack();
+
+	/* 31 registers supported, _not_ 32 */
+	for(i=0; i<31; i++)
+		if(f12Op1 & (1<<i)) {
+			v60.reg[i] = MemRead32(f12Op2);
+			f12Op2 += 4;
+		}
+
+	/* #### Ignore the virtual addressing crap. */
+
 	F12END();
 }
 
@@ -934,8 +984,8 @@ UINT32 opMULB(void)
 	F12LOADOP2BYTE();
 
 	/* @@@ OV not set!! */
-	tmp=((INT32)((*(INT8*)&appb) * (INT32)((INT8)(f12Op1 & 0xFF))));
-	appb = (UINT8)(tmp&0xFF);
+	tmp=(INT8)appb * (INT32)(INT8)f12Op1;
+	appb = tmp;
 	_Z = (appb == 0);
 	_S = ((appb & 0x80)!=0);
 	_OV = ((tmp >> 8)!=0);
@@ -953,8 +1003,8 @@ UINT32 opMULH(void)
 	F12LOADOP2HALF();
 
 	/* @@@ OV not set!! */
-	tmp=(INT32)((*(INT16*)&apph) * (INT32)((INT16)(f12Op1&0xFFFF)));
-	apph = (UINT16)(tmp&0xFFFF);
+	tmp=(INT16)apph * (INT32)(INT16)f12Op1;
+	apph = tmp;
 	_Z = (apph == 0);
 	_S = ((apph & 0x8000)!=0);
 	_OV = ((tmp >> 16)!=0);
@@ -972,8 +1022,8 @@ UINT32 opMULW(void)
 	F12LOADOP2WORD();
 
 	/* @@@ OV not set!! */
-	tmp=(INT64)((*(INT32*)&appw) * (INT64)(*(INT32*)&f12Op1));
-	appw = (UINT32)(tmp&0xFFFFFFFF);
+	tmp=(INT32)appw * (INT64)(INT32)f12Op1;
+	appw = tmp;
 	_Z = (appw == 0);
 	_S = ((appw & 0x80000000)!=0);
 	_OV = ((tmp >> 32) != 0);
@@ -991,8 +1041,8 @@ UINT32 opMULUB(void)
 	F12LOADOP2BYTE();
 
 	/* @@@ OV not set!! */
-	tmp=(appb * (UINT8)f12Op1);
-	appb = (UINT8)(tmp&0xFF);
+	tmp = appb * (UINT8)f12Op1;
+	appb = tmp;
 	_Z = (appb == 0);
 	_S = ((appb & 0x80)!=0);
 	_OV = ((tmp >> 8)!=0);
@@ -1010,8 +1060,8 @@ UINT32 opMULUH(void)
 	F12LOADOP2HALF();
 
 	/* @@@ OV not set!! */
-	tmp=(apph * (UINT16)f12Op1);
-	apph = (UINT16)(tmp&0xFFFF);
+	tmp=apph * (UINT16)f12Op1;
+	apph = tmp;
 	_Z = (apph == 0);
 	_S = ((apph & 0x8000)!=0);
 	_OV = ((tmp >> 16)!=0);
@@ -1029,8 +1079,8 @@ UINT32 opMULUW(void)
 	F12LOADOP2WORD();
 
 	/* @@@ OV not set!! */
-	tmp=((UINT64)appw * (UINT64)f12Op1);
-	appw = (UINT32)(tmp&0xFFFFFFFF);
+	tmp=(UINT64)appw * (UINT64)f12Op1;
+	appw = tmp;
 	_Z = (appw == 0);
 	_S = ((appw & 0x80000000)!=0);
 	_OV = ((tmp >> 32)!=0);
@@ -1041,12 +1091,10 @@ UINT32 opMULUW(void)
 
 UINT32 opNEGB(void) /* TRUSTED  (C too!)*/
 {
-	UINT8 tmpb;
 	F12DecodeFirstOperand(ReadAM,0);
 
-	tmpb = (INT8)(f12Op1&0xFF);
 	modWriteValB = 0;
-	SUBB(modWriteValB, (INT8)tmpb);
+	SUBB(modWriteValB, (INT8)f12Op1);
 
 	F12WriteSecondOperand(0);
 	F12END();
@@ -1054,12 +1102,10 @@ UINT32 opNEGB(void) /* TRUSTED  (C too!)*/
 
 UINT32 opNEGH(void) /* TRUSTED  (C too!)*/
 {
-	UINT16 tmph;
 	F12DecodeFirstOperand(ReadAM,1);
 
-	tmph = (INT16)(f12Op1&0xffff);
 	modWriteValH = 0;
-	SUBW(modWriteValH, (INT16)tmph);
+	SUBW(modWriteValH, (INT16)f12Op1);
 
 	F12WriteSecondOperand(1);
 	F12END();
@@ -1067,12 +1113,10 @@ UINT32 opNEGH(void) /* TRUSTED  (C too!)*/
 
 UINT32 opNEGW(void) /* TRUSTED  (C too!)*/
 {
-	UINT32 tmpw;
 	F12DecodeFirstOperand(ReadAM,2);
 
-	tmpw = *(INT32*)&f12Op1;
 	modWriteValW = 0;
-	SUBL(modWriteValW, (INT32)tmpw);
+	SUBL(modWriteValW, (INT32)f12Op1);
 
 	F12WriteSecondOperand(2);
 	F12END();
@@ -1081,7 +1125,7 @@ UINT32 opNEGW(void) /* TRUSTED  (C too!)*/
 UINT32 opNOTB(void) /* TRUSTED */
 {
 	F12DecodeFirstOperand(ReadAM,0);
-	modWriteValB=~(UINT8)f12Op1;
+	modWriteValB=~f12Op1;
 
 	_OV=0;
 	_S=((modWriteValB&0x80)!=0);
@@ -1094,7 +1138,7 @@ UINT32 opNOTB(void) /* TRUSTED */
 UINT32 opNOTH(void) /* TRUSTED */
 {
 	F12DecodeFirstOperand(ReadAM,1);
-	modWriteValH=~(UINT16)f12Op1;
+	modWriteValH=~f12Op1;
 
 	_OV=0;
 	_S=((modWriteValH&0x8000)!=0);
@@ -1204,7 +1248,8 @@ UINT32 opREMB(void)
 	F12LOADOP2BYTE();
 
 	_OV = 0;
-	if (f12Op1) appb=((*(INT8*)&appb) % ((INT8)(f12Op1&0xFF)));
+	if (f12Op1)
+		appb= (INT8)appb % (INT8)f12Op1;
 	_Z = (appb == 0);
 	_S = ((appb & 0x80)!=0);
 
@@ -1220,7 +1265,8 @@ UINT32 opREMH(void)
 	F12LOADOP2HALF();
 
 	_OV = 0;
-	if (f12Op1)	apph=((*(INT16*)&apph) % ((INT16)(f12Op1&0xFFFF)));
+	if (f12Op1)
+		apph=(INT16)apph % (INT16)f12Op1;
 	_Z = (apph == 0);
 	_S = ((apph & 0x8000)!=0);
 
@@ -1236,7 +1282,8 @@ UINT32 opREMW(void)
 	F12LOADOP2WORD();
 
 	_OV = 0;
-	if (f12Op1)	appw=((*(INT32*)&appw) % (*(INT32*)&f12Op1));
+	if (f12Op1)
+		appw=(INT32)appw % (INT32)f12Op1;
 	_Z = (appw == 0);
 	_S = ((appw & 0x80000000)!=0);
 
@@ -1252,7 +1299,8 @@ UINT32 opREMUB(void)
 	F12LOADOP2BYTE();
 
 	_OV = 0;
-	if (f12Op1)	appb %= (UINT8)f12Op1;
+	if (f12Op1)
+		appb %= (UINT8)f12Op1;
 	_Z = (appb == 0);
 	_S = ((appb & 0x80)!=0);
 
@@ -1268,7 +1316,8 @@ UINT32 opREMUH(void)
 	F12LOADOP2HALF();
 
 	_OV = 0;
-	if (f12Op1)	apph %= (UINT16)f12Op1;
+	if (f12Op1)
+		apph %= (UINT16)f12Op1;
 	_Z = (apph == 0);
 	_S = ((apph & 0x8000)!=0);
 
@@ -1284,7 +1333,8 @@ UINT32 opREMUW(void)
 	F12LOADOP2WORD();
 
 	_OV = 0;
-	if (f12Op1)	appw %= f12Op1;
+	if (f12Op1)
+		appw %= f12Op1;
 	_Z = (appw == 0);
 	_S = ((appw & 0x80000000)!=0);
 
@@ -1652,12 +1702,12 @@ UINT32 opSETF(void)
 /*
 #define SHIFTLEFT_OY(val, count, bitsize) \
 {\
-	UINT32 tmp = ((val) >> (bitsize-1)) & 1; \
-	tmp <<= count; \
-	tmp -= 1; \
-	tmp <<= (bitsize - (count)); \
-	_OV = (((val) & tmp) != tmp); \
-	_CY = (((val) & (1 << (count-1))) != 0); \
+    UINT32 tmp = ((val) >> (bitsize-1)) & 1; \
+    tmp <<= count; \
+    tmp -= 1; \
+    tmp <<= (bitsize - (count)); \
+    _OV = (((val) & tmp) != tmp); \
+    _CY = (((val) & (1 << (count-1))) != 0); \
 }
 */
 
@@ -1732,12 +1782,12 @@ UINT32 opSHAB(void)
 		if (count >= 8)
 			appb = (appb & 0x80) ? 0xFF : 0;
 		else
-			appb = (*(INT8*)&appb) >> count;
+			appb = ((INT8)appb) >> count;
 
 		SetSZPF_Byte(appb);
 	}
 
-/*	printf("SHAB: %x _CY: %d _Z: %d _OV: %d _S: %d\n", appb, _CY, _Z, _OV, _S); */
+/*  printf("SHAB: %x _CY: %d _Z: %d _OV: %d _S: %d\n", appb, _CY, _Z, _OV, _S); */
 
 	F12STOREOP2BYTE();
 	F12END();
@@ -1786,12 +1836,12 @@ UINT32 opSHAH(void)
 		if (count >= 16)
 			apph = (apph & 0x8000) ? 0xFFFF : 0;
 		else
-			apph = (*(INT16*)&apph) >> count;
+			apph = ((INT16)apph) >> count;
 
 		SetSZPF_Word(apph);
 	}
 
-/*	printf("SHAH: %x >> %d = %x _CY: %d _Z: %d _OV: %d _S: %d\n", oldval, count, apph, _CY, _Z, _OV, _S); */
+/*  printf("SHAH: %x >> %d = %x _CY: %d _Z: %d _OV: %d _S: %d\n", oldval, count, apph, _CY, _Z, _OV, _S); */
 
 	F12STOREOP2HALF();
 	F12END();
@@ -1840,12 +1890,12 @@ UINT32 opSHAW(void)
 		if (count >= 32)
 			appw = (appw & 0x80000000) ? 0xFFFFFFFF : 0;
 		else
-			appw = (*(INT32*)&appw) >> count;
+			appw = ((INT32)appw) >> count;
 
 		SetSZPF_Long(appw);
 	}
 
-/*	printf("SHAW: %x >> %d = %x _CY: %d _Z: %d _OV: %d _S: %d\n", oldval, count, appw, _CY, _Z, _OV, _S); */
+/*  printf("SHAW: %x >> %d = %x _CY: %d _Z: %d _OV: %d _S: %d\n", oldval, count, appw, _CY, _Z, _OV, _S); */
 
 	F12STOREOP2WORD();
 	F12END();
@@ -1905,7 +1955,7 @@ UINT32 opSHLB(void) /* TRUSTED */
 		}
 	}
 
-/*	printf("SHLB: %x _CY: %d _Z: %d _OV: %d _S: %d\n", appb, _CY, _Z, _OV, _S); */
+/*  printf("SHLB: %x _CY: %d _Z: %d _OV: %d _S: %d\n", appb, _CY, _Z, _OV, _S); */
 
 	F12STOREOP2BYTE();
 	F12END();
@@ -1922,7 +1972,7 @@ UINT32 opSHLH(void) /* TRUSTED */
 	F12LOADOP2HALF();
 
 	count=(INT8)(f12Op1&0xFF);
-/*	printf("apph: %x count: %d  ", apph, count); */
+/*  printf("apph: %x count: %d  ", apph, count); */
 	if (count>0)
 	{
 		/* left shift flags: */
@@ -1965,7 +2015,7 @@ UINT32 opSHLH(void) /* TRUSTED */
 		}
 	}
 
-/*	printf("SHLH: %x _CY: %d _Z: %d _OV: %d _S: %d\n", apph, _CY, _Z, _OV, _S); */
+/*  printf("SHLH: %x _CY: %d _Z: %d _OV: %d _S: %d\n", apph, _CY, _Z, _OV, _S); */
 
 	F12STOREOP2HALF();
 	F12END();
@@ -2024,7 +2074,7 @@ UINT32 opSHLW(void) /* TRUSTED */
 		}
 	}
 
-/*	printf("SHLW: %x _CY: %d _Z: %d _OV: %d _S: %d\n", appw, _CY, _Z, _OV, _S); */
+/*  printf("SHLW: %x _CY: %d _Z: %d _OV: %d _S: %d\n", appw, _CY, _Z, _OV, _S); */
 
 	F12STOREOP2WORD();
 	F12END();
@@ -2036,7 +2086,9 @@ UINT32 opSTPR(void)
 	if (f12Op1 >= 0 && f12Op1 <= 28)
 		modWriteValW = v60.reg[f12Op1 + 36];
 	else
-		messagebox("Invalid operand on STPR\n");
+	{
+		osd_die("Invalid operand on STPR PC=%x\n", PC);
+	}
 	F12WriteSecondOperand(2);
 	F12END();
 }
@@ -2143,6 +2195,9 @@ UINT32 opUPDPSWW(void)
 {
 	F12DecodeOperands(ReadAM,2,ReadAM,2);
 
+	/* can only modify condition code and control fields */
+	f12Op2 &= 0xFFFFFF;
+	f12Op1 &= 0xFFFFFF;
 	v60WritePSW((v60ReadPSW() & (~f12Op2)) | (f12Op1 & f12Op2));
 
 	F12END();
@@ -2152,6 +2207,7 @@ UINT32 opUPDPSWH(void)
 {
 	F12DecodeOperands(ReadAM,2,ReadAM,2);
 
+	/* can only modify condition code fields */
 	f12Op2 &= 0xFFFF;
 	f12Op1 &= 0xFFFF;
 	v60WritePSW((v60ReadPSW() & (~f12Op2)) | (f12Op1 & f12Op2));
@@ -2262,7 +2318,8 @@ UINT32 opMULX(void)
 		a=MemRead32(f12Op2);
 	}
 
-	res = (INT64)a * (INT64)f12Op1;
+	res = (INT64)a * (INT64)(INT32)f12Op1;
+
 	b = (INT32)((res >> 32)&0xffffffff);
 	a = (INT32)(res&0xffffffff);
 
@@ -2285,7 +2342,7 @@ UINT32 opMULX(void)
 
 UINT32 opMULUX(void)
 {
-	int a,b;
+	INT32 a,b;
 	UINT64 res;
 
 	F12DecodeOperands(ReadAM,2,ReadAMAddress,3);
@@ -2299,7 +2356,7 @@ UINT32 opMULUX(void)
 		a=MemRead32(f12Op2);
 	}
 
-	res = (INT64)a * (INT64)f12Op1;
+	res = (UINT64)a * (UINT64)f12Op1;
 	b = (INT32)((res >> 32)&0xffffffff);
 	a = (INT32)(res&0xffffffff);
 
@@ -2319,4 +2376,3 @@ UINT32 opMULUX(void)
 
 	F12END();
 }
-
