@@ -58,7 +58,7 @@ void F7aDecodeOperands(UINT32 (*DecodeOp1)(void), UINT8 dim1, UINT32 (*DecodeOp2
 	f7aOp1=amOut;
 
 	/* Decode length */
-	appb=MemRead8(PC+2+amLength1);
+	appb=OpRead8(PC+2+amLength1);
 	if (appb&0x80)
 		f7aLenOp1=v60.reg[appb&0x1F];
 	else
@@ -73,7 +73,7 @@ void F7aDecodeOperands(UINT32 (*DecodeOp1)(void), UINT8 dim1, UINT32 (*DecodeOp2
 	f7aOp2=amOut;
 
 	/* Decode length */
-	appb=MemRead8(PC+3+amLength1+amLength2);
+	appb=OpRead8(PC+3+amLength1+amLength2);
 	if (appb&0x80)
 		f7aLenOp2=v60.reg[appb&0x1F];
 	else
@@ -92,7 +92,7 @@ void F7bDecodeFirstOperand(UINT32 (*DecodeOp1)(void), UINT8 dim1)
 	f7bOp1=amOut;
 
 	/* Decode ext */
-	appb=MemRead8(PC+2+amLength1);
+	appb=OpRead8(PC+2+amLength1);
 	if (appb&0x80)
 		f7bLen=v60.reg[appb&0x1F];
 	else
@@ -145,7 +145,7 @@ void F7cDecodeOperands(UINT32 (*DecodeOp1)(void), UINT8 dim1, UINT32 (*DecodeOp2
 	f7cOp2=amOut;
 
 	/* Decode ext */
-	appb=MemRead8(PC+2+amLength1+amLength2);
+	appb=OpRead8(PC+2+amLength1+amLength2);
 	if (appb&0x80)
 		f7cLen=v60.reg[appb&0x1F];
 	else
@@ -316,10 +316,10 @@ UINT32 opMOVSTRUB(UINT8 bFill, UINT8 bStop) /* TRUSTED (0,0) (1,0) */
 	UINT32 i,dest;
 	UINT8 c1;
 
-/*	if (bStop) */
-/*	{ */
-/*		int a=1; */
-/*	} */
+/*  if (bStop) */
+/*  { */
+/*      int a=1; */
+/*  } */
 
 	F7aDecodeOperands(ReadAMAddress,0,ReadAMAddress,0);
 
@@ -386,8 +386,8 @@ UINT32 opMOVSTRUH(UINT8 bFill, UINT8 bStop) /* TRUSTED (0,0) (1,0) */
 	UINT32 i,dest;
 	UINT16 c1;
 
-/*	if (bStop) */
-/*	{	int a=1; } */
+/*  if (bStop) */
+/*  {   int a=1; } */
 
 	F7aDecodeOperands(ReadAMAddress,1,ReadAMAddress,1);
 
@@ -420,13 +420,13 @@ UINT32 opMOVSTRDH(UINT8 bFill, UINT8 bStop)
 	UINT32 i,dest;
 	UINT16 c1;
 
-/*	if (bFill | bStop) */
-/*	{ int a=1; } */
+/*  if (bFill | bStop) */
+/*  { int a=1; } */
 
 	F7aDecodeOperands(ReadAMAddress,1,ReadAMAddress,1);
 
-/*	if (f7aLenOp1 != f7aLenOp2) */
-/*	{ int a=1; } */
+/*  if (f7aLenOp1 != f7aLenOp2) */
+/*  { int a=1; } */
 
 	dest=(f7aLenOp1 < f7aLenOp2 ? f7aLenOp1 : f7aLenOp2);
 
@@ -722,8 +722,8 @@ UINT32 opMOVBSD(void)
 
 	F7bDecodeOperands(BitReadAMAddress,10,BitReadAMAddress,10);
 
-/*	if (f7bLen!=1) */
-/*	{ int a=1; } */
+/*  if (f7bLen!=1) */
+/*  { int a=1; } */
 
 	f7bBamOffset1 += f7bLen-1;
 	f7bBamOffset2 += f7bLen-1;
@@ -831,13 +831,13 @@ UINT32 opADDDC(void)
 
 	if (f7cLen != 0)
 	{
-		logWrite(0, "ADDDC %x (pat: %x)\n", f7cOp1, f7cLen);
+		logerror("ADDDC %x (pat: %x)\n", f7cOp1, f7cLen);
 	}
 
 	F7CLOADOP2BYTE(appb);
 
-	src = (appb >> 4) * 10 + (appb & 0xF);
-	dst = (UINT8)(f7cOp1 >> 4) * 10 + (UINT8)(f7cOp1 & 0xF);
+	src = (UINT8)(f7cOp1 >> 4) * 10 + (UINT8)(f7cOp1 & 0xF);
+	dst = (appb >> 4) * 10 + (appb & 0xF);
 
 	appb = src + dst + (_CY?1:0);
 
@@ -870,16 +870,16 @@ UINT32 opSUBDC(void)
 
 	if (f7cLen != 0)
 	{
-		logWrite(0, "SUBDC %x (pat: %x)\n", f7cOp1, f7cLen);
+		logerror("SUBDC %x (pat: %x)\n", f7cOp1, f7cLen);
 	}
 
 	F7CLOADOP2BYTE(appb);
 
-	src = (appb >> 4) * 10 + (appb & 0xF);
-	dst = (UINT32)(f7cOp1 >> 4) * 10 + (UINT32)(f7cOp1 & 0xF);
+	src = (UINT32)(f7cOp1 >> 4) * 10 + (UINT32)(f7cOp1 & 0xF);
+	dst = ((appb & 0xF0) >> 4) * 10 + (appb & 0xF);
 
 	/* Note that this APPB must be SIGNED! */
-	appb = (INT32)src - (INT32)dst - (_CY?1:0);
+	appb = (INT32)dst - (INT32)src - (_CY?1:0);
 
 	if (appb < 0)
 	{
@@ -903,10 +903,41 @@ UINT32 opSUBDC(void)
 
 UINT32 opSUBRDC(void)
 {
+	INT8 appb;
+	UINT32 src, dst;
+
 	F7cDecodeOperands(ReadAM, 0, ReadAMAddress, 0);
 
-	logWrite(0, "SUBRDC %x (pat: %x)\n", f7cOp1, f7cLen);
+	if (f7cLen != 0)
+	{
+		logerror("SUBRDC %x (pat: %x)\n", f7cOp1, f7cLen);
+	}
 
+	F7CLOADOP2BYTE(appb);
+
+	src = (UINT32)(f7cOp1 >> 4) * 10 + (UINT32)(f7cOp1 & 0xF);
+	dst = ((appb & 0xF0) >> 4) * 10 + (appb & 0xF);
+
+	/* Note that this APPB must be SIGNED! */
+	appb = (INT32)src - (INT32)dst - (_CY?1:0);
+
+	if (appb < 0)
+	{
+		appb += 100;
+		_CY = 1;
+	}
+	else
+		_CY = 0;
+
+	/* compute z flag: */
+	/* cleared if result non-zero or carry generated */
+	/* unchanged otherwise */
+	if (appb != 0 || _CY)
+		_Z = 0;
+
+	appb = ((appb/10)<<4) | (appb % 10);
+
+	F7CSTOREOP2BYTE();
 	F7CEND();
 }
 
@@ -935,13 +966,13 @@ UINT32 opCVTDZP(void)
 	if ((f7cOp1 & 0xF0) != (f7cLen & 0xF0) || ((f7cOp1 >> 8) & 0xF0) != (f7cLen & 0xF0))
 	{
 		/* Decimal exception */
-		logWrite(0, "CVTD.ZP Decimal exception #1!\n");
+		logerror("CVTD.ZP Decimal exception #1!\n");
 	}
 
 	if ((f7cOp1 & 0xF) > 9 || ((f7cOp1 >> 8) & 0xF) > 9)
 	{
 		/* Decimal exception */
-		logWrite(0, "CVTD.ZP Decimal exception #2!\n");
+		logerror("CVTD.ZP Decimal exception #2!\n");
 	}
 
 	appb = (UINT8)(((f7cOp1 >> 8) & 0xF) | ((f7cOp1 & 0xF) << 4));
@@ -953,44 +984,39 @@ UINT32 opCVTDZP(void)
 
 UINT32 op58UNHANDLED(void)
 {
-	logWrite(0, "Unhandled 58 opcode at PC: /%06x\n", PC);
-
-	return 1;
+	osd_die("Unhandled 58 opcode at PC: /%06x\n", PC);
+	return 0; /* never reached, osd_die won't return */
 }
 
 UINT32 op5AUNHANDLED(void)
 {
-	logWrite(0, "Unhandled 5A opcode at PC: /%06x\n", PC);
-
-	return 1;
+	osd_die("Unhandled 5A opcode at PC: /%06x\n", PC);
+	return 0; /* never reached, osd_die won't return */
 }
 
 UINT32 op5BUNHANDLED(void)
 {
-	logWrite(0, "Unhandled 5B opcode at PC: /%06x\n", PC);
-
-	return 1;
+	osd_die("Unhandled 5B opcode at PC: /%06x\n", PC);
+	return 0; /* never reached, osd_die won't return */
 }
 
 UINT32 op5DUNHANDLED(void)
 {
-	logWrite(0, "Unhandled 5D opcode at PC: /%06x\n", PC);
-
-	return 1;
+	osd_die("Unhandled 5D opcode at PC: /%06x\n", PC);
+	return 0; /* never reached, osd_die won't return */
 }
 
 UINT32 op59UNHANDLED(void)
 {
-	logWrite(0, "Unhandled 59 opcode at PC: /%06x\n", PC);
-
-	return 1;
+	osd_die("Unhandled 59 opcode at PC: /%06x\n", PC);
+	return 0; /* never reached, osd_die won't return */
 }
 
 UINT32 (*Op59Table[32])(void) =
 {
 	opADDDC,
 	opSUBDC,
-	op59UNHANDLED,
+	opSUBRDC,
 	op59UNHANDLED,
 	op59UNHANDLED,
 	op59UNHANDLED,
@@ -1118,35 +1144,35 @@ UINT32 (*Op585ATable[32][2])(void) =
 
 UINT32 op58(void)
 {
-	subOp = MemRead8(PC + 1);
+	subOp = OpRead8(PC + 1);
 
 	return Op585ATable[subOp&0x1F][0]();
 }
 
 UINT32 op5A(void)
 {
-	subOp = MemRead8(PC + 1);
+	subOp = OpRead8(PC + 1);
 
 	return Op585ATable[subOp&0x1F][1]();
 }
 
 UINT32 op5B(void)
 {
-	subOp = MemRead8(PC + 1);
+	subOp = OpRead8(PC + 1);
 
 	return Op5BTable[subOp&0x1F]();
 }
 
 UINT32 op5D(void)
 {
-	subOp = MemRead8(PC + 1);
+	subOp = OpRead8(PC + 1);
 
 	return Op5DTable[subOp&0x1F]();
 }
 
 UINT32 op59(void)
 {
-	subOp = MemRead8(PC + 1);
+	subOp = OpRead8(PC + 1);
 
 	return Op59Table[subOp&0x1F]();
 }
