@@ -7,19 +7,21 @@
 #include <stdio.h>
 #include "v60.h"
 
+static UINT8 (*readop)(offs_t adr);
+
 static signed char read8(unsigned pc)
 {
-	return cpu_readmem24lew(pc);
+	return readop(pc);
 }
 
 static signed short read16(unsigned pc)
 {
-	return cpu_readmem24lew(pc) | (cpu_readmem24lew(pc+1) << 8);
+	return readop(pc) | (readop(pc+1) << 8);
 }
 
 static signed int read32(unsigned pc)
 {
-	return cpu_readmem24lew(pc) | (cpu_readmem24lew(pc+1) << 8)| (cpu_readmem24lew(pc+2) << 16)| (cpu_readmem24lew(pc+3) << 24);
+	return readop(pc) | (readop(pc+1) << 8)| (readop(pc+2) << 16)| (readop(pc+3) << 24);
 }
 
 static void out_AM_Register(int reg, char *out)
@@ -174,7 +176,7 @@ static void out_AM_Immediate(unsigned value, int opsize, char *out)
 
 static int decode_AM(unsigned ipc, unsigned pc, int m, int opsize, char *out)
 {
-	unsigned char mod = cpu_readmem24lew(pc);
+	unsigned char mod = readop(pc);
 	if(m) {
 		switch(mod>>5) {
 		case 0: /* Double displacement (8 bit) */
@@ -202,38 +204,38 @@ static int decode_AM(unsigned ipc, unsigned pc, int m, int opsize, char *out)
 			return 1;
 
 		case 6:
-			switch (cpu_readmem24lew(pc+1)>>5)
+			switch (readop(pc+1)>>5)
 				{
 				case 0: /* Displacement indexed (8 bit) */
-					out_AM_DisplacementIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, read8(pc+2), opsize, out);
+					out_AM_DisplacementIndexed(readop(pc+1)&0x1F, mod&0x1F, read8(pc+2), opsize, out);
 					return 3;
 
 				case 1: /* Displacement indexed (16 bit) */
-					out_AM_DisplacementIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, read16(pc+2), opsize, out);
+					out_AM_DisplacementIndexed(readop(pc+1)&0x1F, mod&0x1F, read16(pc+2), opsize, out);
 					return 4;
 
 				case 2: /* Displacement indexed (32 bit) */
-					out_AM_DisplacementIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, read32(pc+2), opsize, out);
+					out_AM_DisplacementIndexed(readop(pc+1)&0x1F, mod&0x1F, read32(pc+2), opsize, out);
 					return 6;
 
 				case 3:	/* Register indirect indexed */
-					out_AM_RegisterIndirectIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, opsize, out);
+					out_AM_RegisterIndirectIndexed(readop(pc+1)&0x1F, mod&0x1F, opsize, out);
 					return 2;
 
 				case 4: /* Displacement indirect indexed (8 bit) */
-					out_AM_DisplacementIndirectIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, read8(pc+2), opsize, out);
+					out_AM_DisplacementIndirectIndexed(readop(pc+1)&0x1F, mod&0x1F, read8(pc+2), opsize, out);
 					return 3;
 
 				case 5: /* Displacement indirect indexed (16 bit) */
-					out_AM_DisplacementIndirectIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, read16(pc+2), opsize, out);
+					out_AM_DisplacementIndirectIndexed(readop(pc+1)&0x1F, mod&0x1F, read16(pc+2), opsize, out);
 					return 4;
 
 				case 6: /* Displacement indirect indexed (32 bit) */
-					out_AM_DisplacementIndirectIndexed(cpu_readmem24lew(pc+1)&0x1F, mod&0x1F, read32(pc+2), opsize, out);
+					out_AM_DisplacementIndirectIndexed(readop(pc+1)&0x1F, mod&0x1F, read32(pc+2), opsize, out);
 					return 6;
 
 				case 7:
-					switch (cpu_readmem24lew(pc+1)&0x1F)
+					switch (readop(pc+1)&0x1F)
 						{
 						case 16: /* PC Displacement Indexed (8 bit) */
 							out_AM_PCDisplacementIndexed(ipc, read8(pc+2), mod&0x1F, opsize, out);
@@ -390,11 +392,11 @@ static int decode_AM(unsigned ipc, unsigned pc, int m, int opsize, char *out)
 
 			case 29: /* PC Double Displacement (16 bit) */
 				out_AM_PCDoubleDisplacement(ipc, read16(pc+1), read16(pc+3), opsize, out);
-				return 3;
+				return 5;
 
 			case 30: /* PC Double Displacement (32 bit) */
 				out_AM_PCDoubleDisplacement(ipc, read32(pc+1), read32(pc+5), opsize, out);
-				return 3;
+				return 9;
 
 			default:
 				strcat(out, "!ERRAM5");
@@ -411,8 +413,8 @@ static int decode_AM(unsigned ipc, unsigned pc, int m, int opsize, char *out)
 
 static int decode_F1(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
-	unsigned char code = cpu_readmem24lew(pc);
-	sprintf(out, "%s ", opnm);
+	unsigned char code = readop(pc);
+	sprintf(out, "%-8s", opnm);
 	if(code & 0x20) {
 		int ret = decode_AM(ipc, pc+1, code & 0x40, opsize1, out + strlen(out)) + 2;
 		strcat(out, ", ");
@@ -428,8 +430,8 @@ static int decode_F1(const char *opnm, int opsize1, int opsize2, unsigned ipc, u
 static int decode_F2(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
 	int ret;
-	unsigned char code = cpu_readmem24lew(pc);
-	sprintf(out, "%s ", opnm);
+	unsigned char code = readop(pc);
+	sprintf(out, "%-8s", opnm);
 	ret = decode_AM(ipc, pc+1, code & 0x40, opsize1, out + strlen(out));
 	strcat(out, ", ");
 	ret += decode_AM(ipc, pc+1+ret, code & 0x20, opsize2, out + strlen(out));
@@ -438,7 +440,7 @@ static int decode_F2(const char *opnm, int opsize1, int opsize2, unsigned ipc, u
 
 static int decode_F1F2(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
-	if(cpu_readmem24lew(pc) & 0x80)
+	if(readop(pc) & 0x80)
 		return decode_F2(opnm, opsize1, opsize2, ipc, pc, out);
 	else
 		return decode_F1(opnm, opsize1, opsize2, ipc, pc, out);
@@ -446,19 +448,19 @@ static int decode_F1F2(const char *opnm, int opsize1, int opsize2, unsigned ipc,
 
 static int decode_F3(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
-	sprintf(out, "%s ", opnm);
-	return decode_AM(ipc, pc, cpu_readmem24lew(pc-1) & 1, opsize1, out + strlen(out)) + 1;
+	sprintf(out, "%-8s", opnm);
+	return decode_AM(ipc, pc, readop(pc-1) & 1, opsize1, out + strlen(out)) + 1;
 }
 
 static int decode_F4a(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
-	sprintf(out, "%s %X", opnm, ipc+read8(pc));
+	sprintf(out, "%-8s%X", opnm, ipc+read8(pc));
 	return 2;
 }
 
 static int decode_F4b(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
-	sprintf(out, "%s %X", opnm, ipc+read16(pc));
+	sprintf(out, "%-8s%X", opnm, ipc+read16(pc));
 	return 3;
 }
 
@@ -470,21 +472,21 @@ static int decode_F5(const char *opnm, int opsize1, int opsize2, unsigned ipc, u
 
 static int decode_F6(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
-	sprintf(out, "%s %s, %X[PC]", opnm, v60_reg_names[cpu_readmem24lew(pc) & 0x1f], ipc+read16(pc+1));
+	sprintf(out, "%-8s%s, %X[PC]", opnm, v60_reg_names[readop(pc) & 0x1f], ipc+read16(pc+1));
 	return 4;
 }
 
 static int decode_F7a(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
 	int ret;
-	unsigned char code = cpu_readmem24lew(pc);
+	unsigned char code = readop(pc);
 	unsigned char code2;
 
-	sprintf(out, "%s ", opnm);
+	sprintf(out, "%-8s", opnm);
 	ret = decode_AM(ipc, pc+1, code & 0x40, opsize1, out + strlen(out));
 	strcat(out, ", ");
 
-	code2 = cpu_readmem24lew(pc+1+ret);
+	code2 = readop(pc+1+ret);
 	if(code2 & 0x80)
 		out_AM_Register(code2 & 0x1f, out + strlen(out));
 	else
@@ -494,7 +496,7 @@ static int decode_F7a(const char *opnm, int opsize1, int opsize2, unsigned ipc,
 	ret += decode_AM(ipc, pc+2+ret, code & 0x20, opsize2, out + strlen(out));
 	strcat(out, ", ");
 
-	code2 = cpu_readmem24lew(pc+2+ret);
+	code2 = readop(pc+2+ret);
 	if(code2 & 0x80)
 		out_AM_Register(code2 & 0x1f, out + strlen(out));
 	else
@@ -506,14 +508,14 @@ static int decode_F7a(const char *opnm, int opsize1, int opsize2, unsigned ipc,
 static int decode_F7b(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
 	int ret;
-	unsigned char code = cpu_readmem24lew(pc);
+	unsigned char code = readop(pc);
 	unsigned char code2;
 
-	sprintf(out, "%s ", opnm);
+	sprintf(out, "%-8s", opnm);
 	ret = decode_AM(ipc, pc+1, code & 0x40, opsize1, out + strlen(out));
 	strcat(out, ", ");
 
-	code2 = cpu_readmem24lew(pc+1+ret);
+	code2 = readop(pc+1+ret);
 	if(code2 & 0x80)
 		out_AM_Register(code2 & 0x1f, out + strlen(out));
 	else
@@ -528,17 +530,17 @@ static int decode_F7b(const char *opnm, int opsize1, int opsize2, unsigned ipc,
 static int decode_F7c(const char *opnm, int opsize1, int opsize2, unsigned ipc, unsigned pc, char *out)
 {
 	int ret;
-	unsigned char code = cpu_readmem24lew(pc);
+	unsigned char code = readop(pc);
 	unsigned char code2;
 
-	sprintf(out, "%s ", opnm);
+	sprintf(out, "%-8s", opnm);
 	ret = decode_AM(ipc, pc+1, code & 0x40, opsize1, out + strlen(out));
 	strcat(out, ", ");
 
 	ret += decode_AM(ipc, pc+1+ret, code & 0x20, opsize2, out + strlen(out));
 	strcat(out, ", ");
 
-	code2 = cpu_readmem24lew(pc+1+ret);
+	code2 = readop(pc+1+ret);
 	if(code2 & 0x80)
 		out_AM_Register(code2 & 0x1f, out + strlen(out));
 	else
@@ -549,6 +551,7 @@ static int decode_F7c(const char *opnm, int opsize1, int opsize2, unsigned ipc,
 
 static int (*dasm_optable[256])(unsigned ipc, unsigned pc, char *out);
 static int (*dasm_optable_58[64])(unsigned ipc, unsigned pc, char *out);
+static int (*dasm_optable_59[64])(unsigned ipc, unsigned pc, char *out);
 static int (*dasm_optable_5A[64])(unsigned ipc, unsigned pc, char *out);
 static int (*dasm_optable_5B[64])(unsigned ipc, unsigned pc, char *out);
 static int (*dasm_optable_5C[64])(unsigned ipc, unsigned pc, char *out);
@@ -560,7 +563,7 @@ static int (*dasm_optable_C7[64])(unsigned ipc, unsigned pc, char *out);
 
 static int dopUNHANDLED(unsigned ipc, unsigned pc, char *out)
 {
-	sprintf(out, "$%02X", cpu_readmem24lew(pc));
+	sprintf(out, "$%02X", readop(pc));
 	return 1;
 }
 
@@ -620,47 +623,52 @@ static int dopC7UNHANDLED(unsigned ipc, unsigned pc, char *out)
 
 static int dop58(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_58[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_58[readop(pc) & 0x1f](ipc, pc, out);
+}
+
+static int dop59(unsigned ipc, unsigned pc, char *out)
+{
+	return dasm_optable_59[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dop5A(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_5A[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_5A[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dop5B(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_5B[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_5B[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dop5C(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_5C[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_5C[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dop5D(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_5D[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_5D[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dop5E(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_5E[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_5E[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dop5F(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_5F[cpu_readmem24lew(pc) & 0x1f](ipc, pc, out);
+	return dasm_optable_5F[readop(pc) & 0x1f](ipc, pc, out);
 }
 
 static int dopC6(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_C6[cpu_readmem24lew(pc) >> 5](ipc, pc, out);
+	return dasm_optable_C6[readop(pc) >> 5](ipc, pc, out);
 }
 
 static int dopC7(unsigned ipc, unsigned pc, char *out)
 {
-	return dasm_optable_C7[cpu_readmem24lew(pc) >> 5](ipc, pc, out);
+	return dasm_optable_C7[readop(pc) >> 5](ipc, pc, out);
 }
 
 #define DEFINE_EASY_OPCODE(name, opnm, ftype, opsize1, opsize2) \
@@ -669,6 +677,12 @@ static int dopC7(unsigned ipc, unsigned pc, char *out)
 		return decode_ ## ftype(opnm, opsize1, opsize2, ipc, pc, out); \
 	}
 
+#define DEFINE_EASY_OPCODE_EX(name, opnm, ftype, opsize1, opsize2, flags) \
+	static int dop ## name(unsigned ipc, unsigned pc, char *out) \
+	{ \
+		return decode_ ## ftype(opnm, opsize1, opsize2, ipc, pc, out) | (flags); \
+	}
+
 #define DEFINE_TRIPLE_OPCODE(name, string, ftype) \
 	DEFINE_EASY_OPCODE(name##B,string ".b", ftype, 0, 0) \
 	DEFINE_EASY_OPCODE(name##H,string ".h", ftype, 1, 1) \
@@ -686,6 +700,7 @@ static int dopC7(unsigned ipc, unsigned pc, char *out)
 DEFINE_FPU_OPCODE(ABSF, "absf", F2)
 DEFINE_TRIPLE_OPCODE(ADD, "add", F1F2)
 DEFINE_TRIPLE_OPCODE(ADDC, "addc", F1F2)
+DEFINE_EASY_OPCODE(ADDDC, "adddc", F7c, 0, 0)
 DEFINE_FPU_OPCODE(ADDF, "addf", F2)
 DEFINE_TRIPLE_OPCODE(AND, "and", F1F2)
 DEFINE_EASY_OPCODE(ANDBSU, "andbsu", F7b, 0x80, 0x80)
@@ -724,8 +739,8 @@ DEFINE_EASY_OPCODE(BR8, "br", F4a, 0, 0)
 DEFINE_EASY_OPCODE(BR16, "br", F4b, 0, 0)
 DEFINE_EASY_OPCODE(BRK, "brk", F5, 0, 0)
 DEFINE_EASY_OPCODE(BRKV, "brkv", F5, 0, 0)
-DEFINE_EASY_OPCODE(BSR, "bsr", F4b, 0, 0)
-DEFINE_EASY_OPCODE(CALL, "call", F1F2, 0, 2)
+DEFINE_EASY_OPCODE_EX(BSR, "bsr", F4b, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(CALL, "call", F1F2, 0, 2, DASMFLAG_STEP_OVER)
 DEFINE_EASY_OPCODE(CAXI, "caxi", F1, 2, 2)
 DEFINE_EASY_OPCODE(CHKAR, "chkar", F1F2, 0, 0) /* ? */
 DEFINE_EASY_OPCODE(CHKAW, "chkaw", F1F2, 0, 0) /* ? */
@@ -748,21 +763,23 @@ DEFINE_EASY_OPCODE(CVTWS, "cvt.ws", F2, 2, 0)
 DEFINE_EASY_OPCODE(CVTWL, "cvt.wl", F2, 2, 1)
 DEFINE_EASY_OPCODE(CVTSW, "cvt.sw", F2, 0, 2)
 DEFINE_EASY_OPCODE(CVTLW, "cvt.lw", F2, 1, 2)
-DEFINE_EASY_OPCODE(DBGT, "dbgt", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBGE, "dbge", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBLT, "dbgt", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBLE, "dbge", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBH, "dbh", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBNL, "dbnl", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBL, "dbl", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBNH, "dbnh", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBE, "dbe", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBNE, "dbne", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBV, "dbe", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBNV, "dbne", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBN, "dbn", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBP, "dbp", F6, 0, 0)
-DEFINE_EASY_OPCODE(DBR, "dbr", F6, 0, 0)
+DEFINE_EASY_OPCODE(CVTDPZ, "cvtd.pz", F7c, 0, 1)
+DEFINE_EASY_OPCODE(CVTDZP, "cvtd.zp", F7c, 1, 0)
+DEFINE_EASY_OPCODE_EX(DBGT, "dbgt", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBGE, "dbge", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBLT, "dbgt", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBLE, "dbge", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBH, "dbh", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBNL, "dbnl", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBL, "dbl", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBNH, "dbnh", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBE, "dbe", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBNE, "dbne", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBV, "dbe", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBNV, "dbne", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBN, "dbn", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBP, "dbp", F6, 0, 0, DASMFLAG_STEP_OVER)
+DEFINE_EASY_OPCODE_EX(DBR, "dbr", F6, 0, 0, DASMFLAG_STEP_OVER)
 DEFINE_TRIPLE_OPCODE(DEC, "dec", F3)
 DEFINE_EASY_OPCODE(DISPOSE, "dispose", F5, 0, 0)
 DEFINE_TRIPLE_OPCODE(DIV, "div", F1F2)
@@ -783,7 +800,7 @@ DEFINE_TRIPLE_OPCODE(INC, "inc", F3)
 DEFINE_EASY_OPCODE(INSBFL, "insbfl", F7c, 2, 0x82)
 DEFINE_EASY_OPCODE(INSBFR, "insbfr", F7c, 2, 0x82)
 DEFINE_EASY_OPCODE(JMP, "jmp", F3, 0, 0)
-DEFINE_EASY_OPCODE(JSR, "jsr", F3, 0, 0)
+DEFINE_EASY_OPCODE_EX(JSR, "jsr", F3, 0, 0, DASMFLAG_STEP_OVER)
 DEFINE_EASY_OPCODE(LDPR, "ldpr", F1F2, 2, 2)
 DEFINE_EASY_OPCODE(LDTASK, "ldtask", F1F2, 2, 2)
 DEFINE_TRIPLE_OPCODE(MOV, "mov", F1F2)
@@ -833,16 +850,16 @@ DEFINE_EASY_OPCODE(PUSH, "push", F3, 2, 0)
 DEFINE_EASY_OPCODE(PUSHM, "pushm", F3, 2, 0)
 DEFINE_TRIPLE_OPCODE(REM, "rem", F1F2)
 DEFINE_TRIPLE_OPCODE(REMU, "remu", F1F2)
-DEFINE_EASY_OPCODE(RET, "ret", F3, 2, 0)
-DEFINE_EASY_OPCODE(RETIU, "retiu", F3, 1, 0)
-DEFINE_EASY_OPCODE(RETIS, "retis", F3, 1, 0)
+DEFINE_EASY_OPCODE_EX(RET, "ret", F3, 2, 0, DASMFLAG_STEP_OUT)
+DEFINE_EASY_OPCODE_EX(RETIU, "retiu", F3, 1, 0, DASMFLAG_STEP_OUT)
+DEFINE_EASY_OPCODE_EX(RETIS, "retis", F3, 1, 0, DASMFLAG_STEP_OUT)
 DEFINE_EASY_OPCODE(ROTB, "rot.b", F1F2, 0, 0)
 DEFINE_EASY_OPCODE(ROTH, "rot.h", F1F2, 0, 1)
 DEFINE_EASY_OPCODE(ROTW, "rot.w", F1F2, 0, 2)
 DEFINE_EASY_OPCODE(ROTCB, "rotc.b", F1F2, 0, 0)
 DEFINE_EASY_OPCODE(ROTCH, "rotc.h", F1F2, 0, 1)
 DEFINE_EASY_OPCODE(ROTCW, "rotc.w", F1F2, 0, 2)
-DEFINE_EASY_OPCODE(RSR, "rsr", F5, 0, 0)
+DEFINE_EASY_OPCODE_EX(RSR, "rsr", F5, 0, 0, DASMFLAG_STEP_OUT)
 DEFINE_EASY_OPCODE(RVBIT, "rvbit", F1F2, 0, 0)
 DEFINE_EASY_OPCODE(RVBYT, "rvbyt", F1F2, 2, 2)
 DEFINE_EASY_OPCODE(SCH0BSU, "sch0bsu", F7b, 0x80, 2)
@@ -871,12 +888,14 @@ DEFINE_EASY_OPCODE(STPR, "stpr", F1F2, 2, 2)
 DEFINE_EASY_OPCODE(STTASK, "sttask", F3, 2, 0)
 DEFINE_TRIPLE_OPCODE(SUB, "sub", F1F2)
 DEFINE_TRIPLE_OPCODE(SUBC, "subc", F1F2)
+DEFINE_EASY_OPCODE(SUBDC, "subdc", F7c, 0, 0)
+DEFINE_EASY_OPCODE(SUBRDC, "subrdc", F7c, 0, 0)
 DEFINE_FPU_OPCODE(SUBF, "subf", F2)
 DEFINE_EASY_OPCODE(TASI, "tasi", F3, 0, 0)
 DEFINE_EASY_OPCODE(TB, "tb", F6, 0, 0)
 DEFINE_TRIPLE_OPCODE(TEST, "test", F3)
 DEFINE_EASY_OPCODE(TEST1, "test1", F1F2, 2, 2)
-DEFINE_EASY_OPCODE(TRAP, "trap", F3, 0, 0)
+DEFINE_EASY_OPCODE_EX(TRAP, "trap", F3, 0, 0, DASMFLAG_STEP_OVER)
 DEFINE_EASY_OPCODE(TRAPFL, "trapfl", F5, 0, 0)
 DEFINE_EASY_OPCODE(UPDATE, "update", F1F2, 0, 3) /* ? */
 DEFINE_EASY_OPCODE(UPDPSWH, "updpsw.h", F1F2, 2, 2)
@@ -898,6 +917,7 @@ void v60_dasm_init(void)
 	for (i=0; i<64; i++)
 	{
 		dasm_optable_58[i] = dop58UNHANDLED;
+		dasm_optable_59[i] = dop58UNHANDLED;
 		dasm_optable_5A[i] = dop5AUNHANDLED;
 		dasm_optable_5B[i] = dop5BUNHANDLED;
 		dasm_optable_5C[i] = dop5CUNHANDLED;
@@ -952,6 +972,12 @@ void v60_dasm_init(void)
 	dasm_optable_5C[0x1B] = dopDIVFS;
 	dasm_optable_5E[0x1B] = dopDIVFL;
 
+	dasm_optable_59[0x00] = dopADDDC;
+	dasm_optable_59[0x01] = dopSUBDC;
+	dasm_optable_59[0x02] = dopSUBRDC;
+	dasm_optable_59[0x10] = dopCVTDPZ;
+	dasm_optable_59[0x18] = dopCVTDZP;
+
 	dasm_optable_5F[0x00] = dopCVTWS;
 	dasm_optable_5F[0x01] = dopCVTSW;
 	dasm_optable_5F[0x08] = dopCVTLS;
@@ -1066,6 +1092,7 @@ void v60_dasm_init(void)
 	dasm_optable[0x54] = dopREMW;
 	dasm_optable[0x55] = dopREMUW;
 	dasm_optable[0x58] = dop58;
+	dasm_optable[0x59] = dop59;
 	dasm_optable[0x5A] = dop5A;
 	dasm_optable[0x5B] = dop5B;
 	dasm_optable[0x5C] = dop5C;
@@ -1217,8 +1244,15 @@ void v60_dasm_init(void)
 }
 
 #ifdef MAME_DEBUG
-unsigned v60_dasm(char *buffer,  unsigned pc)
+offs_t v60_dasm(char *buffer, offs_t pc)
 {
-	return dasm_optable[cpu_readmem24lew(pc)](pc, pc+1, buffer);
+	readop = program_read_byte_16le;
+	return dasm_optable[readop(pc)](pc, pc+1, buffer) | DASMFLAG_SUPPORTED;
+}
+
+offs_t v70_dasm(char *buffer, offs_t pc)
+{
+	readop = program_read_byte_32le;
+	return dasm_optable[readop(pc)](pc, pc+1, buffer) | DASMFLAG_SUPPORTED;
 }
 #endif
