@@ -1,11 +1,13 @@
-#ifndef Z80_H
-#define Z80_H
+#ifndef _Z80_H_
+#define _Z80_H_
 
 #include "cpuintrf.h"
 #include "osd_cpu.h"
 
 enum {
-	Z80_PC=1, Z80_SP, Z80_AF, Z80_BC, Z80_DE, Z80_HL,
+	Z80_PC=1, Z80_SP,
+	Z80_A, Z80_B, Z80_C, Z80_D, Z80_E, Z80_H, Z80_L,
+	Z80_AF, Z80_BC, Z80_DE, Z80_HL,
 	Z80_IX, Z80_IY,	Z80_AF2, Z80_BC2, Z80_DE2, Z80_HL2,
 	Z80_R, Z80_I, Z80_IM, Z80_IFF1, Z80_IFF2, Z80_HALT,
 	Z80_DC0, Z80_DC1, Z80_DC2, Z80_DC3
