@@ -1,12 +1,13 @@
-/*###################################################################################################
-**
-**
-**      debugcmd.c
-**      Debugger command interface engine.
-**      Written by Aaron Giles
-**
-**
-**#################################################################################################*/
+/*********************************************************************
+
+    debugcmd.h
+
+    Debugger command interface engine.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+*********************************************************************/
 
 #include "driver.h"
 #include "debugcmd.h"
@@ -40,6 +41,7 @@ static void execute_out(int ref, int params, const char **param);
 static void execute_go(int ref, int params, const char **param);
 static void execute_go_vblank(int ref, int params, const char **param);
 static void execute_go_interrupt(int ref, int params, const char **param);
+static void execute_go_time(int ref, int params, const char *param[]);
 static void execute_focus(int ref, int params, const char **param);
 static void execute_ignore(int ref, int params, const char **param);
 static void execute_observe(int ref, int params, const char **param);
@@ -59,6 +61,7 @@ static void execute_dasm(int ref, int params, const char **param);
 static void execute_find(int ref, int params, const char **param);
 static void execute_trace(int ref, int params, const char **param);
 static void execute_traceover(int ref, int params, const char **param);
+static void execute_traceflush(int ref, int params, const char **param);
 static void execute_snap(int ref, int params, const char **param);
 static void execute_source(int ref, int params, const char **param);
 static void execute_map(int ref, int params, const char **param);
@@ -77,6 +80,8 @@ static void execute_memdump(int ref, int params, const char **param);
 
 void debug_command_init(void)
 {
+	int cpunum;
+
 	/* add a few simple global functions */
 	symtable_add_function(global_symtable, "min", 0, 2, 2, execute_min);
 	symtable_add_function(global_symtable, "max", 0, 2, 2, execute_max);
@@ -100,6 +105,8 @@ void debug_command_init(void)
 	debug_console_register_command("gv",        CMDFLAG_NONE, 0, 0, 0, execute_go_vblank);
 	debug_console_register_command("gint",      CMDFLAG_NONE, 0, 0, 1, execute_go_interrupt);
 	debug_console_register_command("gi",        CMDFLAG_NONE, 0, 0, 1, execute_go_interrupt);
+	debug_console_register_command("gtime",     CMDFLAG_NONE, 0, 0, 1, execute_go_time);
+	debug_console_register_command("gt",        CMDFLAG_NONE, 0, 0, 1, execute_go_time);
 	debug_console_register_command("next",      CMDFLAG_NONE, 0, 0, 0, execute_next);
 	debug_console_register_command("n",         CMDFLAG_NONE, 0, 0, 0, execute_next);
 	debug_console_register_command("focus",     CMDFLAG_NONE, 0, 1, 1, execute_focus);
@@ -145,6 +152,7 @@ void debug_command_init(void)
 
 	debug_console_register_command("trace",     CMDFLAG_NONE, 0, 1, 3, execute_trace);
 	debug_console_register_command("traceover", CMDFLAG_NONE, 0, 1, 3, execute_traceover);
+	debug_console_register_command("traceflush",CMDFLAG_NONE, 0, 0, 0, execute_traceflush);
 
 	debug_console_register_command("snap",      CMDFLAG_NONE, 0, 0, 1, execute_snap);
 
@@ -154,6 +162,14 @@ void debug_command_init(void)
 	debug_console_register_command("mapd",		CMDFLAG_NONE, ADDRESS_SPACE_DATA, 1, 1, execute_map);
 	debug_console_register_command("mapi",		CMDFLAG_NONE, ADDRESS_SPACE_IO, 1, 1, execute_map);
 	debug_console_register_command("memdump",	CMDFLAG_NONE, 0, 0, 1, execute_memdump);
+
+	for (cpunum = 0; cpunum < cpu_gettotalcpu(); cpunum++)
+	{
+		void (*setup_commands)(void);
+		setup_commands = cpunum_get_info_fct(cpunum, CPUINFO_PTR_DEBUG_SETUP_COMMANDS);
+		if (setup_commands)
+			setup_commands();
+	}
 }
 
 
@@ -550,6 +566,22 @@ static void execute_go_interrupt(int ref, int params, const char *param[])
 }
 
 
+/*-------------------------------------------------
+    execute_go_time - execute the gtime command
+-------------------------------------------------*/
+
+static void execute_go_time(int ref, int params, const char *param[])
+{
+	UINT64 milliseconds = -1;
+
+	/* if we have a parameter, use it instead */
+	if (params > 0 && !validate_parameter_number(param[0], &milliseconds))
+		return;
+
+	debug_cpu_go_milliseconds(milliseconds);
+}
+
+
 /*-------------------------------------------------
     execute_next - execute the next command
 -------------------------------------------------*/
@@ -1146,8 +1178,8 @@ static void execute_save(int ref, int params, const char *param[])
 
 	/* determine the addresses to write */
 	info = debug_get_cpu_info(cpunum);
-	offset = ADDR2BYTE(offset, info, spacenum);
-	endoffset = ADDR2BYTE(offset + length - 1, info, spacenum);
+	offset = ADDR2BYTE_MASKED(offset, info, spacenum);
+	endoffset = ADDR2BYTE_MASKED(offset + length - 1, info, spacenum);
 
 	/* open the file */
 	f = fopen(param[0], "wb");
@@ -1212,8 +1244,8 @@ static void execute_dump(int ref, int params, const char *param[])
 		debug_console_printf("Invalid width! (must be 1,2,4 or 8)");
 		return;
 	}
-	offset = ADDR2BYTE(offset, info, spacenum);
-	endoffset = ADDR2BYTE(offset + length - 1, info, spacenum);
+	offset = ADDR2BYTE_MASKED(offset, info, spacenum);
+	endoffset = ADDR2BYTE_MASKED(offset + length - 1, info, spacenum);
 
 	/* open the file */
 	f = fopen(param[0], "w");
@@ -1231,7 +1263,7 @@ static void execute_dump(int ref, int params, const char *param[])
 		int outdex = 0;
 
 		/* print the address */
-		outdex += sprintf(&output[outdex], "%0*X: ", info->space[spacenum].addrchars, (UINT32)BYTE2ADDR(i, info, spacenum));
+		outdex += sprintf(&output[outdex], "%0*X: ", info->space[spacenum].logchars, (UINT32)BYTE2ADDR(i, info, spacenum));
 
 		/* print the bytes */
 		switch (width)
@@ -1370,8 +1402,8 @@ static void execute_find(int ref, int params, const char *param[])
 		return;
 	}
 	info = debug_get_cpu_info(cpunum);
-	offset = ADDR2BYTE(offset, info, spacenum);
-	endoffset = ADDR2BYTE(offset + length - 1, info, spacenum);
+	offset = ADDR2BYTE_MASKED(offset, info, spacenum);
+	endoffset = ADDR2BYTE_MASKED(offset + length - 1, info, spacenum);
 	cur_data_size = ADDR2BYTE(1, info, spacenum);
 	if (cur_data_size == 0)
 		cur_data_size = 1;
@@ -1436,7 +1468,7 @@ static void execute_find(int ref, int params, const char *param[])
 		if (match)
 		{
 			found++;
-			debug_console_printf("Found at %08X\n", (UINT32)BYTE2ADDR(i, info, spacenum));
+			debug_console_printf("Found at %*X\n", info->space[spacenum].logchars, (UINT32)BYTE2ADDR(i, info, spacenum));
 		}
 	}
 	cpuintrf_pop_context();
@@ -1501,7 +1533,7 @@ static void execute_dasm(int ref, int params, const char *param[])
 	use_new_dasm = (activecpu_get_info_fct(CPUINFO_PTR_DISASSEMBLE_NEW) != NULL);
 	for (i = 0; i < length; )
 	{
-		int pcbyte = ADDR2BYTE(offset + i, info, ADDRESS_SPACE_PROGRAM);
+		int pcbyte = ADDR2BYTE_MASKED(offset + i, info, ADDRESS_SPACE_PROGRAM);
 		char output[200], disasm[200];
 		UINT64 dummyreadop;
 		offs_t tempaddr;
@@ -1509,7 +1541,7 @@ static void execute_dasm(int ref, int params, const char *param[])
 		int numbytes;
 
 		/* print the address */
-		outdex += sprintf(&output[outdex], "%0*X: ", info->space[ADDRESS_SPACE_PROGRAM].addrchars, (UINT32)BYTE2ADDR(pcbyte, info, ADDRESS_SPACE_PROGRAM));
+		outdex += sprintf(&output[outdex], "%0*X: ", info->space[ADDRESS_SPACE_PROGRAM].logchars, (UINT32)BYTE2ADDR(pcbyte, info, ADDRESS_SPACE_PROGRAM));
 
 		/* make sure we can translate the address */
 		tempaddr = pcbyte;
@@ -1535,7 +1567,7 @@ static void execute_dasm(int ref, int params, const char *param[])
 			else
 			{
 				/* get the disassembly up front, but only if mapped */
-				if (memory_get_op_ptr(cpunum, pcbyte) != NULL || (info->readop && (*info->readop)(pcbyte, 1, &dummyreadop)))
+				if (memory_get_op_ptr(cpunum, pcbyte, 0) != NULL || (info->readop && (*info->readop)(pcbyte, 1, &dummyreadop)))
 				{
 					memory_set_opbase(pcbyte);
 					i += numbytes = activecpu_dasm(disasm, offset + i) & DASMFLAG_LENGTHMASK;
@@ -1675,6 +1707,16 @@ static void execute_traceover(int ref, int params, const char *param[])
 }
 
 
+/*-------------------------------------------------
+    execute_traceflush - execute the trace flush command
+-------------------------------------------------*/
+
+static void execute_traceflush(int ref, int params, const char *param[])
+{
+	debug_flush_traces();
+}
+
+
 /*-------------------------------------------------
     execute_snap - execute the trace over command
 -------------------------------------------------*/
@@ -1731,7 +1773,7 @@ static void execute_map(int ref, int params, const char *param[])
 	info = debug_get_cpu_info(cpunum);
 
 	/* do the translation first */
-	taddress = ADDR2BYTE(address, info, spacenum);
+	taddress = ADDR2BYTE_MASKED(address, info, spacenum);
 	if (info->translate)
 	{
 		if ((*info->translate)(spacenum, &taddress))
