@@ -1,12 +1,13 @@
-/*###################################################################################################
-**
-**
-**      debugcmd.c
-**      Debugger help engine.
-**      Written by Aaron Giles
-**
-**
-**#################################################################################################*/
+/*********************************************************************
+
+    debughlp.c
+
+    Debugger help engine.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+*********************************************************************/
 
 #include "driver.h"
 
@@ -528,6 +529,20 @@ static struct help_item static_help_list[] =
 		"  acknowledged on the current CPU.\n"
 		"\n"
 	},
+	{
+		"gtime",
+		"\n"
+		"  gt[ime] <milliseconds>\n"
+		"\n"
+		"The gtime command resumes execution of the current code. Control will not be returned to the\n"
+		"debugger until	a specified delay has elapsed. The delay is in milliseconds.\n"
+		"\n"
+		"Example:\n"
+		"\n"
+		"gtime #10000\n"
+		"  Resume execution for ten seconds\n"
+		"\n"
+	},
 	{
 		"next",
 		"\n"
@@ -659,6 +674,13 @@ static struct help_item static_help_list[] =
 		"  output A=<aval> to the tracelog.\n"
 		"\n"
 	},
+	{
+		"traceflush",
+		"\n"
+		"  traceflush\n"
+		"\n"
+		"Flushes all open trace files.\n"
+	},
 	{
 		"bpset",
 		"\n"
