@@ -1127,7 +1127,7 @@ INPUT_PORTS_START( undoukai )
 INPUT_PORTS_END
 
 
-static gfx_layout char_layout =
+static const gfx_layout char_layout =
 {
 	8,8,
 	0x400,
@@ -1138,7 +1138,7 @@ static gfx_layout char_layout =
 	16*8
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -1154,7 +1154,7 @@ static gfx_layout sprite_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0, &char_layout, 0, 64 },
 	{ REGION_GFX1, 0, &sprite_layout, 0, 64 },
