@@ -46,7 +46,7 @@ static READ8_HANDLER( aeroboto_201_r )
 {
 	/* if you keep a button pressed during boot, the game will expect this */
 	/* serie of values to be returned from 3004, and display "PASS 201" if it is */
-	int res[4] = { 0xff,0x9f,0x1b,0x03};
+	static const UINT8 res[4] = { 0xff,0x9f,0x1b,0x03};
 	static int count;
 	logerror("PC %04x: read 3004\n",activecpu_get_pc());
 	return res[(count++)&3];
