@@ -404,7 +404,7 @@ INPUT_PORTS_START( minesw4p )
 INPUT_PORTS_END
 
 
-static gfx_layout blockade_layout =
+static const gfx_layout blockade_layout =
 {
 	8,8,    /* 8*8 characters */
 	32, /* 32 characters */
@@ -415,7 +415,7 @@ static gfx_layout blockade_layout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout blasto_layout =
+static const gfx_layout blasto_layout =
 {
 	8,8,    /* 8*8 characters */
 	64, /* 64 characters */
@@ -426,13 +426,13 @@ static gfx_layout blasto_layout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &blockade_layout, 0, 1 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode blasto_gfxdecodeinfo[] =
+static const gfx_decode blasto_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &blasto_layout,   0, 1 },
 	{ -1 } /* end of array */
@@ -581,9 +581,9 @@ ROM_START( minesw4p )
     ROM_LOAD_NIB_LOW(  "mineswee.cls", 0x0000, 0x0200, CRC(70959755) SHA1(f62d448742da3fae8bbd96eb3a2714db500cecce) )
 ROM_END
 
-GAMEX( 1976, blockade, 0, blockade, blockade, blockade, ROT0, "Gremlin", "Blockade", GAME_IMPERFECT_SOUND )
-GAMEX( 1976, comotion, 0, comotion, comotion, blockade, ROT0, "Gremlin", "Comotion", GAME_IMPERFECT_SOUND )
-GAMEX( 1978, blasto,   0, blasto,   blasto,   blockade, ROT0, "Gremlin", "Blasto", GAME_IMPERFECT_SOUND )
-GAMEX( 1977, hustle,   0, hustle,   hustle,   blockade, ROT0, "Gremlin", "Hustle", GAME_IMPERFECT_SOUND )
-GAMEX( 1977, mineswpr, 0, blasto,   mineswpr, blockade, ROT0, "Amutech", "Minesweeper", GAME_IMPERFECT_SOUND )
-GAMEX( 1977, minesw4p, 0, blasto,   minesw4p, blockade, ROT0, "Amutech", "Minesweeper (4-Player)", GAME_IMPERFECT_SOUND )
+GAME( 1976, blockade, 0, blockade, blockade, blockade, ROT0, "Gremlin", "Blockade", GAME_IMPERFECT_SOUND )
+GAME( 1976, comotion, 0, comotion, comotion, blockade, ROT0, "Gremlin", "Comotion", GAME_IMPERFECT_SOUND )
+GAME( 1978, blasto,   0, blasto,   blasto,   blockade, ROT0, "Gremlin", "Blasto", GAME_IMPERFECT_SOUND )
+GAME( 1977, hustle,   0, hustle,   hustle,   blockade, ROT0, "Gremlin", "Hustle", GAME_IMPERFECT_SOUND )
+GAME( 1977, mineswpr, 0, blasto,   mineswpr, blockade, ROT0, "Amutech", "Minesweeper", GAME_IMPERFECT_SOUND )
+GAME( 1977, minesw4p, 0, blasto,   minesw4p, blockade, ROT0, "Amutech", "Minesweeper (4-Player)", GAME_IMPERFECT_SOUND )
