@@ -207,7 +207,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout ccastles_spritelayout =
+static const gfx_layout ccastles_spritelayout =
 {
 	8,16,
 	256,
@@ -220,7 +220,7 @@ static gfx_layout ccastles_spritelayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &ccastles_spritelayout,  0, 1 },
 	{ -1 }
@@ -356,6 +356,6 @@ ROM_END
  *
  *************************************/
 
-GAME( 1983, ccastles, 0,        ccastles, ccastles, 0, ROT0, "Atari", "Crystal Castles (version 4)" )
-GAME( 1983, ccastle3, ccastles, ccastles, ccastles, 0, ROT0, "Atari", "Crystal Castles (version 3)" )
-GAME( 1983, ccastle2, ccastles, ccastles, ccastles, 0, ROT0, "Atari", "Crystal Castles (version 2)" )
+GAME( 1983, ccastles, 0,        ccastles, ccastles, 0, ROT0, "Atari", "Crystal Castles (version 4)", 0 )
+GAME( 1983, ccastle3, ccastles, ccastles, ccastles, 0, ROT0, "Atari", "Crystal Castles (version 3)", 0 )
+GAME( 1983, ccastle2, ccastles, ccastles, ccastles, 0, ROT0, "Atari", "Crystal Castles (version 2)", 0 )
