@@ -271,7 +271,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	256,
@@ -282,7 +282,7 @@ static gfx_layout charlayout =
 	16*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	8,16,
 	128,
@@ -294,7 +294,7 @@ static gfx_layout spritelayout =
 	16*16
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,     0,  1 },
 	{ REGION_GFX2, 0, &spritelayout,  32,  1 },
