@@ -53,6 +53,7 @@ write:
 #include "vidhrdw/generic.h"
 #include "sound/sn76477.h"
 #include "sound/custom.h"
+#include "crbaloon.h"
 
 
 extern WRITE8_HANDLER( crbaloon_videoram_w );
@@ -67,9 +68,6 @@ extern VIDEO_UPDATE( crbaloon );
 
 int val06,val08,val0a;
 
-static sound_stream *crbaloon_tone_stream;
-static UINT32 crbaloon_tone_step;
-static UINT32 crbaloon_tone_pos;
 
 static MACHINE_INIT( crbaloon )
 {
@@ -89,44 +87,22 @@ WRITE8_HANDLER( crbaloon_06_w )
 
 	interrupt_enable_w(offset,data & 1);
 
-	/* SOUND STOP high? */
-    if( data & 0x02 )
-	{
+	/* SOUND STOP is really sound enable */
+	sound_global_enable(data & 0x02);
 
-		if( data & 0x08 )
-		{
-			/* enable is connected to EXPLOSION */
-			SN76477_enable_w(0, 1);
-		}
-		else
-		{
-			SN76477_enable_w(0, 0);
-		}
-		if( data & 0x10 )
-		{
-			/* BREATH changes slf_res to 10k (middle of two 10k resistors) */
-			SN76477_set_slf_res(0, RES_K(10));
-			/* it also puts a tantal capacitor agains GND on the output,
-               but this section of the schematics is not readable. */
-		}
-		else
-		{
-			SN76477_set_slf_res(0, RES_K(20));
-		}
+	/* enable is connected to EXPLOSION */
+	SN76477_enable_w(0, (data & 0x08) ? 1 : 0);
 
-		if( data & 0x20 )
-		{
-			/* APPEAR is connected to MIXER B */
-			SN76477_mixer_b_w(0, 1);
-		}
-		else
-		{
-			SN76477_mixer_b_w(0, 4);
-		}
+	/* BREATH changes slf_res to 10k (middle of two 10k resistors) */
+	/* it also puts a tantal capacitor agains GND on the output,
+       but this section of the schematics is not readable. */
+	SN76477_set_slf_res(0, (data & 0x10) ? RES_K(10) : RES_K(20) );
 
-		/* constant: pin1 = hi, pin 28 = lo */
-		SN76477_envelope_w(0, 1);
-	}
+	/* APPEAR is connected to MIXER B */
+	SN76477_mixer_b_w(0, (data & 0x20) ? 1 : 4);
+
+	discrete_sound_w(CRBALOON_MUSIC_EN, data & 0x04);
+	discrete_sound_w(CRBALOON_LAUGH_EN, data & 0x40);
 }
 
 WRITE8_HANDLER( crbaloon_08_w )
@@ -205,13 +181,7 @@ READ8_HANDLER( crbaloon_IN_r )
 
 WRITE8_HANDLER( crbaloon_tone_w )
 {
-	crbaloon_tone_step = 0;
-	if (data && data != 0xff)
-	{
-		double freq = (13630.0 / (256 - data) + (data>=0xea ? 13 : 0))*0.5;
-
-		crbaloon_tone_step = (UINT32)(freq * 65536.0 * 65536.0 / (double)Machine->sample_rate);
-	}
+	discrete_sound_w(CRBALOON_MUSIC_DATA, data);
 }
 
 
@@ -247,7 +217,7 @@ ADDRESS_MAP_END
 
 
 INPUT_PORTS_START( crbaloon )
-	PORT_START_TAG("DSW0")
+	PORT_START_TAG("DSW0") /* 0 */
 	PORT_DIPNAME( 0x01, 0x01, "Test?" )
 	PORT_DIPSETTING(    0x01, "I/O Check?" )
 	PORT_DIPSETTING(    0x00, "RAM Check?" )
@@ -272,7 +242,7 @@ INPUT_PORTS_START( crbaloon )
 	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x00, "Disable" )
 
-	PORT_START_TAG("IN0")
+	PORT_START_TAG("IN0") /* 1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
@@ -282,7 +252,7 @@ INPUT_PORTS_START( crbaloon )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 
-	PORT_START_TAG("DSW1")
+	PORT_START_TAG("DSW1") /* 2 */
 	PORT_BIT( 0x0f, IP_ACTIVE_HIGH, IPT_UNKNOWN )	/* from chip PC3259 */
 	PORT_DIPNAME( 0x10, 0x10, "Invulnerability (Cheat)")
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
@@ -297,7 +267,7 @@ INPUT_PORTS_START( crbaloon )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("IN1")
+	PORT_START_TAG("IN1") /* 3 */
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -309,6 +279,13 @@ INPUT_PORTS_START( crbaloon )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+
+	PORT_START /* 4 */
+	PORT_ADJUSTER(50, "VR2 - Beep")
+
+	PORT_START /* 5 */
+	PORT_ADJUSTER(50, "VR3 - Music")
+
 INPUT_PORTS_END
 
 
@@ -370,38 +347,6 @@ static struct SN76477interface sn76477_interface =
 };
 
 
-static void crbaloon_tone_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int len)
-{
-	stream_sample_t *buffer = outputs[0];
-
-	memset(buffer, 0, len * sizeof(stream_sample_t));
-
-	if (crbaloon_tone_step)
-	{
-		while (len-- > 0)
-		{
-			*buffer++ = crbaloon_tone_pos & 0x80000000 ? 32767 : -32768;
-			crbaloon_tone_pos += crbaloon_tone_step;
-		}
-	}
-}
-
-static void *crbaloon_sh_start(int clock, const struct CustomSound_interface *config)
-{
-	crbaloon_tone_step = 0;
-	crbaloon_tone_pos = 0;
-
-	crbaloon_tone_stream = stream_create(0, 1, Machine->sample_rate, NULL, crbaloon_tone_update);
-
-	return auto_malloc(1);
-}
-
-struct CustomSound_interface crbaloon_custom_interface =
-{
-	crbaloon_sh_start
-};
-
-
 static MACHINE_DRIVER_START( crbaloon )
 
 	/* basic machine hardware */
@@ -432,11 +377,11 @@ static MACHINE_DRIVER_START( crbaloon )
 
 	MDRV_SOUND_ADD(SN76477, 0)
 	MDRV_SOUND_CONFIG(sn76477_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 2.0)
 
-	MDRV_SOUND_ADD(CUSTOM, 0)
-	MDRV_SOUND_CONFIG(crbaloon_custom_interface)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
+	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_CONFIG(crbaloon_discrete_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
