@@ -363,7 +363,7 @@ INPUT_PORTS_START( cybertnk )
 	PORT_BIT( 	  0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
-static gfx_layout tile_8x8x4 =
+static const gfx_layout tile_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -374,7 +374,7 @@ static gfx_layout tile_8x8x4 =
     8*8
 };
 
-static gfx_layout tile_16x16x4 =
+static const gfx_layout tile_16x16x4 =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -385,7 +385,7 @@ static gfx_layout tile_16x16x4 =
     32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_8x8x4,     0x1400, 16 }, /*Pal offset???*/
 	{ REGION_GFX2, 0, &tile_8x8x4,     0,      0x400 },
@@ -543,4 +543,4 @@ ROM_START( cybertnk )
 	ROM_LOAD( "ic30", 0x0260, 0x0020, CRC(2bb6033f) SHA1(eb994108734d7d04f8e293eca21bb3051a63cfe9) )
 ROM_END
 
-GAMEX( 1990, cybertnk,  0,       cybertnk,  cybertnk,  0, ROT0, "Coreland", "Cyber Tank (v1.04)", GAME_NO_SOUND|GAME_NOT_WORKING )
+GAME( 1990, cybertnk,  0,       cybertnk,  cybertnk,  0, ROT0, "Coreland", "Cyber Tank (v1.04)", GAME_NO_SOUND|GAME_NOT_WORKING )
