@@ -141,7 +141,7 @@ INPUT_PORTS_START( dynadice )
 
 INPUT_PORTS_END
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -152,7 +152,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout charlayout2 =
+static const gfx_layout charlayout2 =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -164,7 +164,7 @@ static gfx_layout charlayout2 =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,   0, 1 }, /* 1bpp */
 	{ REGION_GFX2, 0, &charlayout2,  0, 1 }, /* 3bpp */
