@@ -433,12 +433,12 @@ ROM_START( dbldyn )
 	ROM_COPY( REGION_CPU3, 0, 0x018000, 0x08000 )
 
 	ROM_REGION( 0x020000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "9.5k",	    0x004000, 0x4000, CRC(16bec703) SHA1(c3b5311dee0e4750bc4dbce10deb46669179ac6f) ) /* chars */
-	ROM_CONTINUE(           0x000000, 0x4000 )
-	ROM_CONTINUE(           0x008000, 0x8000 )
-	ROM_LOAD( "10.4k",	    0x014000, 0x4000, CRC(719f909d) SHA1(fbe8d8c554caa15a19efc6ac2a3a6857f9ef3feb) )
-	ROM_CONTINUE(           0x010000, 0x4000 )
-	ROM_CONTINUE(           0x008000, 0x8000 )
+	ROM_LOAD( "dd9.5k",	    0x004000, 0x4000, CRC(16bec703) SHA1(c3b5311dee0e4750bc4dbce10deb46669179ac6f) ) /* chars */
+	ROM_CONTINUE(               0x000000, 0x4000 )
+	ROM_CONTINUE(               0x008000, 0x8000 )
+	ROM_LOAD( "dd10.4k",	    0x014000, 0x4000, CRC(719f909d) SHA1(fbe8d8c554caa15a19efc6ac2a3a6857f9ef3feb) )
+	ROM_CONTINUE(               0x010000, 0x4000 )
+	ROM_CONTINUE(               0x008000, 0x8000 )
 
 	ROM_REGION( 0x180000, REGION_GFX2, ROMREGION_DISPOSE )
 	ROM_LOAD( "dd.a2",		0x000000, 0x40000, CRC(598f343f) SHA1(eee794d9d0a92e066f00818bfb63e8ca46bda764) ) /* background */
