@@ -5,6 +5,8 @@ Fast Lane(GX752) (c) 1987 Konami
 Driver by Manuel Abadia <manu@teleline.es>
 
 TODO:
+- is the game playable? How do you end a level?
+- colors don't seem 100% accurate.
 - verify that sound is correct (volume and bank switching)
 
 ***************************************************************************/
@@ -13,29 +15,31 @@ TODO:
 #include "cpu/hd6309/hd6309.h"
 #include "vidhrdw/generic.h"
 #include "vidhrdw/konamiic.h"
+#include "sound/k007232.h"
 
 /* from vidhrdw/fastlane.c */
 extern unsigned char *fastlane_k007121_regs,*fastlane_videoram1,*fastlane_videoram2;
-WRITE_HANDLER( fastlane_vram1_w );
-WRITE_HANDLER( fastlane_vram2_w );
-void fastlane_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom);
-int fastlane_vh_start(void);
-void fastlane_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh);
+WRITE8_HANDLER( fastlane_vram1_w );
+WRITE8_HANDLER( fastlane_vram2_w );
+PALETTE_INIT( fastlane );
+VIDEO_START( fastlane );
+VIDEO_UPDATE( fastlane );
 
-static int fastlane_interrupt(void)
+static INTERRUPT_GEN( fastlane_interrupt )
 {
 	if (cpu_getiloops() == 0)
 	{
-		if (K007121_ctrlram[0][0x07] & 0x02) return HD6309_INT_IRQ;
+		if (K007121_ctrlram[0][0x07] & 0x02)
+			cpunum_set_input_line(0, HD6309_IRQ_LINE, HOLD_LINE);
 	}
 	else if (cpu_getiloops() % 2)
 	{
-		if (K007121_ctrlram[0][0x07] & 0x01) return nmi_interrupt();
+		if (K007121_ctrlram[0][0x07] & 0x01)
+			cpunum_set_input_line(0, INPUT_LINE_NMI, PULSE_LINE);
 	}
-	return ignore_interrupt();
 }
 
-WRITE_HANDLER( k007121_registers_w )
+WRITE8_HANDLER( k007121_registers_w )
 {
 	if (offset < 8)
 		K007121_ctrl_0_w(offset,data);
@@ -43,7 +47,7 @@ WRITE_HANDLER( k007121_registers_w )
 		fastlane_k007121_regs[offset] = data;
 }
 
-static WRITE_HANDLER( fastlane_bankswitch_w )
+static WRITE8_HANDLER( fastlane_bankswitch_w )
 {
 	int bankaddress;
 	unsigned char *RAM = memory_region(REGION_CPU1);
@@ -54,11 +58,10 @@ static WRITE_HANDLER( fastlane_bankswitch_w )
 
 	/* bits 2 & 3 = bank number */
 	bankaddress = 0x10000 + ((data & 0x0c) >> 2) * 0x4000;
-	cpu_setbank(1,&RAM[bankaddress]);
+	memory_set_bankptr(1,&RAM[bankaddress]);
 
 	/* bit 4: bank # for the 007232 (chip 2) */
-	RAM = memory_region(REGION_SOUND2);
-	K007232_bankswitch(1,RAM + 0x40000*((data & 0x10) >> 4),RAM + 0x40000*((data & 0x10) >> 4));
+	K007232_set_bank(1,0 + ((data & 0x10) >> 4),2 + ((data & 0x10) >> 4));
 
 	/* other bits seems to be unused */
 }
@@ -66,60 +69,60 @@ static WRITE_HANDLER( fastlane_bankswitch_w )
 /* Read and write handlers for one K007232 chip:
    even and odd register are mapped swapped */
 
-static READ_HANDLER( fastlane_K007232_read_port_0_r )
+static READ8_HANDLER( fastlane_K007232_read_port_0_r )
 {
 	return K007232_read_port_0_r(offset ^ 1);
 }
-static WRITE_HANDLER( fastlane_K007232_write_port_0_w )
+static WRITE8_HANDLER( fastlane_K007232_write_port_0_w )
 {
 	K007232_write_port_0_w(offset ^ 1, data);
 }
-static READ_HANDLER( fastlane_K007232_read_port_1_r )
+static READ8_HANDLER( fastlane_K007232_read_port_1_r )
 {
 	return K007232_read_port_1_r(offset ^ 1);
 }
-static WRITE_HANDLER( fastlane_K007232_write_port_1_w )
+static WRITE8_HANDLER( fastlane_K007232_write_port_1_w )
 {
 	K007232_write_port_1_w(offset ^ 1, data);
 }
 
 
 
-static MEMORY_READ_START( fastlane_readmem )
-	{ 0x0000, 0x005f, MRA_RAM },
-	{ 0x0800, 0x0800, input_port_2_r }, 	/* DIPSW #3 */
-	{ 0x0801, 0x0801, input_port_5_r }, 	/* 2P inputs */
-	{ 0x0802, 0x0802, input_port_4_r }, 	/* 1P inputs */
-	{ 0x0803, 0x0803, input_port_3_r }, 	/* COINSW */
-	{ 0x0900, 0x0900, input_port_0_r }, 	/* DIPSW #1 */
-	{ 0x0901, 0x0901, input_port_1_r }, 	/* DISPW #2 */
-	{ 0x0d00, 0x0d0d, fastlane_K007232_read_port_0_r },/* 007232 registers (chip 1) */
-	{ 0x0e00, 0x0e0d, fastlane_K007232_read_port_1_r },/* 007232 registers (chip 2) */
-	{ 0x0f00, 0x0f1f, K051733_r },			/* 051733 (protection) */
-	{ 0x1000, 0x1fff, MRA_RAM },			/* Palette RAM/Work RAM */
-	{ 0x2000, 0x3fff, MRA_RAM },			/* Video RAM + Sprite RAM */
-	{ 0x4000, 0x7fff, MRA_BANK1 },			/* banked ROM */
-	{ 0x8000, 0xffff, MRA_ROM },			/* ROM */
-MEMORY_END
+static ADDRESS_MAP_START( fastlane_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x005f) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0800, 0x0800) AM_READ(input_port_2_r) 	/* DIPSW #3 */
+	AM_RANGE(0x0801, 0x0801) AM_READ(input_port_5_r) 	/* 2P inputs */
+	AM_RANGE(0x0802, 0x0802) AM_READ(input_port_4_r) 	/* 1P inputs */
+	AM_RANGE(0x0803, 0x0803) AM_READ(input_port_3_r) 	/* COINSW */
+	AM_RANGE(0x0900, 0x0900) AM_READ(input_port_0_r) 	/* DIPSW #1 */
+	AM_RANGE(0x0901, 0x0901) AM_READ(input_port_1_r) 	/* DISPW #2 */
+	AM_RANGE(0x0d00, 0x0d0d) AM_READ(fastlane_K007232_read_port_0_r)/* 007232 registers (chip 1) */
+	AM_RANGE(0x0e00, 0x0e0d) AM_READ(fastlane_K007232_read_port_1_r)/* 007232 registers (chip 2) */
+	AM_RANGE(0x0f00, 0x0f1f) AM_READ(K051733_r)			/* 051733 (protection) */
+	AM_RANGE(0x1000, 0x1fff) AM_READ(MRA8_RAM)			/* Palette RAM/Work RAM */
+	AM_RANGE(0x2000, 0x3fff) AM_READ(MRA8_RAM)			/* Video RAM + Sprite RAM */
+	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)			/* banked ROM */
+	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)			/* ROM */
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( fastlane_writemem )
-	{ 0x0000, 0x005f, k007121_registers_w, &fastlane_k007121_regs },/* 007121 registers */
-	{ 0x0b00, 0x0b00, watchdog_reset_w },		/* watchdog reset */
-	{ 0x0c00, 0x0c00, fastlane_bankswitch_w },	/* bankswitch control */
-	{ 0x0d00, 0x0d0d, fastlane_K007232_write_port_0_w },	/* 007232 registers (chip 1) */
-	{ 0x0e00, 0x0e0d, fastlane_K007232_write_port_1_w },	/* 007232 registers (chip 2) */
-	{ 0x0f00, 0x0f1f, K051733_w },				/* 051733 (protection) */
-	{ 0x1000, 0x17ff, paletteram_xBBBBBGGGGGRRRRR_swap_w, &paletteram },/* palette RAM */
-	{ 0x1800, 0x1fff, MWA_RAM },				/* Work RAM */
-	{ 0x2000, 0x27ff, fastlane_vram1_w, &fastlane_videoram1 },
-	{ 0x2800, 0x2fff, fastlane_vram2_w, &fastlane_videoram2 },
-	{ 0x3000, 0x3fff, MWA_RAM, &spriteram },	/* Sprite RAM */
-	{ 0x4000, 0xffff, MWA_ROM },				/* ROM/banked ROM */
-MEMORY_END
+static ADDRESS_MAP_START( fastlane_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x005f) AM_WRITE(k007121_registers_w) AM_BASE(&fastlane_k007121_regs)/* 007121 registers */
+	AM_RANGE(0x0b00, 0x0b00) AM_WRITE(watchdog_reset_w)		/* watchdog reset */
+	AM_RANGE(0x0c00, 0x0c00) AM_WRITE(fastlane_bankswitch_w)	/* bankswitch control */
+	AM_RANGE(0x0d00, 0x0d0d) AM_WRITE(fastlane_K007232_write_port_0_w)	/* 007232 registers (chip 1) */
+	AM_RANGE(0x0e00, 0x0e0d) AM_WRITE(fastlane_K007232_write_port_1_w)	/* 007232 registers (chip 2) */
+	AM_RANGE(0x0f00, 0x0f1f) AM_WRITE(K051733_w)				/* 051733 (protection) */
+	AM_RANGE(0x1000, 0x17ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_swap_w) AM_BASE(&paletteram)/* palette RAM */
+	AM_RANGE(0x1800, 0x1fff) AM_WRITE(MWA8_RAM)				/* Work RAM */
+	AM_RANGE(0x2000, 0x27ff) AM_WRITE(fastlane_vram1_w) AM_BASE(&fastlane_videoram1)
+	AM_RANGE(0x2800, 0x2fff) AM_WRITE(fastlane_vram2_w) AM_BASE(&fastlane_videoram2)
+	AM_RANGE(0x3000, 0x3fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)	/* Sprite RAM */
+	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)				/* ROM/banked ROM */
+ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -158,7 +161,7 @@ INPUT_PORTS_START( fastlane )
 	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(	0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -208,26 +211,26 @@ INPUT_PORTS_START( fastlane )
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START	/* PLAYER 1 INPUTS */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER1 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_PLAYER1 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 	PORT_START	/* PLAYER 2 INPUTS */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER2 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_PLAYER2 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
 INPUT_PORTS_END
 
-static struct GfxLayout gfxlayout =
+static const gfx_layout gfxlayout =
 {
 	8,8,
 	0x80000/32,
@@ -238,7 +241,7 @@ static struct GfxLayout gfxlayout =
 	32*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &gfxlayout, 0, 64*16 },
 	{ -1 } /* end of array */
@@ -246,7 +249,7 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
@@ -262,51 +265,53 @@ static void volume_callback1(int v)
 	K007232_set_volume(1,1,0,(v & 0x0f) * 0x11);
 }
 
-static struct K007232_interface k007232_interface =
+static struct K007232_interface k007232_interface_1 =
 {
-	2,			/* number of chips */
-	{ REGION_SOUND1, REGION_SOUND2 },	/* memory regions */
-	{ K007232_VOL(50,MIXER_PAN_CENTER,50,MIXER_PAN_CENTER),
-			K007232_VOL(50,MIXER_PAN_LEFT,50,MIXER_PAN_RIGHT) },	/* volume */
-	{ volume_callback0,  volume_callback1 } /* external port callback */
+	REGION_SOUND1,
+	volume_callback0
 };
 
-static const struct MachineDriver machine_driver_fastlane =
+static struct K007232_interface k007232_interface_2 =
 {
+	REGION_SOUND2,
+	volume_callback1
+};
+
+static MACHINE_DRIVER_START( fastlane )
+
 	/* basic machine hardware */
-	{
-		{
-			CPU_HD6309,
-			3000000,		/* 24MHz/8? */
-			fastlane_readmem,fastlane_writemem,0,0,
-			fastlane_interrupt,16	/* 1 IRQ + ??? NMI (generated by the 007121) */
-		}
-	},
-	60, DEFAULT_60HZ_VBLANK_DURATION,
-	1,
-	0,
+	MDRV_CPU_ADD(HD6309, 3000000)		/* 24MHz/8? */
+	MDRV_CPU_PROGRAM_MAP(fastlane_readmem,fastlane_writemem)
+	MDRV_CPU_VBLANK_INT(fastlane_interrupt,16)	/* 1 IRQ + ??? NMI (generated by the 007121) */
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	/* video hardware */
-	37*8, 32*8, { 0*8, 35*8-1, 2*8, 30*8-1 },
-	gfxdecodeinfo,
-	1024, 1024*16,
-	fastlane_vh_convert_color_prom,
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(37*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 35*8-1, 2*8, 30*8-1)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(1024)
+	MDRV_COLORTABLE_LENGTH(1024*16)
 
-	VIDEO_TYPE_RASTER,
-	0,
-	fastlane_vh_start,
-	0,
-	fastlane_vh_screenrefresh,
+	MDRV_PALETTE_INIT(fastlane)
+	MDRV_VIDEO_START(fastlane)
+	MDRV_VIDEO_UPDATE(fastlane)
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{
-			SOUND_K007232,
-			&k007232_interface
-		}
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface_1)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 0.50)
+
+	MDRV_SOUND_ADD(K007232, 3579545)
+	MDRV_SOUND_CONFIG(k007232_interface_2)
+	MDRV_SOUND_ROUTE(0, "mono", 0.50)
+	MDRV_SOUND_ROUTE(1, "mono", 0.50)
+MACHINE_DRIVER_END
 
 
 /***************************************************************************
@@ -317,23 +322,22 @@ static const struct MachineDriver machine_driver_fastlane =
 
 ROM_START( fastlane )
 	ROM_REGION( 0x21000, REGION_CPU1, 0 ) /* code + banked roms */
-	ROM_LOAD( "752_m02.9h",  0x08000, 0x08000, 0xe1004489 )  /* fixed ROM */
-	ROM_LOAD( "752_e01.10h", 0x10000, 0x10000, 0xff4d6029 )  /* banked ROM */
+	ROM_LOAD( "752_m02.9h",  0x08000, 0x08000, CRC(e1004489) SHA1(615b608d22abc3611f1620503cd6a8c9a6218db8) )  /* fixed ROM */
+	ROM_LOAD( "752_e01.10h", 0x10000, 0x10000, CRC(ff4d6029) SHA1(b5c5d8654ce728300d268628bd3dd878570ba7b8) )  /* banked ROM */
 
 	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "752e04.2i",   0x00000, 0x80000, 0xa126e82d )  /* tiles + sprites */
+	ROM_LOAD( "752e04.2i",   0x00000, 0x80000, CRC(a126e82d) SHA1(6663230c2c36dec563969bccad8c62e3d454d240) )  /* tiles + sprites */
 
 	ROM_REGION( 0x0100, REGION_PROMS, 0 )
-	ROM_LOAD( "752e03.6h",   0x0000, 0x0100, 0x44300aeb )
+	ROM_LOAD( "752e03.6h",   0x0000, 0x0100, CRC(44300aeb) SHA1(580c6e88cbb3b6d8156ea0b9103834f199ec2747) )
 
 	ROM_REGION( 0x20000, REGION_SOUND1, 0 )	/* 007232 data */
-	ROM_LOAD( "752e06.4c",   0x00000, 0x20000, 0x85d691ed ) /* chip 1 */
+	ROM_LOAD( "752e06.4c",   0x00000, 0x20000, CRC(85d691ed) SHA1(7f8d05562a68c75672141fc80ce7e7acb80588b9) ) /* chip 1 */
 
 	ROM_REGION( 0x80000, REGION_SOUND2, 0 )	/* 007232 data */
-	ROM_LOAD( "752e05.12b",  0x00000, 0x80000, 0x119e9cbf ) /* chip 2 */
+	ROM_LOAD( "752e05.12b",  0x00000, 0x80000, CRC(119e9cbf) SHA1(21e3def9ab10b210632df11b6df4699140c473db) ) /* chip 2 */
 ROM_END
 
 
 
-GAMEX( 1987, fastlane, 0, fastlane, fastlane, 0, ROT90, "Konami", "Fast Lane", GAME_NOT_WORKING | GAME_IMPERFECT_COLORS )
-
+GAME( 1987, fastlane, 0, fastlane, fastlane, 0, ROT90, "Konami", "Fast Lane", GAME_IMPERFECT_COLORS )
