@@ -59,17 +59,17 @@ AT08XX03:
 #include "sound/ay8910.h"
 #include "sound/3812intf.h"
 
-static UINT8 *shared_ram, *shared_auxram;
 static UINT8 *hal21_vreg, *hal21_sndfifo;
+static UINT8 *textram;
+static UINT8 *aso_scroll_sync;
 
 /**************************************************************************/
 /* Test Handlers */
 
 static WRITE8_HANDLER( aso_scroll_sync_w )
 {
-	if (data == 0x7f && shared_auxram[0x04d2] & 1) data++;
-
-	shared_auxram[0x04f8] = data;
+	if (data == 0x7f && (program_read_byte(0xdcd2) & 1)) data++;
+	aso_scroll_sync[offset] = data;
 }
 
 static void hal21_sound_scheduler(int mode, int data)
@@ -122,10 +122,6 @@ static void hal21_sound_scheduler(int mode, int data)
 
 /**************************************************************************/
 
-static WRITE8_HANDLER( hal21_videoram_w ){ videoram[offset] = data; }
-static READ8_HANDLER( hal21_spriteram_r ){ return spriteram[offset]; }
-static WRITE8_HANDLER( hal21_spriteram_w ){ spriteram[offset] = data; }
-
 static WRITE8_HANDLER( hal21_vreg0_w ){ hal21_vreg[0] = data; }
 static WRITE8_HANDLER( hal21_vreg1_w ){ hal21_vreg[1] = data; }
 static WRITE8_HANDLER( hal21_vreg2_w ){ hal21_vreg[2] = data; }
@@ -323,7 +319,6 @@ static void aso_draw_sprites( mame_bitmap *bitmap, int scrollx, int scrolly,
 
 VIDEO_UPDATE( aso )
 {
-	UINT8 *ram = memory_region(REGION_CPU1);
 	int attr, msbs, spsy, spsx, bgsy, bgsx, bank, i;
 
 	attr = (int)hal21_vreg[0];
@@ -350,8 +345,8 @@ VIDEO_UPDATE( aso )
 	}
 
 	bank = msbs>>6 & 1;
-	tnk3_draw_text(bitmap, bank, &ram[0xf800]);
-	tnk3_draw_status(bitmap, bank, &ram[0xfc00]);
+	tnk3_draw_text(bitmap, bank, &textram[0]);
+	tnk3_draw_status(bitmap, bank, &textram[0x400]);
 }
 
 
@@ -518,7 +513,7 @@ INPUT_PORTS_END
 
 /**************************************************************************/
 
-static gfx_layout char256 = {
+static const gfx_layout char256 = {
 	8,8,
 	0x100,
 	4,
@@ -528,7 +523,7 @@ static gfx_layout char256 = {
 	256
 };
 
-static gfx_layout char1024 = {
+static const gfx_layout char1024 = {
 	8,8,
 	0x400,
 	4,
@@ -538,7 +533,7 @@ static gfx_layout char1024 = {
 	256
 };
 
-static gfx_layout sprite1024 = {
+static const gfx_layout sprite1024 = {
 	16,16,
 	0x400,
 	3,
@@ -554,7 +549,7 @@ static gfx_layout sprite1024 = {
 	256
 };
 
-static gfx_decode aso_gfxdecodeinfo[] =
+static const gfx_decode aso_gfxdecodeinfo[] =
 {
 	/* colors 512-1023 are currently unused, I think they are a second bank */
 	{ REGION_GFX1, 0, &char256,    128*3,  8 }, /* colors 384..511 */
@@ -565,12 +560,6 @@ static gfx_decode aso_gfxdecodeinfo[] =
 
 /**************************************************************************/
 
-static READ8_HANDLER( shared_auxram_r ) { return shared_auxram[offset]; }
-static WRITE8_HANDLER( shared_auxram_w ) { shared_auxram[offset] = data; }
-
-static READ8_HANDLER( shared_ram_r ) { return shared_ram[offset]; }
-static WRITE8_HANDLER( shared_ram_w ) { shared_ram[offset] = data; }
-
 static READ8_HANDLER( CPUC_ready_r ) { snk_sound_busy_bit = 0; return 0; }
 
 static READ8_HANDLER( hal21_input_port_0_r ) { return input_port_0_r(0) | snk_sound_busy_bit; }
@@ -599,36 +588,25 @@ static INTERRUPT_GEN( hal21_sound_interrupt )
 
 /**************************************************************************/
 
-static ADDRESS_MAP_START( aso_readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(MRA8_RAM)
+static ADDRESS_MAP_START( aso_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM
 	AM_RANGE(0xd000, 0xd000) AM_READ(hal21_soundcommand_r)
 	AM_RANGE(0xe000, 0xe000) AM_READ(CPUC_ready_r)
-	AM_RANGE(0xf000, 0xf000) AM_READ(YM3526_status_port_0_r)
-	AM_RANGE(0xf002, 0xf002) AM_READ(MRA8_NOP) /* unknown read */
-	AM_RANGE(0xf004, 0xf004) AM_READ(MRA8_NOP) /* unknown read */
-	AM_RANGE(0xf006, 0xf006) AM_READ(MRA8_NOP) /* unknown read */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( aso_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(YM3526_control_port_0_w) /* YM3526 #1 control port? */
+	AM_RANGE(0xf000, 0xf000) AM_READWRITE(YM3526_status_port_0_r, YM3526_control_port_0_w) /* YM3526 #1 control port? */
 	AM_RANGE(0xf001, 0xf001) AM_WRITE(YM3526_write_port_0_w)   /* YM3526 #1 write port?  */
+	AM_RANGE(0xf002, 0xf002) AM_READNOP /* unknown read */
+	AM_RANGE(0xf004, 0xf004) AM_READNOP /* unknown read */
+	AM_RANGE(0xf006, 0xf006) AM_READNOP /* unknown read */
 ADDRESS_MAP_END
 
 /**************************************************************************/
 
-static ADDRESS_MAP_START( hal21_readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_READ(MRA8_RAM)
+static ADDRESS_MAP_START( hal21_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x3fff) AM_ROM
+	AM_RANGE(0x8000, 0x87ff) AM_RAM
 	AM_RANGE(0xa000, 0xa000) AM_READ(hal21_soundcommand_r)
 	AM_RANGE(0xc000, 0xc000) AM_READ(CPUC_ready_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hal21_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM)
 	AM_RANGE(0xe000, 0xe000) AM_WRITE(AY8910_control_port_0_w)
 	AM_RANGE(0xe001, 0xe001) AM_WRITE(AY8910_write_port_0_w)
 	AM_RANGE(0xe002, 0xe002) AM_WRITE(hal21_soundack_w) /* bitfielded(0-5) acknowledge write, details unknown */
@@ -636,33 +614,22 @@ static ADDRESS_MAP_START( hal21_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xe009, 0xe009) AM_WRITE(AY8910_write_port_1_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( hal21_readport_sound, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( hal21_sound_portmap, ADDRESS_SPACE_IO, 8 )
 	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x0000, 0x0000) AM_READ(MRA8_NOP) /* external sound ROM detection? */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hal21_writeport_sound, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x0000, 0x0000) AM_WRITE(MWA8_NOP) /* external sound ROM switch? */
+	AM_RANGE(0x0000, 0x0000) AM_NOP				/* external sound ROM detection? */
 ADDRESS_MAP_END
 
 /**************************** ASO/Alpha Mission *************************/
 
-static ADDRESS_MAP_START( aso_readmem_cpuA, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(MRA8_ROM)
+static ADDRESS_MAP_START( aso_cpuA_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xc000) AM_READ(hal21_input_port_0_r) /* coin, start */
 	AM_RANGE(0xc100, 0xc100) AM_READ(input_port_1_r) /* P1 */
 	AM_RANGE(0xc200, 0xc200) AM_READ(input_port_2_r) /* P2 */
+	AM_RANGE(0xc400, 0xc400) AM_WRITE(aso_soundcommand_w)
 	AM_RANGE(0xc500, 0xc500) AM_READ(input_port_3_r) /* DSW1 */
 	AM_RANGE(0xc600, 0xc600) AM_READ(input_port_4_r) /* DSW2 */
-	AM_RANGE(0xc700, 0xc700) AM_READ(snk_cpuB_nmi_trigger_r)
-	AM_RANGE(0xd800, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( aso_writemem_cpuA, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc400, 0xc400) AM_WRITE(aso_soundcommand_w)
-	AM_RANGE(0xc700, 0xc700) AM_WRITE(snk_cpuA_nmi_ack_w)
+	AM_RANGE(0xc700, 0xc700) AM_READWRITE(snk_cpuB_nmi_trigger_r, snk_cpuA_nmi_ack_w)
 	AM_RANGE(0xc800, 0xc800) AM_WRITE(hal21_vreg1_w)
 	AM_RANGE(0xc900, 0xc900) AM_WRITE(hal21_vreg2_w)
 	AM_RANGE(0xca00, 0xca00) AM_WRITE(hal21_vreg3_w)
@@ -671,71 +638,50 @@ static ADDRESS_MAP_START( aso_writemem_cpuA, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xcd00, 0xcd00) AM_WRITE(hal21_vreg6_w)
 	AM_RANGE(0xce00, 0xce00) AM_WRITE(hal21_vreg7_w)
 	AM_RANGE(0xcf00, 0xcf00) AM_WRITE(hal21_vreg0_w)
-	AM_RANGE(0xdcf8, 0xdcf8) AM_WRITE(aso_scroll_sync_w)
-	AM_RANGE(0xd800, 0xdfff) AM_WRITE(MWA8_RAM) AM_BASE(&shared_auxram)
-	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)
-	AM_RANGE(0xe800, 0xf7ff) AM_WRITE(MWA8_RAM) AM_BASE(&videoram)
-	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM) AM_BASE(&shared_ram)
+	AM_RANGE(0xdcf8, 0xdcf8) AM_WRITE(aso_scroll_sync_w) AM_BASE(&aso_scroll_sync)
+	AM_RANGE(0xd800, 0xe7ff) AM_RAM AM_SHARE(2)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_BASE(&spriteram)
+	AM_RANGE(0xe800, 0xf7ff) AM_RAM AM_SHARE(3) AM_BASE(&videoram)
+	AM_RANGE(0xf800, 0xffff) AM_RAM AM_SHARE(1) AM_BASE(&textram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( aso_readmem_cpuB, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc000, 0xc000) AM_READ(snk_cpuA_nmi_trigger_r)
-	AM_RANGE(0xc800, 0xe7ff) AM_READ(shared_auxram_r)
-	AM_RANGE(0xe800, 0xf7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xf800, 0xffff) AM_READ(shared_ram_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( aso_writemem_cpuB, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(snk_cpuB_nmi_ack_w)
-	AM_RANGE(0xc800, 0xd7ff) AM_WRITE(shared_auxram_w)
-	AM_RANGE(0xd800, 0xe7ff) AM_WRITE(hal21_videoram_w)
-	AM_RANGE(0xe800, 0xf7ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xf800, 0xffff) AM_WRITE(shared_ram_w)
+static ADDRESS_MAP_START( aso_cpuB_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc000) AM_READWRITE(snk_cpuA_nmi_trigger_r, snk_cpuB_nmi_ack_w)
+	AM_RANGE(0xc800, 0xd7ff) AM_RAM AM_SHARE(2)
+	AM_RANGE(0xd800, 0xe7ff) AM_RAM AM_SHARE(3)
+	AM_RANGE(0xe800, 0xf7ff) AM_RAM
+	AM_RANGE(0xf800, 0xffff) AM_RAM AM_SHARE(1)
 ADDRESS_MAP_END
 
 /**************************** HAL21 *************************/
 
-static ADDRESS_MAP_START( hal21_readmem_CPUA, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
+static ADDRESS_MAP_START( hal21_cpuA_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0xc000, 0xc000) AM_READ(hal21_input_port_0_r) /* coin, start */
 	AM_RANGE(0xc100, 0xc100) AM_READ(input_port_1_r) /* P1 */
 	AM_RANGE(0xc200, 0xc200) AM_READ(input_port_2_r) /* P2 */
+	AM_RANGE(0xc300, 0xc300) AM_WRITE(hal21_soundcommand_w)
 	AM_RANGE(0xc400, 0xc400) AM_READ(input_port_3_r) /* DSW1 */
 	AM_RANGE(0xc500, 0xc500) AM_READ(input_port_4_r) /* DSW2 */
-	AM_RANGE(0xc700, 0xc700) AM_READ(snk_cpuB_nmi_trigger_r)
-	AM_RANGE(0xe000, 0xefff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xf000, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hal21_writemem_CPUA, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc300, 0xc300) AM_WRITE(hal21_soundcommand_w)
 	AM_RANGE(0xc600, 0xc600) AM_WRITE(hal21_vreg0_w)
-	AM_RANGE(0xc700, 0xc700) AM_WRITE(snk_cpuA_nmi_ack_w)
+	AM_RANGE(0xc700, 0xc700) AM_READWRITE(snk_cpuB_nmi_trigger_r, snk_cpuA_nmi_ack_w)
 	AM_RANGE(0xd300, 0xd300) AM_WRITE(hal21_vreg1_w)
 	AM_RANGE(0xd400, 0xd400) AM_WRITE(hal21_vreg2_w)
 	AM_RANGE(0xd500, 0xd500) AM_WRITE(hal21_vreg3_w)
 	AM_RANGE(0xd600, 0xd600) AM_WRITE(hal21_vreg4_w)
 	AM_RANGE(0xd700, 0xd700) AM_WRITE(hal21_vreg5_w)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)
-	AM_RANGE(0xf000, 0xffff) AM_WRITE(MWA8_RAM) AM_BASE(&shared_ram)
+	AM_RANGE(0xe000, 0xefff) AM_RAM AM_SHARE(2) AM_BASE(&spriteram)
+	AM_RANGE(0xf000, 0xffff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0xf800, 0xffff) AM_RAM AM_BASE(&textram)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( hal21_readmem_CPUB, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc000, 0xcfff) AM_READ(hal21_spriteram_r)
-	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_READ(shared_ram_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hal21_writemem_CPUB, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_WRITE(MWA8_ROM)
+static ADDRESS_MAP_START( hal21_cpuB_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x9fff) AM_ROM
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(snk_cpuB_nmi_ack_w)
-	AM_RANGE(0xc000, 0xcfff) AM_WRITE(hal21_spriteram_w)
-	AM_RANGE(0xd000, 0xdfff) AM_WRITE(MWA8_RAM) AM_BASE(&videoram)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(shared_ram_w)
+	AM_RANGE(0xc000, 0xcfff) AM_RAM AM_SHARE(2)
+	AM_RANGE(0xd000, 0xdfff) AM_RAM AM_BASE(&videoram)
+	AM_RANGE(0xe000, 0xefff) AM_RAM AM_SHARE(1)
 ADDRESS_MAP_END
 
 /**************************************************************************/
@@ -764,16 +710,16 @@ static MACHINE_DRIVER_START( aso )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(aso_readmem_cpuA,aso_writemem_cpuA)
+	MDRV_CPU_PROGRAM_MAP(aso_cpuA_map,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(aso_readmem_cpuB,aso_writemem_cpuB)
+	MDRV_CPU_PROGRAM_MAP(aso_cpuB_map,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
 	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(aso_readmem_sound,aso_writemem_sound)
+	MDRV_CPU_PROGRAM_MAP(aso_sound_map,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_FRAMES_PER_SECOND(60)
@@ -804,17 +750,17 @@ static MACHINE_DRIVER_START( hal21 )
 
 	/* basic machine hardware */
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(hal21_readmem_CPUA,hal21_writemem_CPUA)
+	MDRV_CPU_PROGRAM_MAP(hal21_cpuA_map,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
-	MDRV_CPU_PROGRAM_MAP(hal21_readmem_CPUB,hal21_writemem_CPUB)
+	MDRV_CPU_PROGRAM_MAP(hal21_cpuB_map,0)
 	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
 
 	MDRV_CPU_ADD(Z80, 4000000)
 	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(hal21_readmem_sound,hal21_writemem_sound)
-	MDRV_CPU_IO_MAP(hal21_readport_sound,hal21_writeport_sound)
+	MDRV_CPU_PROGRAM_MAP(hal21_sound_map,0)
+	MDRV_CPU_IO_MAP(hal21_sound_portmap,0)
 	MDRV_CPU_VBLANK_INT(hal21_sound_interrupt,1)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,TIME_IN_HZ(220)) /* music tempo, hand tuned */
 
@@ -985,7 +931,7 @@ ROM_START( alphamis )
 	ROM_LOAD( "up02_f14.rom",  0x800, 0x00400, CRC(c3fd1dd3) SHA1(c48030cc458f0bebea0ffccf3d3c43260da6a7fb) )
 ROM_END
 
-GAMEX( 1985, aso,      0,     aso,   aso,   aso,   ROT270, "SNK", "ASO - Armored Scrum Object", GAME_NO_COCKTAIL )
-GAMEX( 1985, alphamis, aso,   aso,   aso,   aso,   ROT270, "SNK", "Alpha Mission", GAME_NO_COCKTAIL )
-GAMEX( 1985, hal21,    0,     hal21, hal21, hal21, ROT270, "SNK", "HAL21", GAME_IMPERFECT_COLORS | GAME_NO_COCKTAIL )
-GAMEX( 1985, hal21j,   hal21, hal21, hal21, hal21, ROT270, "SNK", "HAL21 (Japan)", GAME_IMPERFECT_COLORS | GAME_NO_COCKTAIL )
+GAME( 1985, aso,      0,     aso,   aso,   aso,   ROT270, "SNK", "ASO - Armored Scrum Object", GAME_NO_COCKTAIL )
+GAME( 1985, alphamis, aso,   aso,   aso,   aso,   ROT270, "SNK", "Alpha Mission", GAME_NO_COCKTAIL )
+GAME( 1985, hal21,    0,     hal21, hal21, hal21, ROT270, "SNK", "HAL21", GAME_IMPERFECT_COLORS | GAME_NO_COCKTAIL )
+GAME( 1985, hal21j,   hal21, hal21, hal21, hal21, ROT270, "SNK", "HAL21 (Japan)", GAME_IMPERFECT_COLORS | GAME_NO_COCKTAIL )
