@@ -2129,30 +2129,30 @@ static int init_common(void)
 
 
 	/* allocate memory for unpacked graphics */
-	if (!(buf = auto_malloc(0x100000))) return(0);
+	buf = auto_malloc(0x100000);
 	gfx_plane02 = buf;
 	gfx_plane13 = buf + 0x80000;
 
 
 	/* allocate memory for render layers */
-	if (!(buf = auto_malloc(SCREEN_BYTESIZE * MAX_LAYERS))) return(0);
+	buf = auto_malloc(SCREEN_BYTESIZE * MAX_LAYERS);
 	for (i=0; i<MAX_LAYERS; buf+=SCREEN_BYTESIZE, i++) render_layer[i] = (WORD*)buf;
 
 
 	/* allocate memory for pre-processed ROMs */
-	if (!(gfx1_base = auto_malloc(0x20000))) return(0);
+	gfx1_base = auto_malloc(0x20000);
 
 
 	/* allocate memory for alpha table */
-	if (!(alpha_table = auto_malloc(sizeof(DWORD) * 0x10000))) return(0);
+	alpha_table = auto_malloc(sizeof(DWORD) * 0x10000);
 
 
 	/* allocate memory for internal palette */
-	if (!(internal_palette = auto_malloc(sizeof(DWORD) * PALETTE_SIZE))) return(0);
+	internal_palette = auto_malloc(sizeof(DWORD) * PALETTE_SIZE);
 
 
 	/* allocate memory for hardware collision list */
-	if (!(collision_list = auto_malloc(MAX_SPRITES))) return(0);;
+	collision_list = auto_malloc(MAX_SPRITES);
 
 
 	/* decrypt main program ROM */
@@ -2225,7 +2225,7 @@ static DRIVER_INIT( halleys )
 /*************************************************************************** */
 /* Game Definitions */
 
-GAMEX( 1984, benberob, 0,       benberob, benberob, benberob, ROT0, "Taito", "Ben Bero Beh (Japan)", GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_COLORS )
-GAMEX( 1986, halleys,  0,       halleys, halleys, halleys,  ROT90, "Taito America Corporation (Coin-It license)", "Halley's Comet (US)", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
-GAMEX( 1986, halleysc, halleys, halleys, halleys, halleys,  ROT90, "Taito Corporation", "Halley's Comet (Japan set 1)", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
-GAMEX( 1986, halleycj, halleys, halleys, halleys, halleys,  ROT90, "Taito Corporation", "Halley's Comet (Japan set 2)", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
+GAME( 1984, benberob, 0,       benberob, benberob, benberob, ROT0, "Taito", "Ben Bero Beh (Japan)", GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_COLORS )
+GAME( 1986, halleys,  0,       halleys, halleys, halleys,  ROT90, "Taito America Corporation (Coin-It license)", "Halley's Comet (US)", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
+GAME( 1986, halleysc, halleys, halleys, halleys, halleys,  ROT90, "Taito Corporation", "Halley's Comet (Japan set 1)", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
+GAME( 1986, halleycj, halleys, halleys, halleys, halleys,  ROT90, "Taito Corporation", "Halley's Comet (Japan set 2)", GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
