@@ -598,7 +598,7 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 /* 8x8x4 tiles */
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -610,7 +610,7 @@ static gfx_layout layout_8x8x4 =
 };
 
 /* 8x8x8 tiles for later games */
-static gfx_layout layout_8x8x8h =
+static const gfx_layout layout_8x8x8h =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -621,7 +621,7 @@ static gfx_layout layout_8x8x8h =
 	32*8		/* char modulo (half char step) */
 };
 
-static gfx_decode gfxdecodeinfo_14220[] =
+static const gfx_decode gfxdecodeinfo_14220[] =
 {
 	{ REGION_GFX1, 0, &layout_8x8x4,    0x0, 0x200 }, /* [0] 4 Bit Tiles */
 	{ REGION_GFX1, 0, &layout_8x8x8h,   0x0,  0x20 }, /* [1] 8 Bit Tiles */
@@ -755,6 +755,6 @@ ROM_START( hyprdelj )
 ROM_END
 
 
-GAME( 1993, hyprduel, 0,        hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan set 1)" )
-GAME( 1993, hyprdelj, hyprduel, hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan set 2)" )
+GAME( 1993, hyprduel, 0,        hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan set 1)", 0 )
+GAME( 1993, hyprdelj, hyprduel, hyprduel, hyprduel, hyprduel, ROT0, "Technosoft", "Hyper Duel (Japan set 2)", 0 )
 
