@@ -79,8 +79,7 @@ VIDEO_START(igs)
 
 	for (i = 0; i < 8; i++)
 	{
-		if ((layer[i] = (UINT8*)auto_malloc(512 * 256)) == 0)
-			return 1;
+		layer[i] = auto_malloc(512 * 256);
 	}
 
 	chmplst2_pen_hi = 0;
@@ -2660,7 +2659,19 @@ SOUND DATA?: "CHINA DRAGON U44"
 
 ROM_START( drgnwrld )
 	ROM_REGION( 0x80000, REGION_CPU1, 0 )
-	ROM_LOAD16_WORD_SWAP( "dwen.bin", 0x00000, 0x80000, CRC(a6daa2b8) SHA1(0cbfd001c1fd82a6385453d1c2a808add67746af) )
+	ROM_LOAD16_WORD_SWAP( "chinadr-v0400.bin", 0x00000, 0x80000, CRC(a6daa2b8) SHA1(0cbfd001c1fd82a6385453d1c2a808add67746af) )
+
+	ROM_REGION( 0x420000, REGION_GFX1, 0 )
+	ROM_LOAD( "d0301", 0x000000, 0x400000, CRC(78ab45d9) SHA1(c326ee9f150d766edd6886075c94dea3691b606d) )
+	ROM_LOAD( "cg",    0x400000, 0x020000, CRC(2dda0be3) SHA1(587b7cab747d4336515c98eb3365341bb6c7e5e4) )
+
+	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_LOAD( "sp", 0x00000, 0x40000, CRC(fde63ce1) SHA1(cc32d2cace319fe4d5d0aa96d7addb2d1def62f2) )
+ROM_END
+
+ROM_START( drgwrld3 )
+	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_LOAD16_WORD_SWAP( "chinadr-v0300.bin", 0x00000, 0x80000, CRC(5ac243e5) SHA1(50cccff0307239187ac2b65331ad2bcc666f8033) )
 
 	ROM_REGION( 0x420000, REGION_GFX1, 0 )
 	ROM_LOAD( "d0301", 0x000000, 0x400000, CRC(78ab45d9) SHA1(c326ee9f150d766edd6886075c94dea3691b606d) )
@@ -2772,7 +2783,7 @@ there are 4 banks of 8 dip switches
 
 ROM_START( vbowl )
 	ROM_REGION( 0x80000, REGION_CPU1, 0 )
-	ROM_LOAD( "v101xcm.u45", 0x00000, 0x80000, BAD_DUMP CRC(a086050f) SHA1(5d044665a786e7f8f60e0474ebe02ecd33e36290) ) /* second half all 00 */
+	ROM_LOAD( "bowlingv101xcm.u45", 0x00000, 0x80000, CRC(ab8e3f1f) SHA1(69159e22559d6a26fe2afafd770aa640c192ba4b) )
 
 	ROM_REGION( 0x800000, REGION_GFX1, 0)
 	ROM_LOAD( "vrbowlng.u69", 0x000000, 0x400000, CRC(b0d339e8) SHA1(a26a5e0202a78e8cdc562b10d64e14eadfa4e115) )
@@ -2846,6 +2857,7 @@ GAME( 1995, chugokur, drgnwrld, chindrag, chindrag, chugokur, ROT0, "IGS / ALTA"
 GAME( 1996, chmplst2, 0,        chmplst2, chmplst2, chmplst2, ROT0, "IGS",        "Long Hu Bang II",                 GAME_IMPERFECT_GRAPHICS )
 GAME( 1996, xymg,     0,        xymg,     xymg,     xymg,     ROT0, "IGS",        "Xing Yen Man Guan (V651C)",       GAME_IMPERFECT_GRAPHICS | GAME_NOT_WORKING )
 GAME( 1996, grtwall,  xymg,     grtwall,  grtwall,  grtwall,  ROT0, "IGS",        "Wan Li Chang Cheng (V638C)",      GAME_IMPERFECT_GRAPHICS )
-GAME( 1996, vbowl,    0,        vbowl,    vbowl,    vbowl,    ROT0, "Alta / IGS", "Virtua Bowling (World, V101XCM)", GAME_NOT_WORKING )
+GAME( 1996, vbowl,    0,        vbowl,    vbowl,    vbowlj,   ROT0, "Alta / IGS", "Virtua Bowling (World, V101XCM)", GAME_NOT_WORKING )
 GAME( 1996, vbowlj,   vbowl,    vbowl,    vbowl,    vbowlj,   ROT0, "Alta / IGS", "Virtua Bowling (Japan, V100JCM)", GAME_IMPERFECT_SOUND )
 GAME( 1997, drgnwrld, 0,        chindrag, drgnwrld, drgnwrld, ROT0, "IGS",        "Dragon World (World, V0400)",     0 )
+GAME( 1995, drgwrld3, drgnwrld, chindrag, drgnwrld, drgnwrld, ROT0, "IGS",        "Dragon World (World, V0300)",     0 )
