@@ -601,7 +601,7 @@ INPUT_PORTS_END
 
 /******************************************************************************/
 
-static gfx_layout chars =
+static const gfx_layout chars =
 {
 	8,8,
 	1024,
@@ -612,7 +612,7 @@ static gfx_layout chars =
 	8*8	/* every sprite takes 8 consecutive bytes */
 };
 
-static gfx_layout sprites =
+static const gfx_layout sprites =
 {
 	16,16,
 	4096,
@@ -626,7 +626,7 @@ static gfx_layout sprites =
 
 
 /* 16x16 tiles, 4 Planes, each plane is 0x10000 bytes */
-static gfx_layout tiles =
+static const gfx_layout tiles =
 {
 	16,16,
 	2048,
@@ -638,7 +638,7 @@ static gfx_layout tiles =
 	16*16
 };
 
-static gfx_decode karnov_gfxdecodeinfo[] =
+static const gfx_decode karnov_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &chars,     0,  4 },	/* colors 0-31 */
 	{ REGION_GFX2, 0, &tiles,   512, 16 },	/* colors 512-767 */
@@ -1024,9 +1024,9 @@ static DRIVER_INIT( chelnovj )
 
 /******************************************************************************/
 
-GAME( 1987, karnov,   0,       karnov,   karnov,  karnov,   ROT0,   "Data East USA",         "Karnov (US)" )
-GAME( 1987, karnovj,  karnov,  karnov,   karnov,  karnovj,  ROT0,   "Data East Corporation", "Karnov (Japan)" )
-GAME( 1987, wndrplnt, 0,       wndrplnt, wndrplnt,wndrplnt, ROT270, "Data East Corporation", "Wonder Planet (Japan)" )
-GAME( 1988, chelnov,  0,       karnov,   chelnov, chelnovw, ROT0,   "Data East Corporation", "Chelnov - Atomic Runner (World)" )
-GAME( 1988, chelnovu, chelnov, karnov,   chelnov, chelnov,  ROT0,   "Data East USA",         "Chelnov - Atomic Runner (US)" )
-GAME( 1988, chelnovj, chelnov, karnov,   chelnov, chelnovj, ROT0,   "Data East Corporation", "Chelnov - Atomic Runner (Japan)" )
+GAME( 1987, karnov,   0,       karnov,   karnov,  karnov,   ROT0,   "Data East USA",         "Karnov (US)", 0 )
+GAME( 1987, karnovj,  karnov,  karnov,   karnov,  karnovj,  ROT0,   "Data East Corporation", "Karnov (Japan)", 0 )
+GAME( 1987, wndrplnt, 0,       wndrplnt, wndrplnt,wndrplnt, ROT270, "Data East Corporation", "Wonder Planet (Japan)", 0 )
+GAME( 1988, chelnov,  0,       karnov,   chelnov, chelnovw, ROT0,   "Data East Corporation", "Chelnov - Atomic Runner (World)", 0 )
+GAME( 1988, chelnovu, chelnov, karnov,   chelnov, chelnov,  ROT0,   "Data East USA",         "Chelnov - Atomic Runner (US)", 0 )
+GAME( 1988, chelnovj, chelnov, karnov,   chelnov, chelnovj, ROT0,   "Data East Corporation", "Chelnov - Atomic Runner (Japan)", 0 )
