@@ -569,7 +569,7 @@ INPUT_PORTS_END
 
 /* GFX Decodes ***************************************************************/
 
-static gfx_layout fg816_charlayout =
+static const gfx_layout fg816_charlayout =
 {
 	8,16,
 	RGN_FRAC(1,4),
@@ -581,7 +581,7 @@ static gfx_layout fg816_charlayout =
 	16*8
 };
 
-static gfx_layout bg1632_charlayout =
+static const gfx_layout bg1632_charlayout =
 {
 	16,32,
 	RGN_FRAC(1,4),
@@ -593,7 +593,7 @@ static gfx_layout bg1632_charlayout =
 	16*16
 };
 
-static gfx_layout bg3264_charlayout =
+static const gfx_layout bg3264_charlayout =
 {
 	32,64,
 	RGN_FRAC(1,4),
@@ -609,7 +609,7 @@ static gfx_layout bg3264_charlayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &fg816_charlayout,   0x000, 0x40 },
 	{ REGION_GFX1, 0, &bg1632_charlayout,  0x000, 0x40 },
@@ -617,7 +617,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_layout actionhw_fg88_alt_charlayout =
+static const gfx_layout actionhw_fg88_alt_charlayout =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -629,7 +629,7 @@ static gfx_layout actionhw_fg88_alt_charlayout =
 };
 
 
-static gfx_layout actionhw_bg1616_charlayout =
+static const gfx_layout actionhw_bg1616_charlayout =
 {
 	16,16,
 	RGN_FRAC(1,4),
@@ -643,7 +643,7 @@ static gfx_layout actionhw_bg1616_charlayout =
 
 
 
-static gfx_decode actionhw_gfxdecodeinfo[] =
+static const gfx_decode actionhw_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &actionhw_fg88_alt_charlayout,   0x000, 0x40 },
 	{ REGION_GFX1, 0, &actionhw_bg1616_charlayout,  0x000, 0x40 },
@@ -728,7 +728,7 @@ MACHINE_DRIVER_END
 /* Rom Loading ***************************************************************/
 
 ROM_START( kickgoal )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )	/* 68000 code */
+	ROM_REGION( 0x100000, REGION_CPU1, 0 )	/* 68000 code */
 	ROM_LOAD16_BYTE( "ic6",   0x000000, 0x40000, CRC(498ca792) SHA1(c638c3a1755870010c5961b58bcb02458ff4e238) )
 	ROM_LOAD16_BYTE( "ic5",   0x000001, 0x40000, CRC(d528740a) SHA1(d56a71004aabc839b0833a6bf383e5ef9d4948fa) )
 
@@ -799,5 +799,5 @@ DRIVER_INIT( kickgoal )
 }
 
 
-GAMEX( 1995, kickgoal,0, kickgoal, kickgoal, kickgoal, ROT0, "TCH", "Kick Goal", GAME_NO_SOUND )
-GAMEX( 1995, actionhw,0, actionhw, kickgoal, kickgoal, ROT0, "TCH", "Action Hollywood", GAME_IMPERFECT_SOUND )
+GAME( 1995, kickgoal,0, kickgoal, kickgoal, kickgoal, ROT0, "TCH", "Kick Goal", GAME_NO_SOUND )
+GAME( 1995, actionhw,0, actionhw, kickgoal, kickgoal, ROT0, "TCH", "Action Hollywood", GAME_IMPERFECT_SOUND )
