@@ -420,7 +420,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8*8 characters */
 	512,   /* 1024 characters */
@@ -431,7 +431,7 @@ static gfx_layout charlayout =
 	8*8     /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,	/* 16*16 chars */
 	1024, 	/* 1024 characters */
@@ -445,7 +445,7 @@ static gfx_layout spritelayout =
 	16*8
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,	/* 16*16 chars */
 	512,	/* 512 characters */
@@ -459,7 +459,7 @@ static gfx_layout tilelayout =
 	16*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &charlayout,   256,  8 },	/* characters */
 	{ REGION_GFX1, 0x01000, &charlayout,   256,  8 },	/* characters */
@@ -469,7 +469,7 @@ static gfx_decode gfxdecodeinfo[] =
 };
 
 /* Ring King */
-static gfx_layout rk_charlayout1 =
+static const gfx_layout rk_charlayout1 =
 {
 	8,8,    /* 8*8 characters */
 	512,   /* 1024 characters */
@@ -480,7 +480,7 @@ static gfx_layout rk_charlayout1 =
 	8*8     /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout rk_charlayout2 =
+static const gfx_layout rk_charlayout2 =
 {
 	8,8,    /* 8*8 characters */
 	512,   /* 1024 characters */
@@ -491,7 +491,7 @@ static gfx_layout rk_charlayout2 =
 	8*8     /* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout rk_spritelayout =
+static const gfx_layout rk_spritelayout =
 {
 	16,16,	/* 16*16 chars */
 	1024, 	/* 1024 characters */
@@ -504,7 +504,7 @@ static gfx_layout rk_spritelayout =
 	32*8
 };
 
-static gfx_layout rk_tilelayout =
+static const gfx_layout rk_tilelayout =
 {
 	16,16,	/* 16*16 chars */
 	512, 	/* 1024 characters */
@@ -517,7 +517,7 @@ static gfx_layout rk_tilelayout =
 	32*8
 };
 
-static gfx_layout rk_bglayout =
+static const gfx_layout rk_bglayout =
 {
 	16,16,	/* 16*16 chars */
 	256, 	/* 1024 characters */
@@ -531,7 +531,7 @@ static gfx_layout rk_bglayout =
 };
 
 
-static gfx_decode rk_gfxdecodeinfo[] =
+static const gfx_decode rk_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x00000, &rk_charlayout1,  256,  8 },	/* characters */
 	{ REGION_GFX1, 0x00000, &rk_charlayout2,  256,  8 },	/* characters */
@@ -892,8 +892,8 @@ static DRIVER_INIT( ringkinw )
 
 
 
-GAME( 1985, kingofb,  0,       kingofb,  kingofb,  0,        ROT90, "Woodplace", "King of Boxer (English)" )
-GAME( 1985, ringking, kingofb, ringking, ringking, 0,        ROT90, "Data East USA", "Ring King (US set 1)" )
-GAME( 1985, ringkin2, kingofb, ringking, ringking, 0,        ROT90, "Data East USA", "Ring King (US set 2)" )
-GAME( 1985, ringkin3, kingofb, kingofb,  kingofb,  ringkin3, ROT90, "Data East USA", "Ring King (US set 3)" )
-GAME( 1985, ringkinw, kingofb, kingofb,  kingofb,  ringkinw, ROT90, "Woodplace", "Ring King (US, Woodplace license)" )
+GAME( 1985, kingofb,  0,       kingofb,  kingofb,  0,        ROT90, "Woodplace", "King of Boxer (English)", 0 )
+GAME( 1985, ringking, kingofb, ringking, ringking, 0,        ROT90, "Data East USA", "Ring King (US set 1)", 0 )
+GAME( 1985, ringkin2, kingofb, ringking, ringking, 0,        ROT90, "Data East USA", "Ring King (US set 2)", 0 )
+GAME( 1985, ringkin3, kingofb, kingofb,  kingofb,  ringkin3, ROT90, "Data East USA", "Ring King (US set 3)", 0 )
+GAME( 1985, ringkinw, kingofb, kingofb,  kingofb,  ringkinw, ROT90, "Woodplace", "Ring King (US, Woodplace license)", 0 )
