@@ -168,7 +168,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout pfmolayout =
+static const gfx_layout pfmolayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -180,7 +180,7 @@ static gfx_layout pfmolayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &pfmolayout,  256, 16 },		/* sprites & playfield */
 	{ REGION_GFX2, 0, &pfmolayout,    0, 16 },		/* sprites & playfield */
