@@ -578,7 +578,7 @@ static MACHINE_INIT( lethalen )
 	memory_set_bankptr(1, &prgrom[0x10000]);
 	memory_set_bankptr(2, &prgrom[0x48000]);
 }
-static gfx_layout lethal_6bpp =
+static const gfx_layout lethal_6bpp =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -592,7 +592,7 @@ static gfx_layout lethal_6bpp =
 };
 
 /* we use this decode instead of the one done by the sprite video start due to it being 6bpp */
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0, &lethal_6bpp,   0x000/*0x400*/, 256  }, /* sprites tiles */
 	{ -1 } /* end of array */
@@ -720,5 +720,5 @@ static DRIVER_INIT( lethalen )
 	state_save_register_int("LE", 0, "control2", &cur_control2);
 }
 
-GAMEX( 1992, lethalen, 0,        lethalen, lethalen, lethalen, ORIENTATION_FLIP_Y, "Konami", "Lethal Enforcers (ver UAE)", GAME_IMPERFECT_GRAPHICS)
-GAMEX( 1992, lethalej, lethalen, lethalej, lethalen, lethalen, ORIENTATION_FLIP_X, "Konami", "Lethal Enforcers (ver JAD)", GAME_NOT_WORKING)
+GAME( 1992, lethalen, 0,        lethalen, lethalen, lethalen, ORIENTATION_FLIP_Y, "Konami", "Lethal Enforcers (ver UAE)", GAME_IMPERFECT_GRAPHICS)
+GAME( 1992, lethalej, lethalen, lethalej, lethalen, lethalen, ORIENTATION_FLIP_X, "Konami", "Lethal Enforcers (ver JAD)", GAME_NOT_WORKING)
