@@ -304,7 +304,7 @@ INPUT_PORTS_START( magmax )
 INPUT_PORTS_END
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8, 8,	/* 8*8 characters */
 	256,	/* 256 characters */
@@ -315,7 +315,7 @@ static gfx_layout charlayout =
 	32*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16, 16,	/* 16*16 characters */
 	512,	/* 512 characters */
@@ -328,7 +328,7 @@ static gfx_layout spritelayout =
 	64*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,           0,  1 }, /*no color codes*/
 	{ REGION_GFX2, 0, &spritelayout,      1*16, 16 }, /*16 color codes*/
