@@ -218,22 +218,21 @@ INPUT_PORTS_START( matmania )
 	PORT_DIPSETTING(   0x02, DEF_STR( Medium ) )
 	PORT_DIPSETTING(   0x01, DEF_STR( Hard ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( Hardest ) )
-	PORT_DIPNAME(0x04, 0x04, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(   0x04, DEF_STR( Off ) )
-	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x08, 0x08, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(   0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x10, 0x10, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x0c, 0x0c, "Tournament Time" )    /* Tournament time is always 3:00, but time per 1 second is shorter. */
+	PORT_DIPSETTING(   0x00, "2:12" )
+	PORT_DIPSETTING(   0x04, "2:24" )
+	PORT_DIPSETTING(   0x08, "2:30" )
+	PORT_DIPSETTING(   0x0c, "2:36" )
+	PORT_DIPNAME(0x10, 0x10, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x20, 0x20, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x20, 0x20, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x40, 0x40, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x40, 0x40, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x80, 0x80, DEF_STR( Unknown ) )
+	PORT_DIPNAME(0x80, 0x80, DEF_STR( Unused ) )
 	PORT_DIPSETTING(   0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( On ) )
 
@@ -251,7 +250,7 @@ INPUT_PORTS_START( matmania )
 	PORT_DIPNAME(0x10, 0x10, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(   0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(   0x10, DEF_STR( On ) )
-	PORT_DIPNAME(0x20, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPNAME(0x20, 0x00, DEF_STR( Cabinet ) )    /* The default setting should be cocktail. */
 	PORT_DIPSETTING(   0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(   0x20, DEF_STR( Cocktail ) )
 	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
