@@ -17,7 +17,6 @@
     - Fix additional sound bugs
     - Emulate extra chips - superfx, dsp2, sa-1 etc.
     - Add horizontal mosaic, hi-res. interlaced etc to video emulation.
-    - Add support for fullgraphic mode(partially done).
     - Fix support for Mode 7. (In Progress)
     - Handle interleaved roms (maybe even multi-part roms, but how?)
     - Add support for running at 3.58Mhz at the appropriate time.
@@ -28,6 +27,270 @@
   There is a second processor and Menu system for selecting the games
   controlling timer etc.? which still needs emulating there are dipswitches too
 
+***************************************************************************
+
+Nintendo Super System Hardware Overview
+Nintendo, 1992
+
+This system is basically a Super Nintendo with a timer.
+The main board has 3 slots on it and can accept up to 3 plug-in carts. The player
+can choose to play any of the available games, although I'm not sure why anyone
+would have wanted to pay money to play these games when the home SNES was selling as well ;-)
+The control panel was also just some SNES pads mounted into the arcade machine control panel....
+not very usable as-is and very cheaply presented.
+
+
+PCB Layouts
+-----------
+NSS-01-CPU MADE IN JAPAN
+(C) 1991 Nintendo
+|----------------------------------------------------|
+|           HA13001             AN5836               |
+|     SL4          SL2  CL2          SL3             |
+|-|                CL1  SL1                          |
+  |         |--------------|                         |
+|-|        14.31818MHz     |         SL5             |
+|           |              |                         |
+|   IR3P32A |         M50458          |-|  |-|  |-|  |
+|J          | VC1         21.47724MHz | |  | |  | |  |
+|A          |              |          | |  | |  | |  |
+|M          |   CN6        |          | |  | |  | |  |
+|M          |--------------|          | |  | |  | |  |
+|A             |-------|   |-------|  | |  | |  | |  |
+|      84256   |S-PPU1 |   |S-CPU  |  | |  | |  | |  |
+|              |5C77-01|   |5A22-02|  | |  | |  | |  |
+|-|            |-------|   |-------|  | |  | |  | |  |
+  |                                   | |  | |  | |  |
+|-|            |-------|   |-------|  | |  | |  | |  |
+|      84256   |S-PPU2 |   |S-WRAM |  | |  | |  | |  |
+|CN4           |5C78-01|   |LH68120|  | |  | |  | |  |
+|              |-------|   |-------|  | |  | |  | |  |
+|                                     | |  | |  | |  |
+|                                     | |  | |  | |  |
+|CN3                                  | |  | |  | |  |
+|                             4MHz    | |  | |  | |  |
+|                                     |-|  |-|  |-|  |
+|                                    CN11 CN12  CN13 |
+|                             Z84C0006               |
+|CN5                                      LH5168     |
+|                                                    |
+|                M6M80011                            |
+|                                                    |
+|                               S-3520               |
+|CN2                       32.678kHz   *MM1026       |
+|                               5.5V    NSS-C_IC14_02|
+|----------------------------------------------------|
+Notes:
+      (The main board has many surface mounted logic chips and transistors on the lower side of the PCB
+       which are not documented here. There's also a lot of custom Nintendo parts)
+      IR3P32A - Sharp IR3P32A Special Function TV Interface Circuit, Conversion of color diff sig. & lumin. to RGB (NDIP30)
+      M50458  - Mitsubishi M50458-001SP On-Screen Display (OSD) Chip (NDIP32)
+      HA13001 - Hitachi Dual 5.5W Power Amplifier IC
+      AN5836  - Matsushita AN5836 DC Volume and Tone Control IC (SIL12)
+      84256   - Fujitsu MB84256-10L 32k x8 SRAM (SOP28)
+      LH5168  - Sharp LH5168N-10L 8k x8 SRAM (SOP28)
+      Z84C0006- Zilog Z84C0006FEC Z80 CPU, clock input 4.000MHz (QFP44)
+      M6M80011- Mitsubishi M6M80011 64 x16 Serial EEPROM (DIP8). Pinout..... 1 CS, 2 CLK, 3 DATA IN, 4 DATA OUT, 5 VSS, 6 RESET, 7 RDY, 8 VCC
+      S-3520  - Seiko Epson S-3520 Real Time Clock (SOIC14)
+      5.5V    - 5.5 volt supercap
+      MM1026  - Mitsumi Monolithic IC MM1026BF System Reset with Battery Backup (SOIC8)
+      VSync   - 60Hz
+      HSync   - 15.57kHz
+      *       - This IC located underneath PCB
+      NSS-C_IC14_02 - 27C256 EPROM (DIP28)
+      CN11/12/13    - 50 pin connectors for game carts
+      CN2           - 10 pin connector
+      CN3           - 13 pin connector
+      CN4           - 8 pin connector
+      CN5           - 7 pin connector
+      CN6           - 24 pin connector for plug in custom sound module
+      Custom IC's -
+                   S-CPU (QFP100)
+                   S-PPU1 (QFP100)
+                   S-PPU2 (QFP100)
+                   S-WRAM (SOP64)
+
+
+Custom Sound Module (plugs in CN6)
+----------------------------------
+
+Note - This board is encased in a metal shield which is soldered together.
+
+MITSUMI ELEC CO. LTD.
+(C) 1990 Nintendo Co. Ltd.
+|-----------------------|
+|  CN1                  |
+|            JRC2904    |---|
+|  |-------|                |
+|  |S-SMP  |                |
+|  |       |  D6376         |
+|  |-------|         51832  |
+|                           |
+|  |-------|                |
+|  |S-DSP  |                |
+|  |       |     51832      |
+|  |-------|                |
+|---|                       |
+    |                       |
+    |-----------------------|
+Notes:
+      JRC2904 - Japan Radio Co. JRC2904 Dual Low Power Op Amp (SOIC8)
+      D6376   - NEC D6376 Audio 2-Channel 16-Bit D/A Converter (SOIC16)
+      51832   - Toshiba TC51832FL-12 32k x8 SRAM (SOP28)
+      CN1     - 24 pin connector to plug in custom sound module to main board
+      S-SMP   - Stamped 'Nintendo S-SMP (M) SONY (C) Nintendo '89' custom sound chip (QFP80)
+      S-DSP   - Stamped 'Nintendo S-DSP (M) (C) SONY '89' custom sound DSP (QFP80)
+
+      Note - Without this PCB, the board will boot up and work, displaying the game
+             selection menu, but once the game tries to load attract mode, the PCB resets.
+
+
+Game Carts
+----------
+There are 3 types of carts. The carts have only a few components on them, including some
+ROMs/sockets, a few logic chips/resistors/caps, a DIPSW8 block, one unknown DIP8 chip
+(with it's surface scratched) and some solder-jumper pads to config the ROM types.
+The unknown DIP8 chip is different per game also. There is a sticker on top with a 2-digit game code (I.E. MW/AT/L3 etc)
+
+NSS-01-ROM-A
+|-------------------------------------------------------|
+|     SL3  CL1                                          |
+|     CL3  SL1  IC1_PRG_ROM     IC3_INST_ROM       IC4  |
+|CL4  SL2  SL5                                          |
+|SL4  CL2  CL5                                          |
+|--|                                                 |--|
+   |-------------------------------------------------|
+Notes:
+      IC1 - Program ROM
+      IC2 - Instruction ROM
+      IC4 - Unknown DIP8 chip
+
+Game Name            IC1             IC1 Type    IC3            IC3 Type    Jumpers
+-------------------------------------------------------------------------------------------------------
+Super Mario World    NSS-MW-0_PRG    LH534J      NSS-R_IC3_MW   27C256      CL1 CL2 CL3 CL4 CL5 - Short
+                                                                            SL1 SL2 SL3 SL4 SL5 - Open
+Super Tennis         NSS-ST-0        LH534J      NSS-R_IC3_ST   27C256      CL1 CL2 CL3 CL4 CL5 - Short
+                                                                            SL1 SL2 SL3 SL4 SL5 - Open
+Super Soccer         NSS-R_IC1_FS    TC574000    NSS-R_IC3_FS   27C256      CL1 CL2 CL3 CL4 CL5 - Open
+                                                                            SL1 SL2 SL3 SL4 SL5 - Short
+-------------------------------------------------------------------------------------------------------
+Note - By setting the jumpers to 'Super Soccer', the other 2 games can use standard EPROMs if required.
+
+LH534J is a 4MBit x8 MaskROM with non-standard pinout. An adapter can be made easily to read them.
+
+  Sharp LH534J           Common 27C040
+    +--\/--+               +--\/--+
+A17 |1   32| +5V       VPP |1   32| +5V
+A18 |2   31| /OE       A16 |2   31| A18
+A15 |3   30| NC        A15 |3   30| A17
+A12 |4   29| A14       A12 |4   29| A14
+ A7 |5   28| A13       A7  |5   28| A13
+ A6 |6   27| A8        A6  |6   27| A8
+ A5 |7   26| A9        A5  |7   26| A9
+ A4 |8   25| A11       A4  |8   25| A11
+ A3 |9   24| A16       A3  |9   24| OE/
+ A2 |10  23| A10       A2  |10  23| A10
+ A1 |11  22| /CE       A1  |11  22| CE/,PGM/
+ A0 |12  21| D7        A0  |12  21| D7
+ D0 |13  20| D6        D0  |13  20| D6
+ D1 |14  19| D5        D1  |14  19| D5
+ D2 |15  18| D4        D2  |15  18| D4
+GND |16  17| D3        GND |16  17| D3
+    +------+               +------+
+
+
+NSS-01-ROM-B
+|-------------------------------------------------------|
+|  BAT1  SL3 CL1 CL2 SL5 CL6 CL7                        |
+|        CL3 SL1 SL2 CL5 SL6 SL7                        |
+|                 CL4 SL4                               |
+|                   IC1                                 |
+|                                                       |
+|                                                       |
+|                   IC2_PRG_ROM      IC7_INST_ROM  IC9  |
+|                                                       |
+|                                                       |
+|--|                                                 |--|
+   |-------------------------------------------------|
+Notes:
+      Battery is populated on this board, type CR2032 3V coin battery
+      IC1 - LH5168 8k x8 SRAM (DIP28)
+      IC2 - Program ROM
+      IC7 - Instruction ROM
+      IC9 - Unknown DIP8 chip
+
+Game Name            IC2             IC2 Type    IC7            IC7 Type    Jumpers
+---------------------------------------------------------------------------------------------------------------
+F-Zero               NSS-FZ-0        LH534J      NSS-R_IC3_FZ   27C256      CL1 CL2 CL3 CL4 CL5 CL6 CL7 - Short
+                                                                            SL1 SL2 SL3 SL4 SL5 SL6 SL7 - Open
+---------------------------------------------------------------------------------------------------------------
+
+
+NSS-01-ROM-C
+|-------------------------------------------------------|
+|  BAT1 CL19 SL22   IC1_SRAM                    DIPSW8  |
+|       CL18 SL21                                       |
+|       CL17 SL20                                       |
+|       CL15 SL16   IC2_PRG_ROM-1                       |
+|       SL12                                            |
+|       CL13 SL14                                       |
+|       CL5  SL11                                       |
+|       CL6  SL10   IC3_PRG_ROM-0    IC8_INST_ROM  IC10 |
+|       CL3  SL9                                        |
+|       CL4  SL8                                        |
+|   SL1 CL2  SL7                                        |
+|--|                                                 |--|
+   |-------------------------------------------------|
+Notes:
+      Battery is not populated on this board for any games
+      IC1   - 6116 2k x8 SRAM, not populated (DIP24)
+      IC2/3 - Program ROM
+      IC8   - Instruction ROM
+      IC10  - Unknown DIP8 chip
+
+Game Name       IC2            IC2 Type   IC3            IC3 Type    IC8            IC8 Type    Jumpers
+---------------------------------------------------------------------------------------------------------------------------------------------------------
+Actraiser       NSS-R_IC2_AR   TC574000   NSS-R_IC3_AR   TC574000    NSS-R_IC8_AR   27C256      CL2 CL3 CL4 CL5 CL6 CL12 CL13 CL15 CL17 CL18 CL19 - Short
+                                                                                                SL1 SL7 SL8 SL9 SL10 SL11 SL12 SL14 SL16 SL20 SL21 SL22 - Open
+Addams Family   NSS-R_IC2_AF   TC574000   NSS-R_IC3_AF   TC574000    NSS-R_IC8_AF   27C256      All games use the above jumper configuration.
+Amazing Tennis  NSS-R_IC2_AT   TC574000   NSS-R_IC3_AT   TC574000    NSS-R_IC8_AT   27C256
+Irem Skins Game NSS-R_IC2_MT   TC574000   NSS-R_IC3_MT   TC574000    NSS-R_IC8_MT   27C256
+Lethal Weapon   NSS-R_IC2_L3   TC574000   NSS-R_IC3_L3   TC574000    NSS-R_IC8_L3   27C256
+NCAA Basketball NSS-R_IC2_DU   TC574000   NSS-R_IC3_DU   TC574000    NSS-R_IC8_DU   27C256
+Robocop 3       NSS-R_IC2_R3   TC574000   NSS-R_IC3_R3   TC574000    NSS-R_IC8_R3   27C256
+---------------------------------------------------------------------------------------------------------------------------------------------------------
+
+
+NSS-01-ROM-C
+Sticker - NSS-X1-ROM-C (this is just a ROM-C board with a sticker over the top)
+                       (the differences being the SRAM and battery are populated)
+|-------------------------------------------------------|
+|  BAT1 CL19 SL22   IC1_SRAM                    DIPSW8  |
+|       CL18 SL21                                       |
+|       CL17 SL20                                       |
+|       CL15 SL16   IC2_PRG_ROM-1                       |
+|       SL12                                            |
+|       CL13 SL14                                       |
+|       CL5  SL11                                       |
+|       CL6  SL10   IC3_PRG_ROM-0    IC8_INST_ROM  IC10 |
+|       CL3  SL9                                        |
+|       CL4  SL8                                        |
+|   SL1 CL2  SL7                                        |
+|--|                                                 |--|
+   |-------------------------------------------------|
+Notes:
+      Battery is populated on this board, type CR2032 3V coin battery
+      IC1   - 6116 2k x8 SRAM, populated (DIP24)
+      IC2/3 - Program ROM
+      IC8   - Instruction ROM
+      IC10  - Unknown DIP8 chip
+
+Game Name    IC2            IC2 Type   IC3            IC3 Type    IC8           IC8 Type    Jumpers
+-----------------------------------------------------------------------------------------------------------------------------------------------------
+Contra III   CONTRA_III_1   TC574000   CONTRA_III_0   TC574000    GAME1_NSSU    27C256      CL2 CL3 CL4 CL5 CL6 CL12 CL13 CL15 CL17 CL18 CL19 - Short
+                                                                                            SL1 SL7 SL8 SL9 SL10 SL11 SL12 SL14 SL16 SL20 SL21 SL22 - Open
+-----------------------------------------------------------------------------------------------------------------------------------------------------
+
 ***************************************************************************/
 #include "driver.h"
 #include "vidhrdw/generic.h"
@@ -35,26 +298,15 @@
 
 extern DRIVER_INIT( snes );
 
-static ADDRESS_MAP_START( snes_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x000000, 0x2fffff) AM_READ(snes_r_bank1)	/* I/O and ROM (repeats for each bank) */
-	AM_RANGE(0x300000, 0x3fffff) AM_READ(snes_r_bank2)	/* I/O and ROM (repeats for each bank) */
-	AM_RANGE(0x400000, 0x5fffff) AM_READ(snes_r_bank3)	/* ROM (and reserved in Mode 20) */
-	AM_RANGE(0x600000, 0x6fffff) AM_READ(MRA8_NOP)		/* Reserved */
-	AM_RANGE(0x700000, 0x77ffff) AM_READ(snes_r_sram)	/* 256KB Mode 20 save ram + reserved from 0x8000 - 0xffff */
-	AM_RANGE(0x780000, 0x7dffff) AM_READ(MRA8_NOP)		/* Reserved */
-	AM_RANGE(0x7e0000, 0x7fffff) AM_READ(MRA8_RAM)		/* 8KB Low RAM, 24KB High RAM, 96KB Expanded RAM */
-	AM_RANGE(0x800000, 0xffffff) AM_READ(snes_r_bank4)	/* Mirror and ROM */
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( snes_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x000000, 0x2fffff) AM_WRITE(snes_w_bank1)	/* I/O and ROM (repeats for each bank) */
-	AM_RANGE(0x300000, 0x3fffff) AM_WRITE(snes_w_bank2)	/* I/O and ROM (repeats for each bank) */
-	AM_RANGE(0x400000, 0x5fffff) AM_WRITE(MWA8_ROM)		/* ROM (and reserved in Mode 20) */
-	AM_RANGE(0x600000, 0x6fffff) AM_WRITE(MWA8_NOP)		/* Reserved */
-	AM_RANGE(0x700000, 0x77ffff) AM_WRITE(snes_w_sram) 	/* 256KB Mode 20 save ram + reserved from 0x8000 - 0xffff */
-	AM_RANGE(0x780000, 0x7dffff) AM_WRITE(MWA8_NOP)		/* Reserved */
-	AM_RANGE(0x7e0000, 0x7fffff) AM_WRITE(MWA8_RAM)		/* 8KB Low RAM, 24KB High RAM, 96KB Expanded RAM */
-	AM_RANGE(0x800000, 0xffffff) AM_WRITE(snes_w_bank4)	/* Mirror and ROM */
+static ADDRESS_MAP_START( snes_map, ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE(0x000000, 0x2fffff) AM_READWRITE(snes_r_bank1, snes_w_bank1)	/* I/O and ROM (repeats for each bank) */
+	AM_RANGE(0x300000, 0x3fffff) AM_READWRITE(snes_r_bank2, snes_w_bank2)	/* I/O and ROM (repeats for each bank) */
+	AM_RANGE(0x400000, 0x5fffff) AM_READWRITE(snes_r_bank3, MWA8_ROM)	/* ROM (and reserved in Mode 20) */
+	AM_RANGE(0x600000, 0x6fffff) AM_READWRITE(snes_r_bank6, snes_w_bank6)	/* used by Mode 20 DSP-1 */
+	AM_RANGE(0x700000, 0x77ffff) AM_READWRITE(snes_r_sram, snes_w_sram)	/* 256KB Mode 20 save ram + reserved from 0x8000 - 0xffff */
+	AM_RANGE(0x780000, 0x7dffff) AM_NOP					/* Reserved */
+	AM_RANGE(0x7e0000, 0x7fffff) AM_RAM					/* 8KB Low RAM, 24KB High RAM, 96KB Expanded RAM */
+	AM_RANGE(0x800000, 0xffffff) AM_READWRITE(snes_r_bank4, snes_w_bank4)	/* Mirror and ROM */
 ADDRESS_MAP_END
 
 static READ8_HANDLER( spc_ram_100_r )
@@ -219,9 +471,8 @@ static PALETTE_INIT( snes )
 
 static MACHINE_DRIVER_START( snes )
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", G65816, 2680000)	/* 2.68Mhz, also 3.58Mhz */
-	MDRV_CPU_PROGRAM_MAP(snes_readmem, snes_writemem)
-	MDRV_CPU_VBLANK_INT(snes_scanline_interrupt, SNES_MAX_LINES_NTSC)
+	MDRV_CPU_ADD_TAG("main", G65816, 3580000)	/* 2.68Mhz, also 3.58Mhz */
+	MDRV_CPU_PROGRAM_MAP(snes_map, 0)
 
 	MDRV_CPU_ADD_TAG("sound", SPC700, 2048000/2)	/* 2.048 Mhz, but internal divider */
 	/* audio CPU */
@@ -229,7 +480,7 @@ static MACHINE_DRIVER_START( snes )
 	MDRV_CPU_VBLANK_INT(NULL, 0)
 
 	MDRV_FRAMES_PER_SECOND(60)
-	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_VBLANK_DURATION((int)(((262. - 240.) / 262.) * 1000000. / 60.))
 	MDRV_INTERLEAVE(400)
 
 	MDRV_MACHINE_INIT( snes )
@@ -252,7 +503,7 @@ static MACHINE_DRIVER_START( snes )
 	MDRV_SOUND_ADD(CUSTOM, 0)
 	MDRV_SOUND_CONFIG(snes_sound_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.00)
-	MDRV_SOUND_ROUTE(0, "right", 1.00)
+	MDRV_SOUND_ROUTE(1, "right", 1.00)
 MACHINE_DRIVER_END
 
 /***************************************************************************
@@ -269,6 +520,8 @@ MACHINE_DRIVER_END
 	ROM_REGION(0x10000,         REGION_CPU2,  0)		/* SPC700 */ \
 	ROM_REGION(0x100,           REGION_USER5, 0)		/* IPL ROM */ \
 	ROM_LOAD("spc700.rom", 0, 0x40, CRC(44bb3a40) SHA1(97e352553e94242ae823547cd853eecda55c20f0) ) \
+	ROM_REGION(0x800,           REGION_USER6, 0)		/* add-on chip ROMs (DSP, SFX, etc) */\
+        ROM_LOAD("dsp1data.bin", 0x000000, 0x000800, CRC(4b02d66d) SHA1(1534f4403d2a0f68ba6e35186fe7595d33de34b1))\
 	ROM_REGION(0x10000,         REGION_CPU3,  0)		/* Bios CPU (what is it?) */ \
 	ROM_LOAD("nss-c.dat"  , 0, 0x8000, CRC(a8e202b3) SHA1(b7afcfe4f5cf15df53452dc04be81929ced1efb2) )	/* bios */ \
 	ROM_LOAD("nss-ic14.02", 0, 0x8000, CRC(e06cb58f) SHA1(62f507e91a2797919a78d627af53f029c7d81477) )	/* bios */ \
@@ -376,12 +629,10 @@ ROM_START( nss_ssoc )
 	ROM_LOAD( "s-soccer.ic3", 0x0000, 0x8000, CRC(c09211c3) SHA1(b274a57f93ae0a8774664df3d3615fb7dbecfa2e) )
 ROM_END
 
-/* the ones below could be bad, smw certainly is */
-
 ROM_START( nss_smw )
 	NSS_BIOS
 	ROM_REGION( 0x100000, REGION_USER3, 0 )
-	ROM_LOAD( "mw.ic1", 0x00000, 0x40000, BAD_DUMP CRC(cfa601e7) SHA1(5c9a9a9fccd4b4fcbbda06dfdee41e92dc4e9097) ) /* half size? */
+	ROM_LOAD( "nss-mw-0_prg.ic1", 0x000000, 0x100000, CRC(971ff812) SHA1(4e8f5f0d160ca3e14db3d88c00f2e7e2dce4dca6) )
 
 	/* instruction / data rom for bios */
 	ROM_REGION( 0x8000, REGION_USER4, 0 )
@@ -391,7 +642,7 @@ ROM_END
 ROM_START( nss_fzer )
 	NSS_BIOS
 	ROM_REGION( 0x100000, REGION_USER3, 0 )
-	ROM_LOAD( "fz.ic2", 0x00000, 0x40000, BAD_DUMP CRC(cd281855) SHA1(c9f7895028bbeed3deaa82f4fb51f2569093124b) ) /* maybe wrong size? */
+	ROM_LOAD( "nss-fz-0.ic2", 0x000000, 0x100000, CRC(e9b3cdf1) SHA1(ab616eecd292b94ca74c55446bddd23e9dc3e3bb) )
 
 	/* instruction / data rom for bios */
 	ROM_REGION( 0x8000, REGION_USER4, 0 )
@@ -401,7 +652,7 @@ ROM_END
 ROM_START( nss_sten )
 	NSS_BIOS
 	ROM_REGION( 0x100000, REGION_USER3, 0 )
-	ROM_LOAD( "st.ic1", 0x00000, 0x40000, BAD_DUMP CRC(e94b48d9) SHA1(1ce9c25f8fb62798bbe016b2d1de1724d52e5674) )/* maybe wrong size? */
+	ROM_LOAD( "nss-st-0.ic1", 0x000000, 0x100000, CRC(f131611f) SHA1(0797936e1fc9e705cd7e029097fc013a58e69002) )
 
 	/* instruction / data rom for bios */
 	ROM_REGION( 0x8000, REGION_USER4, 0 )
@@ -418,6 +669,6 @@ GAME( 1992, nss_ncaa,  nss,	  snes,	     snes,    snes,		ROT0, "Sculptured Softw
 GAME( 1992, nss_rob3,  nss,	  snes,	     snes,    snes,		ROT0, "Ocean",						"Robocop 3 (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING ) /* invisible enemy? gameplay prob? */
 GAME( 1992, nss_skin,  nss,	  snes,	     snes,    snes,		ROT0, "Irem",						"Skins Game (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING ) /* no controls */
 GAME( 1992, nss_ssoc,  nss,	  snes,	     snes,    snes,		ROT0, "Human Inc.",					"Super Soccer (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING ) /* some gfx issues */
-GAME( 199?, nss_smw,   nss,	  snes,	     snes,    snes,		ROT0, "Nintendo",					"Super Mario World (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING ) /* bad rom */
-GAME( 199?, nss_fzer,  nss,	  snes,	     snes,    snes,		ROT0, "Nintendo",					"F-Zero (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING ) /* bad rom */
-GAME( 199?, nss_sten,  nss,	  snes,	     snes,    snes,		ROT0, "Nintendo",					"Super Tennis (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING ) /* bad rom */
+GAME( 1991, nss_smw,   nss,	  snes,	     snes,    snes,		ROT0, "Nintendo",					"Super Mario World (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING )
+GAME( 1991, nss_fzer,  nss,	  snes,	     snes,    snes,		ROT0, "Nintendo",					"F-Zero (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING )
+GAME( 199?, nss_sten,  nss,	  snes,	     snes,    snes,		ROT0, "Nintendo",					"Super Tennis (Nintendo Super System)", GAME_IMPERFECT_SOUND | GAME_NOT_WORKING )
