@@ -908,7 +908,7 @@ INPUT_PORTS_START( ojankoc )
 INPUT_PORTS_END
 
 
-static gfx_layout ojankohs_bglayout =
+static const gfx_layout ojankohs_bglayout =
 {
 	8, 4,
 	RGN_FRAC(1, 1),
@@ -919,7 +919,7 @@ static gfx_layout ojankohs_bglayout =
 	16*8
 };
 
-static gfx_decode ojankohs_gfxdecodeinfo[] =
+static const gfx_decode ojankohs_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &ojankohs_bglayout,   0, 64 },
 	{ -1 } 						/* end of array */
@@ -1188,8 +1188,8 @@ ROM_START( ojankoc )
 ROM_END
 
 
-GAME( 1986, ojankoc,  0, ojankoc,  ojankoc,  0, ROT0, "V-System Co.", "Ojanko Club (Japan)" )
-GAME( 1986, ojankoy,  0, ojankoy,  ojankoy,  0, ROT0, "V-System Co.", "Ojanko Yakata (Japan)" )
-GAME( 1987, ojanko2,  0, ojankoy,  ojankoy,  0, ROT0, "V-System Co.", "Ojanko Yakata 2bankan (Japan)" )
-GAME( 1987, ccasino,  0, ccasino,  ccasino,  0, ROT0, "V-System Co.", "Chinese Casino [BET] (Japan)" )
-GAME( 1988, ojankohs, 0, ojankohs, ojankohs, 0, ROT0, "V-System Co.", "Ojanko High School (Japan)" )
+GAME( 1986, ojankoc,  0, ojankoc,  ojankoc,  0, ROT0, "V-System Co.", "Ojanko Club (Japan)", 0 )
+GAME( 1986, ojankoy,  0, ojankoy,  ojankoy,  0, ROT0, "V-System Co.", "Ojanko Yakata (Japan)", 0 )
+GAME( 1987, ojanko2,  0, ojankoy,  ojankoy,  0, ROT0, "V-System Co.", "Ojanko Yakata 2bankan (Japan)", 0 )
+GAME( 1987, ccasino,  0, ccasino,  ccasino,  0, ROT0, "V-System Co.", "Chinese Casino [BET] (Japan)", 0 )
+GAME( 1988, ojankohs, 0, ojankohs, ojankohs, 0, ROT0, "V-System Co.", "Ojanko High School (Japan)", 0 )
