@@ -865,10 +865,10 @@ static MACHINE_DRIVER_START( sound_board_2203 )
 	MDRV_SOUND_ROUTE(3, "left",  0.37)
 	MDRV_SOUND_ROUTE(3, "right", 0.37)
 
-	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, SEGAPCM_SAMPLE32K)
+	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, 8000000)
 	MDRV_SOUND_CONFIG(segapcm_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -903,10 +903,10 @@ static MACHINE_DRIVER_START( sound_board_2203x2 )
 	MDRV_SOUND_ROUTE(3, "left",  0.37)
 	MDRV_SOUND_ROUTE(3, "right", 0.37)
 
-	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, SEGAPCM_SAMPLE15K)
+	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, 4000000)
 	MDRV_SOUND_CONFIG(segapcm_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
@@ -925,10 +925,10 @@ static MACHINE_DRIVER_START( sound_board_2151 )
 	MDRV_SOUND_ROUTE(0, "left", 0.43)
 	MDRV_SOUND_ROUTE(1, "right", 0.43)
 
-	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, SEGAPCM_SAMPLE15K)
+	MDRV_SOUND_ADD_TAG("pcm", SEGAPCM, 4000000)
 	MDRV_SOUND_CONFIG(segapcm_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
-	MDRV_SOUND_ROUTE(0, "right", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
