@@ -77,7 +77,7 @@ static const char *instruction_name[64] =
 	"RGCPY","RGCPY","RGCPY","RGCPY" 	/* Fx */
 };
 
-int HD63484_start(void)
+static int HD63484_start(void)
 {
 	fifo_counter = 0;
 	HD63484_ram = auto_malloc(HD63484_RAM_SIZE);
@@ -86,10 +86,6 @@ int HD63484_start(void)
 	return 0;
 }
 
-void HD63484_stop(void)
-{
-}
-
 static void doclr(int opcode,UINT16 fill,int *dst,INT16 _ax,INT16 _ay)
 {
 	INT16 ax,ay;
@@ -717,11 +713,6 @@ VIDEO_START( shanghai )
 	return HD63484_start();
 }
 
-VIDEO_STOP( shanghai )
-{
-	HD63484_stop();
-}
-
 VIDEO_UPDATE( shanghai )
 {
 	int x,y,b;
