@@ -609,7 +609,7 @@ INPUT_PORTS_END
 
 /******************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,	/* 8*8 chars */
 	2048,
@@ -620,7 +620,7 @@ static gfx_layout charlayout =
 	16*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout pow_spritelayout =
+static const gfx_layout pow_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	4096*4,
@@ -633,7 +633,7 @@ static gfx_layout pow_spritelayout =
 	8*32	/* every sprite takes 32 consecutive bytes */
 };
 
-static gfx_layout searchar_spritelayout =
+static const gfx_layout searchar_spritelayout =
 {
 	16,16,
 	0x6000,
@@ -648,7 +648,7 @@ static gfx_layout searchar_spritelayout =
 	64*8
 };
 
-static gfx_layout ikari3_spritelayout =
+static const gfx_layout ikari3_spritelayout =
 {
 	16,16,	/* 16*16 sprites */
 	4096*5,
@@ -661,21 +661,21 @@ static gfx_layout ikari3_spritelayout =
 	8*32	/* every sprite takes 32 consecutive bytes */
 };
 
-static gfx_decode pow_gfxdecodeinfo[] =
+static const gfx_decode pow_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,		 0, 128 },
 	{ REGION_GFX2, 0, &pow_spritelayout, 0, 128 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode searchar_gfxdecodeinfo[] =
+static const gfx_decode searchar_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,			  0,  16 },
 	{ REGION_GFX2, 0, &searchar_spritelayout, 0, 128 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode ikari3_gfxdecodeinfo[] =
+static const gfx_decode ikari3_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,			0,	16 },
 	{ REGION_GFX2, 0, &ikari3_spritelayout, 0, 128 },
@@ -1153,14 +1153,14 @@ static DRIVER_INIT( searchar )
 
 /******************************************************************************/
 
-GAME( 1988, pow,	  0,		pow,	  pow,		0,		  ROT0,  "SNK", "P.O.W. - Prisoners of War (US)" )
-GAME( 1988, powj,	  pow,		pow,	  powj, 	0,		  ROT0,  "SNK", "Datsugoku - Prisoners of War (Japan)" )
-GAME( 1989, searchar, 0,		searchar, searchar, searchar, ROT90, "SNK", "SAR - Search And Rescue (World)" )
-GAME( 1989, sercharu, searchar, searchar, searchar, searchar, ROT90, "SNK", "SAR - Search And Rescue (US)" )
-GAME( 1989, sercharj, searchar, searchar, searchar, searchar, ROT90, "SNK", "SAR - Search And Rescue (Japan)" )
-GAME( 1989, streetsm, 0,		streetsm, streetsm, 0,		  ROT0,  "SNK", "Street Smart (US version 2)" )
-GAME( 1989, streets1, streetsm, searchar, streetsm, 0,		  ROT0,  "SNK", "Street Smart (US version 1)" )
-GAME( 1989, streetsw, streetsm, searchar, streetsj, 0,		  ROT0,  "SNK", "Street Smart (World version 1)" )
-GAME( 1989, streetsj, streetsm, searchar, streetsj, 0,		  ROT0,  "SNK", "Street Smart (Japan version 1)" )
-GAME( 1989, ikari3,   0,		ikari3,   ikari3,	searchar, ROT0,  "SNK", "Ikari III - The Rescue" )
+GAME( 1988, pow,	  0,		pow,	  pow,		0,		  ROT0,  "SNK", "P.O.W. - Prisoners of War (US)", 0 )
+GAME( 1988, powj,	  pow,		pow,	  powj, 	0,		  ROT0,  "SNK", "Datsugoku - Prisoners of War (Japan)", 0 )
+GAME( 1989, searchar, 0,		searchar, searchar, searchar, ROT90, "SNK", "SAR - Search And Rescue (World)", 0 )
+GAME( 1989, sercharu, searchar, searchar, searchar, searchar, ROT90, "SNK", "SAR - Search And Rescue (US)", 0 )
+GAME( 1989, sercharj, searchar, searchar, searchar, searchar, ROT90, "SNK", "SAR - Search And Rescue (Japan)", 0 )
+GAME( 1989, streetsm, 0,		streetsm, streetsm, 0,		  ROT0,  "SNK", "Street Smart (US version 2)", 0 )
+GAME( 1989, streets1, streetsm, searchar, streetsm, 0,		  ROT0,  "SNK", "Street Smart (US version 1)", 0 )
+GAME( 1989, streetsw, streetsm, searchar, streetsj, 0,		  ROT0,  "SNK", "Street Smart (World version 1)", 0 )
+GAME( 1989, streetsj, streetsm, searchar, streetsj, 0,		  ROT0,  "SNK", "Street Smart (Japan version 1)", 0 )
+GAME( 1989, ikari3,   0,		ikari3,   ikari3,	searchar, ROT0,  "SNK", "Ikari III - The Rescue", 0 )
 
