@@ -501,7 +501,7 @@ INPUT_PORTS_START( dominos )
 INPUT_PORTS_END
 
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	16, 8,
 	64,
@@ -517,7 +517,7 @@ static gfx_layout tile_layout =
 };
 
 
-static gfx_layout car_layout =
+static const gfx_layout car_layout =
 {
 	16, 8,
 	32,
@@ -534,7 +534,7 @@ static gfx_layout car_layout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout, 0, 2 },
 	{ REGION_GFX2, 0, &car_layout, 4, 4 },
@@ -701,7 +701,7 @@ ROM_START( dominos )
 ROM_END
 
 
-GAME( 1978, sprint1,  0,       sprint1, sprint1, sprint1, ROT0, "Atari", "Sprint 1" )
-GAME( 1976, sprint2,  sprint1, sprint2, sprint2, sprint2, ROT0, "Atari", "Sprint 2 (set 1)" )
-GAME( 1976, sprint2a, sprint1, sprint2, sprint2, sprint2, ROT0, "Atari", "Sprint 2 (set 2)" )
-GAME( 1977, dominos,  0,       dominos, dominos, dominos, ROT0, "Atari", "Dominos" )
+GAME( 1978, sprint1,  0,       sprint1, sprint1, sprint1, ROT0, "Atari", "Sprint 1", 0 )
+GAME( 1976, sprint2,  sprint1, sprint2, sprint2, sprint2, ROT0, "Atari", "Sprint 2 (set 1)", 0 )
+GAME( 1976, sprint2a, sprint1, sprint2, sprint2, sprint2, ROT0, "Atari", "Sprint 2 (set 2)", 0 )
+GAME( 1977, dominos,  0,       dominos, dominos, dominos, ROT0, "Atari", "Dominos", 0 )
