@@ -538,7 +538,7 @@ INPUT_PORTS_END
 
 /* Tiles are 8x8x4 but the minimum sprite size is 2x2 tiles */
 
-static gfx_layout layout_8x8x4 =
+static const gfx_layout layout_8x8x4 =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -549,7 +549,7 @@ static gfx_layout layout_8x8x4 =
 	8*8*4/2
 };
 
-static gfx_decode suna16_gfxdecodeinfo[] =
+static const gfx_decode suna16_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &layout_8x8x4, 0, 16*2 }, /* [0] Sprites */
 	{ -1 }
@@ -811,5 +811,5 @@ DRIVER_INIT( uballoon )
 
 ***************************************************************************/
 
-GAME( 1996, bssoccer, 0, bssoccer, bssoccer, 0,        ROT0, "SunA", "Back Street Soccer" )
-GAME( 1996, uballoon, 0, uballoon, uballoon, uballoon, ROT0, "SunA", "Ultra Balloon" )
+GAME( 1996, bssoccer, 0, bssoccer, bssoccer, 0,        ROT0, "SunA", "Back Street Soccer", 0 )
+GAME( 1996, uballoon, 0, uballoon, uballoon, uballoon, ROT0, "SunA", "Ultra Balloon", 0 )
