@@ -12,25 +12,24 @@ driver by Nicola Salmoria
 #include "vidhrdw/generic.h"
 #include "cpu/konami/konami.h" /* for the callback and the firq irq definition */
 #include "vidhrdw/konamiic.h"
+#include "sound/2151intf.h"
 
 /* prototypes */
-static void surpratk_init_machine( void );
+static MACHINE_INIT( surpratk );
 static void surpratk_banking( int lines );
-int surpratk_vh_start( void );
-void surpratk_vh_stop( void );
-void surpratk_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh);
+VIDEO_START( surpratk );
+VIDEO_UPDATE( surpratk );
 
 
 static int videobank;
 static unsigned char *ram;
 
-static int surpratk_interrupt(void)
+static INTERRUPT_GEN( surpratk_interrupt )
 {
-	if (K052109_is_IRQ_enabled()) return interrupt();
-	else return ignore_interrupt();
+	if (K052109_is_IRQ_enabled()) cpunum_set_input_line(0,0,HOLD_LINE);
 }
 
-static READ_HANDLER( bankedram_r )
+static READ8_HANDLER( bankedram_r )
 {
 	if (videobank & 0x02)
 	{
@@ -45,7 +44,7 @@ static READ_HANDLER( bankedram_r )
 		return ram[offset];
 }
 
-static WRITE_HANDLER( bankedram_w )
+static WRITE8_HANDLER( bankedram_w )
 {
 	if (videobank & 0x02)
 	{
@@ -60,18 +59,18 @@ static WRITE_HANDLER( bankedram_w )
 		ram[offset] = data;
 }
 
-static WRITE_HANDLER( surpratk_videobank_w )
+static WRITE8_HANDLER( surpratk_videobank_w )
 {
-logerror("%04x: videobank = %02x\n",cpu_get_pc(),data);
+logerror("%04x: videobank = %02x\n",activecpu_get_pc(),data);
 	/* bit 0 = select 053245 at 0000-07ff */
 	/* bit 1 = select palette at 0000-07ff */
 	/* bit 2 = select palette bank 0 or 1 */
 	videobank = data;
 }
 
-static WRITE_HANDLER( surpratk_5fc0_w )
+static WRITE8_HANDLER( surpratk_5fc0_w )
 {
-	if ((data & 0xf4) != 0x10) logerror("%04x: 3fc0 = %02x\n",cpu_get_pc(),data);
+	if ((data & 0xf4) != 0x10) logerror("%04x: 3fc0 = %02x\n",activecpu_get_pc(),data);
 
 	/* bit 0/1 = coin counters */
 	coin_counter_w(0,data & 0x01);
@@ -86,62 +85,62 @@ static WRITE_HANDLER( surpratk_5fc0_w )
 
 /********************************************/
 
-static MEMORY_READ_START( surpratk_readmem )
-	{ 0x0000, 0x07ff, bankedram_r },
-	{ 0x0800, 0x1fff, MRA_RAM },
-	{ 0x2000, 0x3fff, MRA_BANK1 },			/* banked ROM */
-	{ 0x5f8c, 0x5f8c, input_port_0_r },
-	{ 0x5f8d, 0x5f8d, input_port_1_r },
-	{ 0x5f8e, 0x5f8e, input_port_4_r },
-	{ 0x5f8f, 0x5f8f, input_port_2_r },
-	{ 0x5f90, 0x5f90, input_port_3_r },
-/*	{ 0x5f91, 0x5f91, YM2151_status_port_0_r },	   ?    */
-	{ 0x5fa0, 0x5faf, K053244_r },
-	{ 0x5fc0, 0x5fc0, watchdog_reset_r },
-	{ 0x4000, 0x7fff, K052109_r },
-	{ 0x8000, 0xffff, MRA_ROM },			/* ROM */
-MEMORY_END
+static ADDRESS_MAP_START( surpratk_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_READ(bankedram_r)
+	AM_RANGE(0x0800, 0x1fff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x2000, 0x3fff) AM_READ(MRA8_BANK1)			/* banked ROM */
+	AM_RANGE(0x5f8c, 0x5f8c) AM_READ(input_port_0_r)
+	AM_RANGE(0x5f8d, 0x5f8d) AM_READ(input_port_1_r)
+	AM_RANGE(0x5f8e, 0x5f8e) AM_READ(input_port_4_r)
+	AM_RANGE(0x5f8f, 0x5f8f) AM_READ(input_port_2_r)
+	AM_RANGE(0x5f90, 0x5f90) AM_READ(input_port_3_r)
+/*  AM_RANGE(0x5f91, 0x5f91) AM_READ(YM2151_status_port_0_r)       ?    */
+	AM_RANGE(0x5fa0, 0x5faf) AM_READ(K053244_r)
+	AM_RANGE(0x5fc0, 0x5fc0) AM_READ(watchdog_reset_r)
+	AM_RANGE(0x4000, 0x7fff) AM_READ(K052109_r)
+	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)			/* ROM */
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( surpratk_writemem )
-	{ 0x0000, 0x07ff, bankedram_w, &ram },
-	{ 0x0800, 0x1fff, MWA_RAM },
-	{ 0x2000, 0x3fff, MWA_ROM },					/* banked ROM */
-	{ 0x5fa0, 0x5faf, K053244_w },
-	{ 0x5fb0, 0x5fbf, K053251_w },
-	{ 0x5fc0, 0x5fc0, surpratk_5fc0_w },
-	{ 0x5fd0, 0x5fd0, YM2151_register_port_0_w },
-	{ 0x5fd1, 0x5fd1, YM2151_data_port_0_w },
-	{ 0x5fc4, 0x5fc4, surpratk_videobank_w },
-	{ 0x4000, 0x7fff, K052109_w },
-	{ 0x8000, 0xffff, MWA_ROM },					/* ROM */
-MEMORY_END
+static ADDRESS_MAP_START( surpratk_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_WRITE(bankedram_w) AM_BASE(&ram)
+	AM_RANGE(0x0800, 0x1fff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x2000, 0x3fff) AM_WRITE(MWA8_ROM)					/* banked ROM */
+	AM_RANGE(0x5fa0, 0x5faf) AM_WRITE(K053244_w)
+	AM_RANGE(0x5fb0, 0x5fbf) AM_WRITE(K053251_w)
+	AM_RANGE(0x5fc0, 0x5fc0) AM_WRITE(surpratk_5fc0_w)
+	AM_RANGE(0x5fd0, 0x5fd0) AM_WRITE(YM2151_register_port_0_w)
+	AM_RANGE(0x5fd1, 0x5fd1) AM_WRITE(YM2151_data_port_0_w)
+	AM_RANGE(0x5fc4, 0x5fc4) AM_WRITE(surpratk_videobank_w)
+	AM_RANGE(0x4000, 0x7fff) AM_WRITE(K052109_w)
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)					/* ROM */
+ADDRESS_MAP_END
 
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
 INPUT_PORTS_START( surpratk )
 	PORT_START	/* PLAYER 1 INPUTS */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER1 )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_PLAYER1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* PLAYER 2 INPUTS */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START2 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER2 )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_PLAYER2 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 	PORT_START	/* DSW #1 */
@@ -178,7 +177,7 @@ INPUT_PORTS_START( surpratk )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(    0x00, "No Use" ) */
+/*  PORT_DIPSETTING(    0x00, "No Use" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -196,8 +195,8 @@ INPUT_PORTS_START( surpratk )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x60, 0x40, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x60, "Easy" )
-	PORT_DIPSETTING(    0x40, "Normal" )
+	PORT_DIPSETTING(    0x60, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x20, "Difficult" )
 	PORT_DIPSETTING(    0x00, "Very Difficult" )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )
@@ -213,8 +212,8 @@ INPUT_PORTS_START( surpratk )
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x20, 0x20, "Upright Controls" )
-	PORT_DIPSETTING(    0x20, "Single" )
-	PORT_DIPSETTING(    0x00, "Dual" )
+	PORT_DIPSETTING(    0x20, DEF_STR( Single ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Dual ) )
 	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
@@ -225,55 +224,45 @@ INPUT_PORTS_END
 
 static void irqhandler(int linestate)
 {
-	cpu_set_irq_line(0,KONAMI_FIRQ_LINE,linestate);
+	cpunum_set_input_line(0,KONAMI_FIRQ_LINE,linestate);
 }
 
 static struct YM2151interface ym2151_interface =
 {
-	1,			/* 1 chip */
-	3579545,	/* 3.579545 MHz */
-	{ YM3012_VOL(100,MIXER_PAN_LEFT,100,MIXER_PAN_RIGHT) },
-	{ irqhandler },
+	irqhandler
 };
 
 
 
-static const struct MachineDriver machine_driver_surpratk =
-{
+static MACHINE_DRIVER_START( surpratk )
+
 	/* basic machine hardware */
-	{
-		{
-			CPU_KONAMI,		/* 053248 */
-			3000000,		/* ? */
-			surpratk_readmem,surpratk_writemem,0,0,
-            surpratk_interrupt,1
-		}
-	},
-	60, DEFAULT_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-	1,	/* 1 CPU slice per frame - interleaving is forced when a sound command is written */
-	surpratk_init_machine,
+	MDRV_CPU_ADD(KONAMI, 3000000)	/* 053248 */
+	MDRV_CPU_PROGRAM_MAP(surpratk_readmem,surpratk_writemem)
+	MDRV_CPU_VBLANK_INT(surpratk_interrupt,1)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+
+	MDRV_MACHINE_INIT(surpratk)
 
 	/* video hardware */
-	64*8, 32*8, { 14*8, (64-14)*8-1, 2*8, 30*8-1 },
-	0,	/* gfx decoded by konamiic.c */
-	2048, 0,
-	0,
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
+	MDRV_SCREEN_SIZE(64*8, 32*8)
+	MDRV_VISIBLE_AREA(14*8, (64-14)*8-1, 2*8, 30*8-1 )
+	MDRV_PALETTE_LENGTH(2048)
 
-	VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS,
-	0,
-	surpratk_vh_start,
-	surpratk_vh_stop,
-	surpratk_vh_screenrefresh,
+	MDRV_VIDEO_START(surpratk)
+	MDRV_VIDEO_UPDATE(surpratk)
 
 	/* sound hardware */
-	SOUND_SUPPORTS_STEREO,0,0,0,
-	{
-		{
-			SOUND_YM2151,
-			&ym2151_interface
-		}
-	}
-};
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
+MACHINE_DRIVER_END
 
 /***************************************************************************
 
@@ -281,19 +270,50 @@ static const struct MachineDriver machine_driver_surpratk =
 
 ***************************************************************************/
 
-ROM_START( surpratk )
+
+ROM_START( suratk )
 	ROM_REGION( 0x51000, REGION_CPU1, 0 ) /* code + banked roms + palette RAM */
-	ROM_LOAD( "911m01.bin", 0x10000, 0x20000, 0xee5b2cc8 )
-	ROM_LOAD( "911m02.bin", 0x30000, 0x18000, 0x5d4148a8 )
+	ROM_LOAD( "911j01.f5", 0x10000, 0x20000, CRC(1e647881) SHA1(241e421d5599ebd9fcfb8be9c48dfd3b4c671958) )
+	ROM_LOAD( "911k02.h5", 0x30000, 0x18000, CRC(ef10e7b6) SHA1(0b41a929c0c579d688653a8d90dd6b40db12cfb3) )
 	ROM_CONTINUE(           0x08000, 0x08000 )
 
 	ROM_REGION( 0x080000, REGION_GFX1, 0 ) /* graphics ( don't dispose as the program can read them, 0 ) */
-	ROM_LOAD( "911d05.bin", 0x000000, 0x040000, 0x308d2319 ) /* characters */
-	ROM_LOAD( "911d06.bin", 0x040000, 0x040000, 0x91cc9b32 ) /* characters */
+	ROM_LOAD( "911d05.bin", 0x000000, 0x040000, CRC(308d2319) SHA1(521d2a72fecb094e2c2f23b535f0b527886b4d3a) ) /* characters */
+	ROM_LOAD( "911d06.bin", 0x040000, 0x040000, CRC(91cc9b32) SHA1(e05b7bbff30f24fe6f009560410f5e90bb118692) ) /* characters */
 
 	ROM_REGION( 0x080000, REGION_GFX2, 0 ) /* graphics ( don't dispose as the program can read them, 0 ) */
-	ROM_LOAD( "911d03.bin", 0x000000, 0x040000, 0xe34ff182 )	/* sprites */
-	ROM_LOAD( "911d04.bin", 0x040000, 0x040000, 0x20700bd2 )	/* sprites */
+	ROM_LOAD( "911d03.bin", 0x000000, 0x040000, CRC(e34ff182) SHA1(075ca7a91c843bdac7da21ddfcd43f7a043a09b6) )	/* sprites */
+	ROM_LOAD( "911d04.bin", 0x040000, 0x040000, CRC(20700bd2) SHA1(a2fa4a3ee28c1542cdd798907a9ece249aadff0a) )	/* sprites */
+ROM_END
+
+ROM_START( suratka )
+	ROM_REGION( 0x51000, REGION_CPU1, 0 ) /* code + banked roms + palette RAM */
+	ROM_LOAD( "911j01.f5", 0x10000, 0x20000, CRC(1e647881) SHA1(241e421d5599ebd9fcfb8be9c48dfd3b4c671958) )
+	ROM_LOAD( "911l02.h5", 0x30000, 0x18000, CRC(11db8288) SHA1(09fe187855172ebf0c57f561cce7f41e47f53114) )
+	ROM_CONTINUE(           0x08000, 0x08000 )
+
+	ROM_REGION( 0x080000, REGION_GFX1, 0 ) /* graphics ( don't dispose as the program can read them, 0 ) */
+	ROM_LOAD( "911d05.bin", 0x000000, 0x040000, CRC(308d2319) SHA1(521d2a72fecb094e2c2f23b535f0b527886b4d3a) ) /* characters */
+	ROM_LOAD( "911d06.bin", 0x040000, 0x040000, CRC(91cc9b32) SHA1(e05b7bbff30f24fe6f009560410f5e90bb118692) ) /* characters */
+
+	ROM_REGION( 0x080000, REGION_GFX2, 0 ) /* graphics ( don't dispose as the program can read them, 0 ) */
+	ROM_LOAD( "911d03.bin", 0x000000, 0x040000, CRC(e34ff182) SHA1(075ca7a91c843bdac7da21ddfcd43f7a043a09b6) )	/* sprites */
+	ROM_LOAD( "911d04.bin", 0x040000, 0x040000, CRC(20700bd2) SHA1(a2fa4a3ee28c1542cdd798907a9ece249aadff0a) )	/* sprites */
+ROM_END
+
+ROM_START( suratkj )
+	ROM_REGION( 0x51000, REGION_CPU1, 0 ) /* code + banked roms + palette RAM */
+	ROM_LOAD( "911m01.f5", 0x10000, 0x20000, CRC(ee5b2cc8) SHA1(4b05f7ba4e804a3bccb41fe9d3258cbcfe5324aa) )
+	ROM_LOAD( "911m02.h5", 0x30000, 0x18000, CRC(5d4148a8) SHA1(4fa5947db777b4c742775d588dea38758812a916) )
+	ROM_CONTINUE(           0x08000, 0x08000 )
+
+	ROM_REGION( 0x080000, REGION_GFX1, 0 ) /* graphics ( don't dispose as the program can read them, 0 ) */
+	ROM_LOAD( "911d05.bin", 0x000000, 0x040000, CRC(308d2319) SHA1(521d2a72fecb094e2c2f23b535f0b527886b4d3a) ) /* characters */
+	ROM_LOAD( "911d06.bin", 0x040000, 0x040000, CRC(91cc9b32) SHA1(e05b7bbff30f24fe6f009560410f5e90bb118692) ) /* characters */
+
+	ROM_REGION( 0x080000, REGION_GFX2, 0 ) /* graphics ( don't dispose as the program can read them, 0 ) */
+	ROM_LOAD( "911d03.bin", 0x000000, 0x040000, CRC(e34ff182) SHA1(075ca7a91c843bdac7da21ddfcd43f7a043a09b6) )	/* sprites */
+	ROM_LOAD( "911d04.bin", 0x040000, 0x040000, CRC(20700bd2) SHA1(a2fa4a3ee28c1542cdd798907a9ece249aadff0a) )	/* sprites */
 ROM_END
 
 /***************************************************************************
@@ -307,26 +327,27 @@ static void surpratk_banking(int lines)
 	unsigned char *RAM = memory_region(REGION_CPU1);
 	int offs = 0;
 
-logerror("%04x: setlines %02x\n",cpu_get_pc(),lines);
+logerror("%04x: setlines %02x\n",activecpu_get_pc(),lines);
 
 	offs = 0x10000 + ((lines & 0x1f) * 0x2000);
 	if (offs >= 0x48000) offs -= 0x40000;
-	cpu_setbank(1,&RAM[offs]);
+	memory_set_bankptr(1,&RAM[offs]);
 }
 
-static void surpratk_init_machine( void )
+static MACHINE_INIT( surpratk )
 {
-	konami_cpu_setlines_callback = surpratk_banking;
+	cpunum_set_info_fct(0, CPUINFO_PTR_KONAMI_SETLINES_CALLBACK, (genf *)surpratk_banking);
 
 	paletteram = &memory_region(REGION_CPU1)[0x48000];
 }
 
-static void init_surpratk(void)
+static DRIVER_INIT( surpratk )
 {
 	konami_rom_deinterleave_2(REGION_GFX1);
 	konami_rom_deinterleave_2(REGION_GFX2);
 }
 
 
-
-GAME( 1990, surpratk, 0, surpratk, surpratk, surpratk, ROT0, "Konami", "Surprise Attack (Japan)" )
+GAME( 1990, suratk,  0,      surpratk, surpratk, surpratk, ROT0, "Konami", "Surprise Attack (World ver. K)", 0 )
+GAME( 1990, suratka, suratk, surpratk, surpratk, surpratk, ROT0, "Konami", "Surprise Attack (Asia ver. L)", 0 )
+GAME( 1990, suratkj, suratk, surpratk, surpratk, surpratk, ROT0, "Konami", "Surprise Attack (Japan ver. M)", 0 )
