@@ -283,7 +283,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -294,7 +294,7 @@ static gfx_layout charlayout =
 	8*8
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -307,7 +307,7 @@ static gfx_layout spritelayout =
 	32*8
 };
 
-static gfx_layout sht_spritelayout =
+static const gfx_layout sht_spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -320,14 +320,14 @@ static gfx_layout sht_spritelayout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,      0, 16 },
 	{ REGION_GFX2, 0, &spritelayout, 16*8, 16 },
 	{ -1 } /* end of array */
 };
 
-static gfx_decode sht_gfxdecodeinfo[] =
+static const gfx_decode sht_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,          0, 16 },
 	{ REGION_GFX2, 0, &sht_spritelayout, 16*8, 16 },
