@@ -82,8 +82,8 @@ static PALETTE_INIT( wallc )
 {
 	int i;
 
-	const int resistances_rg[2] = { 330, 220 };
-	const int resistances_b[3] = { 655, 330, 220 };
+	static const int resistances_rg[2] = { 330, 220 };
+	static const int resistances_b[3] = { 655, 330, 220 };
 	double weights_r[2], weights_g[2], weights_b[3];
 
 	compute_resistor_weights(0,	255,	-1.0,
