@@ -1,15 +1,13 @@
 /***************************************************************************
 
-  machine.c
-
-  Functions to emulate general aspects of the machine (RAM, ROM, interrupts,
-  I/O ports)
+    Atari I, Robot hardware
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "cpuintrf.h"
 #include "cpu/m6809/m6809.h"
+#include "irobot.h"
 
 /* Note:
  * There's probably something wrong with the way the Mathbox gets started.
@@ -28,24 +26,18 @@
 
 #define IR_CPU_STATE \
 	logerror(\
-			"pc: %4x, scanline: %d\n", cpu_getpreviouspc(), cpu_getscanline())
+			"pc: %4x, scanline: %d\n", activecpu_get_previouspc(), cpu_getscanline())
 
 
 UINT8 irvg_clear;
 static UINT8 irvg_vblank;
 static UINT8 irvg_running;
 static UINT8 irmb_running;
-static void *irscanline_timer;
 
 #if IR_TIMING
 static void *irvg_timer;
 static void *irmb_timer;
 #endif
-extern void run_video(void);
-
-extern void irobot_poly_clear(void);
-
-extern struct mame_bitmap *polybitmapt;
 
 static UINT8 *comRAM[2], *mbRAM, *mbROM;
 static UINT8 irobot_control_num = 0;
@@ -65,7 +57,7 @@ static void irmb_run(void);
 
 
 
-READ_HANDLER( irobot_sharedmem_r )
+READ8_HANDLER( irobot_sharedmem_r )
 {
 	if (irobot_outx == 3)
 		return mbRAM[BYTE_XOR_BE(offset)];
@@ -83,7 +75,7 @@ READ_HANDLER( irobot_sharedmem_r )
 }
 
 /* Comment out the mbRAM =, comRAM2 = or comRAM1 = and it will start working */
-WRITE_HANDLER( irobot_sharedmem_w )
+WRITE8_HANDLER( irobot_sharedmem_w )
 {
 	if (irobot_outx == 3)
 		mbRAM[BYTE_XOR_BE(offset)] = data;
@@ -99,7 +91,7 @@ static void irvg_done_callback (int param)
 	irvg_running = 0;
 }
 
-WRITE_HANDLER( irobot_statwr_w )
+WRITE8_HANDLER( irobot_statwr_w )
 {
 	logerror("write %2x ", data);
 	IR_CPU_STATE;
@@ -114,20 +106,14 @@ WRITE_HANDLER( irobot_statwr_w )
 
 	if ((data & 0x04) && !(irobot_statwr & 0x04))
 	{
-		run_video();
+		irobot_run_video();
 #if IR_TIMING
 		if (irvg_running == 0)
-		{
 			logerror("vg start ");
-			IR_CPU_STATE;
-			irvg_timer = timer_set (TIME_IN_MSEC(10), 0, irvg_done_callback);
-		}
 		else
-		{
 			logerror("vg start [busy!] ");
-			IR_CPU_STATE;
-			timer_reset (irvg_timer , TIME_IN_MSEC(10));
-		}
+		IR_CPU_STATE;
+		timer_adjust(irvg_timer, TIME_IN_MSEC(10), 0, 0);
 #endif
 		irvg_running=1;
 	}
@@ -136,7 +122,7 @@ WRITE_HANDLER( irobot_statwr_w )
 	irobot_statwr = data;
 }
 
-WRITE_HANDLER( irobot_out0_w )
+WRITE8_HANDLER( irobot_out0_w )
 {
 	UINT8 *RAM = memory_region(REGION_CPU1);
 
@@ -144,13 +130,13 @@ WRITE_HANDLER( irobot_out0_w )
 	switch (data & 0x60)
 	{
 		case 0:
-			cpu_setbank(2, &RAM[0x1C000]);
+			memory_set_bankptr(2, &RAM[0x1C000]);
 			break;
 		case 0x20:
-			cpu_setbank(2, &RAM[0x1C800]);
+			memory_set_bankptr(2, &RAM[0x1C800]);
 			break;
 		case 0x40:
-			cpu_setbank(2, &RAM[0x1D000]);
+			memory_set_bankptr(2, &RAM[0x1D000]);
 			break;
 	}
 	irobot_outx = (data & 0x18) >> 3;
@@ -158,29 +144,29 @@ WRITE_HANDLER( irobot_out0_w )
 	irobot_alphamap = (data & 0x80);
 }
 
-WRITE_HANDLER( irobot_rom_banksel_w )
+WRITE8_HANDLER( irobot_rom_banksel_w )
 {
 	UINT8 *RAM = memory_region(REGION_CPU1);
 
 	switch ((data & 0x0E) >> 1)
 	{
 		case 0:
-			cpu_setbank(1, &RAM[0x10000]);
+			memory_set_bankptr(1, &RAM[0x10000]);
 			break;
 		case 1:
-			cpu_setbank(1, &RAM[0x12000]);
+			memory_set_bankptr(1, &RAM[0x12000]);
 			break;
 		case 2:
-			cpu_setbank(1, &RAM[0x14000]);
+			memory_set_bankptr(1, &RAM[0x14000]);
 			break;
 		case 3:
-			cpu_setbank(1, &RAM[0x16000]);
+			memory_set_bankptr(1, &RAM[0x16000]);
 			break;
 		case 4:
-			cpu_setbank(1, &RAM[0x18000]);
+			memory_set_bankptr(1, &RAM[0x18000]);
 			break;
 		case 5:
-			cpu_setbank(1, &RAM[0x1A000]);
+			memory_set_bankptr(1, &RAM[0x1A000]);
 			break;
 	}
 	set_led_status(0,data & 0x10);
@@ -193,15 +179,16 @@ static void scanline_callback(int scanline)
     if (scanline == 224) irvg_vblank=1;
     logerror("SCANLINE CALLBACK %d\n",scanline);
     /* set the IRQ line state based on the 32V line state */
-    cpu_set_irq_line(0, M6809_IRQ_LINE, (scanline & 32) ? ASSERT_LINE : CLEAR_LINE);
+    cpunum_set_input_line(0, M6809_IRQ_LINE, (scanline & 32) ? ASSERT_LINE : CLEAR_LINE);
 
     /* set a callback for the next 32-scanline increment */
     scanline += 32;
     if (scanline >= 256) scanline = 0;
-    irscanline_timer = timer_set(cpu_getscanlinetime(scanline), scanline, scanline_callback);
+    timer_set(cpu_getscanlinetime(scanline), scanline, scanline_callback);
 }
 
-void irobot_init_machine(void)
+static void irmb_done_callback (int param);
+MACHINE_INIT( irobot )
 {
 	UINT8 *MB = memory_region(REGION_CPU2);
 
@@ -213,10 +200,12 @@ void irobot_init_machine(void)
 
 	irvg_vblank=0;
 	irvg_running = 0;
+	irvg_timer = timer_alloc(irvg_done_callback);
 	irmb_running = 0;
+	irmb_timer = timer_alloc(irmb_done_callback);
 
 	/* set an initial timer to go off on scanline 0 */
-	irscanline_timer = timer_set(cpu_getscanlinetime(0), 0, scanline_callback);
+	timer_set(cpu_getscanlinetime(0), 0, scanline_callback);
 
 	irobot_rom_banksel_w(0,0);
 	irobot_out0_w(0,0);
@@ -225,13 +214,13 @@ void irobot_init_machine(void)
 	irobot_outx = 0;
 }
 
-WRITE_HANDLER( irobot_control_w )
+WRITE8_HANDLER( irobot_control_w )
 {
 
 	irobot_control_num = offset & 0x03;
 }
 
-READ_HANDLER( irobot_control_r )
+READ8_HANDLER( irobot_control_r )
 {
 
 	if (irobot_control_num == 0)
@@ -243,8 +232,8 @@ READ_HANDLER( irobot_control_r )
 }
 
 /*  we allow irmb_running and irvg_running to appear running before clearing
-	them to simulate the mathbox and vector generator running in real time */
-READ_HANDLER( irobot_status_r )
+    them to simulate the mathbox and vector generator running in real time */
+READ8_HANDLER( irobot_status_r )
 {
 	int d=0;
 
@@ -268,7 +257,7 @@ READ_HANDLER( irobot_status_r )
 
 /***********************************************************************
 
-	I-Robot Mathbox
+    I-Robot Mathbox
 
     Based on 4 2901 chips slice processors connected to form a 16-bit ALU
 
@@ -385,8 +374,7 @@ void load_oproms(void)
 	int i;
 
 	/* allocate RAM */
-	mbops = malloc(sizeof(irmb_ops) * 1024);
-	if (!mbops) return;
+	mbops = auto_malloc(sizeof(irmb_ops) * 1024);
 
 	for (i = 0; i < 1024; i++)
 	{
@@ -452,7 +440,7 @@ void load_oproms(void)
 
 
 /* Init mathbox (only called once) */
-void init_irobot(void)
+DRIVER_INIT( irobot )
 {
 	int i;
 	for (i = 0; i < 16; i++)
@@ -469,7 +457,7 @@ static void irmb_done_callback (int param)
     logerror("mb done. ");
 	IR_CPU_STATE;
 	irmb_running = 0;
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
 }
 
 
@@ -862,7 +850,7 @@ default:	case 0x3f:	IXOR(irmb_din(curop), 0);							break;
 #if IR_TIMING
 	if (irmb_running == 0)
 	{
-		irmb_timer = timer_set (TIME_IN_HZ(12000000) * icount, 0, irmb_done_callback);
+		timer_adjust(irmb_timer, TIME_IN_HZ(12000000) * icount, 0, 0);
 		logerror("mb start ");
 		IR_CPU_STATE;
 	}
@@ -870,10 +858,10 @@ default:	case 0x3f:	IXOR(irmb_din(curop), 0);							break;
 	{
 		logerror("mb start [busy!] ");
 		IR_CPU_STATE;
-		timer_reset (irmb_timer, TIME_IN_NSEC(200) * icount);
+		timer_adjust(irmb_timer, TIME_IN_NSEC(200) * icount, 0, 0);
 	}
 #else
-	cpu_set_irq_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpunum_set_input_line(0, M6809_FIRQ_LINE, ASSERT_LINE);
 #endif
 	irmb_running=1;
 }
