@@ -1242,15 +1242,15 @@ int konamigx_mixer_init(int objdma)
 	gx_primode = 0;
 
 	gx_objzbuf = (UINT8 *)priority_bitmap->base;
-	if (!(gx_shdzbuf = auto_malloc(GX_ZBUFSIZE))) return(1);
-	if (!(gx_objpool = auto_malloc(sizeof(struct GX_OBJ) * (GX_MAX_OBJECTS)))) return(1);
+	gx_shdzbuf = auto_malloc(GX_ZBUFSIZE);
+	gx_objpool = auto_malloc(sizeof(struct GX_OBJ) * (GX_MAX_OBJECTS));
 
 	K053247_export_config(&K053247_ram, &K053247_gfx, &K053247_callback, &K053247_dx, &K053247_dy);
 	K054338_export_config(&K054338_shdRGB);
 
 	if (objdma)
 	{
-		if (!(gx_spriteram = auto_malloc(0x1000))) return(1);
+		gx_spriteram = auto_malloc(0x1000);
 		gx_objdma = 1;
 	}
 	else
