@@ -2,6 +2,8 @@
 #define _KONPPC_H
 
 void init_konami_cgboard(int board_id);
+void set_cgboard_id(int board_id);
+void set_cgboard_texture_bank(int);
 
 READ32_HANDLER( cgboard_dsp_comm_r_ppc );
 WRITE32_HANDLER( cgboard_dsp_comm_w_ppc );
