@@ -35,7 +35,7 @@ MACHINE_INIT( sys16_onetime ){
 	sys18_splittab_fg_y=0;
 }
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
