@@ -4,6 +4,9 @@
 
     General core utilities and macros used throughout MAME.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #pragma once
@@ -15,6 +18,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <ctype.h>
+#include <assert.h>
 #include "osd_cpu.h"
 
 
@@ -157,6 +161,15 @@ typedef union
 
 ***************************************************************************/
 
+/* Standard MAME assertion macro */
+#undef assert
+#ifdef MAME_DEBUG
+#define assert(x)	do { if (!(x)) osd_die("assert: %s:%d: %s", __FILE__, __LINE__, #x); } while (0)
+#else
+#define assert(x)
+#endif
+
+
 /* Standard MIN/MAX macros */
 #ifndef MIN
 #define MIN(x,y) ((x)<(y)?(x):(y))
@@ -329,10 +342,12 @@ INLINE int mame_stricmp(const char *s1, const char *s2)
  	}
 }
 
+
 /* this macro prevents people from using stricmp directly */
 #undef stricmp
 #define stricmp !MUST_USE_MAME_STRICMP_INSTEAD!
 
+
 /* compute the intersection of two rectangles */
 INLINE void sect_rect(rectangle *dst, const rectangle *src)
 {
@@ -342,6 +357,7 @@ INLINE void sect_rect(rectangle *dst, const rectangle *src)
 	if (src->max_y < dst->max_y) dst->max_y = src->max_y;
 }
 
+
 /* convert a series of 32 bits into a float */
 INLINE float u2f(UINT32 v)
 {
@@ -353,6 +369,7 @@ INLINE float u2f(UINT32 v)
 	return u.ff;
 }
 
+
 /* convert a float into a series of 32 bits */
 INLINE UINT32 f2u(float f)
 {
@@ -364,6 +381,7 @@ INLINE UINT32 f2u(float f)
 	return u.vv;
 }
 
+
 /* convert a series of 64 bits into a double */
 INLINE float u2d(UINT64 v)
 {
@@ -375,6 +393,7 @@ INLINE float u2d(UINT64 v)
 	return u.dd;
 }
 
+
 /* convert a double into a series of 64 bits */
 INLINE UINT64 d2u(double d)
 {
@@ -430,6 +449,60 @@ INLINE INT32 fixed_mul_shift(INT32 val1, INT32 val2, UINT8 shift)
 
 
 
+/***************************************************************************
+
+    Binary coded decimal
+
+***************************************************************************/
+
+INLINE int bcd_adjust(int value)
+{
+	if ((value & 0xf) >= 0xa)
+		value = value + 0x10 - 0xa;
+	if ((value & 0xf0) >= 0xa0)
+		value = value - 0xa0 + 0x100;
+	return value;
+}
+
+
+INLINE int dec_2_bcd(int a)
+{
+	return (a % 10) | ((a / 10) << 4);
+}
+
+
+INLINE int bcd_2_dec(int a)
+{
+	return (a & 0xf) + (a >> 4) * 10;
+}
+
+
+
+/***************************************************************************
+
+    Gregorian calendar code
+
+***************************************************************************/
+
+INLINE int gregorian_is_leap_year(int year)
+{
+	return !(year % 100 ? year % 4 : year % 400);
+}
+
+
+/* months are one counted */
+INLINE int gregorian_days_in_month(int month, int year)
+{
+	if (month == 2)
+		return gregorian_is_leap_year(year) ? 29 : 28;
+	else if (month == 4 || month == 6 || month == 9 || month == 11)
+		return 30;
+	else
+		return 31;
+}
+
+
+
 /***************************************************************************
 
     Compiler-specific nastiness
