@@ -4,6 +4,9 @@
 
     Functions which handle the CPU memory accesses.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #pragma once
@@ -928,7 +931,7 @@ void 		memory_set_decrypted_region(int cpunum, offs_t start, offs_t end, void *b
 /* ----- return a base pointer to memory ---- */
 void *		memory_get_read_ptr(int cpunum, int spacenum, offs_t offset);
 void *		memory_get_write_ptr(int cpunum, int spacenum, offs_t offset);
-void *		memory_get_op_ptr(int cpunum, offs_t offset);
+void *		memory_get_op_ptr(int cpunum, offs_t offset, int arg);
 
 /* ----- memory banking ----- */
 void		memory_configure_bank(int banknum, int startentry, int numentries, void *base, offs_t stride);
@@ -940,19 +943,23 @@ void		memory_set_bankptr(int banknum, void *base);
 void		memory_set_debugger_access(int debugger);
 
 /* ----- dynamic address space mapping ----- */
+void *		_memory_install_read_handler   (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, int handler, const char *handler_name);
 UINT8 *		_memory_install_read8_handler  (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read8_handler handler, const char *handler_name);
 UINT16 *	_memory_install_read16_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read16_handler handler, const char *handler_name);
 UINT32 *	_memory_install_read32_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read32_handler handler, const char *handler_name);
 UINT64 *	_memory_install_read64_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, read64_handler handler, const char *handler_name);
+void *		_memory_install_write_handler  (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, int handler, const char *handler_name);
 UINT8 *		_memory_install_write8_handler (int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write8_handler handler, const char *handler_name);
 UINT16 *	_memory_install_write16_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write16_handler handler, const char *handler_name);
 UINT32 *	_memory_install_write32_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write32_handler handler, const char *handler_name);
 UINT64 *	_memory_install_write64_handler(int cpunum, int spacenum, offs_t start, offs_t end, offs_t mask, offs_t mirror, write64_handler handler, const char *handler_name);
 
+void *		_memory_install_read_matchmask_handler   (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, int handler, const char *handler_name);
 UINT8 *		_memory_install_read8_matchmask_handler  (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read8_handler handler, const char *handler_name);
 UINT16 *	_memory_install_read16_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read16_handler handler, const char *handler_name);
 UINT32 *	_memory_install_read32_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read32_handler handler, const char *handler_name);
 UINT64 *	_memory_install_read64_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, read64_handler handler, const char *handler_name);
+void *		_memory_install_write_matchmask_handler  (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, int handler, const char *handler_name);
 UINT8 *		_memory_install_write8_matchmask_handler (int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write8_handler handler, const char *handler_name);
 UINT16 *	_memory_install_write16_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write16_handler handler, const char *handler_name);
 UINT32 *	_memory_install_write32_matchmask_handler(int cpunum, int spacenum, offs_t matchval, offs_t maskval, offs_t mask, offs_t mirror, write32_handler handler, const char *handler_name);
@@ -1014,6 +1021,8 @@ extern address_map *	construct_map_0(address_map *map);
 #endif
 
 /* ----- dynamic memory installation ----- */
+#define memory_install_read_handler(cpu, space, start, end, mask, mirror, handler)				\
+	_memory_install_read_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_read8_handler(cpu, space, start, end, mask, mirror, handler)				\
 	_memory_install_read8_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_read16_handler(cpu, space, start, end, mask, mirror, handler)			\
@@ -1023,6 +1032,8 @@ extern address_map *	construct_map_0(address_map *map);
 #define memory_install_read64_handler(cpu, space, start, end, mask, mirror, handler)			\
 	_memory_install_read64_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 
+#define memory_install_write_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_write8_handler(cpu, space, start, end, mask, mirror, handler)			\
 	_memory_install_write8_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_write16_handler(cpu, space, start, end, mask, mirror, handler)			\
@@ -1032,6 +1043,8 @@ extern address_map *	construct_map_0(address_map *map);
 #define memory_install_write64_handler(cpu, space, start, end, mask, mirror, handler)			\
 	_memory_install_write64_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 
+#define memory_install_read_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_read_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_read8_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
 	_memory_install_read8_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_read16_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
@@ -1041,6 +1054,8 @@ extern address_map *	construct_map_0(address_map *map);
 #define memory_install_read64_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
 	_memory_install_read64_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 
+#define memory_install_write_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
+	_memory_install_write_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_write8_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
 	_memory_install_write8_matchmask_handler(cpu, space, start, end, mask, mirror, handler, #handler)
 #define memory_install_write16_matchmask_handler(cpu, space, start, end, mask, mirror, handler)			\
