@@ -1,12 +1,12 @@
-/*
- * Aztarac soundboard interface emulation
- *
- * Jul 25 1999 by Mathis Rosenhauer
- *
- */
+/***************************************************************************
+
+    Centuri Aztarac hardware
+
+***************************************************************************/
 
 #include "driver.h"
 #include "cpu/z80/z80.h"
+#include "aztarac.h"
 
 static int sound_status;
 
@@ -26,35 +26,33 @@ WRITE16_HANDLER( aztarac_sound_w )
 		soundlatch_w(offset, data);
 		sound_status ^= 0x21;
 		if (sound_status & 0x20)
-			cpu_cause_interrupt( 1, Z80_IRQ_INT );
+			cpunum_set_input_line(1, 0, HOLD_LINE);
 	}
 }
 
-READ_HANDLER( aztarac_snd_command_r )
+READ8_HANDLER( aztarac_snd_command_r )
 {
     sound_status |= 0x01;
     sound_status &= ~0x20;
     return soundlatch_r(offset);
 }
 
-READ_HANDLER( aztarac_snd_status_r )
+READ8_HANDLER( aztarac_snd_status_r )
 {
     return sound_status & ~0x01;
 }
 
-WRITE_HANDLER( aztarac_snd_status_w )
+WRITE8_HANDLER( aztarac_snd_status_w )
 {
     sound_status &= ~0x10;
 }
 
-int aztarac_snd_timed_irq (void)
+INTERRUPT_GEN( aztarac_snd_timed_irq )
 {
     sound_status ^= 0x10;
 
     if (sound_status & 0x10)
-        return interrupt();
-    else
-        return ignore_interrupt();
+        cpunum_set_input_line(1,0,HOLD_LINE);
 }
 
 
