@@ -1,13 +1,15 @@
 /***************************************************************************
 
-	Exidy 440 sound system
+    Exidy 440 sound system
 
-	Special thanks to Zonn Moore and Neil Bradley for letting me hack
-	their Retrocade CVSD decoder into the sound system here.
+    Special thanks to Zonn Moore and Neil Bradley for letting me hack
+    their Retrocade CVSD decoder into the sound system here.
 
 ***************************************************************************/
 
 #include "driver.h"
+#include "exidy440.h"
+#include "state.h"
 #include <math.h>
 
 
@@ -17,10 +19,6 @@
 
 
 
-/* sample rates for each chip */
-#define	SAMPLE_RATE_FAST		(12979200/256)	/* FCLK */
-#define	SAMPLE_RATE_SLOW		(12979200/512)	/* SCLK */
-
 /* internal caching */
 #define	MAX_CACHE_ENTRIES		1024				/* maximum separate samples we expect to ever see */
 #define	SAMPLE_BUFFER_LENGTH	1024				/* size of temporary decode buffer on the stack */
@@ -92,18 +90,16 @@ static int m6844_interrupt;
 static int m6844_chain;
 
 /* sound interface parameters */
-static int sound_stream;
+static sound_stream *stream;
 static sound_channel_data sound_channel[4];
 
 /* debugging */
 static FILE *debuglog;
 
+/* channel frequency is configurable */
+static int channel_frequency[4];
+
 /* constant channel parameters */
-static const int channel_frequency[4] =
-{
-	SAMPLE_RATE_FAST, SAMPLE_RATE_FAST,		/* channels 0 and 1 are run by FCLK */
-	SAMPLE_RATE_SLOW, SAMPLE_RATE_SLOW		/* channels 2 and 3 are run by SCLK */
-};
 static const int channel_bits[4] =
 {
 	4, 4,									/* channels 0 and 1 are MC3418s, 4-bit CVSD */
@@ -112,7 +108,7 @@ static const int channel_bits[4] =
 
 
 /* function prototypes */
-static void channel_update(int ch, INT16 **buffer, int length);
+static void channel_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length);
 static void m6844_finished(int ch);
 static void play_cvsd(int ch);
 static void stop_cvsd(int ch);
@@ -148,23 +144,19 @@ static void finish_wav_file(void);
 
 /*************************************
  *
- *	Initialize the sound system
+ *  Initialize the sound system
  *
  *************************************/
 
-int exidy440_sh_start(const struct MachineSound *msound)
+void *exidy440_sh_start(int clock, const struct CustomSound_interface *config)
 {
-	const char *names[] =
-	{
-		"Exidy 440 sound left",
-		"Exidy 440 sound right"
-	};
 	int i, length;
-	int vol[2];
 
 	/* reset the system */
 	exidy440_sound_command = 0;
 	exidy440_sound_command_ack = 1;
+	state_save_register_global(exidy440_sound_command);
+	state_save_register_global(exidy440_sound_command_ack);
 
 	/* reset the 6844 */
 	for (i = 0; i < 4; i++)
@@ -176,76 +168,55 @@ int exidy440_sh_start(const struct MachineSound *msound)
 	m6844_interrupt = 0x00;
 	m6844_chain = 0x00;
 
+	state_save_register_int("m6844", 0, "priority", &m6844_priority);
+	state_save_register_int("m6844", 0, "interrupt", &m6844_interrupt);
+	state_save_register_int("m6844", 0, "chain", &m6844_chain);
+
+	channel_frequency[0] = clock;   /* channels 0 and 1 are run by FCLK */
+	channel_frequency[1] = clock;
+	channel_frequency[2] = clock/2; /* channels 2 and 3 are run by SCLK */
+	channel_frequency[3] = clock/2;
+
 	/* get stream channels */
-	vol[0] = MIXER(100, MIXER_PAN_LEFT);
-	vol[1] = MIXER(100, MIXER_PAN_RIGHT);
-	sound_stream = stream_init_multi(2, names, vol, SAMPLE_RATE_FAST, 0, channel_update);
+	stream = stream_create(0, 2, clock, NULL, channel_update);
 
 	/* allocate the sample cache */
 	length = memory_region_length(REGION_SOUND1) * 16 + MAX_CACHE_ENTRIES * sizeof(sound_cache_entry);
-	sound_cache = malloc(length);
-	if (!sound_cache)
-		return 1;
+	sound_cache = auto_malloc(length);
 
 	/* determine the hard end of the cache and reset */
 	sound_cache_max = (sound_cache_entry *)((UINT8 *)sound_cache + length);
 	reset_sound_cache();
 
 	/* allocate the mixer buffer */
-	mixer_buffer_left = malloc(2 * SAMPLE_RATE_FAST * sizeof(INT32));
-	if (!mixer_buffer_left)
-	{
-		free(sound_cache);
-		sound_cache = NULL;
-		return 1;
-	}
-	mixer_buffer_right = mixer_buffer_left + SAMPLE_RATE_FAST;
+	mixer_buffer_left = auto_malloc(2 * clock * sizeof(INT32));
+	mixer_buffer_right = mixer_buffer_left + clock;
 
 	if (SOUND_LOG)
 		debuglog = fopen("sound.log", "w");
 
-	return 0;
+	return auto_malloc(1);
 }
 
 
 
 /*************************************
  *
- *	Tear down the sound system
+ *  Tear down the sound system
  *
  *************************************/
 
-void exidy440_sh_stop(void)
+void exidy440_sh_stop(void *token)
 {
 	if (SOUND_LOG && debuglog)
 		fclose(debuglog);
-
-	if (sound_cache)
-		free(sound_cache);
-	sound_cache = NULL;
-
-	if (mixer_buffer_left)
-		free(mixer_buffer_left);
-	mixer_buffer_left = mixer_buffer_right = NULL;
 }
 
 
 
 /*************************************
  *
- *	Periodic sound update
- *
- *************************************/
-
-void exidy440_sh_update(void)
-{
-}
-
-
-
-/*************************************
- *
- *	Add a bunch of samples to the mix
+ *  Add a bunch of samples to the mix
  *
  *************************************/
 
@@ -289,11 +260,11 @@ static void add_and_scale_samples(int ch, INT32 *dest, int samples, int volume)
 
 /*************************************
  *
- *	Mix the result to 16 bits
+ *  Mix the result to 16 bits
  *
  *************************************/
 
-static void mix_to_16(int length, INT16 *dest_left, INT16 *dest_right)
+static void mix_to_16(int length, stream_sample_t *dest_left, stream_sample_t *dest_right)
 {
 	INT32 *mixer_left = mixer_buffer_left;
 	INT32 *mixer_right = mixer_buffer_right;
@@ -318,12 +289,14 @@ static void mix_to_16(int length, INT16 *dest_left, INT16 *dest_right)
 
 /*************************************
  *
- *	Stream callback
+ *  Stream callback
  *
  *************************************/
 
-static void channel_update(int ch, INT16 **buffer, int length)
+static void channel_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
 {
+	int ch;
+
 	/* reset the mixer buffers */
 	memset(mixer_buffer_left, 0, length * sizeof(INT32));
 	memset(mixer_buffer_right, 0, length * sizeof(INT32));
@@ -370,21 +343,21 @@ static void channel_update(int ch, INT16 **buffer, int length)
 	}
 
 	/* all done, time to mix it */
-	mix_to_16(length, buffer[0], buffer[1]);
+	mix_to_16(length, outputs[0], outputs[1]);
 }
 
 
 
 /*************************************
  *
- *	Sound command register
+ *  Sound command register
  *
  *************************************/
 
-READ_HANDLER( exidy440_sound_command_r )
+READ8_HANDLER( exidy440_sound_command_r )
 {
 	/* clear the FIRQ that got us here and acknowledge the read to the main CPU */
-	cpu_set_irq_line(1, 1, CLEAR_LINE);
+	cpunum_set_input_line(1, 1, CLEAR_LINE);
 	exidy440_sound_command_ack = 1;
 
 	return exidy440_sound_command;
@@ -394,17 +367,17 @@ READ_HANDLER( exidy440_sound_command_r )
 
 /*************************************
  *
- *	Sound volume registers
+ *  Sound volume registers
  *
  *************************************/
 
-WRITE_HANDLER( exidy440_sound_volume_w )
+WRITE8_HANDLER( exidy440_sound_volume_w )
 {
 	if (SOUND_LOG && debuglog)
 		fprintf(debuglog, "Volume %02X=%02X\n", offset, data);
 
 	/* update the stream */
-	stream_update(sound_stream, 0);
+	stream_update(stream, 0);
 
 	/* set the new volume */
 	exidy440_sound_volume[offset] = ~data;
@@ -414,34 +387,27 @@ WRITE_HANDLER( exidy440_sound_volume_w )
 
 /*************************************
  *
- *	Sound interrupt handling
+ *  Sound interrupt handling
  *
  *************************************/
 
-int exidy440_sound_interrupt(void)
+WRITE8_HANDLER( exidy440_sound_interrupt_clear_w )
 {
-	cpu_set_irq_line(1, 0, ASSERT_LINE);
-	return ignore_interrupt();
-}
-
-
-WRITE_HANDLER( exidy440_sound_interrupt_clear_w )
-{
-	cpu_set_irq_line(1, 0, CLEAR_LINE);
+	cpunum_set_input_line(1, 0, CLEAR_LINE);
 }
 
 
 
 /*************************************
  *
- *	MC6844 DMA controller interface
+ *  MC6844 DMA controller interface
  *
  *************************************/
 
 void exidy440_m6844_update(void)
 {
 	/* update the stream */
-	stream_update(sound_stream, 0);
+	stream_update(stream, 0);
 }
 
 
@@ -465,11 +431,11 @@ void m6844_finished(int ch)
 
 /*************************************
  *
- *	MC6844 DMA controller I/O
+ *  MC6844 DMA controller I/O
  *
  *************************************/
 
-READ_HANDLER( exidy440_m6844_r )
+READ8_HANDLER( exidy440_m6844_r )
 {
 	int result = 0;
 
@@ -550,7 +516,7 @@ READ_HANDLER( exidy440_m6844_r )
 }
 
 
-WRITE_HANDLER( exidy440_m6844_w )
+WRITE8_HANDLER( exidy440_m6844_w )
 {
 	int i;
 
@@ -653,7 +619,7 @@ WRITE_HANDLER( exidy440_m6844_w )
 
 /*************************************
  *
- *	Sound cache management
+ *  Sound cache management
  *
  *************************************/
 
@@ -705,7 +671,7 @@ INT16 *find_or_add_to_sound_cache(int address, int length, int bits, int frequen
 
 /*************************************
  *
- *	Internal CVSD decoder and player
+ *  Internal CVSD decoder and player
  *
  *************************************/
 
@@ -760,7 +726,7 @@ void stop_cvsd(int ch)
 {
 	/* the DMA channel is marked inactive; that will kill the audio */
 	sound_channel[ch].remaining = 0;
-	stream_update(sound_stream, 0);
+	stream_update(stream, 0);
 
 	if (SOUND_LOG && debuglog)
 		fprintf(debuglog, "Channel %d stop\n", ch);
@@ -770,7 +736,7 @@ void stop_cvsd(int ch)
 
 /*************************************
  *
- *	FIR digital filter
+ *  FIR digital filter
  *
  *************************************/
 
@@ -805,7 +771,7 @@ void fir_filter(INT32 *input, INT16 *output, int count)
 
 /*************************************
  *
- *	CVSD decoder
+ *  CVSD decoder
  *
  *************************************/
 
@@ -961,7 +927,7 @@ void decode_and_filter_cvsd(UINT8 *input, int bytes, int maskbits, int frequency
 
 /*************************************
  *
- *	Debugging
+ *  Debugging
  *
  *************************************/
 
