@@ -18,6 +18,7 @@
 #include "sound/dac.h"
 #include "includes/mcr.h"
 #include "sndhrdw/mcr.h"
+#include "state.h"
 
 
 
@@ -122,6 +123,12 @@ void mcr_sound_init(UINT8 config)
 	{
 		ssio_sound_cpu = sound_cpu++;
 		ssio_compute_ay8910_modulation();
+		state_save_register_global_array(ssio_data);
+		state_save_register_global(ssio_status);
+		state_save_register_global(ssio_14024_count);
+		state_save_register_global(ssio_mute);
+		state_save_register_global_array(ssio_overall);
+		state_save_register_global_2d_array(ssio_duty_cycle);
 	}
 
 	/* Turbo Chip Squeak */
@@ -130,6 +137,7 @@ void mcr_sound_init(UINT8 config)
 		pia_config(0, PIA_ALTERNATE_ORDERING, &turbocs_pia_intf);
 		turbocs_dac_index = dac_index++;
 		turbocs_sound_cpu = sound_cpu++;
+		state_save_register_global(turbocs_status);
 	}
 
 	/* Chip Squeak Deluxe */
@@ -138,6 +146,7 @@ void mcr_sound_init(UINT8 config)
 		pia_config(0, PIA_ALTERNATE_ORDERING, &csdeluxe_pia_intf);
 		csdeluxe_dac_index = dac_index++;
 		csdeluxe_sound_cpu = sound_cpu++;
+		state_save_register_global(csdeluxe_status);
 	}
 
 	/* Sounds Good */
@@ -147,6 +156,7 @@ void mcr_sound_init(UINT8 config)
 		pia_config(1, PIA_ALTERNATE_ORDERING, &soundsgood_pia_intf);
 		soundsgood_dac_index = dac_index++;
 		soundsgood_sound_cpu = sound_cpu++;
+		state_save_register_global(soundsgood_status);
 	}
 
 	/* Squawk n Talk */
@@ -155,12 +165,15 @@ void mcr_sound_init(UINT8 config)
 		pia_config(0, PIA_STANDARD_ORDERING, &squawkntalk_pia0_intf);
 		pia_config(1, PIA_STANDARD_ORDERING, &squawkntalk_pia1_intf);
 		squawkntalk_sound_cpu = sound_cpu++;
+		state_save_register_global(squawkntalk_tms_command);
+		state_save_register_global(squawkntalk_tms_strobes);
 	}
 
 	/* Advanced Audio */
 	if (mcr_sound_config & MCR_WILLIAMS_SOUND)
 	{
-		williams_cvsd_init(sound_cpu++, 0);
+		williams_cvsd_init(0);
+		sound_cpu++;
 		dac_index++;
 	}
 }
@@ -327,7 +340,6 @@ static void ssio_update_volumes(void)
 	AY8910_set_volume(1, 0, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][0]]);
 	AY8910_set_volume(1, 1, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][1]]);
 	AY8910_set_volume(1, 2, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][2]]);
-/*printf("overall: %d/%d\n", ssio_overall[0], ssio_overall[1]); */
 }
 
 static WRITE8_HANDLER( ssio_porta0_w )
