@@ -77,10 +77,6 @@ Revision History:
 
 #include "fmopl.h"
 
-#ifndef PI
-#define PI 3.14159265358979323846
-#endif
-
 
 
 /* output final shift */
@@ -1193,7 +1189,7 @@ static int init_tables(void)
 	for (i=0; i<SIN_LEN; i++)
 	{
 		/* non-standard sinus */
-		m = sin( ((i*2)+1) * PI / SIN_LEN ); /* checked against the real chip */
+		m = sin( ((i*2)+1) * M_PI / SIN_LEN ); /* checked against the real chip */
 
 		/* we never reach zero here due to ((i*2)+1) */
 
