@@ -1,32 +1,33 @@
 /*********************************************************************
 
-  ui_text.c
+    ui_text.c
 
-  Functions used to retrieve text used by MAME, to aid in
-  translation.
+    Functions used to retrieve text used by MAME, to aid in
+    translation.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
 
 *********************************************************************/
 
 #include "driver.h"
 #include "ui_text.h"
 
-struct lang_struct lang;
+#ifdef MESS
+extern const char *mess_default_text[];
+#endif /* MESS */
 
-char *trans_text[UI_last_entry + 1];
+
+lang_struct lang;
 
 /* All entries in this table must match the enum ordering in "ui_text.h" */
-const char * default_text[] =
+static const char *mame_default_text[] =
 {
-#ifndef MESS
-	"MAME",
-#else
-	"MESS",
-#endif
-
+	APPNAME,
 	/* copyright stuff */
 	"Usage of emulators in conjunction with ROMs you don't own is forbidden by copyright law.",
 	"IF YOU ARE NOT LEGALLY ENTITLED TO PLAY \"%s\" ON THIS EMULATOR, PRESS ESC.",
-	"Otherwise, type OK to continue",
+	"Otherwise, type OK or move the joystick left then right to continue",
 
 	/* misc stuff */
 	"Return to Main Menu",
@@ -56,11 +57,7 @@ const char * default_text[] =
 	"Vector Intensity",
 	"Overclock",
 	"ALL CPUS",
-#ifndef MESS
-	"History not available",
-#else
-	"System Info not available",
-#endif
+	HISTORYNAME " not available",
 
 	/* special characters */
 	"\x11",
@@ -71,29 +68,18 @@ const char * default_text[] =
 	"\x1b",
 
 	/* known problems */
-#ifndef MESS
-	"There are known problems with this game:",
-#else
-	"There are known problems with this system",
-#endif
+	"There are known problems with this " GAMENOUN,
 	"The colors aren't 100% accurate.",
 	"The colors are completely wrong.",
 	"The video emulation isn't 100% accurate.",
 	"The sound emulation isn't 100% accurate.",
 	"The game lacks sound.",
 	"Screen flipping in cocktail mode is not supported.",
-#ifndef MESS
-	"THIS GAME DOESN'T WORK PROPERLY",
-#else
-	"THIS SYSTEM DOESN'T WORK PROPERLY",
-#endif
+	"THIS " CAPGAMENOUN " DOESN'T WORK PROPERLY",
 	"The game has protection which isn't fully emulated.",
 	"There are working clones of this game. They are:",
-	"Type OK to continue",
-#ifdef MESS
-	"The emulated system is a computer: ",
-	"The keyboard emulation may not be 100% accurate.",
-#endif
+	"One or more ROMs/CHDs for this game are incorrect. The " GAMENOUN " may not run correctly.",
+	"Type OK or move the joystick left then right to continue",
 
 	/* main menu */
 	"Input (general)",
@@ -101,47 +87,52 @@ const char * default_text[] =
 	"Analog Controls",
 	"Calibrate Joysticks",
 	"Bookkeeping Info",
-#ifndef MESS
-	"Input (this game)",
-	"Game Information",
-	"Game History",
-	"Reset Game",
-	"Return to Game",
-#else
-	"Input (this machine)",
-	"Machine Information",
-	"Machine Usage & History",
-	"Reset Machine",
-	"Return to Machine",
-	"Image Information",
-	"File Manager",
-	"Tape Control",
-#endif
+
+	"Input (this " CAPSTARTGAMENOUN")",
+	CAPSTARTGAMENOUN " Information",
+	CAPSTARTGAMENOUN " History",
+	"Reset " CAPSTARTGAMENOUN,
+	"Return to " CAPSTARTGAMENOUN,
+
 	"Cheat",
 	"Memory Card",
 
 	/* input */
-	"Key/Joy Speed",
+	"Digital Speed",
+	"Autocenter Speed",
 	"Reverse",
 	"Sensitivity",
 
+	/* input groups */
+	"User Interface",
+	"Player 1 Controls",
+	"Player 2 Controls",
+	"Player 3 Controls",
+	"Player 4 Controls",
+	"Player 5 Controls",
+	"Player 6 Controls",
+	"Player 7 Controls",
+	"Player 8 Controls",
+	"Other Controls",
+	"Return to Groups",
+
 	/* stats */
+	"Uptime",
 	"Tickets dispensed",
 	"Coin",
 	"(locked)",
 
 	/* memory card */
-	"Load Memory Card",
-	"Eject Memory Card",
-	"Create Memory Card",
-	"Call Memory Card Manager (RESET)",
-	"Failed To Load Memory Card!",
-	"Load OK!",
-	"Memory Card Ejected!",
-	"Memory Card Created OK!",
-	"Failed To Create Memory Card!",
-	"(It already exists ?)",
-	"DAMN!! Internal Error!",
+	"Card Number:",
+	"Load Selected Card",
+	"Eject Current Card",
+	"Create New Card",
+	"Error loading memory card",
+	"Memory card loaded",
+	"Memory card ejected",
+	"Memory card created",
+	"Error creating memory card",
+	"(Card may already exist)",
 
 	/* cheats */
 	"Enable/Disable a Cheat",
@@ -204,39 +195,79 @@ const char * default_text[] =
 	"All values saved",
 	"One match found - added to list",
 
+	/* refresh rate */
+	"Refresh rate",
+	"Decoding Graphics",
+
+	/* XMAME-specific */
+	"Rapid fire",
+
 	NULL
 };
 
-int uistring_init (void *langfile)
+
+
+static const char **default_text[] =
+{
+	mame_default_text,
+#ifdef MESS
+	mess_default_text,
+#endif /* MESS */
+	NULL
+};
+
+
+
+static const char **trans_text;
+
+
+int uistring_init (mame_file *langfile)
 {
 	/*
-		TODO: This routine needs to do several things:
-			- load an external font if needed
-			- determine the number of characters in the font
-			- deal with multibyte languages
+        TODO: This routine needs to do several things:
+            - load an external font if needed
+            - determine the number of characters in the font
+            - deal with multibyte languages
 
-	*/
+    */
 
-	int i;
+	int i, j, str;
 	char curline[255];
 	char section[255] = "\0";
 	char *ptr;
+	int string_count;
 
-	/* Clear out any default strings */
-	for (i = 0; i <= UI_last_entry; i ++)
+	/* count the total amount of strings */
+	string_count = 0;
+	for (i = 0; default_text[i]; i++)
 	{
-		trans_text[i] = NULL;
+		for (j = 0; default_text[i][j]; j++)
+			string_count++;
+	}
+
+	/* allocate the translated text array, and set defaults */
+	trans_text = auto_malloc(sizeof(const char *) * string_count);
+
+	/* copy in references to all of the strings */
+	str = 0;
+	for (i = 0; default_text[i]; i++)
+	{
+		for (j = 0; default_text[i][j]; j++)
+			trans_text[str++] = default_text[i][j];
 	}
 
 	memset(&lang, 0, sizeof(lang));
 
-	if (!langfile) return 0;
+	/* if no language file, exit */
+	if (!langfile)
+		return 0;
 
-	while (osd_fgets (curline, 255, langfile) != NULL)
+	while (mame_fgets (curline, sizeof(curline) / sizeof(curline[0]), langfile) != NULL)
 	{
 		/* Ignore commented and blank lines */
 		if (curline[0] == ';') continue;
 		if (curline[0] == '\n') continue;
+		if (curline[0] == '\r') continue;
 
 		if (curline[0] == '[')
 		{
@@ -254,22 +285,22 @@ int uistring_init (void *langfile)
 			ptr = strtok (curline, "=");
 			if (strcmp (ptr, "Version") == 0)
 			{
-				ptr = strtok (NULL, "\n");
+				ptr = strtok (NULL, "\n\r");
 				sscanf (ptr, "%d", &lang.version);
 			}
 			else if (strcmp (ptr, "Language") == 0)
 			{
-				ptr = strtok (NULL, "\n");
+				ptr = strtok (NULL, "\n\r");
 				strcpy (lang.langname, ptr);
 			}
 			else if (strcmp (ptr, "Author") == 0)
 			{
-				ptr = strtok (NULL, "\n");
+				ptr = strtok (NULL, "\n\r");
 				strcpy (lang.author, ptr);
 			}
 			else if (strcmp (ptr, "Font") == 0)
 			{
-				ptr = strtok (NULL, "\n");
+				ptr = strtok (NULL, "\n\r");
 				strcpy (lang.fontname, ptr);
 			}
 		}
@@ -278,27 +309,30 @@ int uistring_init (void *langfile)
 		if (strcmp (section, "Strings") == 0)
 		{
 			/* Get all text up to the first line ending */
-			ptr = strtok (curline, "\n");
+			ptr = strtok (curline, "\n\r");
 
 			/* Find a matching default string */
-			for (i = 0; i < UI_last_entry; i ++)
+			str = 0;
+			for (i = 0; default_text[i]; i++)
 			{
-				if (strcmp (curline, default_text[i]) == 0)
+				for (j = 0; default_text[i][j]; j++)
+				{
+					if (strcmp (curline, default_text[i][j]) == 0)
 				{
 					char transline[255];
 
 					/* Found a match, read next line as the translation */
-					osd_fgets (transline, 255, langfile);
+					mame_fgets (transline, 255, langfile);
 
 					/* Get all text up to the first line ending */
-					ptr = strtok (transline, "\n");
+					ptr = strtok (transline, "\n\r");
 
 					/* Allocate storage and copy the string */
-					trans_text[i] = malloc (strlen(transline)+1);
-					strcpy (trans_text[i], transline);
-
-					/* Done searching */
-					break;
+						trans_text[str] = auto_strdup(transline);
+						if (!trans_text[str])
+							return 1;
+					}
+					str++;
 				}
 			}
 		}
@@ -308,27 +342,9 @@ int uistring_init (void *langfile)
 	return 0;
 }
 
-void uistring_shutdown (void)
-{
-	int i;
 
-	/* Deallocate storage for the strings */
-	for (i = 0; i <= UI_last_entry; i ++)
-	{
-		if (trans_text[i])
-		{
-			free (trans_text[i]);
-			trans_text[i] = NULL;
-		}
-	}
-}
 
 const char * ui_getstring (int string_num)
 {
-	/* Try to use the language file strings first */
-	if (trans_text[string_num] != NULL)
 		return trans_text[string_num];
-	else
-		/* That failed, use the default strings */
-		return default_text[string_num];
 }
