@@ -1,5 +1,16 @@
+/***************************************************************************
+
+    unzip.c
+
+    Functions to manipulate data within ZIP files.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+***************************************************************************/
+
 #include "unzip.h"
-#include "mame.h"
+#include "driver.h"
 
 #include <stdlib.h>
 #include <string.h>
@@ -49,10 +60,10 @@ static UINT32 read_dword (char *buf) {
 
 /* Locate end-of-central-dir sig in buffer and return offset
    out:
-	*offset offset of cent dir start in buffer
+    *offset offset of cent dir start in buffer
    return:
-	==0 not found
-	!=0 found, *offset valid
+    ==0 not found
+    !=0 found, *offset valid
 */
 static int ecd_find_sig (char *buffer, int buflen, int *offset)
 {
@@ -73,7 +84,7 @@ static int ecd_find_sig (char *buffer, int buflen, int *offset)
    out:
      zip->ecd, zip->ecd_length ecd data
 */
-static int ecd_read(ZIP* zip) {
+static int ecd_read(zip_file* zip) {
 	char* buf;
 	int buf_length = 1024; /* initial buffer length */
 
@@ -83,7 +94,7 @@ static int ecd_read(ZIP* zip) {
 		if (buf_length > zip->length)
 			buf_length = zip->length;
 
-		if (fseek(zip->fp, zip->length - buf_length, SEEK_SET) != 0) {
+		if (osd_fseek(zip->fp, zip->length - buf_length, SEEK_SET) != 0) {
 			return -1;
 		}
 
@@ -93,7 +104,7 @@ static int ecd_read(ZIP* zip) {
 			return -1;
 		}
 
-		if (fread( buf, buf_length, 1, zip->fp ) != 1) {
+		if (osd_fread( zip->fp, buf, buf_length ) != buf_length) {
 			free(buf);
 			return -1;
 		}
@@ -179,15 +190,17 @@ static int ecd_read(ZIP* zip) {
      !=0 success, zip stream
      ==0 error
 */
-ZIP* openzip(const char* zipfile) {
+zip_file* openzip(int pathtype, int pathindex, const char* zipfile) {
+	osd_file_error error;
+
 	/* allocate */
-	ZIP* zip = (ZIP*)malloc( sizeof(ZIP) );
+	zip_file* zip = (zip_file*)malloc( sizeof(zip_file) );
 	if (!zip) {
 		return 0;
 	}
 
 	/* open */
-	zip->fp = fopen(zipfile, "rb");
+	zip->fp = osd_fopen(pathtype, pathindex, zipfile, "rb", &error);
 	if (!zip->fp) {
 		errormsg ("Opening for reading", ERROR_FILESYSTEM, zipfile);
 		free(zip);
@@ -195,24 +208,24 @@ ZIP* openzip(const char* zipfile) {
 	}
 
 	/* go to end */
-	if (fseek(zip->fp, 0L, SEEK_END) != 0) {
+	if (osd_fseek(zip->fp, 0L, SEEK_END) != 0) {
 		errormsg ("Seeking to end", ERROR_FILESYSTEM, zipfile);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
 
 	/* get length */
-	zip->length = ftell(zip->fp);
+	zip->length = osd_ftell(zip->fp);
 	if (zip->length < 0) {
 		errormsg ("Get file size", ERROR_FILESYSTEM, zipfile);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
 	if (zip->length == 0) {
 		errormsg ("Empty file", ERROR_CORRUPT, zipfile);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
@@ -220,7 +233,7 @@ ZIP* openzip(const char* zipfile) {
 	/* read ecd data */
 	if (ecd_read(zip)!=0) {
 		errormsg ("Reading ECD (end of central directory)", ERROR_CORRUPT, zipfile);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
@@ -242,15 +255,15 @@ ZIP* openzip(const char* zipfile) {
 		(zip->total_entries_cent_dir < 1)) {
 		errormsg("Cannot span disks", ERROR_UNSUPPORTED, zipfile);
 		free(zip->ecd);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
 
-	if (fseek(zip->fp, zip->offset_to_start_of_cent_dir, SEEK_SET)!=0) {
+	if (osd_fseek(zip->fp, zip->offset_to_start_of_cent_dir, SEEK_SET)!=0) {
 		errormsg ("Seeking to central directory", ERROR_CORRUPT, zipfile);
 		free(zip->ecd);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
@@ -259,16 +272,16 @@ ZIP* openzip(const char* zipfile) {
 	zip->cd = (char*)malloc( zip->size_of_cent_dir );
 	if (!zip->cd) {
 		free(zip->ecd);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
 
-	if (fread(zip->cd, zip->size_of_cent_dir, 1, zip->fp)!=1) {
+	if (osd_fread(zip->fp, zip->cd, zip->size_of_cent_dir)!=zip->size_of_cent_dir) {
 		errormsg ("Reading central directory", ERROR_CORRUPT, zipfile);
 		free(zip->cd);
 		free(zip->ecd);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
@@ -284,11 +297,13 @@ ZIP* openzip(const char* zipfile) {
 	if (!zip->zip) {
 		free(zip->cd);
 		free(zip->ecd);
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		free(zip);
 		return 0;
 	}
 	strcpy(zip->zip, zipfile);
+	zip->pathtype = pathtype;
+	zip->pathindex = pathindex;
 
 	return zip;
 }
@@ -300,7 +315,7 @@ ZIP* openzip(const char* zipfile) {
      !=0 success
      ==0 error
 */
-struct zipent* readzip(ZIP* zip) {
+zip_entry* readzip(zip_file* zip) {
 
 	/* end of directory */
 	if (zip->cd_pos >= zip->size_of_cent_dir)
@@ -348,14 +363,14 @@ struct zipent* readzip(ZIP* zip) {
 }
 
 /* Closes a zip stream */
-void closezip(ZIP* zip) {
+void closezip(zip_file* zip) {
 	/* release all */
 	free(zip->ent.name);
 	free(zip->cd);
 	free(zip->ecd);
 	/* only if not suspended */
 	if (zip->fp)
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 	free(zip->zip);
 	free(zip);
 }
@@ -367,9 +382,9 @@ void closezip(ZIP* zip) {
      A suspended zip is automatically reopened at first call of
      readuncompressd() or readcompressed() functions
 */
-void suspendzip(ZIP* zip) {
+void suspendzip(zip_file* zip) {
 	if (zip->fp) {
-		fclose(zip->fp);
+		osd_fclose(zip->fp);
 		zip->fp = 0;
 	}
 }
@@ -378,12 +393,14 @@ void suspendzip(ZIP* zip) {
    in:
      zip suspended zip
    return:
-	zip success
-	==0 error (zip must be closed with closezip)
+    zip success
+    ==0 error (zip must be closed with closezip)
 */
-static ZIP* revivezip(ZIP* zip) {
+static zip_file* revivezip(zip_file* zip) {
+	osd_file_error error;
+
 	if (!zip->fp) {
-		zip->fp = fopen(zip->zip, "rb");
+		zip->fp = osd_fopen(zip->pathtype, zip->pathindex, zip->zip, "rb", &error);
 		if (!zip->fp) {
 			return 0;
 		}
@@ -398,16 +415,16 @@ static ZIP* revivezip(ZIP* zip) {
    note:
      ZIP file must be opened and not suspended
 */
-void rewindzip(ZIP* zip) {
+void rewindzip(zip_file* zip) {
 	zip->cd_pos = 0;
 }
 
 /* Seek zip->fp to compressed data
    return:
-	==0 success
-	<0 error
+    ==0 success
+    <0 error
 */
-int seekcompresszip(ZIP* zip, struct zipent* ent) {
+int seekcompresszip(zip_file* zip, zip_entry* ent) {
 	char buf[ZIPNAME];
 	long offset;
 
@@ -416,12 +433,12 @@ int seekcompresszip(ZIP* zip, struct zipent* ent) {
 			return -1;
 	}
 
-	if (fseek(zip->fp, ent->offset_lcl_hdr_frm_frst_disk, SEEK_SET)!=0) {
+	if (osd_fseek(zip->fp, ent->offset_lcl_hdr_frm_frst_disk, SEEK_SET)!=0) {
 		errormsg ("Seeking to header", ERROR_CORRUPT, zip->zip);
 		return -1;
 	}
 
-	if (fread(buf, ZIPNAME, 1, zip->fp)!=1) {
+	if (osd_fread(zip->fp, buf, ZIPNAME)!=ZIPNAME) {
 		errormsg ("Reading header", ERROR_CORRUPT, zip->zip);
 		return -1;
 	}
@@ -430,10 +447,10 @@ int seekcompresszip(ZIP* zip, struct zipent* ent) {
 		UINT16 filename_length = read_word (buf+ZIPFNLN);
 		UINT16 extra_field_length = read_word (buf+ZIPXTRALN);
 
-		/* calculate offset to data and fseek() there */
+		/* calculate offset to data and osd_fseek() there */
 		offset = ent->offset_lcl_hdr_frm_frst_disk + ZIPNAME + filename_length + extra_field_length;
 
-		if (fseek(zip->fp, offset, SEEK_SET) != 0) {
+		if (osd_fseek(zip->fp, offset, SEEK_SET) != 0) {
 			errormsg ("Seeking to compressed data", ERROR_CORRUPT, zip->zip);
 			return -1;
 		}
@@ -455,7 +472,7 @@ int seekcompresszip(ZIP* zip, struct zipent* ent) {
 
    990525 rewritten for use with zlib MLR
 */
-static int inflate_file(FILE* in_file, unsigned in_size, unsigned char* out_data, unsigned out_size)
+static int inflate_file(osd_file* in_file, unsigned in_size, unsigned char* out_data, unsigned out_size)
 {
     int err;
 	unsigned char* in_buffer;
@@ -472,10 +489,10 @@ static int inflate_file(FILE* in_file, unsigned in_size, unsigned char* out_data
 
     err = inflateInit2(&d_stream, -MAX_WBITS);
 	/* windowBits is passed < 0 to tell that there is no zlib header.
-	 * Note that in this case inflate *requires* an extra "dummy" byte
-	 * after the compressed stream in order to complete decompression and
-	 * return Z_STREAM_END.
-	 */
+     * Note that in this case inflate *requires* an extra "dummy" byte
+     * after the compressed stream in order to complete decompression and
+     * return Z_STREAM_END.
+     */
     if (err != Z_OK)
 	{
 		logerror("inflateInit error: %d\n", err);
@@ -495,7 +512,7 @@ static int inflate_file(FILE* in_file, unsigned in_size, unsigned char* out_data
 			return -1;
 		}
 		d_stream.next_in  = in_buffer;
-		d_stream.avail_in = fread (in_buffer, 1, MIN(in_size, INFLATE_INPUT_BUFFER_MAX), in_file);
+		d_stream.avail_in = osd_fread (in_file, in_buffer, MIN(in_size, INFLATE_INPUT_BUFFER_MAX));
 		in_size -= d_stream.avail_in;
 		if (in_size == 0)
 			d_stream.avail_in++; /* add dummy byte at end of compressed data */
@@ -532,17 +549,17 @@ static int inflate_file(FILE* in_file, unsigned in_size, unsigned char* out_data
 
 /* Read compressed data
    out:
-	data compressed data read
+    data compressed data read
    return:
-	==0 success
-	<0 error
+    ==0 success
+    <0 error
 */
-int readcompresszip(ZIP* zip, struct zipent* ent, char* data) {
+int readcompresszip(zip_file* zip, zip_entry* ent, char* data) {
 	int err = seekcompresszip(zip,ent);
 	if (err!=0)
 		return err;
 
-	if (fread(data, ent->compressed_size, 1, zip->fp)!=1) {
+	if (osd_fread(zip->fp, data, ent->compressed_size)!=ent->compressed_size) {
 		errormsg ("Reading compressed data", ERROR_CORRUPT, zip->zip);
 		return -1;
 	}
@@ -552,12 +569,12 @@ int readcompresszip(ZIP* zip, struct zipent* ent, char* data) {
 
 /* Read UNcompressed data
    out:
-	data UNcompressed data
+    data UNcompressed data
    return:
-	==0 success
-	<0 error
+    ==0 success
+    <0 error
 */
-int readuncompresszip(ZIP* zip, struct zipent* ent, char* data) {
+int readuncompresszip(zip_file* zip, zip_entry* ent, char* data) {
 	if (ent->compression_method == 0x0000) {
 		/* file is not compressed, simply stored */
 
@@ -620,20 +637,20 @@ int readuncompresszip(ZIP* zip, struct zipent* ent, char* data) {
      zip_cache_map[0] is the newer
      zip_cache_map[ZIP_CACHE_MAX-1] is the older
 */
-static ZIP* zip_cache_map[ZIP_CACHE_MAX];
+static zip_file* zip_cache_map[ZIP_CACHE_MAX];
 
-static ZIP* cache_openzip(const char* zipfile) {
-	ZIP* zip;
+static zip_file* cache_openzip(int pathtype, int pathindex, const char* zipfile) {
+	zip_file* zip;
 	unsigned i;
 
 	/* search in the cache buffer */
 	for(i=0;i<ZIP_CACHE_MAX;++i) {
-		if (zip_cache_map[i] && strcmp(zip_cache_map[i]->zip,zipfile)==0) {
+		if (zip_cache_map[i] && zip_cache_map[i]->pathtype == pathtype && zip_cache_map[i]->pathindex == pathindex && strcmp(zip_cache_map[i]->zip,zipfile)==0) {
 			/* found */
 			unsigned j;
 
 /*
-			logerror("Zip cache HIT  for %s\n", zipfile);
+            logerror("Zip cache HIT  for %s\n", zipfile);
 */
 
 			/* reset the zip directory */
@@ -655,11 +672,11 @@ static ZIP* cache_openzip(const char* zipfile) {
 	/* not found */
 
 /*
-	logerror("Zip cache FAIL for %s\n", zipfile);
+    logerror("Zip cache FAIL for %s\n", zipfile);
 */
 
 	/* open the zip */
-	zip = openzip( zipfile );
+	zip = openzip( pathtype, pathindex, zipfile );
 	if (!zip)
 		return 0;
 
@@ -681,7 +698,7 @@ static ZIP* cache_openzip(const char* zipfile) {
 	return zip_cache_map[0];
 }
 
-static void cache_closezip(ZIP* zip) {
+static void cache_closezip(zip_file* zip) {
 	unsigned i;
 
 	/* search in the cache buffer */
@@ -716,7 +733,7 @@ void unzip_cache_clear()
 
 			/* reset cache entry */
 			zip_cache_map[i] = 0;
-/*			return; */
+/*          return; */
 
 		}
 	}
@@ -726,7 +743,7 @@ void unzip_cache_clear()
 
 #else
 
-#define cache_openzip(a) openzip(a)
+#define cache_openzip(a,b,c) openzip(a,b,c)
 #define cache_closezip(a) closezip(a)
 #define cache_suspendzip(a) closezip(a)
 
@@ -760,11 +777,11 @@ static int equal_filename(const char* zipfile, const char* file) {
 /* Pass the path to the zipfile and the name of the file within the zipfile.
    buf will be set to point to the uncompressed image of that zipped file.
    length will be set to the length of the uncompressed data. */
-int /* error */ load_zipped_file (const char* zipfile, const char* filename, unsigned char** buf, unsigned int* length) {
-	ZIP* zip;
-	struct zipent* ent;
+int /* error */ load_zipped_file (int pathtype, int pathindex, const char* zipfile, const char* filename, unsigned char** buf, unsigned int* length) {
+	zip_file* zip;
+	zip_entry* ent;
 
-	zip = cache_openzip(zipfile);
+	zip = cache_openzip(pathtype, pathindex, zipfile);
 	if (!zip)
 		return -1;
 
@@ -802,14 +819,14 @@ int /* error */ load_zipped_file (const char* zipfile, const char* filename, uns
 	return -1;
 }
 
-/*	Pass the path to the zipfile and the name of the file within the zipfile.
-	sum will be set to the CRC-32 of that zipped file. */
+/*  Pass the path to the zipfile and the name of the file within the zipfile.
+    sum will be set to the CRC-32 of that zipped file. */
 /*  The caller can preset sum to the expected checksum to enable "load by CRC" */
-int /* error */ checksum_zipped_file (const char *zipfile, const char *filename, unsigned int *length, unsigned int *sum) {
-	ZIP* zip;
-	struct zipent* ent;
+int /* error */ checksum_zipped_file (int pathtype, int pathindex, const char *zipfile, const char *filename, unsigned int *length, unsigned int *sum) {
+	zip_file* zip;
+	zip_entry* ent;
 
-	zip = cache_openzip(zipfile);
+	zip = cache_openzip(pathtype, pathindex, zipfile);
 	if (!zip)
 		return -1;
 
@@ -828,7 +845,7 @@ int /* error */ checksum_zipped_file (const char *zipfile, const char *filename,
 	cache_suspendzip(zip);
 
 	/* NS981003: support for "load by CRC" */
-	zip = cache_openzip(zipfile);
+	zip = cache_openzip(pathtype, pathindex, zipfile);
 	if (!zip)
 		return -1;
 
