@@ -4,6 +4,9 @@
 
     Functions used to handle MAME's crude user interface.
 
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
 ***************************************************************************/
 
 #pragma once
@@ -151,6 +154,7 @@ void CLIB_DECL ui_popup(const char *text, ...) ATTR_PRINTF(1,2);
 void CLIB_DECL ui_popup_time(int seconds, const char *text, ...) ATTR_PRINTF(2,3);
 
 /* informational displays used before the game is fully up and running */
+int ui_display_decoding(mame_bitmap *bitmap, int percent);
 int ui_display_copyright(mame_bitmap *bitmap);
 int ui_display_game_warnings(mame_bitmap *bitmap);
 int ui_display_game_info(mame_bitmap *bitmap);
