@@ -1,14 +1,14 @@
 /***************************************************************************
 
-							-= American Speedway =-
+                            -= American Speedway =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
 - 8x8 4 Color Tiles (with 8 palettes) used for both:
 
-	- 1 256x256 non scrolling layer
-	- 64 (32?) Sprites
+    - 1 256x256 non scrolling layer
+    - 64 (32?) Sprites
 
 ***************************************************************************/
 #include "driver.h"
@@ -16,17 +16,17 @@
 
 /* Variables only used here: */
 
-static struct tilemap *tilemap;
+static tilemap *bg_tilemap;
 
 
-WRITE_HANDLER( amspdwy_paletteram_w )
+WRITE8_HANDLER( amspdwy_paletteram_w )
 {
 	data ^= 0xff;
 	paletteram_BBGGGRRR_w(offset,data);
-/*	paletteram_RRRGGGBB_w(offset,data); */
+/*  paletteram_RRRGGGBB_w(offset,data); */
 }
 
-WRITE_HANDLER( amspdwy_flipscreen_w )
+WRITE8_HANDLER( amspdwy_flipscreen_w )
 {
 	static int flip = 0;
 	flip ^= 1;
@@ -35,21 +35,21 @@ WRITE_HANDLER( amspdwy_flipscreen_w )
 
 /***************************************************************************
 
-						Callbacks for the TileMap code
+                        Callbacks for the TileMap code
 
-							  [ Tiles Format ]
+                              [ Tiles Format ]
 
-	Videoram:	76543210	Code Low Bits
-	Colorram:	765-----
-				---43---	Code High Bits
-				-----210	Color
+    Videoram:   76543210    Code Low Bits
+    Colorram:   765-----
+                ---43---    Code High Bits
+                -----210    Color
 
 ***************************************************************************/
 
 static void get_tile_info( int tile_index )
 {
-	data8_t code	=	videoram[ tile_index ];
-	data8_t color	=	colorram[ tile_index ];
+	UINT8 code	=	videoram[ tile_index ];
+	UINT8 color	=	colorram[ tile_index ];
 	SET_TILE_INFO(
 			0,
 			code + ((color & 0x18)<<5),
@@ -57,21 +57,21 @@ static void get_tile_info( int tile_index )
 			0)
 }
 
-WRITE_HANDLER( amspdwy_videoram_w )
+WRITE8_HANDLER( amspdwy_videoram_w )
 {
 	if (videoram[offset] != data)
 	{
 		videoram[offset] = data;
-		tilemap_mark_tile_dirty(tilemap, offset);
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
 	}
 }
 
-WRITE_HANDLER( amspdwy_colorram_w )
+WRITE8_HANDLER( amspdwy_colorram_w )
 {
 	if (colorram[offset] != data)
 	{
 		colorram[offset] = data;
-		tilemap_mark_tile_dirty(tilemap, offset);
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
 	}
 }
 
@@ -83,12 +83,12 @@ UINT32 tilemap_scan_cols_back( UINT32 col, UINT32 row, UINT32 num_cols, UINT32 n
 }
 
 
-int amspdwy_vh_start(void)
+VIDEO_START( amspdwy )
 {
-	tilemap	=	tilemap_create(	get_tile_info,	tilemap_scan_cols_back,
+	bg_tilemap	=	tilemap_create(	get_tile_info,	tilemap_scan_cols_back,
 								TILEMAP_OPAQUE,	8,8,	0x20, 0x20 );
 
-	if (tilemap)	return 0;
+	if (bg_tilemap)	return 0;
 	else			return 1;
 }
 
@@ -96,23 +96,23 @@ int amspdwy_vh_start(void)
 
 /***************************************************************************
 
-								Sprites Drawing
+                                Sprites Drawing
 
-Offset:		Format:		Value:
+Offset:     Format:     Value:
 
-0						Y
-1						X
-2						Code Low Bits
-3			7-------	Flip X
-			-6------	Flip Y
-			--5-----
-			---4----	?
-			----3---	Code High Bit?
-			-----210	Color
+0                       Y
+1                       X
+2                       Code Low Bits
+3           7-------    Flip X
+            -6------    Flip Y
+            --5-----
+            ---4----    ?
+            ----3---    Code High Bit?
+            -----210    Color
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int i;
 	int max_x = Machine->drv->screen_width  - 1;
@@ -134,12 +134,12 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 		}
 
 		drawgfx(bitmap,Machine->gfx[0],
-/*				code + ((attr & 0x18)<<5), */
+/*              code + ((attr & 0x18)<<5), */
 				code + ((attr & 0x08)<<5),
 				attr,
 				flipx, flipy,
 				x,y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0 );
+				cliprect,TRANSPARENCY_PEN,0 );
 	}
 }
 
@@ -148,12 +148,12 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 
 /***************************************************************************
 
-								Screen Drawing
+                                Screen Drawing
 
 ***************************************************************************/
 
-void amspdwy_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( amspdwy )
 {
-	tilemap_draw(bitmap,tilemap,0,0);
-	draw_sprites(bitmap);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	draw_sprites(bitmap,cliprect);
 }
