@@ -7,6 +7,7 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "vidhrdw/generic.h"
 #include "appoooh.h"
 
 unsigned char *appoooh_fg_videoram,*appoooh_fg_colorram;
@@ -15,10 +16,9 @@ unsigned char *appoooh_bg_videoram,*appoooh_bg_colorram;
 #define CHR1_OFST 0x00  /* palette page of char set #1 */
 #define CHR2_OFST 0x10  /* palette page of char set #2 */
 
-static struct tilemap *fg_tilemap,*bg_tilemap;
+static tilemap *fg_tilemap,*bg_tilemap;
 
 static int scroll_x;
-static int flipscreen;
 static int priority;
 
 /***************************************************************************
@@ -31,7 +31,7 @@ static int priority;
   Because these hardware is similar.
 
 ***************************************************************************/
-void appoooh_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( appoooh )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -58,7 +58,6 @@ void appoooh_vh_convert_color_prom(unsigned char *obsolete,unsigned short *color
 		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 
 		palette_set_color(i,r,g,b);
-
 		color_prom++;
 	}
 
@@ -77,6 +76,45 @@ void appoooh_vh_convert_color_prom(unsigned char *obsolete,unsigned short *color
 	/* to use them somewhere in the game. */
 }
 
+PALETTE_INIT( robowres )
+{
+	int i;
+	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
+	#define COLOR(gfxn,offs) (colortable[Machine->drv->gfxdecodeinfo[gfxn].color_codes_start + offs])
+
+	for (i = 0;i < Machine->drv->total_colors;i++)
+	{
+		int bit0,bit1,bit2,r,g,b;
+
+		/* red component */
+		bit0 = (*color_prom >> 0) & 0x01;
+		bit1 = (*color_prom >> 1) & 0x01;
+		bit2 = (*color_prom >> 2) & 0x01;
+		r = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		/* green component */
+		bit0 = (*color_prom >> 3) & 0x01;
+		bit1 = (*color_prom >> 4) & 0x01;
+		bit2 = (*color_prom >> 5) & 0x01;
+		g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		/* blue component */
+		bit0 = 0;
+		bit1 = (*color_prom >> 6) & 0x01;
+		bit2 = (*color_prom >> 7) & 0x01;
+		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+
+		palette_set_color(i,r,g,b);
+		color_prom++;
+	}
+
+	/* color_prom now points to the beginning of the lookup table */
+
+	for (i = 0;i < 32*8;i++)
+		colortable[i]=(*(color_prom++) & 0x0f);
+
+}
+
+
+
 /***************************************************************************
 
   Callbacks for the TileMap code
@@ -112,7 +150,7 @@ static void get_bg_tile_info(int tile_index)
   Start the video hardware emulation.
 
 ***************************************************************************/
-int appoooh_vh_start(void)
+VIDEO_START( appoooh )
 {
 	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
 	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,     8,8,32,32);
@@ -127,21 +165,13 @@ int appoooh_vh_start(void)
 	return 0;
 }
 
-WRITE_HANDLER( appoooh_scroll_w )
+WRITE8_HANDLER( appoooh_scroll_w )
 {
 	scroll_x = data;
 }
 
-/***************************************************************************
 
-  Stop the video hardware emulation.
-
-***************************************************************************/
-void appoooh_vh_stop(void)
-{
-}
-
-WRITE_HANDLER( appoooh_fg_videoram_w )
+WRITE8_HANDLER( appoooh_fg_videoram_w )
 {
 	if (appoooh_fg_videoram[offset] != data)
 	{
@@ -150,7 +180,7 @@ WRITE_HANDLER( appoooh_fg_videoram_w )
 	}
 }
 
-WRITE_HANDLER( appoooh_fg_colorram_w )
+WRITE8_HANDLER( appoooh_fg_colorram_w )
 {
 	if (appoooh_fg_colorram[offset] != data)
 	{
@@ -159,7 +189,7 @@ WRITE_HANDLER( appoooh_fg_colorram_w )
 	}
 }
 
-WRITE_HANDLER( appoooh_bg_videoram_w )
+WRITE8_HANDLER( appoooh_bg_videoram_w )
 {
 	if (appoooh_bg_videoram[offset] != data)
 	{
@@ -168,7 +198,7 @@ WRITE_HANDLER( appoooh_bg_videoram_w )
 	}
 }
 
-WRITE_HANDLER( appoooh_bg_colorram_w )
+WRITE8_HANDLER( appoooh_bg_colorram_w )
 {
 	if (appoooh_bg_colorram[offset] != data)
 	{
@@ -177,17 +207,13 @@ WRITE_HANDLER( appoooh_bg_colorram_w )
 	}
 }
 
-WRITE_HANDLER( appoooh_out_w )
+WRITE8_HANDLER( appoooh_out_w )
 {
 	/* bit 0 controls NMI */
 	interrupt_enable_w(0,data & 0x01);
 
 	/* bit 1 flip screen */
-	if ((data & 0x02) != flipscreen)
-	{
-		flipscreen = data & 0x02;
-		tilemap_set_flip(ALL_TILEMAPS, flipscreen ? TILEMAP_FLIPX+TILEMAP_FLIPY : 0);
-	}
+	flip_screen_set(data & 0x02);
 
 	/* bits 2-3 unknown */
 
@@ -201,14 +227,15 @@ WRITE_HANDLER( appoooh_out_w )
 	{
 		unsigned char *RAM = memory_region(REGION_CPU1);
 
-		cpu_setbank(1,&RAM[data&0x40 ? 0x10000 : 0x0a000]);
+		memory_set_bankptr(1,&RAM[data&0x40 ? 0x10000 : 0x0a000]);
 	}
 
 	/* bit 7 unknown (used) */
 }
 
-static void appoooh_draw_sprites(struct mame_bitmap *dest_bmp,
-        const struct GfxElement *gfx,
+static void appoooh_draw_sprites(mame_bitmap *dest_bmp,
+		const rectangle *cliprect,
+        const gfx_element *gfx,
         unsigned char *sprite)
 {
 	int offs;
@@ -223,7 +250,7 @@ static void appoooh_draw_sprites(struct mame_bitmap *dest_bmp,
 
 		if(sx>=248) sx -= 256;
 
-		if (flipscreen)
+		if (flip_screen)
 		{
 			sx = 239 - sx;
 			sy = 239 - sy;
@@ -232,9 +259,42 @@ static void appoooh_draw_sprites(struct mame_bitmap *dest_bmp,
 		drawgfx( dest_bmp, gfx,
 				code,
 				color,
-				flipx,flipscreen,
+				flipx,flip_screen,
 				sx, sy,
-				&Machine->visible_area,
+				cliprect,
+				TRANSPARENCY_PEN , 0);
+	 }
+}
+
+static void robowres_draw_sprites(mame_bitmap *dest_bmp,
+		const rectangle *cliprect,
+        const gfx_element *gfx,
+        unsigned char *sprite)
+{
+	int offs;
+
+	for (offs = 0x20 - 4;offs >= 0;offs -= 4)
+	{
+		int sy    = 240 - sprite[offs+0];
+		int code  = 0x200 + (sprite[offs+1]>>2) + ((sprite[offs+2]>>5) & 0x07)*0x40;
+		int color = sprite[offs+2]&0x0f;	/* TODO: bit 4 toggles continuously, what is it? */
+		int sx    = sprite[offs+3];
+		int flipx = sprite[offs+1]&0x01;
+
+		if(sx>=248) sx -= 256;
+
+		if (flip_screen)
+		{
+			sx = 239 - sx;
+			sy = 239 - sy;
+			flipx = !flipx;
+		}
+		drawgfx( dest_bmp, gfx,
+				code,
+				color,
+				flipx,flip_screen,
+				sx, sy,
+				cliprect,
 				TRANSPARENCY_PEN , 0);
 	 }
 }
@@ -246,29 +306,56 @@ static void appoooh_draw_sprites(struct mame_bitmap *dest_bmp,
   the main emulation engine.
 
 ***************************************************************************/
-void appoooh_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( appoooh )
 {
-	tilemap_draw(bitmap,bg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
 	if (priority == 0)	/* fg behind sprites */
-		tilemap_draw(bitmap,fg_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 
 	/* draw sprites */
 	if (priority == 1)
 	{
 		/* sprite set #1 */
-		appoooh_draw_sprites( bitmap, Machine->gfx[2],spriteram);
+		appoooh_draw_sprites( bitmap, cliprect, Machine->gfx[2],spriteram);
 		/* sprite set #2 */
-		appoooh_draw_sprites( bitmap, Machine->gfx[3],spriteram_2);
+		appoooh_draw_sprites( bitmap, cliprect, Machine->gfx[3],spriteram_2);
 	}
 	else
 	{
 		/* sprite set #2 */
-		appoooh_draw_sprites( bitmap, Machine->gfx[3],spriteram_2);
+		appoooh_draw_sprites( bitmap, cliprect, Machine->gfx[3],spriteram_2);
 		/* sprite set #1 */
-		appoooh_draw_sprites( bitmap, Machine->gfx[2],spriteram);
+		appoooh_draw_sprites( bitmap, cliprect, Machine->gfx[2],spriteram);
 	}
 
 	if (priority != 0)	/* fg in front of sprites */
-		tilemap_draw(bitmap,fg_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
+}
+
+VIDEO_UPDATE( robowres )
+{
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+
+	if (priority == 0)	/* fg behind sprites */
+		tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
+
+	/* draw sprites */
+	if (priority == 1)
+	{
+		/* sprite set #1 */
+		robowres_draw_sprites( bitmap, cliprect, Machine->gfx[2],spriteram);
+		/* sprite set #2 */
+		robowres_draw_sprites( bitmap, cliprect, Machine->gfx[3],spriteram_2);
+	}
+	else
+	{
+		/* sprite set #2 */
+		robowres_draw_sprites( bitmap, cliprect, Machine->gfx[3],spriteram_2);
+		/* sprite set #1 */
+		robowres_draw_sprites( bitmap, cliprect, Machine->gfx[2],spriteram);
+	}
+
+	if (priority != 0)	/* fg in front of sprites */
+		tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 }
