@@ -1,27 +1,28 @@
 /***************************************************************************
 
-	Atari "Stella on Steroids" hardware
+    Atari "Stella on Steroids" hardware
 
 ****************************************************************************/
 
 #include "vidhrdw/generic.h"
+#include "beathead.h"
 
 
 
 /*************************************
  *
- *	Globals we own
+ *  Globals we own
  *
  *************************************/
 
-data32_t *	beathead_vram_bulk_latch;
-data32_t *	beathead_palette_select;
+UINT32 *	beathead_vram_bulk_latch;
+UINT32 *	beathead_palette_select;
 
 
 
 /*************************************
  *
- *	Statics
+ *  Statics
  *
  *************************************/
 
@@ -29,7 +30,7 @@ static offs_t				scanline_offset[240];
 static UINT8				scanline_palette[240];
 
 static int					current_scanline;
-static data32_t				finescroll;
+static UINT32				finescroll;
 static offs_t				vram_latch_offset;
 
 static offs_t				hsyncram_offset;
@@ -40,30 +41,21 @@ static UINT8 *				hsyncram;
 
 /*************************************
  *
- *	Video start/stop
+ *  Video start/stop
  *
  *************************************/
 
-int beathead_vh_start(void)
+VIDEO_START( beathead )
 {
-	hsyncram = malloc(0x800);
-	if (!hsyncram)
-		return 1;
+	hsyncram = auto_malloc(0x800);
 	return 0;
 }
 
 
-void beathead_vh_stop(void)
-{
-	free(hsyncram);
-	hsyncram = 0;
-}
-
-
 
 /*************************************
  *
- *	VRAM handling
+ *  VRAM handling
  *
  *************************************/
 
@@ -114,20 +106,20 @@ WRITE32_HANDLER( beathead_vram_copy_w )
 
 /*************************************
  *
- *	Scroll offset handling
+ *  Scroll offset handling
  *
  *************************************/
 
 WRITE32_HANDLER( beathead_finescroll_w )
 {
-	data32_t oldword = finescroll;
-	data32_t newword = COMBINE_DATA(&finescroll);
+	UINT32 oldword = finescroll;
+	UINT32 newword = COMBINE_DATA(&finescroll);
 
 	/* if VBLANK is going off on a non-zero scanline, suspend time */
 	if ((oldword & 8) && !(newword & 8) && current_scanline != 0)
 	{
 		logerror("Suspending time! (scanline = %d)\n", current_scanline);
-		cpu_set_halt_line(0, ASSERT_LINE);
+		cpunum_set_input_line(0, INPUT_LINE_HALT, ASSERT_LINE);
 	}
 }
 
@@ -135,7 +127,7 @@ WRITE32_HANDLER( beathead_finescroll_w )
 
 /*************************************
  *
- *	Palette handling
+ *  Palette handling
  *
  *************************************/
 
@@ -157,7 +149,7 @@ WRITE32_HANDLER( beathead_palette_w )
 
 /*************************************
  *
- *	HSYNC RAM handling
+ *  HSYNC RAM handling
  *
  *************************************/
 
@@ -165,7 +157,7 @@ READ32_HANDLER( beathead_hsync_ram_r )
 {
 	/* offset 0 is probably write-only */
 	if (offset == 0)
-		logerror("%08X:Unexpected HSYNC RAM read at offset 0\n", cpu_getpreviouspc());
+		logerror("%08X:Unexpected HSYNC RAM read at offset 0\n", activecpu_get_previouspc());
 
 	/* offset 1 reads the data */
 	else
@@ -193,7 +185,7 @@ WRITE32_HANDLER( beathead_hsync_ram_w )
 
 /*************************************
  *
- *	Scanline updater
+ *  Scanline updater
  *
  *************************************/
 
@@ -216,25 +208,30 @@ void beathead_scanline_update(int scanline)
 
 /*************************************
  *
- *	Main screen refresher
+ *  Main screen refresher
  *
  *************************************/
 
-void beathead_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( beathead )
 {
 	int x, y;
 
 	/* generate the final screen */
-	for (y = 0; y < 240; y++)
+	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
 	{
-		offs_t src = scanline_offset[y];
+		offs_t src = scanline_offset[y] + cliprect->min_x;
 		UINT8 scanline[336];
 
 		/* unswizzle the scanline first */
-		for (x = 0; x < 336; x++)
-			scanline[x] = ((data8_t *)videoram32)[BYTE4_XOR_LE(src++)];
+		if (scanline_offset[y] != ~0)
+		{
+			for (x = cliprect->min_x; x <= cliprect->max_x; x++)
+				scanline[x] = ((UINT8 *)videoram32)[BYTE4_XOR_LE(src++)];
+		}
+		else
+			memset(scanline, 0, sizeof(scanline));
 
 		/* then draw it */
-		draw_scanline8(bitmap, 0, y, 336, scanline, &Machine->pens[scanline_palette[y] * 256], -1);
+		draw_scanline8(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &scanline[cliprect->min_x], &Machine->pens[scanline_palette[y] * 256], -1);
 	}
 }
