@@ -11,7 +11,7 @@ static unsigned char *scroll_ram;
 static int screen_layout;
 static int chon,objon,bgon;
 
-static struct tilemap *tx_tilemap,*bg_tilemap8x4,*bg_tilemap4x8;
+static tilemap *tx_tilemap,*bg_tilemap8x4,*bg_tilemap4x8;
 
 
 /***************************************************************************
@@ -35,7 +35,7 @@ static UINT32 bg4x8_scan(UINT32 col,UINT32 row,UINT32 num_cols,UINT32 num_rows)
 static void get_bg_tile_info(int tile_index)
 {
 	/* the tile priority table is a guess compiled by looking at the game. It
-	   was not derived from a PROM so it could be wrong. */
+       was not derived from a PROM so it could be wrong. */
 	static int split_table[16] =
 	{
 		3,0,2,2,	/* the fourth could be 1 instead of 2 */
@@ -69,25 +69,16 @@ static void get_tx_tile_info(int tile_index)
 
 ***************************************************************************/
 
-void blktiger_vh_stop(void)
+VIDEO_START( blktiger )
 {
-	free(scroll_ram);
-	scroll_ram = NULL;
-}
-
-int blktiger_vh_start(void)
-{
-	scroll_ram = malloc(BGRAM_BANK_SIZE * BGRAM_BANKS);
+	scroll_ram = auto_malloc(BGRAM_BANK_SIZE * BGRAM_BANKS);
 
 	tx_tilemap =    tilemap_create(get_tx_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
 	bg_tilemap8x4 = tilemap_create(get_bg_tile_info,bg8x4_scan,       TILEMAP_SPLIT,   16,16,128,64);
 	bg_tilemap4x8 = tilemap_create(get_bg_tile_info,bg4x8_scan,       TILEMAP_SPLIT,   16,16,64,128);
 
-	if (!scroll_ram || !tx_tilemap || !bg_tilemap8x4 || !bg_tilemap4x8)
-	{
-		blktiger_vh_stop();
+	if (!tx_tilemap || !bg_tilemap8x4 || !bg_tilemap4x8)
 		return 1;
-	}
 
 	tilemap_set_transparent_pen(tx_tilemap,3);
 
@@ -111,7 +102,7 @@ int blktiger_vh_start(void)
 
 ***************************************************************************/
 
-WRITE_HANDLER( blktiger_txvideoram_w )
+WRITE8_HANDLER( blktiger_txvideoram_w )
 {
 	if (blktiger_txvideoram[offset] != data)
 	{
@@ -120,12 +111,12 @@ WRITE_HANDLER( blktiger_txvideoram_w )
 	}
 }
 
-READ_HANDLER( blktiger_bgvideoram_r )
+READ8_HANDLER( blktiger_bgvideoram_r )
 {
 	return scroll_ram[offset + blktiger_scroll_bank];
 }
 
-WRITE_HANDLER( blktiger_bgvideoram_w )
+WRITE8_HANDLER( blktiger_bgvideoram_w )
 {
 	offset += blktiger_scroll_bank;
 
@@ -137,13 +128,13 @@ WRITE_HANDLER( blktiger_bgvideoram_w )
 	}
 }
 
-WRITE_HANDLER( blktiger_bgvideoram_bank_w )
+WRITE8_HANDLER( blktiger_bgvideoram_bank_w )
 {
 	blktiger_scroll_bank = (data % BGRAM_BANKS) * BGRAM_BANK_SIZE;
 }
 
 
-WRITE_HANDLER( blktiger_scrolly_w )
+WRITE8_HANDLER( blktiger_scrolly_w )
 {
 	static unsigned char scroll[2];
 	int scrolly;
@@ -154,7 +145,7 @@ WRITE_HANDLER( blktiger_scrolly_w )
 	tilemap_set_scrolly(bg_tilemap4x8,0,scrolly);
 }
 
-WRITE_HANDLER( blktiger_scrollx_w )
+WRITE8_HANDLER( blktiger_scrollx_w )
 {
 	static unsigned char scroll[2];
 	int scrollx;
@@ -166,14 +157,14 @@ WRITE_HANDLER( blktiger_scrollx_w )
 }
 
 
-WRITE_HANDLER( blktiger_video_control_w )
+WRITE8_HANDLER( blktiger_video_control_w )
 {
 	/* bits 0 and 1 are coin counters */
 	coin_counter_w(0,data & 1);
 	coin_counter_w(1,data & 2);
 
 	/* bit 5 resets the sound CPU */
-	cpu_set_reset_line(1,(data & 0x20) ? ASSERT_LINE : CLEAR_LINE);
+	cpunum_set_input_line(1, INPUT_LINE_RESET, (data & 0x20) ? ASSERT_LINE : CLEAR_LINE);
 
 	/* bit 6 flips screen */
 	flip_screen_set(data & 0x40);
@@ -182,7 +173,7 @@ WRITE_HANDLER( blktiger_video_control_w )
 	chon = ~data & 0x80;
 }
 
-WRITE_HANDLER( blktiger_video_enable_w )
+WRITE8_HANDLER( blktiger_video_enable_w )
 {
 	/* not sure which is which, but I think that bit 1 and 2 enable background and sprites */
 	/* bit 1 enables bg ? */
@@ -192,7 +183,7 @@ WRITE_HANDLER( blktiger_video_enable_w )
 	objon = ~data & 0x04;
 }
 
-WRITE_HANDLER( blktiger_screen_layout_w )
+WRITE8_HANDLER( blktiger_screen_layout_w )
 {
 	screen_layout = data;
 	tilemap_set_enable(bg_tilemap8x4, screen_layout);
@@ -207,7 +198,7 @@ WRITE_HANDLER( blktiger_screen_layout_w )
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs;
 
@@ -233,28 +224,28 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				color,
 				flipx,flip_screen,
 				sx,sy,
-				&Machine->visible_area,TRANSPARENCY_PEN,15);
+				cliprect,TRANSPARENCY_PEN,15);
 	}
 }
 
-void blktiger_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( blktiger )
 {
-	fillbitmap(bitmap,Machine->pens[1023],&Machine->visible_area);
+	fillbitmap(bitmap,Machine->pens[1023],cliprect);
 
 	if (bgon)
-		tilemap_draw(bitmap,screen_layout ? bg_tilemap8x4 : bg_tilemap4x8,TILEMAP_BACK,0);
+		tilemap_draw(bitmap,cliprect,screen_layout ? bg_tilemap8x4 : bg_tilemap4x8,TILEMAP_BACK,0);
 
 	if (objon)
-		draw_sprites(bitmap);
+		draw_sprites(bitmap,cliprect);
 
 	if (bgon)
-		tilemap_draw(bitmap,screen_layout ? bg_tilemap8x4 : bg_tilemap4x8,TILEMAP_FRONT,0);
+		tilemap_draw(bitmap,cliprect,screen_layout ? bg_tilemap8x4 : bg_tilemap4x8,TILEMAP_FRONT,0);
 
 	if (chon)
-		tilemap_draw(bitmap,tx_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 }
 
-void blktiger_eof_callback(void)
+VIDEO_EOF( blktiger )
 {
 	buffer_spriteram_w(0,0);
 }
