@@ -1,29 +1,29 @@
 /***************************************************************************
 
-							  -= Blomby Car =-
+                              -= Blomby Car =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-Note:	if MAME_DEBUG is defined, pressing Z with:
+Note:   if MAME_DEBUG is defined, pressing Z with:
 
-		Q		shows the background
-		W		shows the foreground
-		A		shows the sprites
+        Q       shows the background
+        W       shows the foreground
+        A       shows the sprites
 
-		Keys can be used together!
+        Keys can be used together!
 
 
-	[ 2 Scrolling Layers ]
+    [ 2 Scrolling Layers ]
 
-	The Tilemaps are 64 x 32 tiles in size (1024 x 512).
-	Tiles are 16 x 16 x 4, with 32 color codes and 2 priority
-	leves (wrt sprites). Each tile needs 4 bytes.
+    The Tilemaps are 64 x 32 tiles in size (1024 x 512).
+    Tiles are 16 x 16 x 4, with 32 color codes and 2 priority
+    leves (wrt sprites). Each tile needs 4 bytes.
 
-	[ 1024? Sprites ]
+    [ 1024? Sprites ]
 
-	They use the same graphics the tilemaps use (16 x 16 x 4 tiles)
-	with 16 color codes and 2 levels of priority
+    They use the same graphics the tilemaps use (16 x 16 x 4 tiles)
+    with 16 color codes and 2 levels of priority
 
 
 ***************************************************************************/
@@ -33,14 +33,14 @@ Note:	if MAME_DEBUG is defined, pressing Z with:
 
 /* Variables needed by driver: */
 
-data16_t *blmbycar_vram_0, *blmbycar_scroll_0;
-data16_t *blmbycar_vram_1, *blmbycar_scroll_1;
+UINT16 *blmbycar_vram_0, *blmbycar_scroll_0;
+UINT16 *blmbycar_vram_1, *blmbycar_scroll_1;
 
 
 /***************************************************************************
 
 
-								Palette
+                                Palette
 
 
 ***************************************************************************/
@@ -62,28 +62,28 @@ WRITE16_HANDLER( blmbycar_palette_w )
 /***************************************************************************
 
 
-								Tilemaps
+                                Tilemaps
 
-	Offset:		Bits:					Value:
+    Offset:     Bits:                   Value:
 
-		0.w								Code
-		2.w		fedc ba98 ---- ----
-				---- ---- 7--- ----		Flip Y
-				---- ---- -6-- ----		Flip X
-				---- ---- --5- ----		Priority (0 = Low)
-				---- ---- ---4 3210		Color
+        0.w                             Code
+        2.w     fedc ba98 ---- ----
+                ---- ---- 7--- ----     Flip Y
+                ---- ---- -6-- ----     Flip X
+                ---- ---- --5- ----     Priority (0 = Low)
+                ---- ---- ---4 3210     Color
 
 ***************************************************************************/
 
-static struct tilemap *tilemap_0, *tilemap_1;
+static tilemap *tilemap_0, *tilemap_1;
 
 #define DIM_NX		(0x40)
 #define DIM_NY		(0x20)
 
 static void get_tile_info_0( int tile_index )
 {
-	data16_t code = blmbycar_vram_0[ tile_index * 2 + 0 ];
-	data16_t attr = blmbycar_vram_0[ tile_index * 2 + 1 ];
+	UINT16 code = blmbycar_vram_0[ tile_index * 2 + 0 ];
+	UINT16 attr = blmbycar_vram_0[ tile_index * 2 + 1 ];
 	SET_TILE_INFO(
 			0,
 			code,
@@ -95,8 +95,8 @@ static void get_tile_info_0( int tile_index )
 
 static void get_tile_info_1( int tile_index )
 {
-	data16_t code = blmbycar_vram_1[ tile_index * 2 + 0 ];
-	data16_t attr = blmbycar_vram_1[ tile_index * 2 + 1 ];
+	UINT16 code = blmbycar_vram_1[ tile_index * 2 + 0 ];
+	UINT16 attr = blmbycar_vram_1[ tile_index * 2 + 1 ];
 	SET_TILE_INFO(
 			0,
 			code,
@@ -109,15 +109,15 @@ static void get_tile_info_1( int tile_index )
 
 WRITE16_HANDLER( blmbycar_vram_0_w )
 {
-	data16_t oldword = blmbycar_vram_0[offset];
-	data16_t newword = COMBINE_DATA(&blmbycar_vram_0[offset]);
+	UINT16 oldword = blmbycar_vram_0[offset];
+	UINT16 newword = COMBINE_DATA(&blmbycar_vram_0[offset]);
 	if (oldword != newword)	tilemap_mark_tile_dirty(tilemap_0, offset/2);
 }
 
 WRITE16_HANDLER( blmbycar_vram_1_w )
 {
-	data16_t oldword = blmbycar_vram_1[offset];
-	data16_t newword = COMBINE_DATA(&blmbycar_vram_1[offset]);
+	UINT16 oldword = blmbycar_vram_1[offset];
+	UINT16 newword = COMBINE_DATA(&blmbycar_vram_1[offset]);
 	if (oldword != newword)	tilemap_mark_tile_dirty(tilemap_1, offset/2);
 }
 
@@ -125,12 +125,12 @@ WRITE16_HANDLER( blmbycar_vram_1_w )
 /***************************************************************************
 
 
-								Video Init
+                                Video Init
 
 
 ***************************************************************************/
 
-int blmbycar_vh_start(void)
+VIDEO_START( blmbycar )
 {
 	tilemap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
 								TILEMAP_OPAQUE, 16,16, DIM_NX, DIM_NY );
@@ -157,35 +157,35 @@ int blmbycar_vh_start(void)
 /***************************************************************************
 
 
-								Sprites Drawing
+                                Sprites Drawing
 
-	Offset:		Bits:					Value:
+    Offset:     Bits:                   Value:
 
-		0.w		f--- ---- ---- ----		End Of Sprites
-				-edc ba9- ---- ----
-				---- ---8 7654 3210		Y (Signed)
+        0.w     f--- ---- ---- ----     End Of Sprites
+                -edc ba9- ---- ----
+                ---- ---8 7654 3210     Y (Signed)
 
-		2.w								Code
+        2.w                             Code
 
-		4.w		f--- ---- ---- ----		Flip Y
-				-e-- ---- ---- ----		Flip X
-				--dc ba98 7654 ----
-				---- ---- ---- 3210		Color (Bit 3 = Priority)
+        4.w     f--- ---- ---- ----     Flip Y
+                -e-- ---- ---- ----     Flip X
+                --dc ba98 7654 ----
+                ---- ---- ---- 3210     Color (Bit 3 = Priority)
 
-		6.w		f--- ---- ---- ----		? Is this ever used ?
-				-e-- ---- ---- ----		? 1 = Don't Draw ?
-				--dc ba9- ---- ----
-				---- ---8 7654 3210		X (Signed)
+        6.w     f--- ---- ---- ----     ? Is this ever used ?
+                -e-- ---- ---- ----     ? 1 = Don't Draw ?
+                --dc ba9- ---- ----
+                ---- ---8 7654 3210     X (Signed)
 
 
 ***************************************************************************/
 
-static void blmbycar_draw_sprites(struct mame_bitmap *bitmap)
+static void blmbycar_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
-	data16_t *source, *finish;
+	UINT16 *source, *finish;
 
 	source = spriteram16 + 0x6/2;				/* ! */
-	finish = spriteram16 + spriteram_size/2;
+	finish = spriteram16 + spriteram_size/2 - 8/2;
 
 	/* Find "the end of sprites" marker */
 
@@ -219,7 +219,7 @@ static void blmbycar_draw_sprites(struct mame_bitmap *bitmap)
 					0x20 + (attr & 0xf),
 					flipx, flipy,
 					x, y,
-					&Machine->visible_area, TRANSPARENCY_PEN,0,
+					cliprect, TRANSPARENCY_PEN,0,
 					pri_mask	);
 	}
 }
@@ -228,45 +228,45 @@ static void blmbycar_draw_sprites(struct mame_bitmap *bitmap)
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
-void blmbycar_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( blmbycar )
 {
 	int i,layers_ctrl = -1;
 
 	tilemap_set_scrolly( tilemap_0, 0, blmbycar_scroll_0[ 0 ]);
 	tilemap_set_scrollx( tilemap_0, 0, blmbycar_scroll_0[ 1 ]);
 
-	tilemap_set_scrolly( tilemap_1, 0, blmbycar_scroll_1[ 0 ]);
-	tilemap_set_scrollx( tilemap_1, 0, blmbycar_scroll_1[ 1 ]);
+	tilemap_set_scrolly( tilemap_1, 0, blmbycar_scroll_1[ 0 ]+1);
+	tilemap_set_scrollx( tilemap_1, 0, blmbycar_scroll_1[ 1 ]+5);
 
 #ifdef MAME_DEBUG
-if (keyboard_pressed(KEYCODE_Z))
+if (code_pressed(KEYCODE_Z))
 {
 	int msk = 0;
 
-	if (keyboard_pressed(KEYCODE_Q))	msk |= 1;
-	if (keyboard_pressed(KEYCODE_W))	msk |= 2;
-/*	if (keyboard_pressed(KEYCODE_E))	msk |= 4; */
-	if (keyboard_pressed(KEYCODE_A))	msk |= 8;
+	if (code_pressed(KEYCODE_Q))	msk |= 1;
+	if (code_pressed(KEYCODE_W))	msk |= 2;
+/*  if (code_pressed(KEYCODE_E))    msk |= 4; */
+	if (code_pressed(KEYCODE_A))	msk |= 8;
 	if (msk != 0) layers_ctrl &= msk;
 }
 #endif
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
 	if (layers_ctrl&1)
 		for (i = 0; i <= 1; i++)
-			tilemap_draw(bitmap, tilemap_0, i, i);
-	else	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+			tilemap_draw(bitmap, cliprect, tilemap_0, i, i);
+	else	fillbitmap(bitmap,Machine->pens[0],cliprect);
 
 	if (layers_ctrl&2)
 		for (i = 0; i <= 1; i++)
-			tilemap_draw(bitmap, tilemap_1, i, i);
+			tilemap_draw(bitmap, cliprect, tilemap_1, i, i);
 
 	if (layers_ctrl&8)
-		blmbycar_draw_sprites(bitmap);
+		blmbycar_draw_sprites(bitmap, cliprect);
 }
