@@ -1,16 +1,16 @@
 /***************************************************************************
 
-	Video Hardware for Blood Brothers
+    Video Hardware for Blood Brothers
 
 ***************************************************************************/
 
 #include "vidhrdw/generic.h"
 
-data16_t *bloodbro_txvideoram;
-data16_t *bloodbro_bgvideoram,*bloodbro_fgvideoram;
-data16_t *bloodbro_scroll;
+UINT16 *bloodbro_txvideoram;
+UINT16 *bloodbro_bgvideoram,*bloodbro_fgvideoram;
+UINT16 *bloodbro_scroll;
 
-static struct tilemap *bg_tilemap,*fg_tilemap,*tx_tilemap;
+static tilemap *bg_tilemap,*fg_tilemap,*tx_tilemap;
 
 
 /***************************************************************************
@@ -57,7 +57,7 @@ static void get_tx_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int bloodbro_vh_start(void)
+VIDEO_START( bloodbro )
 {
 	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,     16,16,32,16);
 	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,16,16,32,16);
@@ -111,39 +111,39 @@ WRITE16_HANDLER( bloodbro_txvideoram_w )
   Display refresh
 
 
-	Blood Bros / Skysmash Spriteram
-	-------------------------------
+    Blood Bros / Skysmash Spriteram
+    -------------------------------
 
-	Slightly more sophisticated successor to the Toki sprite chip.
+    Slightly more sophisticated successor to the Toki sprite chip.
 
-	It has "big sprites" created by setting width or height >0. Tile
-	numbers are read consecutively.
+    It has "big sprites" created by setting width or height >0. Tile
+    numbers are read consecutively.
 
       +0   x....... ........  sprite disabled if set
-	+0   .x...... ........  Flip y (no evidence for this!!)
-	+0   ..x..... ........  Flip x
-	+0   ....x... ........  Priority (1=high)
-	+0   ......xx x.......  Width: do this many tiles horizontally
-	+0   ........ .xxx....  Height: do this many tiles vertically
- 	+0   ........ ....xxxx  Color bank
+    +0   .x...... ........  Flip y (no evidence for this!!)
+    +0   ..x..... ........  Flip x
+    +0   ....x... ........  Priority (1=high)
+    +0   ......xx x.......  Width: do this many tiles horizontally
+    +0   ........ .xxx....  Height: do this many tiles vertically
+    +0   ........ ....xxxx  Color bank
 
-	+1   ...xxxxx xxxxxxxx  Tile number
-	+2   .......x xxxxxxxx  X coordinate
-	+3   .......x xxxxxxxx  Y coordinate
+    +1   ...xxxxx xxxxxxxx  Tile number
+    +2   .......x xxxxxxxx  X coordinate
+    +3   .......x xxxxxxxx  Y coordinate
 
 
-	Weststry Bootleg Spriteram
-	--------------------------
+    Weststry Bootleg Spriteram
+    --------------------------
 
-	Lacks the "big sprite" feature of the original. Needs some
-	tile number remapping for some reason.
+    Lacks the "big sprite" feature of the original. Needs some
+    tile number remapping for some reason.
 
-	+0   .......x xxxxxxxx  Sprite Y coordinate
-	+1   ...xxxxx xxxxxxxx  Sprite tile number
- 	+2   xxxx.... ........  Sprite color bank
- 	+2   ......x. ........  Sprite flip x
- 	+2   ........ x.......  Priority ??
-	+3   .......x xxxxxxxx  Sprite X coordinate
+    +0   .......x xxxxxxxx  Sprite Y coordinate
+    +1   ...xxxxx xxxxxxxx  Sprite tile number
+    +2   xxxx.... ........  Sprite color bank
+    +2   ......x. ........  Sprite flip x
+    +2   ........ x.......  Priority ??
+    +3   .......x xxxxxxxx  Sprite X coordinate
 
 ***************************************************************************/
 
@@ -154,7 +154,7 @@ WRITE16_HANDLER( bloodbro_txvideoram_w )
    -------X XXXXXXXX
    -------- YYYYYYYY */
 
-static void bloodbro_draw_sprites( struct mame_bitmap *bitmap)
+static void bloodbro_draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs;
 	for (offs = 0;offs < spriteram_size/2;offs += 4)
@@ -186,7 +186,7 @@ static void bloodbro_draw_sprites( struct mame_bitmap *bitmap)
 						color,
 						flipx,flipy,
 						flipx ? (sx + 16*(width-x)) : (sx + 16*x),flipy ? (sy + 16*(height-y)) : (sy + 16*y),
-						&Machine->visible_area,TRANSPARENCY_PEN,15,
+						cliprect,TRANSPARENCY_PEN,15,
 						pri_mask);
 			}
 		}
@@ -201,7 +201,7 @@ static void bloodbro_draw_sprites( struct mame_bitmap *bitmap)
    -------X XXXXXXXX
 */
 
-static void weststry_draw_sprites( struct mame_bitmap *bitmap)
+static void weststry_draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs;
 
@@ -230,57 +230,57 @@ static void weststry_draw_sprites( struct mame_bitmap *bitmap)
 				color,
 				flipx,flipy,
 				sx,sy,
-				&Machine->visible_area,TRANSPARENCY_PEN,15,
+				cliprect,TRANSPARENCY_PEN,15,
 				pri_mask);
 	}
 }
 
 
 
-void bloodbro_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
+VIDEO_UPDATE( bloodbro )
 {
 	tilemap_set_scrollx(bg_tilemap,0,bloodbro_scroll[0x10]);	/* ? */
 	tilemap_set_scrolly(bg_tilemap,0,bloodbro_scroll[0x11]);	/* ? */
 	tilemap_set_scrollx(fg_tilemap,0,bloodbro_scroll[0x12]);
 	tilemap_set_scrolly(fg_tilemap,0,bloodbro_scroll[0x13]);
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
-	tilemap_draw(bitmap,bg_tilemap,0,0);
-	tilemap_draw(bitmap,fg_tilemap,0,1);
-	bloodbro_draw_sprites(bitmap);
-	tilemap_draw(bitmap,tx_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,1);
+	bloodbro_draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 }
 
-void weststry_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
+VIDEO_UPDATE( weststry )
 {
-/*	tilemap_set_scrollx(bg_tilemap,0,bloodbro_scroll[0x10]);	   ?    */
-/*	tilemap_set_scrolly(bg_tilemap,0,bloodbro_scroll[0x11]);	   ?    */
-/*	tilemap_set_scrollx(fg_tilemap,0,bloodbro_scroll[0x12]); */
-/*	tilemap_set_scrolly(fg_tilemap,0,bloodbro_scroll[0x13]); */
+/*  tilemap_set_scrollx(bg_tilemap,0,bloodbro_scroll[0x10]);       ?    */
+/*  tilemap_set_scrolly(bg_tilemap,0,bloodbro_scroll[0x11]);       ?    */
+/*  tilemap_set_scrollx(fg_tilemap,0,bloodbro_scroll[0x12]); */
+/*  tilemap_set_scrolly(fg_tilemap,0,bloodbro_scroll[0x13]); */
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
-	tilemap_draw(bitmap,bg_tilemap,0,0);
-	tilemap_draw(bitmap,fg_tilemap,0,1);
-	weststry_draw_sprites(bitmap);
-	tilemap_draw(bitmap,tx_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,1);
+	weststry_draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 }
 
 
-void skysmash_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
+VIDEO_UPDATE( skysmash )
 {
 	tilemap_set_scrollx(bg_tilemap,0,bloodbro_scroll[0x08]);
 	tilemap_set_scrolly(bg_tilemap,0,bloodbro_scroll[0x09]);	/* ? */
 	tilemap_set_scrollx(fg_tilemap,0,bloodbro_scroll[0x0a]);
 	tilemap_set_scrolly(fg_tilemap,0,bloodbro_scroll[0x0b]);	/* ? */
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
-	tilemap_draw(bitmap,bg_tilemap,0,0);
-	tilemap_draw(bitmap,fg_tilemap,0,1);
-	bloodbro_draw_sprites(bitmap);
-	tilemap_draw(bitmap,tx_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,1);
+	bloodbro_draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 }
 
 
