@@ -25,7 +25,7 @@ static int btime_palette = 0;
 static unsigned char bnj_scroll1 = 0;
 static unsigned char bnj_scroll2 = 0;
 static unsigned char *dirtybuffer2 = 0;
-static struct mame_bitmap *background_bitmap;
+static mame_bitmap *background_bitmap;
 static int lnc_sound_interrupt_enabled = 0;
 
 /***************************************************************************
@@ -44,7 +44,7 @@ static int lnc_sound_interrupt_enabled = 0;
     bit 0 -- 47 kohm resistor  -- RED (inverted)
 
 ***************************************************************************/
-void btime_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( btime )
 {
 	int i;
 
@@ -93,7 +93,7 @@ void btime_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colorta
     bit 0 -- 15 kohm resistor  -- BLUE
 
 ***************************************************************************/
-void lnc_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( lnc )
 {
 	int i;
 
@@ -123,7 +123,7 @@ void lnc_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colortabl
 }
 
 
-void lnc_init_machine(void)
+MACHINE_INIT( lnc )
 {
     *lnc_charbank = 1;
 }
@@ -134,25 +134,17 @@ void lnc_init_machine(void)
 Start the video hardware emulation.
 
 ***************************************************************************/
-int bnj_vh_start (void)
+VIDEO_START( bnj )
 {
-    if (generic_vh_start() != 0)
+    if (video_start_generic() != 0)
         return 1;
 
-    if ((dirtybuffer2 = malloc(bnj_backgroundram_size)) == 0)
-    {
-        generic_vh_stop();
-        return 1;
-    }
+    dirtybuffer2 = auto_malloc(bnj_backgroundram_size);
     memset(dirtybuffer2,1,bnj_backgroundram_size);
 
     /* the background area is twice as wide as the screen */
-    if ((background_bitmap = bitmap_alloc(2*Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
-    {
-        free(dirtybuffer2);
-        generic_vh_stop();
+    if ((background_bitmap = auto_bitmap_alloc(2*Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
         return 1;
-    }
 
     bnj_scroll1 = 0;
     bnj_scroll2 = 0;
@@ -160,34 +152,23 @@ int bnj_vh_start (void)
     return 0;
 }
 
-int btime_vh_start (void)
+VIDEO_START( btime )
 {
     bnj_scroll1 = 0;
     bnj_scroll2 = 0;
 
-    return generic_vh_start();
-}
-
-/***************************************************************************
-
-Stop the video hardware emulation.
-
-***************************************************************************/
-void bnj_vh_stop (void)
-{
-    bitmap_free(background_bitmap);
-    free(dirtybuffer2);
-    generic_vh_stop();
+    return video_start_generic();
 }
 
 
-WRITE_HANDLER( btime_paletteram_w )
+
+WRITE8_HANDLER( btime_paletteram_w )
 {
     /* RGB output is inverted */
     paletteram_BBGGGRRR_w(offset,~data);
 }
 
-WRITE_HANDLER( lnc_videoram_w )
+WRITE8_HANDLER( lnc_videoram_w )
 {
     if (videoram[offset] != data || colorram[offset] != *lnc_charbank)
     {
@@ -198,7 +179,7 @@ WRITE_HANDLER( lnc_videoram_w )
     }
 }
 
-READ_HANDLER( btime_mirrorvideoram_r )
+READ8_HANDLER( btime_mirrorvideoram_r )
 {
     int x,y;
 
@@ -210,7 +191,7 @@ READ_HANDLER( btime_mirrorvideoram_r )
     return videoram_r(offset);
 }
 
-READ_HANDLER( btime_mirrorcolorram_r )
+READ8_HANDLER( btime_mirrorcolorram_r )
 {
     int x,y;
 
@@ -222,7 +203,7 @@ READ_HANDLER( btime_mirrorcolorram_r )
     return colorram_r(offset);
 }
 
-WRITE_HANDLER( btime_mirrorvideoram_w )
+WRITE8_HANDLER( btime_mirrorvideoram_w )
 {
     int x,y;
 
@@ -234,7 +215,7 @@ WRITE_HANDLER( btime_mirrorvideoram_w )
     videoram_w(offset,data);
 }
 
-WRITE_HANDLER( lnc_mirrorvideoram_w )
+WRITE8_HANDLER( lnc_mirrorvideoram_w )
 {
     int x,y;
 
@@ -246,7 +227,7 @@ WRITE_HANDLER( lnc_mirrorvideoram_w )
     lnc_videoram_w(offset,data);
 }
 
-WRITE_HANDLER( btime_mirrorcolorram_w )
+WRITE8_HANDLER( btime_mirrorcolorram_w )
 {
     int x,y;
 
@@ -258,7 +239,7 @@ WRITE_HANDLER( btime_mirrorcolorram_w )
     colorram_w(offset,data);
 }
 
-WRITE_HANDLER( deco_charram_w )
+WRITE8_HANDLER( deco_charram_w )
 {
     if (deco_charram[offset] == data)  return;
 
@@ -273,7 +254,7 @@ WRITE_HANDLER( deco_charram_w )
     char_dirty  [offset >> 3] = 1;
 }
 
-WRITE_HANDLER( bnj_background_w )
+WRITE8_HANDLER( bnj_background_w )
 {
     if (bnj_backgroundram[offset] != data)
     {
@@ -283,23 +264,23 @@ WRITE_HANDLER( bnj_background_w )
     }
 }
 
-WRITE_HANDLER( bnj_scroll1_w )
+WRITE8_HANDLER( bnj_scroll1_w )
 {
     /* Dirty screen if background is being turned off */
     if (bnj_scroll1 && !data)
     {
-		schedule_full_refresh();
+		set_vh_global_attribute(NULL,0);
     }
 
     bnj_scroll1 = data;
 }
 
-WRITE_HANDLER( bnj_scroll2_w )
+WRITE8_HANDLER( bnj_scroll2_w )
 {
     bnj_scroll2 = data;
 }
 
-WRITE_HANDLER( zoar_video_control_w )
+WRITE8_HANDLER( zoar_video_control_w )
 {
     /* Zoar video control */
     /* */
@@ -311,7 +292,7 @@ WRITE_HANDLER( zoar_video_control_w )
 	flip_screen_set(data & 0x80);
 }
 
-WRITE_HANDLER( btime_video_control_w )
+WRITE8_HANDLER( btime_video_control_w )
 {
     /* Btime video control */
     /* */
@@ -321,7 +302,7 @@ WRITE_HANDLER( btime_video_control_w )
 	flip_screen_set(data & 0x01);
 }
 
-WRITE_HANDLER( bnj_video_control_w )
+WRITE8_HANDLER( bnj_video_control_w )
 {
     /* Bnj/Lnc works a little differently than the btime/eggs (apparently). */
     /* According to the information at: */
@@ -337,7 +318,7 @@ WRITE_HANDLER( bnj_video_control_w )
         btime_video_control_w(offset, data);
 }
 
-WRITE_HANDLER( lnc_video_control_w )
+WRITE8_HANDLER( lnc_video_control_w )
 {
     /* I have a feeling that this only works by coincidence. I couldn't */
     /* figure out how NMI's are disabled by the sound processor */
@@ -346,7 +327,7 @@ WRITE_HANDLER( lnc_video_control_w )
     bnj_video_control_w(offset, data & 0x01);
 }
 
-WRITE_HANDLER( disco_video_control_w )
+WRITE8_HANDLER( disco_video_control_w )
 {
 	set_vh_global_attribute(&btime_palette, (data >> 2) & 0x03);
 
@@ -357,12 +338,10 @@ WRITE_HANDLER( disco_video_control_w )
 }
 
 
-int lnc_sound_interrupt(void)
+INTERRUPT_GEN( lnc_sound_interrupt )
 {
     if (lnc_sound_interrupt_enabled)
-        return nmi_interrupt();
-    else
-        return ignore_interrupt();
+    	cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
@@ -373,7 +352,7 @@ Do NOT call osd_update_display() from this function, it will be called by
 the main emulation engine.
 
 ***************************************************************************/
-static void drawchars(struct mame_bitmap *bitmap, int transparency, int color, int priority)
+static void drawchars(mame_bitmap *bitmap, int transparency, int color, int priority)
 {
     int offs;
 
@@ -412,7 +391,7 @@ static void drawchars(struct mame_bitmap *bitmap, int transparency, int color, i
     }
 }
 
-static void drawsprites(struct mame_bitmap *bitmap, int color,
+static void drawsprites(mame_bitmap *bitmap, int color,
                         int sprite_y_adjust, int sprite_y_adjust_flip_screen,
                         unsigned char *sprite_ram, int interleave)
 {
@@ -462,7 +441,7 @@ static void drawsprites(struct mame_bitmap *bitmap, int color,
 }
 
 
-static void drawbackground(struct mame_bitmap *bitmap, unsigned char* tilemap)
+static void drawbackground(mame_bitmap *bitmap, unsigned char* tilemap)
 {
     int i, offs;
 
@@ -548,9 +527,9 @@ static void decode_modified(unsigned char *sprite_ram, int interleave)
 }
 
 
-void btime_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( btime )
 {
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
         memset(dirtybuffer,1,videoram_size);
 
     if (bnj_scroll1 & 0x10)
@@ -587,9 +566,9 @@ void btime_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void eggs_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( eggs )
 {
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
         memset(dirtybuffer,1,videoram_size);
 
     drawchars(tmpbitmap, TRANSPARENCY_NONE, 0, -1);
@@ -601,9 +580,9 @@ void eggs_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void lnc_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( lnc )
 {
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
         memset(dirtybuffer,1,videoram_size);
 
     drawchars(tmpbitmap, TRANSPARENCY_NONE, 0, -1);
@@ -615,9 +594,9 @@ void lnc_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void zoar_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( zoar )
 {
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
         memset(dirtybuffer,1,videoram_size);
 
     if (bnj_scroll1 & 0x04)
@@ -640,9 +619,9 @@ void zoar_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void bnj_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( bnj )
 {
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
     {
         memset(dirtybuffer,1,videoram_size);
         memset(dirtybuffer2,1,bnj_backgroundram_size);
@@ -706,12 +685,12 @@ void bnj_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void cookrace_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( cookrace )
 {
     int offs;
 
 
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
         memset(dirtybuffer,1,videoram_size);
 
     /*
@@ -745,9 +724,9 @@ void cookrace_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void disco_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( disco )
 {
-    if (full_refresh)
+    if (get_vh_global_attribute_changed())
         memset(dirtybuffer,1,videoram_size);
 
     decode_modified(spriteram, 1);
