@@ -36,7 +36,7 @@ static int sidepanel_enabled;
   bit 0 -- 1  kohm resistor  -- RED
 
 ***************************************************************************/
-void cclimber_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( cclimber )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -45,25 +45,26 @@ void cclimber_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/* red component */
 		bit0 = (*color_prom >> 0) & 0x01;
 		bit1 = (*color_prom >> 1) & 0x01;
 		bit2 = (*color_prom >> 2) & 0x01;
-		*(palette++) = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		r = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 		/* green component */
 		bit0 = (*color_prom >> 3) & 0x01;
 		bit1 = (*color_prom >> 4) & 0x01;
 		bit2 = (*color_prom >> 5) & 0x01;
-		*(palette++) = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		g = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 		/* blue component */
 		bit0 = 0;
 		bit1 = (*color_prom >> 6) & 0x01;
 		bit2 = (*color_prom >> 7) & 0x01;
-		*(palette++) = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
+		b = 0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
@@ -126,7 +127,7 @@ void cclimber_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 #define BGPEN (256+32)
 #define SIDEPEN (256+32+1)
 
-void swimmer_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( swimmer )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -135,24 +136,26 @@ void swimmer_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 
 	for (i = 0;i < 256;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/* red component */
 		bit0 = (color_prom[i] >> 0) & 0x01;
 		bit1 = (color_prom[i] >> 1) & 0x01;
 		bit2 = (color_prom[i] >> 2) & 0x01;
-		*(palette++) = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+		r = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
 		/* green component */
 		bit0 = (color_prom[i] >> 3) & 0x01;
 		bit1 = (color_prom[i+256] >> 0) & 0x01;
 		bit2 = (color_prom[i+256] >> 1) & 0x01;
-		*(palette++) = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+		g = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
 		/* blue component */
 		bit0 = 0;
 		bit1 = (color_prom[i+256] >> 2) & 0x01;
 		bit2 = (color_prom[i+256] >> 3) & 0x01;
-		*(palette++) = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+		b = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+
+		palette_set_color(i,r,g,b);
 
 		/* side panel */
 		if (i % 8)
@@ -173,43 +176,39 @@ void swimmer_vh_convert_color_prom(unsigned char *palette, unsigned short *color
 	/* big sprite */
 	for (i = 0;i < 32;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/* red component */
 		bit0 = (color_prom[i] >> 0) & 0x01;
 		bit1 = (color_prom[i] >> 1) & 0x01;
 		bit2 = (color_prom[i] >> 2) & 0x01;
-		*(palette++) = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+		r = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
 		/* green component */
 		bit0 = (color_prom[i] >> 3) & 0x01;
 		bit1 = (color_prom[i] >> 4) & 0x01;
 		bit2 = (color_prom[i] >> 5) & 0x01;
-		*(palette++) = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+		g = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
 		/* blue component */
 		bit0 = 0;
 		bit1 = (color_prom[i] >> 6) & 0x01;
 		bit2 = (color_prom[i] >> 7) & 0x01;
-		*(palette++) = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+		b = 0x20 * bit0 + 0x40 * bit1 + 0x80 * bit2;
+
+		palette_set_color(i+256,r,g,b);
 
 		if (i % 8 == 0) COLOR(2,i) = BGPEN;  /* enforce transparency */
 		else COLOR(2,i) = i+256;
 	}
 
 	/* background */
-	*(palette++) = 0;
-	*(palette++) = 0;
-	*(palette++) = 0;
+	palette_set_color(BGPEN,0,0,0);
 	/* side panel background color */
 #if 0
 	/* values calculated from the resistors don't seem to match the real board */
-	*(palette++) = 0x24;
-	*(palette++) = 0x5d;
-	*(palette++) = 0x4e;
+	palette_set_color(SIDEPEN,0x24,0x5d,0x4e);
 #endif
-	*(palette++) = 0x20;
-	*(palette++) = 0x98;
-	*(palette++) = 0x79;
+	palette_set_color(SIDEPEN,0x20,0x98,0x79);
 }
 
 
@@ -230,7 +229,7 @@ void swimmer_vh_convert_color_prom(unsigned char *palette, unsigned short *color
   bit 0 -- 1  kohm resistor  -- BLUE
 
 ***************************************************************************/
-WRITE_HANDLER( swimmer_bgcolor_w )
+WRITE8_HANDLER( swimmer_bgcolor_w )
 {
 	int bit0,bit1,bit2;
 	int r,g,b;
@@ -259,34 +258,7 @@ WRITE_HANDLER( swimmer_bgcolor_w )
 
 
 
-/***************************************************************************
-
-  Start the video hardware emulation.
-
-***************************************************************************/
-int cclimber_vh_start(void)
-{
-	if (generic_vh_start() != 0)
-		return 1;
-
-	return 0;
-}
-
-
-
-/***************************************************************************
-
-  Stop the video hardware emulation.
-
-***************************************************************************/
-void cclimber_vh_stop(void)
-{
-	generic_vh_stop();
-}
-
-
-
-WRITE_HANDLER( cclimber_colorram_w )
+WRITE8_HANDLER( cclimber_colorram_w )
 {
 	if (colorram[offset] != data)
 	{
@@ -305,21 +277,21 @@ WRITE_HANDLER( cclimber_colorram_w )
 
 
 
-WRITE_HANDLER( cclimber_bigsprite_videoram_w )
+WRITE8_HANDLER( cclimber_bigsprite_videoram_w )
 {
 	cclimber_bsvideoram[offset] = data;
 }
 
 
 
-WRITE_HANDLER( swimmer_palettebank_w )
+WRITE8_HANDLER( swimmer_palettebank_w )
 {
 	set_vh_global_attribute(&palettebank, data & 1);
 }
 
 
 
-WRITE_HANDLER( swimmer_sidepanel_enable_w )
+WRITE8_HANDLER( swimmer_sidepanel_enable_w )
 {
 	set_vh_global_attribute(&sidepanel_enabled, data );
 }
@@ -333,7 +305,7 @@ WRITE_HANDLER( swimmer_sidepanel_enable_w )
   the main emulation engine.
 
 ***************************************************************************/
-static void drawbigsprite(struct mame_bitmap *bitmap)
+static void drawbigsprite(mame_bitmap *bitmap)
 {
 	int offs;
 	int ox,oy,sx,sy,flipx,flipy;
@@ -350,7 +322,7 @@ static void drawbigsprite(struct mame_bitmap *bitmap)
 		flipy = !flipy;
 	}
 	color = cclimber_bigspriteram[1] & 0x07;	/* cclimber */
-/*	color = cclimber_bigspriteram[1] & 0x03;	   swimmer    */
+/*  color = cclimber_bigspriteram[1] & 0x03;       swimmer    */
 
 	for (offs = cclimber_bsvideoram_size - 1;offs >= 0;offs--)
 	{
@@ -360,7 +332,7 @@ static void drawbigsprite(struct mame_bitmap *bitmap)
 		if (flipy) sy = 15 - sy;
 
 		drawgfx(bitmap,Machine->gfx[2],
-/*				cclimber_bsvideoram[offs],	   cclimber    */
+/*              cclimber_bsvideoram[offs],     cclimber    */
 				cclimber_bsvideoram[offs] + ((cclimber_bigspriteram[1] & 0x08) << 5),	/* swimmer */
 				color,
 				flipx,flipy,
@@ -369,7 +341,7 @@ static void drawbigsprite(struct mame_bitmap *bitmap)
 
 		/* wraparound */
 		drawgfx(bitmap,Machine->gfx[2],
-/*				cclimber_bsvideoram[offs],	   cclimber    */
+/*              cclimber_bsvideoram[offs],     cclimber    */
 				cclimber_bsvideoram[offs] + ((cclimber_bigspriteram[1] & 0x08) << 5),	/* swimmer */
 				color,
 				flipx,flipy,
@@ -379,12 +351,12 @@ static void drawbigsprite(struct mame_bitmap *bitmap)
 }
 
 
-void cclimber_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( cclimber )
 {
 	int offs;
 
 
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 	{
 		memset(dirtybuffer,1,videoram_size);
 	}
@@ -496,13 +468,11 @@ void cclimber_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-
-void swimmer_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( swimmer )
 {
 	int offs;
 
-
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 	{
 		memset(dirtybuffer,1,videoram_size);
 	}
@@ -612,3 +582,282 @@ void swimmer_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		/* draw the "big sprite" over sprites */
 		drawbigsprite(bitmap);
 }
+
+VIDEO_UPDATE( yamato )
+{
+	int offs;
+	int i,j;
+
+	/* bg gradient */
+	fillbitmap(bitmap, 0, cliprect);
+
+	for(i=0;i<256;i++)
+	{
+		for(j=0;j<256;j++)
+		{
+			plot_pixel(bitmap, i-8, j, 16*4+8*4 + memory_region(REGION_USER1)[(flip_screen_x?0x1280:0x1200)+(i>>1)]);
+		}
+	}
+
+	if (get_vh_global_attribute_changed())
+	{
+		memset(dirtybuffer,1,videoram_size);
+	}
+
+	/* for every character in the Video RAM, check if it has been modified */
+	/* since last time and update it accordingly. */
+	for (offs = videoram_size - 1;offs >= 0;offs--)
+	{
+		if (dirtybuffer[offs])
+		{
+			int sx,sy,flipx,flipy;
+
+
+			dirtybuffer[offs] = 0;
+
+			sx = offs % 32;
+			sy = offs / 32;
+			flipx = colorram[offs] & 0x40;
+			flipy = colorram[offs] & 0x80;
+			/* vertical flipping flips two adjacent characters */
+			if (flipy) sy ^= 1;
+
+			if (flip_screen_x)
+			{
+				sx = 31 - sx;
+				flipx = !flipx;
+			}
+			if (flip_screen_y)
+			{
+				sy = 31 - sy;
+				flipy = !flipy;
+			}
+
+			drawgfx(tmpbitmap,Machine->gfx[(colorram[offs] & 0x10) ? 1 : 0],
+					videoram[offs] + 8 * (colorram[offs] & 0x20),
+					colorram[offs] & 0x0f,
+					flipx,flipy,
+					8*sx,8*sy,
+					0,TRANSPARENCY_NONE,0);
+		}
+	}
+
+
+	/* copy the temporary bitmap to the screen */
+	{
+		int scroll[32];
+
+
+		if (flip_screen_x)
+		{
+			for (offs = 0;offs < 32;offs++)
+			{
+				scroll[offs] = -cclimber_column_scroll[31 - offs];
+				if (flip_screen_y) scroll[offs] = -scroll[offs];
+			}
+		}
+		else
+		{
+			for (offs = 0;offs < 32;offs++)
+			{
+				scroll[offs] = -cclimber_column_scroll[offs];
+				if (flip_screen_y) scroll[offs] = -scroll[offs];
+			}
+		}
+
+		copyscrollbitmap(bitmap,tmpbitmap,0,0,32,scroll,&Machine->visible_area,TRANSPARENCY_PEN,0);
+	}
+
+
+	if (cclimber_bigspriteram[0] & 1)
+		/* draw the "big sprite" below sprites */
+		drawbigsprite(bitmap);
+
+
+	/* Draw the sprites. Note that it is important to draw them exactly in this */
+	/* order, to have the correct priorities. */
+	for (offs = spriteram_size - 4;offs >= 0;offs -= 4)
+	{
+		int sx,sy,flipx,flipy;
+
+
+		sx = spriteram[offs + 3];
+		sy = 240 - spriteram[offs + 2];
+		flipx = spriteram[offs] & 0x40;
+		flipy = spriteram[offs] & 0x80;
+		if (flip_screen_x)
+		{
+			sx = 240 - sx;
+			flipx = !flipx;
+		}
+		if (flip_screen_y)
+		{
+			sy = 240 - sy;
+			flipy = !flipy;
+		}
+
+		drawgfx(bitmap,Machine->gfx[spriteram[offs + 1] & 0x10 ? 4 : 3],
+				(spriteram[offs] & 0x3f) + 2 * (spriteram[offs + 1] & 0x20),
+				spriteram[offs + 1] & 0x0f,
+				flipx,flipy,
+				sx,sy,
+				&Machine->visible_area,TRANSPARENCY_PEN,0);
+	}
+
+
+	if ((cclimber_bigspriteram[0] & 1) == 0)
+		/* draw the "big sprite" over sprites */
+		drawbigsprite(bitmap);
+}
+
+
+/* Top Roller */
+#define PRIORITY_OVER  	0x20
+#define PRIORITY_UNDER 	0x00
+#define PRIORITY_MASK 	0x20
+
+static tilemap *bg_tilemap;
+
+UINT8 *videoram2;
+UINT8 *videoram3;
+UINT8 *videoram4;
+
+
+static void get_tile_info_bg(int tile_index)
+{
+	int code = videoram3[tile_index];
+	int atr = videoram4[tile_index];
+	int flipx,flipy,bank;
+
+	bank=(atr&8)<<5;
+
+	flipx=(atr&2)?1:0;
+	flipy=atr&4;
+
+	if(bank)
+		flipx=1;
+
+	code+=bank;
+	SET_TILE_INFO(1, code, 0, (flipx?TILE_FLIPX:0)|(flipy?TILE_FLIPY:0))
+}
+
+VIDEO_START( toprollr )
+{
+	bg_tilemap = tilemap_create(get_tile_info_bg,tilemap_scan_rows,TILEMAP_OPAQUE,8,8,32,32);
+	return 0;
+}
+
+static void trdrawbigsprite(mame_bitmap *bitmap,const rectangle *cliprect,int priority)
+{
+		if((cclimber_bigspriteram[1]&PRIORITY_MASK)==priority)
+		{
+			int code,xs,ys,pal,bank,x,y;
+			int flipx=0;
+			int flipy=0;
+
+			xs=136-cclimber_bigspriteram[3];
+			ys=128-cclimber_bigspriteram[2];
+
+			if (flip_screen_x)
+			{
+				flipx^=1;
+			}
+
+			pal=cclimber_bigspriteram[1]&7;
+
+			bank=(cclimber_bigspriteram[1]>>3)&3;
+
+
+			for(y=0;y<16;y++)
+				for(x=0;x<16;x++)
+				{
+					int sx=x;
+					int sy=y;
+					if (flipx) sx = 15 - x;
+					if (flipy) sy = 15 - y;
+
+					code=cclimber_bsvideoram[y*16+x];
+					drawgfx(bitmap, Machine->gfx[3], code+bank*256, pal, flipx, flipy,(sx*8+xs)&0xff,(sy*8+ys)&0xff, cliprect, TRANSPARENCY_PEN, 0);
+					drawgfx(bitmap, Machine->gfx[3], code+bank*256, pal, flipx, flipy,((sx*8+xs)&0xff)-256,((sy*8+ys)&0xff)-256, cliprect, TRANSPARENCY_PEN, 0);
+				}
+
+		}
+}
+
+VIDEO_UPDATE( toprollr )
+{
+
+	UINT32 x,y,c,d;
+	int offs;
+
+	tilemap_set_scrollx(bg_tilemap,0,videoram3[0]+8);
+	tilemap_mark_all_tiles_dirty(bg_tilemap);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
+
+	trdrawbigsprite(bitmap, cliprect, PRIORITY_UNDER);
+
+	for (offs = spriteram_size - 4;offs >= 0;offs -= 4)
+	{
+		int sx,sy,flipx,flipy;
+
+		sx = spriteram[offs + 3]-8;
+		sy = 240 - spriteram[offs + 2];
+		flipx = spriteram[offs] & 0x40;
+		flipy = spriteram[offs] & 0x80;
+		if (flip_screen_x)
+		{
+			sx = 240 - sx;
+			flipx = !flipx;
+		}
+		if (flip_screen_y)
+		{
+			sy = 240 - sy;
+			flipy = !flipy;
+		}
+
+		drawgfx(bitmap,Machine->gfx[2],
+			(spriteram[offs] & 0x3f) + 2 * (spriteram[offs + 1] & 0x20)+8*(spriteram[offs + 1] & 0x10),
+				spriteram[offs + 1] & 0x0f,
+				flipx,flipy,
+				sx,sy,
+				&Machine->visible_area,TRANSPARENCY_PEN,0);
+	}
+
+	trdrawbigsprite(bitmap, cliprect, PRIORITY_OVER);
+
+	for(y=0;y<32;y++)
+		for(x=0;x<32;x++)
+		{
+			int sx=x*8;
+			int sy=y*8;
+			int flipx=0;
+			int flipy=0;
+
+			c=videoram[y*32+x];
+			d=videoram2[y*32+x];
+
+			if (flip_screen_x)
+			{
+				sx = 240 - sx;
+				flipx^=1;
+			}
+			if (flip_screen_y)
+			{
+				sy = 240 - sy;
+				flipy^=1;
+			}
+
+			if(x>3&&x<29)
+				drawgfx(bitmap, Machine->gfx[0], c+((d&0xf0)<<4), (d>>2)&0x3, flipx, flipy, sx, sy, cliprect, TRANSPARENCY_PEN, 0);
+			else
+			{
+				/* hack */
+				drawgfx(bitmap, Machine->gfx[0], 45, 0, flipx, flipy, sx, sy, cliprect, TRANSPARENCY_NONE, 0); /*black */
+				drawgfx(bitmap, Machine->gfx[0], c+((d&0xf0)<<4), (d>>2)&0x3, flipx, flipy, sx, sy, cliprect, TRANSPARENCY_PEN, 0);
+			}
+		}
+}
+
+
+
+
