@@ -10,17 +10,18 @@ Functions to emulate the video hardware of the machine.
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "sound/dac.h"
 
 
 static int redraw_man = 0;
 static int man_scroll = -1;
-static data8_t sprites[0x20];
+static UINT8 sprites[0x20];
 static int char_palette = 0;
 
 
-void cheekyms_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( cheekyms )
 {
-	int i,j,bit;
+	int i,j,bit,r,g,b;
 
 	for (i = 0; i < 3; i++)
 	{
@@ -31,14 +32,15 @@ void cheekyms_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 		{
 			/* red component */
 			bit = (color_prom[0] >> 0) & 0x01;
-			*(palette++) = 0xff * bit;
+			r = 0xff * bit;
 			/* green component */
 			bit = (color_prom[0] >> 1) & 0x01;
-			*(palette++) = 0xff * bit;
+			g = 0xff * bit;
 			/* blue component */
 			bit = (color_prom[0] >> 2) & 0x01;
-			*(palette++) = 0xff * bit;
+			b = 0xff * bit;
 
+			palette_set_color(((i*2)*Machine->drv->total_colors/6)+j,r,g,b);
 			color_prom++;
 		}
 
@@ -49,27 +51,28 @@ void cheekyms_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 		{
 			/* red component */
 			bit = (color_prom[0] >> 4) & 0x01;
-			*(palette++) = 0xff * bit;
+			r = 0xff * bit;
 			/* green component */
 			bit = (color_prom[0] >> 5) & 0x01;
-			*(palette++) = 0xff * bit;
+			g = 0xff * bit;
 			/* blue component */
 			bit = (color_prom[0] >> 6) & 0x01;
-			*(palette++) = 0xff * bit;
+			b = 0xff * bit;
 
+			palette_set_color(((i*2+1)*Machine->drv->total_colors/6)+j,r,g,b);
 			color_prom++;
 		}
 	}
 }
 
 
-WRITE_HANDLER( cheekyms_sprite_w )
+WRITE8_HANDLER( cheekyms_sprite_w )
 {
 	sprites[offset] = data;
 }
 
 
-WRITE_HANDLER( cheekyms_port_40_w )
+WRITE8_HANDLER( cheekyms_port_40_w )
 {
 	static int last_dac = -1;
 
@@ -84,7 +87,7 @@ WRITE_HANDLER( cheekyms_port_40_w )
 }
 
 
-WRITE_HANDLER( cheekyms_port_80_w )
+WRITE8_HANDLER( cheekyms_port_80_w )
 {
 	int new_man_scroll;
 
@@ -117,12 +120,12 @@ WRITE_HANDLER( cheekyms_port_80_w )
   the main emulation engine.
 
 ***************************************************************************/
-void cheekyms_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( cheekyms )
 {
 	int offs;
 
 
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 	{
 		memset(dirtybuffer, 1, videoram_size);
 	}
@@ -131,7 +134,7 @@ void cheekyms_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
 
 	/* Draw the sprites first, because they're supposed to appear below
-	   the characters */
+       the characters */
 	for (offs = 0; offs < sizeof(sprites)/sizeof(sprites[0]); offs += 4)
 	{
 		int v1, sx, sy, col, code;
