@@ -1,32 +1,32 @@
 /***************************************************************************
 
-							-= Clash Road =-
+                            -= Clash Road =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
-	[ 2 Horizontally Scrolling Layers ]
+    [ 2 Horizontally Scrolling Layers ]
 
-		Size :	512 x 256
-		Tiles:	16 x 16 x 4.
+        Size :  512 x 256
+        Tiles:  16 x 16 x 4.
 
-		These 2 layers share the same graphics and X scroll value.
-		The tile codes are stuffed together in memory too: first one
-		layer's row, then the other's (and so on for all the rows).
+        These 2 layers share the same graphics and X scroll value.
+        The tile codes are stuffed together in memory too: first one
+        layer's row, then the other's (and so on for all the rows).
 
-	[ 1 Fixed Layer ]
+    [ 1 Fixed Layer ]
 
-		Size :	(256 + 32) x 256
-		Tiles:	8 x 8 x 4.
+        Size :  (256 + 32) x 256
+        Tiles:  8 x 8 x 4.
 
-		This is like a 32x32 tilemap, but the top and bottom rows (that
-		fall outside the visible area) are used to widen the tilemap
-		horizontally, adding 2 vertical columns both sides.
+        This is like a 32x32 tilemap, but the top and bottom rows (that
+        fall outside the visible area) are used to widen the tilemap
+        horizontally, adding 2 vertical columns both sides.
 
-		The result is a 36x28 visible tilemap.
+        The result is a 36x28 visible tilemap.
 
-	[ 64? sprites ]
+    [ 64? sprites ]
 
-		Sprites are 16 x 16 x 4.
+        Sprites are 16 x 16 x 4.
 
 ***************************************************************************/
 
@@ -35,25 +35,34 @@
 
 /* Variables only used here: */
 
-static struct tilemap *tilemap_0a, *tilemap_0b, *tilemap_1;
+static tilemap *tilemap_0a, *tilemap_0b, *tilemap_1;
 
 /* Variables & functions needed by drivers: */
 
-data8_t *clshroad_vram_0, *clshroad_vram_1;
-data8_t *clshroad_vregs;
+UINT8 *clshroad_vram_0, *clshroad_vram_1;
+UINT8 *clshroad_vregs;
 
-WRITE_HANDLER( clshroad_vram_0_w );
-WRITE_HANDLER( clshroad_vram_1_w );
-WRITE_HANDLER( clshroad_flipscreen_w );
+WRITE8_HANDLER( clshroad_vram_0_w );
+WRITE8_HANDLER( clshroad_vram_1_w );
+WRITE8_HANDLER( clshroad_flipscreen_w );
 
 
-WRITE_HANDLER( clshroad_flipscreen_w )
+WRITE8_HANDLER( clshroad_flipscreen_w )
 {
 	flip_screen_set( data & 1 );
 }
 
 
-void firebatl_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( clshroad )
+{
+	int i;
+	for (i = 0;i < 256;i++)
+		palette_set_color(i,	color_prom[i + 256 * 0] * 0x11,
+								color_prom[i + 256 * 1] * 0x11,
+								color_prom[i + 256 * 2] * 0x11	);
+}
+
+PALETTE_INIT( firebatl )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -101,51 +110,51 @@ void firebatl_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colo
 
 /***************************************************************************
 
-						Callbacks for the TileMap code
+                        Callbacks for the TileMap code
 
 ***************************************************************************/
 
 /***************************************************************************
 
-						  Layers 0 Tiles Format
+                          Layers 0 Tiles Format
 
 Offset:
 
-	00-3f:	Even bytes: Codes	Odd bytes: Colors	<- Layer B First Row
-	40-7f:	Even bytes: Codes	Odd bytes: Colors	<- Layer A First Row
-	..										<- 2nd Row
-	..										<- 3rd Row
-	etc.
+    00-3f:  Even bytes: Codes   Odd bytes: Colors   <- Layer B First Row
+    40-7f:  Even bytes: Codes   Odd bytes: Colors   <- Layer A First Row
+    ..                                      <- 2nd Row
+    ..                                      <- 3rd Row
+    etc.
 
 ***************************************************************************/
 
 static void get_tile_info_0a( int tile_index )
 {
-	data8_t code, color;
+	UINT8 code;
 	tile_index = (tile_index & 0x1f) + (tile_index & ~0x1f)*2;
 	code	=	clshroad_vram_0[ tile_index * 2 + 0x40 ];
-	color	=	clshroad_vram_0[ tile_index * 2 + 0x41 ];
+/*  color   =   clshroad_vram_0[ tile_index * 2 + 0x41 ]; */
 	SET_TILE_INFO(
 			1,
 			code,
-			color & 0x0f,
+			0,
 			0)
 }
 
 static void get_tile_info_0b( int tile_index )
 {
-	data8_t code, color;
+	UINT8 code;
 	tile_index = (tile_index & 0x1f) + (tile_index & ~0x1f)*2;
 	code	=	clshroad_vram_0[ tile_index * 2 + 0x00 ];
-	color	=	clshroad_vram_0[ tile_index * 2 + 0x01 ];
+/*  color   =   clshroad_vram_0[ tile_index * 2 + 0x01 ]; */
 	SET_TILE_INFO(
 			1,
 			code,
-			color & 0x0f,
+			0,
 			0)
 }
 
-WRITE_HANDLER( clshroad_vram_0_w )
+WRITE8_HANDLER( clshroad_vram_0_w )
 {
 	if (clshroad_vram_0[offset] != data)
 	{
@@ -159,19 +168,19 @@ WRITE_HANDLER( clshroad_vram_0_w )
 
 /***************************************************************************
 
-						  Layer 1 Tiles Format
+                          Layer 1 Tiles Format
 
 Offset:
 
-	000-3ff		Code
-	400-7ff		7654----	Code (High bits)
-				----3210	Color
+    000-3ff     Code
+    400-7ff     7654----    Code (High bits)
+                ----3210    Color
 
-	This is like a 32x32 tilemap, but the top and bottom rows (that
-	fall outside the visible area) are used to widen the tilemap
-	horizontally, adding 2 vertical columns both sides.
+    This is like a 32x32 tilemap, but the top and bottom rows (that
+    fall outside the visible area) are used to widen the tilemap
+    horizontally, adding 2 vertical columns both sides.
 
-	The result is a 36x28 visible tilemap.
+    The result is a 36x28 visible tilemap.
 
 ***************************************************************************/
 
@@ -194,8 +203,8 @@ static UINT32 tilemap_scan_rows_extra( UINT32 col, UINT32 row, UINT32 num_cols,
 
 static void get_tile_info_fb1( int tile_index )
 {
-	data8_t code	=	clshroad_vram_1[ tile_index + 0x000 ];
-	data8_t color	=	clshroad_vram_1[ tile_index + 0x400 ];
+	UINT8 code	=	clshroad_vram_1[ tile_index + 0x000 ];
+	UINT8 color	=	clshroad_vram_1[ tile_index + 0x400 ];
 	SET_TILE_INFO(
 			2,
 			code,
@@ -205,8 +214,8 @@ static void get_tile_info_fb1( int tile_index )
 
 static void get_tile_info_1( int tile_index )
 {
-	data8_t code	=	clshroad_vram_1[ tile_index + 0x000 ];
-	data8_t color	=	clshroad_vram_1[ tile_index + 0x400 ];
+	UINT8 code	=	clshroad_vram_1[ tile_index + 0x000 ];
+	UINT8 color	=	clshroad_vram_1[ tile_index + 0x400 ];
 	SET_TILE_INFO(
 			2,
 			code + ((color & 0xf0)<<4),
@@ -214,7 +223,7 @@ static void get_tile_info_1( int tile_index )
 			0)
 }
 
-WRITE_HANDLER( clshroad_vram_1_w )
+WRITE8_HANDLER( clshroad_vram_1_w )
 {
 	if (clshroad_vram_1[offset] != data)
 	{
@@ -224,7 +233,7 @@ WRITE_HANDLER( clshroad_vram_1_w )
 }
 
 
-int firebatl_vh_start(void)
+VIDEO_START( firebatl )
 {
 	/* These 2 use the graphics and scroll value */
 	tilemap_0a = tilemap_create(get_tile_info_0a,tilemap_scan_rows,TILEMAP_OPAQUE,     16,16,0x20,0x10);
@@ -253,7 +262,7 @@ int firebatl_vh_start(void)
 	return 0;
 }
 
-int clshroad_vh_start(void)
+VIDEO_START( clshroad )
 {
 	/* These 2 use the graphics and scroll value */
 	tilemap_0a = tilemap_create(get_tile_info_0a,tilemap_scan_rows,TILEMAP_OPAQUE,     16,16,0x20,0x10);
@@ -275,9 +284,9 @@ int clshroad_vh_start(void)
 	tilemap_set_scrolldx( tilemap_0a, -0x30, -0xb5);
 	tilemap_set_scrolldx( tilemap_0b, -0x30, -0xb5);
 
-	tilemap_set_transparent_pen( tilemap_0a, 0 );
-	tilemap_set_transparent_pen( tilemap_0b, 0 );
-	tilemap_set_transparent_pen( tilemap_1,  0 );
+	tilemap_set_transparent_pen( tilemap_0a, 0x0f );
+	tilemap_set_transparent_pen( tilemap_0b, 0x0f );
+	tilemap_set_transparent_pen( tilemap_1,  0x0f );
 
 	return 0;
 }
@@ -285,33 +294,34 @@ int clshroad_vh_start(void)
 
 /***************************************************************************
 
-								Sprites Drawing
+                                Sprites Drawing
 
-Offset:		Format:		Value:
+Offset:     Format:     Value:
 
-	0
+    0
 
-	1					Y (Bottom-up)
+    1                   Y (Bottom-up)
 
-	2		765432--
-			------10	Code (high bits)
+    2       765432--
+            ------10    Code (high bits)
 
-	3		76------
-			--543210	Code (low bits)
+    3       76------
+            --543210    Code (low bits)
 
-	4
+    4
 
-	5					X (low bits)
+    5                   X (low bits)
 
-	6					X (High bits)
+    6                   X (High bits)
 
-	7					Color?
+    7       7654----
+            ----3210    Color
 
 - Sprite flipping ?
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int i;
 
@@ -338,7 +348,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				attr & 0x0f,
 				flipx,flipy,
 				x,y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0 );
+				cliprect,TRANSPARENCY_PEN,15 );
 	}
 }
 
@@ -346,22 +356,22 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
-void clshroad_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( clshroad )
 {
 	int scrollx  = clshroad_vregs[ 0 ] + (clshroad_vregs[ 1 ] << 8);
-/*	int priority = clshroad_vregs[ 2 ]; */
+/*  int priority = clshroad_vregs[ 2 ]; */
 
 	/* Only horizontal scrolling (these 2 layers use the same value) */
 	tilemap_set_scrollx(tilemap_0a, 0, scrollx);
 	tilemap_set_scrollx(tilemap_0b, 0, scrollx);
 
-	tilemap_draw(bitmap,tilemap_0a,0,0);	/* Opaque */
-	tilemap_draw(bitmap,tilemap_0b,0,0);
-	draw_sprites(bitmap);
-	tilemap_draw(bitmap,tilemap_1,0,0);
+	tilemap_draw(bitmap,cliprect,tilemap_0a,0,0);	/* Opaque */
+	tilemap_draw(bitmap,cliprect,tilemap_0b,0,0);
+	draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,tilemap_1,0,0);
 }
