@@ -10,24 +10,24 @@
 #include "vidhrdw/konamiic.h"
 #include "vidhrdw/generic.h"
 
-static struct tilemap *tilemap[2];
-static struct tilemap *textlayer;
-static unsigned char *private_spriteram[2];
+static tilemap *bg_tilemap[2];
+static tilemap *textlayer;
+static UINT8 *private_spriteram[2];
 static int priority;
 
-unsigned char *combasc_io_ram;
+UINT8 *combasc_io_ram;
 static int combasc_vreg;
-unsigned char* banked_area;
+UINT8* banked_area;
 
 static int combasc_bank_select; /* 0x00..0x1f */
 static int combasc_video_circuit; /* 0 or 1 */
-static unsigned char *combasc_page[2];
-static unsigned char combasc_scrollram0[0x40];
-static unsigned char combasc_scrollram1[0x40];
-static unsigned char *combasc_scrollram;
+static UINT8 *combasc_page[2];
+static UINT8 combasc_scrollram0[0x40];
+static UINT8 combasc_scrollram1[0x40];
+static UINT8 *combasc_scrollram;
 
 
-void combasc_convert_color_prom(unsigned char *palette, unsigned short *colortable, const unsigned char *color_prom )
+PALETTE_INIT( combasc )
 {
 	int i,pal,clut = 0;
 	for( pal=0; pal<8; pal++ )
@@ -70,7 +70,7 @@ void combasc_convert_color_prom(unsigned char *palette, unsigned short *colortab
 	}
 }
 
-void combascb_convert_color_prom(unsigned char *palette, unsigned short *colortable, const unsigned char *color_prom )
+PALETTE_INIT( combascb )
 {
 	int i,pal;
 	for( pal=0; pal<8; pal++ )
@@ -87,13 +87,13 @@ void combascb_convert_color_prom(unsigned char *palette, unsigned short *colorta
 
 /***************************************************************************
 
-	Callbacks for the TileMap code
+    Callbacks for the TileMap code
 
 ***************************************************************************/
 
 static void get_tile_info0(int tile_index)
 {
-	unsigned char attributes = combasc_page[0][tile_index];
+	UINT8 attributes = combasc_page[0][tile_index];
 	int bank = 4*((combasc_vreg & 0x0f) - 1);
 	int number,color;
 
@@ -118,7 +118,7 @@ static void get_tile_info0(int tile_index)
 
 static void get_tile_info1(int tile_index)
 {
-	unsigned char attributes = combasc_page[1][tile_index];
+	UINT8 attributes = combasc_page[1][tile_index];
 	int bank = 4*((combasc_vreg >> 4) - 1);
 	int number, color;
 
@@ -143,7 +143,7 @@ static void get_tile_info1(int tile_index)
 
 static void get_text_info(int tile_index)
 {
-	unsigned char attributes = combasc_page[0][tile_index + 0x800];
+	UINT8 attributes = combasc_page[0][tile_index + 0x800];
 	int number = combasc_page[0][tile_index + 0xc00];
 	int color = 16 + (attributes & 0x0f);
 
@@ -157,7 +157,7 @@ static void get_text_info(int tile_index)
 
 static void get_tile_info0_bootleg(int tile_index)
 {
-	unsigned char attributes = combasc_page[0][tile_index];
+	UINT8 attributes = combasc_page[0][tile_index];
 	int bank = 4*((combasc_vreg & 0x0f) - 1);
 	int number, pal, color;
 
@@ -181,7 +181,7 @@ static void get_tile_info0_bootleg(int tile_index)
 
 static void get_tile_info1_bootleg(int tile_index)
 {
-	unsigned char attributes = combasc_page[1][tile_index];
+	UINT8 attributes = combasc_page[1][tile_index];
 	int bank = 4*((combasc_vreg >> 4) - 1);
 	int number, pal, color;
 
@@ -205,7 +205,7 @@ static void get_tile_info1_bootleg(int tile_index)
 
 static void get_text_info_bootleg(int tile_index)
 {
-/*	unsigned char attributes = combasc_page[0][tile_index + 0x800]; */
+/*  UINT8 attributes = combasc_page[0][tile_index + 0x800]; */
 	int number = combasc_page[0][tile_index + 0xc00];
 	int color = 16;/* + (attributes & 0x0f); */
 
@@ -218,27 +218,27 @@ static void get_text_info_bootleg(int tile_index)
 
 /***************************************************************************
 
-	Start the video hardware emulation.
+    Start the video hardware emulation.
 
 ***************************************************************************/
 
-int combasc_vh_start(void)
+VIDEO_START( combasc )
 {
 	combasc_vreg = -1;
 
-	tilemap[0] = tilemap_create(get_tile_info0,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
-	tilemap[1] = tilemap_create(get_tile_info1,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
+	bg_tilemap[0] = tilemap_create(get_tile_info0,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
+	bg_tilemap[1] = tilemap_create(get_tile_info1,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
 	textlayer =  tilemap_create(get_text_info, tilemap_scan_rows,TILEMAP_OPAQUE,     8,8,32,32);
 
-	private_spriteram[0] = malloc(0x800);
-	private_spriteram[1] = malloc(0x800);
+	private_spriteram[0] = auto_malloc(0x800);
+	private_spriteram[1] = auto_malloc(0x800);
 	memset(private_spriteram[0],0,0x800);
 	memset(private_spriteram[1],0,0x800);
 
-	if (tilemap[0] && tilemap[1] && textlayer)
+	if (bg_tilemap[0] && bg_tilemap[1] && textlayer)
 	{
-		tilemap_set_transparent_pen(tilemap[0],0);
-		tilemap_set_transparent_pen(tilemap[1],0);
+		tilemap_set_transparent_pen(bg_tilemap[0],0);
+		tilemap_set_transparent_pen(bg_tilemap[1],0);
 		tilemap_set_transparent_pen(textlayer,0);
 
 		tilemap_set_scroll_rows(textlayer,32);
@@ -249,27 +249,27 @@ int combasc_vh_start(void)
 	return 1;
 }
 
-int combascb_vh_start(void)
+VIDEO_START( combascb )
 {
 	combasc_vreg = -1;
 
-	tilemap[0] = tilemap_create(get_tile_info0_bootleg,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
-	tilemap[1] = tilemap_create(get_tile_info1_bootleg,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
+	bg_tilemap[0] = tilemap_create(get_tile_info0_bootleg,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
+	bg_tilemap[1] = tilemap_create(get_tile_info1_bootleg,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
 	textlayer =  tilemap_create(get_text_info_bootleg, tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
 
-	private_spriteram[0] = malloc(0x800);
-	private_spriteram[1] = malloc(0x800);
+	private_spriteram[0] = auto_malloc(0x800);
+	private_spriteram[1] = auto_malloc(0x800);
 	memset(private_spriteram[0],0,0x800);
 	memset(private_spriteram[1],0,0x800);
 
-	if (tilemap[0] && tilemap[1] && textlayer)
+	if (bg_tilemap[0] && bg_tilemap[1] && textlayer)
 	{
-		tilemap_set_transparent_pen(tilemap[0],0);
-		tilemap_set_transparent_pen(tilemap[1],0);
+		tilemap_set_transparent_pen(bg_tilemap[0],0);
+		tilemap_set_transparent_pen(bg_tilemap[1],0);
 		tilemap_set_transparent_pen(textlayer,0);
 
-		tilemap_set_scroll_rows(tilemap[0],32);
-		tilemap_set_scroll_rows(tilemap[1],32);
+		tilemap_set_scroll_rows(bg_tilemap[0],32);
+		tilemap_set_scroll_rows(bg_tilemap[1],32);
 
 		return 0;
 	}
@@ -277,25 +277,18 @@ int combascb_vh_start(void)
 	return 1;
 }
 
-void combasc_vh_stop(void)
-{
-	free(private_spriteram[0]);
-	free(private_spriteram[1]);
-}
-
-
 /***************************************************************************
 
-	Memory handlers
+    Memory handlers
 
 ***************************************************************************/
 
-READ_HANDLER( combasc_video_r )
+READ8_HANDLER( combasc_video_r )
 {
 	return videoram[offset];
 }
 
-WRITE_HANDLER( combasc_video_w )
+WRITE8_HANDLER( combasc_video_w )
 {
 	if( videoram[offset]!=data )
 	{
@@ -303,9 +296,9 @@ WRITE_HANDLER( combasc_video_w )
 		if( offset<0x800 )
 		{
 			if (combasc_video_circuit)
-				tilemap_mark_tile_dirty(tilemap[1],offset & 0x3ff);
+				tilemap_mark_tile_dirty(bg_tilemap[1],offset & 0x3ff);
 			else
-				tilemap_mark_tile_dirty(tilemap[0],offset & 0x3ff);
+				tilemap_mark_tile_dirty(bg_tilemap[0],offset & 0x3ff);
 		}
 		else if( offset<0x1000 && combasc_video_circuit==0 )
 		{
@@ -315,55 +308,38 @@ WRITE_HANDLER( combasc_video_w )
 }
 
 
-WRITE_HANDLER( combasc_vreg_w )
+WRITE8_HANDLER( combasc_vreg_w )
 {
 	if (data != combasc_vreg)
 	{
 		tilemap_mark_all_tiles_dirty( textlayer );
 		if ((data & 0x0f) != (combasc_vreg & 0x0f))
-			tilemap_mark_all_tiles_dirty( tilemap[0] );
+			tilemap_mark_all_tiles_dirty( bg_tilemap[0] );
 		if ((data >> 4) != (combasc_vreg >> 4))
-			tilemap_mark_all_tiles_dirty( tilemap[1] );
+			tilemap_mark_all_tiles_dirty( bg_tilemap[1] );
 		combasc_vreg = data;
 	}
 }
 
-WRITE_HANDLER( combascb_sh_irqtrigger_w )
+WRITE8_HANDLER( combascb_sh_irqtrigger_w )
 {
 	soundlatch_w(offset,data);
-	cpu_cause_interrupt(1,0xff);
+	cpunum_set_input_line_and_vector(1,0,HOLD_LINE,0xff);
 }
 
-READ_HANDLER( combasc_io_r )
+READ8_HANDLER( combascb_io_r )
 {
-	if ((offset <= 0x403) && (offset >= 0x400))
-	{
-		switch (offset)
-		{
-			case 0x400:	return input_port_0_r(0); break;
-			case 0x401:	return input_port_1_r(0); break;
-			case 0x402:	return input_port_2_r(0); break;
-			case 0x403:	return input_port_3_r(0); break;
-		}
-	}
-	return banked_area[offset];
+	return readinputport(offset);
 }
 
-WRITE_HANDLER( combasc_io_w )
+WRITE8_HANDLER( combascb_priority_w )
 {
-	switch (offset)
-	{
-		case 0x400: priority = data & 0x20; break;
-		case 0x800: combascb_sh_irqtrigger_w(0, data); break;
-		case 0xc00:	combasc_vreg_w(0, data); break;
-		default:
-			combasc_io_ram[offset] = data;
-	}
+	priority = data & 0x20;
 }
 
-WRITE_HANDLER( combasc_bankselect_w )
+WRITE8_HANDLER( combasc_bankselect_w )
 {
-	unsigned char *page = memory_region(REGION_CPU1) + 0x10000;
+	UINT8 *page = memory_region(REGION_CPU1) + 0x10000;
 
 	if (data & 0x40)
 	{
@@ -382,15 +358,15 @@ WRITE_HANDLER( combasc_bankselect_w )
 
 	if (data & 0x10)
 	{
-		cpu_setbank(1,page + 0x4000 * ((data & 0x0e) >> 1));
+		memory_set_bankptr(1,page + 0x4000 * ((data & 0x0e) >> 1));
 	}
 	else
 	{
-		cpu_setbank(1,page + 0x20000 + 0x4000 * (data & 1));
+		memory_set_bankptr(1,page + 0x20000 + 0x4000 * (data & 1));
 	}
 }
 
-WRITE_HANDLER( combascb_bankselect_w )
+WRITE8_HANDLER( combascb_bankselect_w )
 {
 	if (data & 0x40)
 	{
@@ -406,35 +382,37 @@ WRITE_HANDLER( combascb_bankselect_w )
 	data = data & 0x1f;
 	if( data != combasc_bank_select )
 	{
-		unsigned char *page = memory_region(REGION_CPU1) + 0x10000;
+		UINT8 *page = memory_region(REGION_CPU1) + 0x10000;
 		combasc_bank_select = data;
 
 		if (data & 0x10)
 		{
-			cpu_setbank(1,page + 0x4000 * ((data & 0x0e) >> 1));
+			memory_set_bankptr(1,page + 0x4000 * ((data & 0x0e) >> 1));
 		}
 		else
 		{
-			cpu_setbank(1,page + 0x20000 + 0x4000 * (data & 1));
+			memory_set_bankptr(1,page + 0x20000 + 0x4000 * (data & 1));
 		}
 
 		if (data == 0x1f)
 		{
-cpu_setbank(1,page + 0x20000 + 0x4000 * (data & 1));
-			memory_set_bankhandler_r (1, 0, combasc_io_r);/* IO RAM & Video Registers */
-			memory_set_bankhandler_w (1, 0, combasc_io_w);
+			memory_set_bankptr(1,page + 0x20000 + 0x4000 * (data & 1));
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4400, 0x4403, 0, 0, combascb_io_r);/* IO RAM & Video Registers */
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4400, 0x4400, 0, 0, combascb_priority_w);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4800, 0x4800, 0, 0, combascb_sh_irqtrigger_w);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4c00, 0x4c00, 0, 0, combasc_vreg_w);
 		}
 		else
 		{
-			memory_set_bankhandler_r (1, 0, MRA_BANK1);	/* banked ROM */
-			memory_set_bankhandler_w (1, 0, MWA_ROM);
+			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MRA8_BANK1);	/* banked ROM */
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4000, 0x7fff, 0, 0, MWA8_ROM);
 		}
 	}
 }
 
-void combasc_init_machine( void )
+MACHINE_INIT( combasc )
 {
-	unsigned char *MEM = memory_region(REGION_CPU1) + 0x38000;
+	UINT8 *MEM = memory_region(REGION_CPU1) + 0x38000;
 
 
 	combasc_io_ram  = MEM + 0x0000;
@@ -449,12 +427,12 @@ void combasc_init_machine( void )
 	combasc_bankselect_w( 0,0 );
 }
 
-WRITE_HANDLER( combasc_pf_control_w )
+WRITE8_HANDLER( combasc_pf_control_w )
 {
 	K007121_ctrl_w(combasc_video_circuit,offset,data);
 
 	if (offset == 7)
-		tilemap_set_flip(tilemap[combasc_video_circuit],(data & 0x08) ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+		tilemap_set_flip(bg_tilemap[combasc_video_circuit],(data & 0x08) ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 
 	if (offset == 3)
 	{
@@ -465,12 +443,12 @@ WRITE_HANDLER( combasc_pf_control_w )
 	}
 }
 
-READ_HANDLER( combasc_scrollram_r )
+READ8_HANDLER( combasc_scrollram_r )
 {
 	return combasc_scrollram[offset];
 }
 
-WRITE_HANDLER( combasc_scrollram_w )
+WRITE8_HANDLER( combasc_scrollram_w )
 {
 	combasc_scrollram[offset] = data;
 }
@@ -479,77 +457,77 @@ WRITE_HANDLER( combasc_scrollram_w )
 
 /***************************************************************************
 
-	Display Refresh
+    Display Refresh
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap, const unsigned char *source,int circuit,UINT32 pri_mask)
+static void draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *source,int circuit,UINT32 pri_mask)
 {
 	int base_color = (circuit*4)*16+(K007121_ctrlram[circuit][6]&0x10)*2;
 
-	K007121_sprites_draw(circuit,bitmap,source,base_color,0,0,pri_mask);
+	K007121_sprites_draw(circuit,bitmap,cliprect,source,base_color,0,0,pri_mask);
 }
 
 
-void combasc_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
+VIDEO_UPDATE( combasc )
 {
 	int i;
 
 
 	if (K007121_ctrlram[0][0x01] & 0x02)
 	{
-		tilemap_set_scroll_rows(tilemap[0],32);
+		tilemap_set_scroll_rows(bg_tilemap[0],32);
 		for (i = 0;i < 32;i++)
 		{
-			tilemap_set_scrollx(tilemap[0],i,combasc_scrollram0[i]);
+			tilemap_set_scrollx(bg_tilemap[0],i,combasc_scrollram0[i]);
 		}
 	}
 	else
 	{
-		tilemap_set_scroll_rows(tilemap[0],1);
-		tilemap_set_scrollx(tilemap[0],0,K007121_ctrlram[0][0x00] | ((K007121_ctrlram[0][0x01] & 0x01) << 8));
+		tilemap_set_scroll_rows(bg_tilemap[0],1);
+		tilemap_set_scrollx(bg_tilemap[0],0,K007121_ctrlram[0][0x00] | ((K007121_ctrlram[0][0x01] & 0x01) << 8));
 	}
 
 	if (K007121_ctrlram[1][0x01] & 0x02)
 	{
-		tilemap_set_scroll_rows(tilemap[1],32);
+		tilemap_set_scroll_rows(bg_tilemap[1],32);
 		for (i = 0;i < 32;i++)
 		{
-			tilemap_set_scrollx(tilemap[1],i,combasc_scrollram1[i]);
+			tilemap_set_scrollx(bg_tilemap[1],i,combasc_scrollram1[i]);
 		}
 	}
 	else
 	{
-		tilemap_set_scroll_rows(tilemap[1],1);
-		tilemap_set_scrollx(tilemap[1],0,K007121_ctrlram[1][0x00] | ((K007121_ctrlram[1][0x01] & 0x01) << 8));
+		tilemap_set_scroll_rows(bg_tilemap[1],1);
+		tilemap_set_scrollx(bg_tilemap[1],0,K007121_ctrlram[1][0x00] | ((K007121_ctrlram[1][0x01] & 0x01) << 8));
 	}
 
-	tilemap_set_scrolly(tilemap[0],0,K007121_ctrlram[0][0x02]);
-	tilemap_set_scrolly(tilemap[1],0,K007121_ctrlram[1][0x02]);
+	tilemap_set_scrolly(bg_tilemap[0],0,K007121_ctrlram[0][0x02]);
+	tilemap_set_scrolly(bg_tilemap[1],0,K007121_ctrlram[1][0x02]);
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
 	if (priority == 0)
 	{
-		tilemap_draw(bitmap,tilemap[1],TILEMAP_IGNORE_TRANSPARENCY|0,4);
-		tilemap_draw(bitmap,tilemap[1],TILEMAP_IGNORE_TRANSPARENCY|1,8);
-		tilemap_draw(bitmap,tilemap[0],0,1);
-		tilemap_draw(bitmap,tilemap[0],1,2);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[1],TILEMAP_IGNORE_TRANSPARENCY|0,4);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[1],TILEMAP_IGNORE_TRANSPARENCY|1,8);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[0],0,1);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[0],1,2);
 
 		/* we use the priority buffer so sprites are drawn front to back */
-		draw_sprites(bitmap,private_spriteram[1],1,0x0f00);
-		draw_sprites(bitmap,private_spriteram[0],0,0x4444);
+		draw_sprites(bitmap,cliprect,private_spriteram[1],1,0x0f00);
+		draw_sprites(bitmap,cliprect,private_spriteram[0],0,0x4444);
 	}
 	else
 	{
-		tilemap_draw(bitmap,tilemap[0],TILEMAP_IGNORE_TRANSPARENCY|0,1);
-		tilemap_draw(bitmap,tilemap[0],TILEMAP_IGNORE_TRANSPARENCY|1,2);
-		tilemap_draw(bitmap,tilemap[1],1,4);
-		tilemap_draw(bitmap,tilemap[1],0,8);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[0],TILEMAP_IGNORE_TRANSPARENCY|0,1);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[0],TILEMAP_IGNORE_TRANSPARENCY|1,2);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[1],1,4);
+		tilemap_draw(bitmap,cliprect,bg_tilemap[1],0,8);
 
 		/* we use the priority buffer so sprites are drawn front to back */
-		draw_sprites(bitmap,private_spriteram[1],1,0x0f00);
-		draw_sprites(bitmap,private_spriteram[0],0,0x4444);
+		draw_sprites(bitmap,cliprect,private_spriteram[1],1,0x0f00);
+		draw_sprites(bitmap,cliprect,private_spriteram[0],0,0x4444);
 	}
 
 	if (K007121_ctrlram[0][0x01] & 0x08)
@@ -557,20 +535,20 @@ void combasc_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
 		for (i = 0;i < 32;i++)
 		{
 			tilemap_set_scrollx(textlayer,i,combasc_scrollram0[0x20+i] ? 0 : TILE_LINE_DISABLED);
-			tilemap_draw(bitmap,textlayer,0,0);
+			tilemap_draw(bitmap,cliprect,textlayer,0,0);
 		}
 	}
 
 	/* chop the extreme columns if necessary */
 	if (K007121_ctrlram[0][0x03] & 0x40)
 	{
-		struct rectangle clip;
+		rectangle clip;
 
-		clip = Machine->visible_area;
+		clip = *cliprect;
 		clip.max_x = clip.min_x + 7;
 		fillbitmap(bitmap,Machine->pens[0],&clip);
 
-		clip = Machine->visible_area;
+		clip = *cliprect;
 		clip.min_x = clip.max_x - 7;
 		fillbitmap(bitmap,Machine->pens[0],&clip);
 	}
@@ -585,33 +563,31 @@ void combasc_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
 
 /***************************************************************************
 
-	bootleg Combat School sprites. Each sprite has 5 bytes:
+    bootleg Combat School sprites. Each sprite has 5 bytes:
 
-byte #0:	sprite number
-byte #1:	y position
-byte #2:	x position
+byte #0:    sprite number
+byte #1:    y position
+byte #2:    x position
 byte #3:
-	bit 0:		x position (bit 0)
-	bits 1..3:	???
-	bit 4:		flip x
-	bit 5:		unused?
-	bit 6:		sprite bank # (bit 2)
-	bit 7:		???
+    bit 0:      x position (bit 0)
+    bits 1..3:  ???
+    bit 4:      flip x
+    bit 5:      unused?
+    bit 6:      sprite bank # (bit 2)
+    bit 7:      ???
 byte #4:
-	bits 0,1:	sprite bank # (bits 0 & 1)
-	bits 2,3:	unused?
-	bits 4..7:	sprite color
+    bits 0,1:   sprite bank # (bits 0 & 1)
+    bits 2,3:   unused?
+    bits 4..7:  sprite color
 
 ***************************************************************************/
 
-static void bootleg_draw_sprites( struct mame_bitmap *bitmap, const unsigned char *source, int circuit )
+static void bootleg_draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *source, int circuit )
 {
-	const struct GfxElement *gfx = Machine->gfx[circuit+2];
-	const struct rectangle *clip = &Machine->visible_area;
+	const gfx_element *gfx = Machine->gfx[circuit+2];
 
-	unsigned char *RAM = memory_region(REGION_CPU1);
-	int limit = ( circuit) ? (RAM[0xc2]*256 + RAM[0xc3]) : (RAM[0xc0]*256 + RAM[0xc1]);
-	const unsigned char *finish;
+	int limit = ( circuit) ? (program_read_byte(0xc2)*256 + program_read_byte(0xc3)) : (program_read_byte(0xc0)*256 + program_read_byte(0xc1));
+	const UINT8 *finish;
 
 	source+=0x1000;
 	finish = source;
@@ -622,12 +598,12 @@ static void bootleg_draw_sprites( struct mame_bitmap *bitmap, const unsigned cha
 
 	while( source>finish )
 	{
-		unsigned char attributes = source[3]; /* PBxF ?xxX */
+		UINT8 attributes = source[3]; /* PBxF ?xxX */
 		{
 			int number = source[0];
 			int x = source[2] - 71 + (attributes & 0x01)*256;
 			int y = 242 - source[1];
-			unsigned char color = source[4]; /* CCCC xxBB */
+			UINT8 color = source[4]; /* CCCC xxBB */
 
 			int bank = (color & 0x03) | ((attributes & 0x40) >> 4);
 
@@ -636,47 +612,47 @@ static void bootleg_draw_sprites( struct mame_bitmap *bitmap, const unsigned cha
 
 			color = (circuit*4)*16 + (color >> 4);
 
-			/*	hacks to select alternate palettes */
-/*			if(combasc_vreg == 0x40 && (attributes & 0x40)) color += 1*16; */
-/*			if(combasc_vreg == 0x23 && (attributes & 0x02)) color += 1*16; */
-/*			if(combasc_vreg == 0x66 ) color += 2*16; */
+			/*  hacks to select alternate palettes */
+/*          if(combasc_vreg == 0x40 && (attributes & 0x40)) color += 1*16; */
+/*          if(combasc_vreg == 0x23 && (attributes & 0x02)) color += 1*16; */
+/*          if(combasc_vreg == 0x66 ) color += 2*16; */
 
 			drawgfx( bitmap, gfx,
 				number, color,
 				attributes & 0x10,0, /* flip */
 				x,y,
-				clip, TRANSPARENCY_PEN, 15 );
+				cliprect, TRANSPARENCY_PEN, 15 );
 		}
 		source -= 8;
 	}
 }
 
-void combascb_vh_screenrefresh( struct mame_bitmap *bitmap, int fullrefresh )
+VIDEO_UPDATE( combascb )
 {
 	int i;
 
 	for( i=0; i<32; i++ )
 	{
-		tilemap_set_scrollx( tilemap[0],i, combasc_io_ram[0x040+i]+5 );
-		tilemap_set_scrollx( tilemap[1],i, combasc_io_ram[0x060+i]+3 );
+		tilemap_set_scrollx( bg_tilemap[0],i, combasc_io_ram[0x040+i]+5 );
+		tilemap_set_scrollx( bg_tilemap[1],i, combasc_io_ram[0x060+i]+3 );
 	}
-	tilemap_set_scrolly( tilemap[0],0, combasc_io_ram[0x000] );
-	tilemap_set_scrolly( tilemap[1],0, combasc_io_ram[0x020] );
+	tilemap_set_scrolly( bg_tilemap[0],0, combasc_io_ram[0x000] );
+	tilemap_set_scrolly( bg_tilemap[1],0, combasc_io_ram[0x020] );
 
 	if (priority == 0)
 	{
-		tilemap_draw( bitmap,tilemap[1],TILEMAP_IGNORE_TRANSPARENCY,0);
-		bootleg_draw_sprites( bitmap, combasc_page[0], 0 );
-		tilemap_draw( bitmap,tilemap[0],0 ,0);
-		bootleg_draw_sprites( bitmap, combasc_page[1], 1 );
+		tilemap_draw( bitmap,cliprect,bg_tilemap[1],TILEMAP_IGNORE_TRANSPARENCY,0);
+		bootleg_draw_sprites( bitmap,cliprect, combasc_page[0], 0 );
+		tilemap_draw( bitmap,cliprect,bg_tilemap[0],0 ,0);
+		bootleg_draw_sprites( bitmap,cliprect, combasc_page[1], 1 );
 	}
 	else
 	{
-		tilemap_draw( bitmap,tilemap[0],TILEMAP_IGNORE_TRANSPARENCY,0);
-		bootleg_draw_sprites( bitmap, combasc_page[0], 0 );
-		tilemap_draw( bitmap,tilemap[1],0 ,0);
-		bootleg_draw_sprites( bitmap, combasc_page[1], 1 );
+		tilemap_draw( bitmap,cliprect,bg_tilemap[0],TILEMAP_IGNORE_TRANSPARENCY,0);
+		bootleg_draw_sprites( bitmap,cliprect, combasc_page[0], 0 );
+		tilemap_draw( bitmap,cliprect,bg_tilemap[1],0 ,0);
+		bootleg_draw_sprites( bitmap,cliprect, combasc_page[1], 1 );
 	}
 
-	tilemap_draw( bitmap,textlayer,0,0);
+	tilemap_draw( bitmap,cliprect,textlayer,0,0);
 }
