@@ -719,7 +719,7 @@ static void unshuffle(UINT64 *buf,int len)
 
 	if (len == 2) return;
 
-	if (len % 4) exit(1);   /* must not happen */
+	assert(len % 4 == 0);   /* must not happen */
 
 	len /= 2;
 
@@ -1141,8 +1141,6 @@ VIDEO_START( cps )
 	memset(empty_tile,0xff,sizeof(empty_tile));
 
 	cps1_old_palette=auto_malloc(cps1_palette_size);
-	if (!cps1_old_palette)
-		return 1;
 	memset(cps1_old_palette, 0x00, cps1_palette_size);
 	for (i = 0;i < cps1_palette_entries*16;i++)
 	{
@@ -1150,14 +1148,10 @@ VIDEO_START( cps )
 	}
 
     cps1_buffered_obj = auto_malloc (cps1_obj_size);
-    if (!cps1_buffered_obj)
-		return 1;
     memset(cps1_buffered_obj, 0x00, cps1_obj_size);
 
     if (cps_version==2) {
 	cps2_buffered_obj = auto_malloc (cps2_obj_size);
-	if (!cps2_buffered_obj)
-	    return 1;
 	memset(cps2_buffered_obj, 0x00, cps2_obj_size);
     }
 
@@ -1965,3 +1959,4 @@ void cps2_objram_latch(void)
 	cps2_set_sprite_priorities();
 	memcpy(cps2_buffered_obj, cps2_objbase(), cps2_obj_size);
 }
+
