@@ -4,8 +4,8 @@
 #include "vidhrdw/taitoic.h"
 
 
-static struct tilemap *fg_tilemap;
-data16_t *darius_fg_ram;
+static tilemap *fg_tilemap;
+UINT16 *darius_fg_ram;
 
 struct tempsprite
 {
@@ -21,7 +21,7 @@ static struct tempsprite *spritelist;
 
 /***************************************************************************/
 
-static void actual_get_fg_tile_info(data16_t *ram,int gfxnum,int tile_index)
+static void actual_get_fg_tile_info(UINT16 *ram,int gfxnum,int tile_index)
 {
 	UINT16 code = (ram[tile_index + 0x2000] & 0x7ff);
 	UINT16 attr = ram[tile_index];
@@ -50,23 +50,17 @@ static void dirty_fg_tilemap(void)
 
 /***************************************************************************/
 
-int darius_vh_start (void)
+VIDEO_START( darius )
 {
 	fg_tilemap = tilemap_create(darius_fg_get_tile_info[0],tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,128,64);
 	if (!fg_tilemap)
 		return 1;
 
-	spritelist = malloc(0x800 * sizeof(*spritelist));
-	if (!spritelist)
-		return 1;
+	spritelist = auto_malloc(0x800 * sizeof(*spritelist));
 
 	/* (chips, gfxnum, x_offs, y_offs, y_invert, opaque, dblwidth) */
 	if ( PC080SN_vh_start(1,1,-16,8,0,1,1) )
-	{
-		free(spritelist);
-		spritelist = 0;
 		return 1;
-	}
 
 	tilemap_set_transparent_pen(fg_tilemap,0);
 
@@ -76,14 +70,6 @@ int darius_vh_start (void)
 	return 0;
 }
 
-void darius_vh_stop(void)
-{
-	free(spritelist);
-	spritelist = 0;
-
-	PC080SN_vh_stop();
-}
-
 /***************************************************************************/
 
 READ16_HANDLER( darius_fg_layer_r )
@@ -105,14 +91,14 @@ WRITE16_HANDLER( darius_fg_layer_w )
 
 /***************************************************************************/
 
-void darius_draw_sprites(struct mame_bitmap *bitmap,int *primasks, int y_offs)
+void darius_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect,int primask, int y_offs)
 {
 	int offs,curx,cury;
 	UINT16 code,data,sx,sy;
 	UINT8 flipx,flipy,color,priority;
 
 	/* pdrawgfx() needs us to draw sprites front to back, so we have to build a list
-	   while processing sprite ram and then draw them all at the end */
+       while processing sprite ram and then draw them all at the end */
 	struct tempsprite *sprite_ptr = spritelist;
 
 	for (offs = spriteram_size/2-4; offs >= 0; offs -= 4)
@@ -132,7 +118,8 @@ void darius_draw_sprites(struct mame_bitmap *bitmap,int *primasks, int y_offs)
 			flipy = ((data & 0x8000) >> 15);
 
 			data = spriteram16[offs+3];
-			priority = (data &0x80) >> 7;
+			priority = (data &0x80) >> 7;  /* 0 = low */
+			if (priority != primask) continue;
 			color = (data & 0x7f);
 
 			curx = sx;
@@ -148,64 +135,35 @@ void darius_draw_sprites(struct mame_bitmap *bitmap,int *primasks, int y_offs)
 			sprite_ptr->x = curx;
 			sprite_ptr->y = cury;
 
-			if (primasks)
-			{
-				sprite_ptr->primask = primasks[priority];
-				sprite_ptr++;
-			}
-			else
-			{
-				drawgfx(bitmap,Machine->gfx[0],
-						sprite_ptr->code,
-						sprite_ptr->color,
-						sprite_ptr->flipx,sprite_ptr->flipy,
-						sprite_ptr->x,sprite_ptr->y,
-						&Machine->visible_area,TRANSPARENCY_PEN,0);
-			}
+			drawgfx(bitmap,Machine->gfx[0],
+					sprite_ptr->code,
+					sprite_ptr->color,
+					sprite_ptr->flipx,sprite_ptr->flipy,
+					sprite_ptr->x,sprite_ptr->y,
+					cliprect,TRANSPARENCY_PEN,0);
 		}
 	}
-
-	/* this happens only if primsks != NULL */
-	while (sprite_ptr != spritelist)
-	{
-		sprite_ptr--;
-
-		pdrawgfx(bitmap,Machine->gfx[0],
-				sprite_ptr->code,
-				sprite_ptr->color,
-				sprite_ptr->flipx,sprite_ptr->flipy,
-				sprite_ptr->x,sprite_ptr->y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0,
-				sprite_ptr->primask);
-	}
 }
 
 
 
-void darius_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( darius )
 {
-	UINT8 layer[2];
-
 	PC080SN_tilemap_update();
 
-	/* top layer is in fixed position */
-	tilemap_set_scrollx(fg_tilemap,0,0);
-	tilemap_set_scrolly(fg_tilemap,0,-8);
-
-	layer[0] = 0;
-	layer[1] = 1;
-
-	fillbitmap(priority_bitmap,0,NULL);
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
-
- 	PC080SN_tilemap_draw(bitmap,0,layer[0],TILEMAP_IGNORE_TRANSPARENCY,1);
-	PC080SN_tilemap_draw(bitmap,0,layer[1],0,2);
-	tilemap_draw(bitmap,fg_tilemap,0,4);
+	/* draw bottom layer(always active) */
+ 	PC080SN_tilemap_draw(bitmap,cliprect,0,0,TILEMAP_IGNORE_TRANSPARENCY,0);
 
 	/* Sprites can be under/over the layer below text layer */
-	{
-		int primasks[2] = {0xfc,0xf0};
-		darius_draw_sprites(bitmap,primasks,-8);
-	}
-}
+	darius_draw_sprites(bitmap,cliprect,0,-8); /* draw sprites with priority 0 which are under the mid layer */
 
+	/* draw middle layer */
+	PC080SN_tilemap_draw(bitmap,cliprect,0,1,0,0);
+
+	darius_draw_sprites(bitmap,cliprect,1,-8); /* draw sprites with priority 1 which are over the mid layer */
+
+	/* top(text) layer is in fixed position */
+	tilemap_set_scrollx(fg_tilemap,0,0);
+	tilemap_set_scrolly(fg_tilemap,0,-8);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
+}
