@@ -10,11 +10,20 @@
 #include "vidhrdw/generic.h"
 
 
-static int gfx_bank,palette_bank;
+static int gfx_bank, palette_bank;
 static int grid_on;
-static const unsigned char *color_codes;
+static const UINT8 *color_codes;
 
+static tilemap *bg_tilemap;
 
+WRITE8_HANDLER( dkong_videoram_w )
+{
+	if (videoram[offset] != data)
+	{
+		videoram[offset] = data;
+		tilemap_mark_tile_dirty(bg_tilemap, offset);
+	}
+}
 
 /***************************************************************************
 
@@ -36,7 +45,7 @@ static const unsigned char *color_codes;
   bit 0 -- 470 ohm resistor -- inverter  -- BLUE
 
 ***************************************************************************/
-void dkong_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( dkong )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -45,24 +54,25 @@ void dkong_vh_convert_color_prom(unsigned char *palette, unsigned short *colorta
 
 	for (i = 0;i < 256;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/* red component */
 		bit0 = (color_prom[256] >> 1) & 1;
 		bit1 = (color_prom[256] >> 2) & 1;
 		bit2 = (color_prom[256] >> 3) & 1;
-		*(palette++) = 255 - (0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2);
+		r = 255 - (0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2);
 		/* green component */
 		bit0 = (color_prom[0] >> 2) & 1;
 		bit1 = (color_prom[0] >> 3) & 1;
 		bit2 = (color_prom[256] >> 0) & 1;
-		*(palette++) = 255 - (0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2);
+		g = 255 - (0x21 * bit0 + 0x47 * bit1 + 0x97 * bit2);
 		/* blue component */
 		bit0 = (color_prom[0] >> 0) & 1;
 		bit1 = (color_prom[0] >> 1) & 1;
-		*(palette++) = 255 - (0x55 * bit0 + 0xaa * bit1);
+		b = 255 - (0x55 * bit0 + 0xaa * bit1);
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
@@ -101,7 +111,7 @@ void dkong_vh_convert_color_prom(unsigned char *palette, unsigned short *colorta
   bit 0 -- 2.2kohm resistor -- inverter  -- BLUE
 
 ***************************************************************************/
-void dkong3_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( dkong3 )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -110,7 +120,7 @@ void dkong3_vh_convert_color_prom(unsigned char *palette, unsigned short *colort
 
 	for (i = 0;i < 256;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 
 		/* red component */
@@ -118,20 +128,21 @@ void dkong3_vh_convert_color_prom(unsigned char *palette, unsigned short *colort
 		bit1 = (color_prom[0] >> 5) & 0x01;
 		bit2 = (color_prom[0] >> 6) & 0x01;
 		bit3 = (color_prom[0] >> 7) & 0x01;
-		*(palette++) = 255 - (0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3);
+		r = 255 - (0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3);
 		/* green component */
 		bit0 = (color_prom[0] >> 0) & 0x01;
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 255 - (0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3);
+		g = 255 - (0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3);
 		/* blue component */
 		bit0 = (color_prom[256] >> 0) & 0x01;
 		bit1 = (color_prom[256] >> 1) & 0x01;
 		bit2 = (color_prom[256] >> 2) & 0x01;
 		bit3 = (color_prom[256] >> 3) & 0x01;
-		*(palette++) = 255 - (0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3);
+		b = 255 - (0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3);
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
@@ -140,63 +151,83 @@ void dkong3_vh_convert_color_prom(unsigned char *palette, unsigned short *colort
 	color_codes = color_prom;	/* we'll need it later */
 }
 
+static void get_bg_tile_info(int tile_index)
+{
+	int code = videoram[tile_index] + 256 * gfx_bank;
+	int color = (color_codes[tile_index % 32 + 32 * (tile_index / 32 / 4)] & 0x0f) + 0x10 * palette_bank;
 
+	SET_TILE_INFO(0, code, color, 0)
+}
 
-int dkong_vh_start(void)
+VIDEO_START( dkong )
 {
 	gfx_bank = 0;
 	palette_bank = 0;
 
-	return generic_vh_start();
+	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows, TILEMAP_OPAQUE, 8, 8, 32, 32);
+
+	if ( !bg_tilemap )
+		return 1;
+
+	return 0;
 }
 
 
-
-WRITE_HANDLER( dkongjr_gfxbank_w )
+WRITE8_HANDLER( dkongjr_gfxbank_w )
 {
-	set_vh_global_attribute(&gfx_bank, data & 1);
+	if (gfx_bank != (data & 0x01))
+	{
+		gfx_bank = data & 0x01;
+		tilemap_mark_all_tiles_dirty(bg_tilemap);
+	}
 }
 
-WRITE_HANDLER( dkong3_gfxbank_w )
+WRITE8_HANDLER( dkong3_gfxbank_w )
 {
-	set_vh_global_attribute(&gfx_bank, ~data & 1);
+	if (gfx_bank != (~data & 0x01))
+	{
+		gfx_bank = ~data & 0x01;
+		tilemap_mark_all_tiles_dirty(bg_tilemap);
+	}
 }
 
-
-
-WRITE_HANDLER( dkong_palettebank_w )
+WRITE8_HANDLER( dkong_palettebank_w )
 {
 	int newbank;
 
-
 	newbank = palette_bank;
+
 	if (data & 1)
 		newbank |= 1 << offset;
 	else
 		newbank &= ~(1 << offset);
 
-	set_vh_global_attribute(&palette_bank, newbank);
+	if (palette_bank != newbank)
+	{
+		palette_bank = newbank;
+		tilemap_mark_all_tiles_dirty(bg_tilemap);
+	}
 }
 
-WRITE_HANDLER( radarscp_grid_enable_w )
+WRITE8_HANDLER( radarscp_grid_enable_w )
 {
-	grid_on = data & 1;
+	grid_on = data & 0x01;
 }
 
-WRITE_HANDLER( radarscp_grid_color_w )
+WRITE8_HANDLER( radarscp_grid_color_w )
 {
 	int r,g,b;
 
 	r = ((~data >> 0) & 0x01) * 0xff;
 	g = ((~data >> 1) & 0x01) * 0xff;
 	b = ((~data >> 2) & 0x01) * 0xff;
-/*	palette_set_color(257,r,g,b); */
+/*  palette_set_color(257,r,g,b); */
 	palette_set_color(257,0x00,0x00,0xff);
 }
 
-WRITE_HANDLER( dkong_flipscreen_w )
+WRITE8_HANDLER( dkong_flipscreen_w )
 {
-	flip_screen_set(~data & 1);
+	flip_screen_set(~data & 0x01);
 }
 
 /***************************************************************************
@@ -207,49 +238,7 @@ WRITE_HANDLER( dkong_flipscreen_w )
 
 ***************************************************************************/
 
-static void draw_tiles(struct mame_bitmap *bitmap)
-{
-	int offs;
-
-	/* for every character in the Video RAM, check if it has been modified */
-	/* since last time and update it accordingly. */
-	for (offs = videoram_size - 1;offs >= 0;offs--)
-	{
-		if (dirtybuffer[offs])
-		{
-			int sx,sy;
-			int charcode,color;
-
-
-			dirtybuffer[offs] = 0;
-
-			sx = offs % 32;
-			sy = offs / 32;
-
-			charcode = videoram[offs] + 256 * gfx_bank;
-			/* retrieve the character color from the PROM */
-			color = (color_codes[offs % 32 + 32 * (offs / 32 / 4)] & 0x0f) + 0x10 * palette_bank;
-
-			if (flip_screen)
-			{
-				sx = 31 - sx;
-				sy = 31 - sy;
-			}
-
-			drawgfx(tmpbitmap,Machine->gfx[0],
-					charcode,color,
-					flip_screen,flip_screen,
-					8*sx,8*sy,
-					&Machine->visible_area,TRANSPARENCY_NONE,0);
-		}
-	}
-
-
-	/* copy the character mapped graphics */
-	copybitmap(bitmap,tmpbitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_NONE,0);
-}
-
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap, unsigned int mask_bank, unsigned int shift_bits)
 {
 	int offs;
 
@@ -275,7 +264,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				y = 240 - y;
 
 				drawgfx(bitmap,Machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + 2 * (spriteram[offs + 2] & 0x40),
+						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
 						(spriteram[offs + 2] & 0x0f) + 16 * palette_bank,
 						!(spriteram[offs + 2] & 0x80),!(spriteram[offs + 1] & 0x80),
 						x,y,
@@ -283,7 +272,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 
 				/* draw with wrap around - this fixes the 'beheading' bug */
 				drawgfx(bitmap,Machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + 2 * (spriteram[offs + 2] & 0x40),
+						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
 						(spriteram[offs + 2] & 0x0f) + 16 * palette_bank,
 						(spriteram[offs + 2] & 0x80),(spriteram[offs + 1] & 0x80),
 						x-256,y,
@@ -292,7 +281,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 			else
 			{
 				drawgfx(bitmap,Machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + 2 * (spriteram[offs + 2] & 0x40),
+						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
 						(spriteram[offs + 2] & 0x0f) + 16 * palette_bank,
 						(spriteram[offs + 2] & 0x80),(spriteram[offs + 1] & 0x80),
 						x,y,
@@ -300,7 +289,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 
 				/* draw with wrap around - this fixes the 'beheading' bug */
 				drawgfx(bitmap,Machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + 2 * (spriteram[offs + 2] & 0x40),
+						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
 						(spriteram[offs + 2] & 0x0f) + 16 * palette_bank,
 						(spriteram[offs + 2] & 0x80),(spriteram[offs + 1] & 0x80),
 						x+256,y,
@@ -310,9 +299,9 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 	}
 }
 
-static void draw_grid(struct mame_bitmap *bitmap)
+static void draw_grid(mame_bitmap *bitmap)
 {
-	const unsigned char *table = memory_region(REGION_GFX3);
+	const UINT8 *table = memory_region(REGION_GFX3);
 	int x,y,counter;
 
 	counter = flip_screen ? 0x000 : 0x400;
@@ -341,23 +330,46 @@ static void draw_grid(struct mame_bitmap *bitmap)
 	}
 }
 
-void radarscp_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( radarscp )
 {
 	palette_set_color(256,0xff,0x00,0x00);	/* stars */
 
-	if (full_refresh)
-		memset(dirtybuffer,1,videoram_size);
-
-	draw_tiles(bitmap);
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
 	draw_grid(bitmap);
-	draw_sprites(bitmap);
+	draw_sprites(bitmap, 0x40, 1);
 }
 
-void dkong_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( dkong )
 {
-	if (full_refresh)
-		memset(dirtybuffer,1,videoram_size);
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+	draw_sprites(bitmap, 0x40, 1);
+}
 
-	draw_tiles(bitmap);
-	draw_sprites(bitmap);
+VIDEO_UPDATE( pestplce )
+{
+	int offs;
+
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+
+	/* Draw the sprites. */
+	for (offs = 0;offs < spriteram_size;offs += 4)
+	{
+		if (spriteram[offs])
+		{
+			drawgfx(bitmap,Machine->gfx[1],
+					spriteram[offs + 2],
+					(spriteram[offs + 1] & 0x0f) + 16 * palette_bank,
+					spriteram[offs + 1] & 0x80,spriteram[offs + 1] & 0x40,
+					spriteram[offs + 3] - 8,240 - spriteram[offs] + 8,
+					cliprect,TRANSPARENCY_PEN,0);
+		}
+	}
+}
+
+VIDEO_UPDATE( spclforc )
+{
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+
+	/* it uses spriteram[offs + 2] & 0x10 for sprite bank */
+	draw_sprites(bitmap, 0x10, 3);
 }
