@@ -2,15 +2,15 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-static struct tilemap *bg_layer,*fg_layer,*tx_layer;
-unsigned char *dynduke_back_data,*dynduke_fore_data,*dynduke_scroll_ram,*dynduke_control_ram;
+static tilemap *bg_layer,*fg_layer,*tx_layer;
+UINT8 *dynduke_back_data,*dynduke_fore_data,*dynduke_scroll_ram;
 
-static int flipscreen,back_bankbase,fore_bankbase,back_palbase;
+static int back_bankbase,fore_bankbase,back_palbase;
 static int back_enable,fore_enable,sprite_enable;
 
 /******************************************************************************/
 
-WRITE_HANDLER( dynduke_paletteram_w )
+WRITE8_HANDLER( dynduke_paletteram_w )
 {
 	int r,g,b;
 	int color;
@@ -36,29 +36,19 @@ WRITE_HANDLER( dynduke_paletteram_w )
 	}
 }
 
-READ_HANDLER( dynduke_background_r )
-{
-	return dynduke_back_data[offset];
-}
-
-READ_HANDLER( dynduke_foreground_r )
-{
-	return dynduke_fore_data[offset];
-}
-
-WRITE_HANDLER( dynduke_background_w )
+WRITE8_HANDLER( dynduke_background_w )
 {
 	dynduke_back_data[offset]=data;
 	tilemap_mark_tile_dirty(bg_layer,offset/2);
 }
 
-WRITE_HANDLER( dynduke_foreground_w )
+WRITE8_HANDLER( dynduke_foreground_w )
 {
 	dynduke_fore_data[offset]=data;
 	tilemap_mark_tile_dirty(fg_layer,offset/2);
 }
 
-WRITE_HANDLER( dynduke_text_w )
+WRITE8_HANDLER( dynduke_text_w )
 {
 	videoram[offset]=data;
 	tilemap_mark_tile_dirty(tx_layer,offset/2);
@@ -104,7 +94,7 @@ static void get_tx_tile_info(int tile_index)
 			0)
 }
 
-int dynduke_vh_start(void)
+VIDEO_START( dynduke )
 {
 	bg_layer = tilemap_create(get_bg_tile_info,tilemap_scan_cols,TILEMAP_SPLIT,      16,16,32,32);
 	fg_layer = tilemap_create(get_fg_tile_info,tilemap_scan_cols,TILEMAP_TRANSPARENT,16,16,32,32);
@@ -118,7 +108,7 @@ int dynduke_vh_start(void)
 	return 0;
 }
 
-WRITE_HANDLER( dynduke_gfxbank_w )
+WRITE8_HANDLER( dynduke_gfxbank_w )
 {
 	static int old_back,old_fore;
 
@@ -134,14 +124,10 @@ WRITE_HANDLER( dynduke_gfxbank_w )
 	old_fore=fore_bankbase;
 }
 
-WRITE_HANDLER( dynduke_control_w )
+WRITE8_HANDLER( dynduke_control_w )
 {
 	static int old_bpal;
 
-	dynduke_control_ram[offset]=data;
-
-	if (offset!=6) return;
-
 	if (data&0x1) back_enable=0; else back_enable=1;
 	if (data&0x2) back_palbase=16; else back_palbase=0;
 	if (data&0x4) fore_enable=0; else fore_enable=1;
@@ -151,11 +137,10 @@ WRITE_HANDLER( dynduke_control_w )
 		tilemap_mark_all_tiles_dirty(bg_layer);
 
 	old_bpal=back_palbase;
-	flipscreen=data&0x40;
-	tilemap_set_flip(ALL_TILEMAPS,flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+	flip_screen_set(data & 0x40);
 }
 
-static void draw_sprites(struct mame_bitmap *bitmap,int pri)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect,int pri)
 {
 	int offs,fx,fy,x,y,color,sprite;
 
@@ -165,7 +150,6 @@ static void draw_sprites(struct mame_bitmap *bitmap,int pri)
 	{
 		/* Don't draw empty sprite table entries */
 		if (buffered_spriteram[offs+7]!=0xf) continue;
-		if (buffered_spriteram[offs+0]==0xf0f) continue;
 		if (((buffered_spriteram[offs+5]>>5)&3)!=pri) continue;
 
 		fx= buffered_spriteram[offs+1]&0x20;
@@ -179,7 +163,7 @@ static void draw_sprites(struct mame_bitmap *bitmap,int pri)
 		sprite = buffered_spriteram[offs+2]+(buffered_spriteram[offs+3]<<8);
 		sprite &= 0x3fff;
 
-		if (flipscreen) {
+		if (flip_screen) {
 			x=240-x;
 			y=240-y;
 			if (fx) fx=0; else fx=1;
@@ -189,11 +173,11 @@ static void draw_sprites(struct mame_bitmap *bitmap,int pri)
 		drawgfx(bitmap,Machine->gfx[3],
 				sprite,
 				color,fx,fy,x,y,
-				&Machine->visible_area,TRANSPARENCY_PEN,15);
+				cliprect,TRANSPARENCY_PEN,15);
 	}
 }
 
-void dynduke_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( dynduke )
 {
 	/* Setup the tilemaps */
 	tilemap_set_scrolly( bg_layer,0, ((dynduke_scroll_ram[0x02]&0x30)<<4)+((dynduke_scroll_ram[0x04]&0x7f)<<1)+((dynduke_scroll_ram[0x04]&0x80)>>7) );
@@ -204,15 +188,20 @@ void dynduke_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	tilemap_set_enable( fg_layer,fore_enable);
 
 	if (back_enable)
-		tilemap_draw(bitmap,bg_layer,TILEMAP_BACK,0);
+		tilemap_draw(bitmap,cliprect,bg_layer,TILEMAP_BACK,0);
 	else
-		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+		fillbitmap(bitmap,get_black_pen(),cliprect);
 
-	draw_sprites(bitmap,0); /* Untested: does anything use it? Could be behind background */
-	draw_sprites(bitmap,1);
-	tilemap_draw(bitmap,bg_layer,TILEMAP_FRONT,0);
-	draw_sprites(bitmap,2);
-	tilemap_draw(bitmap,fg_layer,0,0);
-	draw_sprites(bitmap,3);
-	tilemap_draw(bitmap,tx_layer,0,0);
+	draw_sprites(bitmap,cliprect,0); /* Untested: does anything use it? Could be behind background */
+	draw_sprites(bitmap,cliprect,1);
+	tilemap_draw(bitmap,cliprect,bg_layer,TILEMAP_FRONT,0);
+	draw_sprites(bitmap,cliprect,2);
+	tilemap_draw(bitmap,cliprect,fg_layer,0,0);
+	draw_sprites(bitmap,cliprect,3);
+	tilemap_draw(bitmap,cliprect,tx_layer,0,0);
+}
+
+VIDEO_EOF( dynduke )
+{
+	buffer_spriteram_w(0,0); /* Could be a memory location instead */
 }
