@@ -17,7 +17,7 @@ static int spriterambank,charbank;
 
 
 
-void finalizr_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( finalizr )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -26,7 +26,7 @@ void finalizr_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 
 		/* red component */
@@ -34,20 +34,21 @@ void finalizr_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		/* green component */
 		bit0 = (color_prom[0] >> 4) & 0x01;
 		bit1 = (color_prom[0] >> 5) & 0x01;
 		bit2 = (color_prom[0] >> 6) & 0x01;
 		bit3 = (color_prom[0] >> 7) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		/* blue component */
 		bit0 = (color_prom[Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
@@ -66,36 +67,23 @@ void finalizr_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 	}
 }
 
-int finalizr_vh_start(void)
+VIDEO_START( finalizr )
 {
 	dirtybuffer = 0;
 	tmpbitmap = 0;
 
-	if ((dirtybuffer = malloc(videoram_size)) == 0)
-		return 1;
+	dirtybuffer = auto_malloc(videoram_size);
 	memset(dirtybuffer,1,videoram_size);
 
-	if ((tmpbitmap = bitmap_alloc(256,256)) == 0)
-	{
-		free(dirtybuffer);
+	if ((tmpbitmap = auto_bitmap_alloc(256,256)) == 0)
 		return 1;
-	}
 
 	return 0;
 }
 
-void finalizr_vh_stop(void)
-{
-	free(dirtybuffer);
-	bitmap_free(tmpbitmap);
-
-	dirtybuffer = 0;
-	tmpbitmap = 0;
-}
 
 
-
-WRITE_HANDLER( finalizr_videoctrl_w )
+WRITE8_HANDLER( finalizr_videoctrl_w )
 {
 	if (charbank != (data & 3))
 	{
@@ -117,7 +105,7 @@ WRITE_HANDLER( finalizr_videoctrl_w )
   the main emulation engine.
 
 ***************************************************************************/
-void finalizr_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( finalizr )
 {
 	int offs;
 
@@ -178,7 +166,7 @@ void finalizr_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 			code = sr[offs] + ((sr[offs+1] & 0x0f) << 8);
 			color = ((sr[offs+1] & 0xf0)>>4);
 
-/*			(sr[offs+4] & 0x02) is used, meaning unknown */
+/*          (sr[offs+4] & 0x02) is used, meaning unknown */
 
 			switch (sr[offs+4] & 0x1c)
 			{
