@@ -3,16 +3,30 @@
 
 
 
-data16_t *galpanic_bgvideoram,*galpanic_fgvideoram;
+UINT16 *galpanic_bgvideoram,*galpanic_fgvideoram;
 size_t galpanic_fgvideoram_size;
+int galpanic_clear_sprites;
 
+static mame_bitmap *sprites_bitmap;
 
+VIDEO_START( galpanic )
+{
+	if ((tmpbitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+		return 1;
 
-void galpanic_init_palette(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+	if ((sprites_bitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+		return 1;
+
+	galpanic_clear_sprites = 1;
+
+	return 0;
+}
+
+PALETTE_INIT( galpanic )
 {
 	int i;
 
-	palette += 3*1024;	/* first 1024 colors are dynamic */
+	/* first 1024 colors are dynamic */
 
 	/* initialize 555 RGB lookup */
 	for (i = 0;i < 32768;i++)
@@ -23,9 +37,10 @@ void galpanic_init_palette(unsigned char *palette, unsigned short *colortable,co
 		g = (i >> 10) & 0x1f;
 		b = (i >>  0) & 0x1f;
 
-		(*palette++) = (r << 3) | (r >> 2);
-		(*palette++) = (g << 3) | (g >> 2);
-		(*palette++) = (b << 3) | (b >> 2);
+		r = (r << 3) | (r >> 2);
+		g = (g << 3) | (g >> 2);
+		b = (b << 3) | (b >> 2);
+		palette_set_color(i+1024,r,g,b);
 	}
 }
 
@@ -72,7 +87,7 @@ WRITE16_HANDLER( galpanic_paletteram_w )
 
 ***************************************************************************/
 
-static void galpanic_draw_sprites(struct mame_bitmap *bitmap)
+static void galpanic_draw_sprites(mame_bitmap *bitmap)
 {
 	int offs;
 	int sx,sy;
@@ -114,21 +129,34 @@ static void galpanic_draw_sprites(struct mame_bitmap *bitmap)
 	}
 }
 
-static void comad_draw_sprites(struct mame_bitmap *bitmap)
+static void comad_draw_sprites(mame_bitmap *bitmap)
 {
 	int offs;
+	int sx=0, sy=0;
 
 	for (offs = 0;offs < spriteram_size/2;offs += 4)
 	{
-		int sx,sy,code,color,flipx,flipy;
+		int code,color,flipx,flipy;
 
-		sx = spriteram16[offs + 2] >> 6;
-		sy = spriteram16[offs + 3] >> 6;
-		code = spriteram16[offs + 1];
+		code = spriteram16[offs + 1] & 0x1fff;
 		color = (spriteram16[offs] & 0x003c) >> 2;
 		flipx = spriteram16[offs] & 0x0002;
 		flipy = spriteram16[offs] & 0x0001;
 
+		if((spriteram16[offs] & 0x6000) == 0x6000) /* Link bits */
+		{
+			sx += spriteram16[offs + 2] >> 6;
+			sy += spriteram16[offs + 3] >> 6;
+		}
+		else
+		{
+			sx = spriteram16[offs + 2] >> 6;
+			sy = spriteram16[offs + 3] >> 6;
+		}
+
+		sx = (sx&0x1ff) - (sx&0x200);
+		sy = (sy&0x1ff) - (sy&0x200);
+
 		drawgfx(bitmap,Machine->gfx[0],
 				code,
 				color,
@@ -138,7 +166,7 @@ static void comad_draw_sprites(struct mame_bitmap *bitmap)
 	}
 }
 
-static void draw_fgbitmap(struct mame_bitmap *bitmap)
+static void draw_fgbitmap(mame_bitmap *bitmap)
 {
 	int offs;
 
@@ -154,22 +182,42 @@ static void draw_fgbitmap(struct mame_bitmap *bitmap)
 	}
 }
 
-void galpanic_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( galpanic )
 {
 	/* copy the temporary bitmap to the screen */
 	copybitmap(bitmap,tmpbitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_NONE,0);
 
 	draw_fgbitmap(bitmap);
 
-	galpanic_draw_sprites(bitmap);
+	if(galpanic_clear_sprites)
+	{
+		fillbitmap(sprites_bitmap,0,cliprect);
+		galpanic_draw_sprites(bitmap);
+	}
+	else
+	{
+		/* keep sprites on the bitmap without clearing them */
+		galpanic_draw_sprites(sprites_bitmap);
+		copybitmap(bitmap,sprites_bitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_PEN,0);
+	}
 }
 
-void comad_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( comad )
 {
 	/* copy the temporary bitmap to the screen */
 	copybitmap(bitmap,tmpbitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_NONE,0);
 
 	draw_fgbitmap(bitmap);
 
-	comad_draw_sprites(bitmap);
+	if(galpanic_clear_sprites)
+	{
+		fillbitmap(sprites_bitmap,0,cliprect);
+		comad_draw_sprites(bitmap);
+	}
+	else
+	{
+		/* keep sprites on the bitmap without clearing them */
+		comad_draw_sprites(sprites_bitmap);
+		copybitmap(bitmap,sprites_bitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_PEN,0);
+	}
 }
