@@ -2,17 +2,15 @@
 #include "vidhrdw/generic.h"
 
 
-data16_t *galspnbl_bgvideoram,*galspnbl_videoram,*galspnbl_colorram;
+UINT16 *galspnbl_bgvideoram,*galspnbl_videoram,*galspnbl_colorram;
 static int screenscroll;
 
 
 
-void galspnbl_init_palette(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( galspnbl )
 {
 	int i;
 
-	palette += 3*1024;	/* first 1024 colors are dynamic */
-
 	/* initialize 555 RGB lookup */
 	for (i = 0;i < 32768;i++)
 	{
@@ -22,9 +20,10 @@ void galspnbl_init_palette(unsigned char *palette, unsigned short *colortable,co
 		g = (i >> 10) & 0x1f;
 		b = (i >>  0) & 0x1f;
 
-		(*palette++) = (r << 3) | (r >> 2);
-		(*palette++) = (g << 3) | (g >> 2);
-		(*palette++) = (b << 3) | (b >> 2);
+		r = (r << 3) | (r >> 2);
+		g = (g << 3) | (g >> 2);
+		b = (b << 3) | (b >> 2);
+		palette_set_color(i+1024,r,g,b);
 	}
 }
 
@@ -53,7 +52,7 @@ WRITE16_HANDLER( galspnbl_scroll_w )
 
 /* sprite format (see also Ninja Gaiden):
  *
- *	word		bit					usage
+ *  word        bit                 usage
  * --------+-fedcba9876543210-+----------------
  *    0    | ---------------x | flip x
  *         | --------------x- | flip y
@@ -67,10 +66,10 @@ WRITE16_HANDLER( galspnbl_scroll_w )
  *    4    | xxxxxxxxxxxxxxxx | x position
  *    5,6,7|                  | unused
  */
-static void draw_sprites(struct mame_bitmap *bitmap,int priority)
+static void draw_sprites(mame_bitmap *bitmap,int priority)
 {
 	int offs;
-	const UINT8 layout[8][8] =
+	static const UINT8 layout[8][8] =
 	{
 		{0,1,4,5,16,17,20,21},
 		{2,3,6,7,18,19,22,23},
@@ -89,7 +88,7 @@ static void draw_sprites(struct mame_bitmap *bitmap,int priority)
 
 		attr = spriteram16[offs];
 		if ((attr & 0x0004) && ((attr & 0x0040) == 0 || (cpu_getcurrentframe() & 1))
-/*				&& ((attr & 0x0030) >> 4) == priority) */
+/*              && ((attr & 0x0030) >> 4) == priority) */
 				&& ((attr & 0x0020) >> 5) == priority)
 		{
 			code = spriteram16[offs+1];
@@ -120,7 +119,7 @@ static void draw_sprites(struct mame_bitmap *bitmap,int priority)
 }
 
 
-void galspnbl_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( galspnbl )
 {
 	int offs;
 
