@@ -1,69 +1,69 @@
 /**************************************************************************
 
-							Ginga NinkyouDen
-							(C) 1987 Jaleco
+                            Ginga NinkyouDen
+                            (C) 1987 Jaleco
 
-					driver by Luca Elia (l.elia@tin.it)
+                    driver by Luca Elia (l.elia@tin.it)
 
 
-Note:	if MAME_DEBUG is defined, pressing Z with:
+Note:   if MAME_DEBUG is defined, pressing Z with:
 
-		Q		shows background
-		W		shows foreground
-		E		shows frontmost (text) layer
-		A		shows sprites
+        Q       shows background
+        W       shows foreground
+        E       shows frontmost (text) layer
+        A       shows sprites
 
-		Keys can be used togheter!
+        Keys can be used togheter!
 
 
 [Screen]
-	Visible Size:		256H x 240V
-	Dynamic Colors: 	256 x 4
-	Color Space:		16R x 16G x 16B
+    Visible Size:       256H x 240V
+    Dynamic Colors:     256 x 4
+    Color Space:        16R x 16G x 16B
 
 [Scrolling layers]
-	Format (all layers):	Offset: 	0x400	 0x000
-							Bit:		fedc---- --------	Color
-										----ba98 76543210	Code
+    Format (all layers):    Offset:     0x400    0x000
+                            Bit:        fedc---- --------   Color
+                                        ----ba98 76543210   Code
 
-	[Background]
-		Size:				8192 x 512	(static: stored in ROM)
-		Scrolling:			X,Y 		(registers: $60006.w, $60004.w)
-		Tiles Size: 		16 x 16
-		Tiles Number:		$400
-		Colors: 			$300-$3ff
+    [Background]
+        Size:               8192 x 512  (static: stored in ROM)
+        Scrolling:          X,Y         (registers: $60006.w, $60004.w)
+        Tiles Size:         16 x 16
+        Tiles Number:       $400
+        Colors:             $300-$3ff
 
-	[Foreground]
-		Size:				4096 x 512
-		Scrolling:			X,Y 		(registers: $60002.w, $60000.w)
-		Tiles Size: 		16 x 16
-		Tiles Number:		$400
-		Colors: 			$200-$2ff
+    [Foreground]
+        Size:               4096 x 512
+        Scrolling:          X,Y         (registers: $60002.w, $60000.w)
+        Tiles Size:         16 x 16
+        Tiles Number:       $400
+        Colors:             $200-$2ff
 
-	[Frontmost]
-		Size:				256 x 256
-		Scrolling:			-
-		Tiles Size: 		8 x 8
-		Tiles Number:		$200
-		Colors: 			$000-$0ff
+    [Frontmost]
+        Size:               256 x 256
+        Scrolling:          -
+        Tiles Size:         8 x 8
+        Tiles Number:       $200
+        Colors:             $000-$0ff
 
 
 [Sprites]
-	On Screen:			256
-	In ROM: 			$a00
-	Colors: 			$100-$1ff
-	Format: 			See Below
+    On Screen:          256
+    In ROM:             $a00
+    Colors:             $100-$1ff
+    Format:             See Below
 
 
 **************************************************************************/
 #include "vidhrdw/generic.h"
 
 /* Variables only used here */
-static struct tilemap *bg_tilemap, *fg_tilemap, *tx_tilemap;
+static tilemap *bg_tilemap, *fg_tilemap, *tx_tilemap;
 static int layers_ctrl, flipscreen;
 
 /* Variables that driver has access to */
-data16_t *ginganin_fgram16, *ginganin_txtram16, *ginganin_vregs16;
+UINT16 *ginganin_fgram16, *ginganin_txtram16, *ginganin_vregs16;
 
 /* Variables defined in drivers */
 
@@ -100,7 +100,7 @@ static void get_bg_tile_info(int tile_index)
 
 static void get_fg_tile_info(int tile_index)
 {
-	data16_t code = ginganin_fgram16[tile_index];
+	UINT16 code = ginganin_fgram16[tile_index];
 	SET_TILE_INFO(
 			FG_GFX,
 			code,
@@ -110,7 +110,7 @@ static void get_fg_tile_info(int tile_index)
 
 WRITE16_HANDLER( ginganin_fgram16_w )
 {
-	data16_t oldword = ginganin_fgram16[offset];
+	UINT16 oldword = ginganin_fgram16[offset];
 	COMBINE_DATA(&ginganin_fgram16[offset]);
 	if (oldword != ginganin_fgram16[offset])
 		tilemap_mark_tile_dirty(fg_tilemap,offset);
@@ -125,7 +125,7 @@ WRITE16_HANDLER( ginganin_fgram16_w )
 
 static void get_txt_tile_info(int tile_index)
 {
-	data16_t code = ginganin_txtram16[tile_index];
+	UINT16 code = ginganin_txtram16[tile_index];
 	SET_TILE_INFO(
 			TXT_GFX,
 			code,
@@ -135,14 +135,14 @@ static void get_txt_tile_info(int tile_index)
 
 WRITE16_HANDLER( ginganin_txtram16_w )
 {
-	data16_t oldword = ginganin_txtram16[offset];
+	UINT16 oldword = ginganin_txtram16[offset];
 	COMBINE_DATA(&ginganin_txtram16[offset]);
 	if (oldword != ginganin_txtram16[offset])
 		tilemap_mark_tile_dirty(tx_tilemap,offset);
 }
 
 
-int ginganin_vh_start(void)
+VIDEO_START( ginganin )
 {
 	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_cols,TILEMAP_OPAQUE,16,16,BG_NX,BG_NY);
 	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_cols,TILEMAP_TRANSPARENT,16,16,FG_NX,FG_NY);
@@ -180,8 +180,8 @@ WRITE16_HANDLER( ginganin_vregs16_w )
 	case 4:
 		layers_ctrl = data;
 		break;
-/*	case 5:
- *		break;
+/*  case 5:
+ *      break;
  */
 	case 6:
 		flipscreen = !(data & 1);
@@ -189,10 +189,10 @@ WRITE16_HANDLER( ginganin_vregs16_w )
 		break;
 	case 7:
 		soundlatch_w(0,data);
-		cpu_set_nmi_line(1,PULSE_LINE);
+		cpunum_set_input_line(1, INPUT_LINE_NMI, PULSE_LINE);
 		break;
 	default:
-		logerror("CPU #0 PC %06X : Warning, videoreg %04X <- %04X\n",cpu_get_pc(),offset,data);
+		logerror("CPU #0 PC %06X : Warning, videoreg %04X <- %04X\n",activecpu_get_pc(),offset,data);
 	}
 }
 
@@ -200,25 +200,25 @@ WRITE16_HANDLER( ginganin_vregs16_w )
 
 /* --------------------------[ Sprites Format ]----------------------------
 
-Offset: 		Values: 		Format:
+Offset:         Values:         Format:
 
-0000.w			y position		fedc ba9- ---- ---- 	unused
-								---- ---8 ---- ---- 	subtract 256
-								---- ---- 7654 3210 	position
+0000.w          y position      fedc ba9- ---- ----     unused
+                                ---- ---8 ---- ----     subtract 256
+                                ---- ---- 7654 3210     position
 
-0002.w			x position		See above
+0002.w          x position      See above
 
-0004.w			code			f--- ---- ---- ---- 	y flip
-								-e-- ---- ---- ---- 	x flip
-								--dc ---- ---- ---- 	unused?
-								---- ba98 7654 3210 	code
+0004.w          code            f--- ---- ---- ----     y flip
+                                -e-- ---- ---- ----     x flip
+                                --dc ---- ---- ----     unused?
+                                ---- ba98 7654 3210     code
 
-0006.w			colour			fedc ---- ---- ---- 	colour code
-								---- ba98 7654 3210 	unused?
+0006.w          colour          fedc ---- ---- ----     colour code
+                                ---- ba98 7654 3210     unused?
 
 ------------------------------------------------------------------------ */
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 int offs;
 
@@ -245,29 +245,28 @@ int offs;
 				attr >> 12,
 				flipx, flipy,
 				x,y,
-				&Machine->visible_area,TRANSPARENCY_PEN,15);
+				cliprect,TRANSPARENCY_PEN,15);
 
 	}
 }
 
 
-void ginganin_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( ginganin )
 {
 	int layers_ctrl1;
 
 	layers_ctrl1 = layers_ctrl;
 
 #ifdef MAME_DEBUG
-if (keyboard_pressed(KEYCODE_Z))
+if (code_pressed(KEYCODE_Z))
 {
 	int msk = 0;
-	char buf[80];
 	static int posx,posy;
 
-	if (keyboard_pressed(KEYCODE_Q)) { msk |= 0xfff1;}
-	if (keyboard_pressed(KEYCODE_W)) { msk |= 0xfff2;}
-	if (keyboard_pressed(KEYCODE_E)) { msk |= 0xfff4;}
-	if (keyboard_pressed(KEYCODE_A))	{ msk |= 0xfff8;}
+	if (code_pressed(KEYCODE_Q)) { msk |= 0xfff1;}
+	if (code_pressed(KEYCODE_W)) { msk |= 0xfff2;}
+	if (code_pressed(KEYCODE_E)) { msk |= 0xfff4;}
+	if (code_pressed(KEYCODE_A))	{ msk |= 0xfff8;}
 	if (msk != 0) layers_ctrl1 &= msk;
 
 #define SETSCROLL \
@@ -275,25 +274,24 @@ if (keyboard_pressed(KEYCODE_Z))
 	tilemap_set_scrolly(bg_tilemap, 0, posy); \
 	tilemap_set_scrollx(fg_tilemap, 0, posx); \
 	tilemap_set_scrolly(fg_tilemap, 0, posy); \
-	sprintf(buf,"B>%04X:%04X F>%04X:%04X",posx%(BG_NX*16),posy%(BG_NY*16),posx%(FG_NX*16),posy%(FG_NY*16)); \
-	usrintf_showmessage(buf);
+	ui_popup("B>%04X:%04X F>%04X:%04X",posx%(BG_NX*16),posy%(BG_NY*16),posx%(FG_NX*16),posy%(FG_NY*16));
 
-	if (keyboard_pressed(KEYCODE_L))	{ posx +=8; SETSCROLL }
-	if (keyboard_pressed(KEYCODE_J))	{ posx -=8; SETSCROLL }
-	if (keyboard_pressed(KEYCODE_K))	{ posy +=8; SETSCROLL }
-	if (keyboard_pressed(KEYCODE_I))	{ posy -=8; SETSCROLL }
-	if (keyboard_pressed(KEYCODE_H))	{ posx = posy = 0;	SETSCROLL }
+	if (code_pressed(KEYCODE_L))	{ posx +=8; SETSCROLL }
+	if (code_pressed(KEYCODE_J))	{ posx -=8; SETSCROLL }
+	if (code_pressed(KEYCODE_K))	{ posy +=8; SETSCROLL }
+	if (code_pressed(KEYCODE_I))	{ posy -=8; SETSCROLL }
+	if (code_pressed(KEYCODE_H))	{ posx = posy = 0;	SETSCROLL }
 
 }
 #endif
 
 
-	if (layers_ctrl1 & 1)	tilemap_draw(bitmap, bg_tilemap,  0,0);
-	else					fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+	if (layers_ctrl1 & 1)	tilemap_draw(bitmap,cliprect, bg_tilemap,  0,0);
+	else					fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	if (layers_ctrl1 & 2)	tilemap_draw(bitmap, fg_tilemap,  0,0);
-	if (layers_ctrl1 & 8)	draw_sprites(bitmap);
-	if (layers_ctrl1 & 4)	tilemap_draw(bitmap, tx_tilemap, 0,0);
+	if (layers_ctrl1 & 2)	tilemap_draw(bitmap,cliprect, fg_tilemap,  0,0);
+	if (layers_ctrl1 & 8)	draw_sprites(bitmap,cliprect);
+	if (layers_ctrl1 & 4)	tilemap_draw(bitmap,cliprect, tx_tilemap, 0,0);
 
 }
 
