@@ -1,34 +1,29 @@
 /***************************************************************************
 
-  vidhrdw.c
-
-  Functions to emulate the video hardware of the machine.
+    Incredible Technologies/Strata system
+    (32-bit blitter variant)
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 #include "cpu/m68000/m68000.h"
-
-
-void itech32_update_interrupts(int vint, int xint, int qint);
-void itech32_update_interrupts_fast(int vint, int xint, int qint);
+#include "itech32.h"
 
 
 /*************************************
  *
- *	Debugging
+ *  Debugging
  *
  *************************************/
 
 #define BLIT_LOGGING			0
-#define INSTANT_BLIT			1
 
 
 
 /*************************************
  *
- *	Blitter constants
+ *  Blitter constants
  *
  *************************************/
 
@@ -100,6 +95,12 @@ void itech32_update_interrupts_fast(int vint, int xint, int qint);
 #define VIDEO_UNKNOWN7c			itech32_video[0x7c/2]	/* $0820 at startup */
 #define VIDEO_UNKNOWN7e			itech32_video[0x7e/2]	/* $0100 at startup */
 
+#define VIDEO_STARTSTEP			itech32_video[0x80/2]	/* drivedge only? */
+#define VIDEO_LEFTSTEPLO		itech32_video[0x82/2]	/* drivedge only? */
+#define VIDEO_LEFTSTEPHI		itech32_video[0x84/2]	/* drivedge only? */
+#define VIDEO_RIGHTSTEPLO		itech32_video[0x86/2]	/* drivedge only? */
+#define VIDEO_RIGHTSTEPHI		itech32_video[0x88/2]	/* drivedge only? */
+
 #define VIDEOINT_SCANLINE		0x0004
 #define VIDEOINT_BLITTER		0x0040
 
@@ -121,19 +122,20 @@ void itech32_update_interrupts_fast(int vint, int xint, int qint);
 
 /*************************************
  *
- *	Global variables
+ *  Global variables
  *
  *************************************/
 
-data16_t *itech32_video;
+UINT16 *itech32_video;
+UINT32 *drivedge_zbuf_control;
 UINT8 itech32_planes;
 UINT16 itech32_vram_height;
 
-static data16_t xfer_xcount, xfer_ycount;
-static data16_t xfer_xcur, xfer_ycur;
+static UINT16 xfer_xcount, xfer_ycount;
+static UINT16 xfer_xcur, xfer_ycur;
 
-static struct rectangle clip_rect, scaled_clip_rect;
-static struct rectangle clip_save;
+static rectangle clip_rect, scaled_clip_rect;
+static rectangle clip_save;
 
 static void *scanline_timer;
 
@@ -149,11 +151,15 @@ static UINT16 *videoplane[2];
 static UINT32 vram_mask;
 static UINT32 vram_xmask, vram_ymask;
 
+static int is_drivedge;
+
+static void scanline_interrupt(int param);
+
 
 
 /*************************************
  *
- *	Macros and inlines
+ *  Macros and inlines
  *
  *************************************/
 
@@ -189,18 +195,16 @@ INLINE void enable_clipping(void)
 
 /*************************************
  *
- *	Video start
+ *  Video start
  *
  *************************************/
 
-int itech32_vh_start(void)
+VIDEO_START( itech32 )
 {
 	int i;
 
 	/* allocate memory */
-	videoram16 = malloc(VRAM_WIDTH * (itech32_vram_height + 16) * 2 * 2);
-	if (!videoram16)
-		return 1;
+	videoram16 = auto_malloc(VRAM_WIDTH * (itech32_vram_height + 16) * 2 * 2);
 	memset(videoram16, 0xff, VRAM_WIDTH * (itech32_vram_height + 16) * 2 * 2);
 
 	/* videoplane[0] is the foreground; videoplane[1] is the background */
@@ -227,8 +231,11 @@ int itech32_vh_start(void)
 	/* reset statics */
 	memset(itech32_video, 0, 0x80);
 
-	scanline_timer = 0;
+	scanline_timer = timer_alloc(scanline_interrupt);
+	enable_latch[0] = 1;
+	enable_latch[1] = (itech32_planes > 1) ? 1 : 0;
 
+	is_drivedge = 0;
 	return 0;
 }
 
@@ -236,20 +243,7 @@ int itech32_vh_start(void)
 
 /*************************************
  *
- *	Video stop
- *
- *************************************/
-
-void itech32_vh_stop(void)
-{
-	free(videoram16);
-}
-
-
-
-/*************************************
- *
- *	Latches
+ *  Latches
  *
  *************************************/
 
@@ -307,6 +301,13 @@ WRITE16_HANDLER( bloodstm_plane_w )
 }
 
 
+WRITE32_HANDLER( drivedge_color0_w )
+{
+	if (!(mem_mask & 0x00ff0000))
+		color_latch[0] = ((data >> 16) & 0x7f) << 8;
+}
+
+
 WRITE32_HANDLER( itech020_color1_w )
 {
 	if (ACCESSING_LSB32)
@@ -335,7 +336,7 @@ WRITE32_HANDLER( itech020_plane_w )
 
 /*************************************
  *
- *	Palette I/O
+ *  Palette I/O
  *
  *************************************/
 
@@ -370,6 +371,20 @@ WRITE16_HANDLER( bloodstm_paletteram_w )
 }
 
 
+WRITE32_HANDLER( drivedge_paletteram_w )
+{
+	int r, g, b;
+
+	COMBINE_DATA(&paletteram32[offset]);
+
+	r = paletteram32[offset] & 0xff;
+	g = (paletteram32[offset] >> 8) & 0xff;
+	b = (paletteram32[offset] >> 16) & 0xff;
+
+	palette_set_color(offset, r, g, b);
+}
+
+
 WRITE32_HANDLER( itech020_paletteram_w )
 {
 	int r, g, b;
@@ -387,47 +402,64 @@ WRITE32_HANDLER( itech020_paletteram_w )
 
 /*************************************
  *
- *	Debugging
+ *  Debugging
  *
  *************************************/
 
 static void logblit(const char *tag)
 {
-	static FILE *blitlog;
+	if (!code_pressed(KEYCODE_L))
+		return;
+	if (is_drivedge && VIDEO_TRANSFER_FLAGS == 0x5490)
+	{
+		/* polygon drawing */
+		logerror("%s: e=%d%d f=%04x s=(%03x-%03x,%03x) w=%03x h=%03x b=%02x%04x c=%02x%02x ss=%04x,%04x ds=%04x,%04x ls=%04x%04x rs=%04x%04x u80=%04x", tag,
+			enable_latch[0], enable_latch[1],
+			VIDEO_TRANSFER_FLAGS,
+			VIDEO_TRANSFER_X, VIDEO_RIGHTCLIP, VIDEO_TRANSFER_Y, VIDEO_TRANSFER_WIDTH, VIDEO_TRANSFER_HEIGHT,
+			VIDEO_TRANSFER_ADDRHI, VIDEO_TRANSFER_ADDRLO,
+			color_latch[0] >> 8, color_latch[1] >> 8,
+			VIDEO_SRC_XSTEP, VIDEO_SRC_YSTEP,
+			VIDEO_DST_XSTEP, VIDEO_DST_YSTEP,
+			VIDEO_LEFTSTEPHI, VIDEO_LEFTSTEPLO, VIDEO_RIGHTSTEPHI, VIDEO_RIGHTSTEPLO,
+			VIDEO_STARTSTEP);
+	}
 
-	if (!blitlog) blitlog = fopen("blitter.log", "w");
-	if (itech32_video[0x16/2] == 0x100 && itech32_video[0x18/2] == 0x100 &&
+	else if (itech32_video[0x16/2] == 0x100 && itech32_video[0x18/2] == 0x100 &&
 		itech32_video[0x1a/2] == 0x000 && itech32_video[0x1c/2] == 0x100 &&
 		itech32_video[0x1e/2] == 0x000 && itech32_video[0x20/2] == 0x000)
 	{
-		fprintf(blitlog, "%s: p=%d%d c=%02x%02x %02x%04x -> (%03x,%03x) %3dx%3d f=%04x/%04x c=(%03x,%03x)-(%03x,%03x)\n", tag,
+		logerror("%s: e=%d%d f=%04x c=%02x%02x %02x%04x -> (%03x,%03x) %3dx%3dc=(%03x,%03x)-(%03x,%03x)", tag,
 				enable_latch[0], enable_latch[1],
+				VIDEO_TRANSFER_FLAGS,
 				color_latch[0] >> 8, color_latch[1] >> 8,
 				VIDEO_TRANSFER_ADDRHI, VIDEO_TRANSFER_ADDRLO,
 				VIDEO_TRANSFER_X, VIDEO_TRANSFER_Y,
-				VIDEO_TRANSFER_WIDTH, ADJUSTED_HEIGHT(VIDEO_TRANSFER_HEIGHT), VIDEO_TRANSFER_FLAGS, VIDEO_TRANSFER_FLAGS & ~XFERFLAG_KNOWNFLAGS,
+				VIDEO_TRANSFER_WIDTH, ADJUSTED_HEIGHT(VIDEO_TRANSFER_HEIGHT),
 				VIDEO_LEFTCLIP, VIDEO_TOPCLIP, VIDEO_RIGHTCLIP, VIDEO_BOTTOMCLIP);
 	}
 	else
 	{
-		fprintf(blitlog, "%s: p=%d%d c=%02x%02x %02x%04x -> (%03x,%03x) %3dx%3d f=%04x/%04x c=(%03x,%03x)-(%03x,%03x) s=%04x %04x %04x %04x %04x %04x\n", tag,
+		logerror("%s: e=%d%d f=%04x c=%02x%02x %02x%04x -> (%03x,%03x) %3dx%3d c=(%03x,%03x)-(%03x,%03x) s=%04x %04x %04x %04x %04x %04x", tag,
 				enable_latch[0], enable_latch[1],
+				VIDEO_TRANSFER_FLAGS,
 				color_latch[0] >> 8, color_latch[1] >> 8,
 				VIDEO_TRANSFER_ADDRHI, VIDEO_TRANSFER_ADDRLO,
 				VIDEO_TRANSFER_X, VIDEO_TRANSFER_Y,
-				VIDEO_TRANSFER_WIDTH, ADJUSTED_HEIGHT(VIDEO_TRANSFER_HEIGHT), VIDEO_TRANSFER_FLAGS, VIDEO_TRANSFER_FLAGS & ~XFERFLAG_KNOWNFLAGS,
+				VIDEO_TRANSFER_WIDTH, ADJUSTED_HEIGHT(VIDEO_TRANSFER_HEIGHT),
 				VIDEO_LEFTCLIP, VIDEO_TOPCLIP, VIDEO_RIGHTCLIP, VIDEO_BOTTOMCLIP,
 				itech32_video[0x16/2], itech32_video[0x18/2], itech32_video[0x1a/2],
 				itech32_video[0x1c/2], itech32_video[0x1e/2], itech32_video[0x20/2]);
 	}
-	fflush(blitlog);
+	if (is_drivedge) logerror(" v0=%08x v1=%08x v2=%08x v3=%08x", drivedge_zbuf_control[0], drivedge_zbuf_control[1], drivedge_zbuf_control[2], drivedge_zbuf_control[3]);
+	logerror("\n");
 }
 
 
 
 /*************************************
  *
- *	Video interrupts
+ *  Video interrupts
  *
  *************************************/
 
@@ -440,19 +472,14 @@ static void update_interrupts(int fast)
 	if (VIDEO_INTSTATE & VIDEO_INTENABLE & VIDEOINT_BLITTER)
 		blitter_state = 1;
 
-#ifndef MAME_DEBUG
-	if (fast)
-		itech32_update_interrupts_fast(-1, blitter_state, scanline_state);
-	else
-#endif
-		itech32_update_interrupts(-1, blitter_state, scanline_state);
+	itech32_update_interrupts(-1, blitter_state, scanline_state);
 }
 
 
 static void scanline_interrupt(int param)
 {
 	/* set timer for next frame */
-	scanline_timer = timer_set(cpu_getscanlinetime(VIDEO_INTSCANLINE), 0, scanline_interrupt);
+	timer_adjust(scanline_timer, cpu_getscanlinetime(VIDEO_INTSCANLINE), 0, 0);
 
 	/* set the interrupt bit in the status reg */
 	logerror("-------------- (DISPLAY INT @ %d) ----------------\n", cpu_getscanline());
@@ -466,7 +493,7 @@ static void scanline_interrupt(int param)
 
 /*************************************
  *
- *	Uncompressed blitter functions
+ *  Uncompressed blitter functions
  *
  *************************************/
 
@@ -509,7 +536,7 @@ static void draw_raw(UINT16 *base, UINT16 color)
 			/* clip in the Y direction */
 			if (sy >= scaled_clip_rect.min_y && sy < scaled_clip_rect.max_y)
 			{
-				UINT16 *dstbase;
+				UINT32 dstoffs;
 
 				/* direction matters here */
 				sx = startx;
@@ -519,14 +546,14 @@ static void draw_raw(UINT16 *base, UINT16 color)
 					for (x = 0; x < width && sx < scaled_clip_rect.min_x; x += xsrcstep, sx += xdststep) ;
 
 					/* compute the address */
-					dstbase = &base[compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8)];
+					dstoffs = compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8);
 
 					/* render middle pixels */
 					for ( ; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep)
 					{
 						int pixel = rowsrc[x >> 8];
 						if (pixel != transparent_pen)
-							dstbase[sx >> 8] = pixel | color;
+							base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
 					}
 				}
 				else
@@ -535,14 +562,14 @@ static void draw_raw(UINT16 *base, UINT16 color)
 					for (x = 0; x < width && sx >= scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep) ;
 
 					/* compute the address */
-					dstbase = &base[compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8)];
+					dstoffs = compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8);
 
 					/* render middle pixels */
 					for ( ; x < width && sx >= scaled_clip_rect.min_x; x += xsrcstep, sx += xdststep)
 					{
 						int pixel = rowsrc[x >> 8];
 						if (pixel != transparent_pen)
-							dstbase[sx >> 8] = pixel | color;
+							base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
 					}
 				}
 			}
@@ -579,10 +606,250 @@ static void draw_raw(UINT16 *base, UINT16 color)
 }
 
 
+static void draw_raw_drivedge(UINT16 *base, UINT16 *zbase, UINT16 color)
+{
+	UINT8 *src = &grom_base[(grom_bank | ((VIDEO_TRANSFER_ADDRHI & 0xff) << 16) | VIDEO_TRANSFER_ADDRLO) % grom_size];
+	int transparent_pen = (VIDEO_TRANSFER_FLAGS & XFERFLAG_TRANSPARENT) ? 0xff : -1;
+	int width = VIDEO_TRANSFER_WIDTH << 8;
+	int height = ADJUSTED_HEIGHT(VIDEO_TRANSFER_HEIGHT) << 8;
+	int xsrcstep = VIDEO_SRC_XSTEP;
+	int ysrcstep = VIDEO_SRC_YSTEP;
+	int sx, sy = ((VIDEO_TRANSFER_Y & 0xfff) << 8) + 0x80;
+	int startx = ((VIDEO_TRANSFER_X & 0xfff) << 8) + 0x80;
+	int xdststep = 0x100;
+	int ydststep = VIDEO_DST_YSTEP;
+	INT32 z0 = drivedge_zbuf_control[2] & 0x7ff00;
+	INT32 zmatch = (drivedge_zbuf_control[2] & 0x1f) << 11;
+	INT32 srcdelta = 0;
+	int x, y;
+
+	/* adjust for (lack of) clipping */
+	if (!(VIDEO_TRANSFER_FLAGS & XFERFLAG_CLIP))
+		disable_clipping();
+
+	/* adjust for scaling */
+	if (VIDEO_TRANSFER_FLAGS & XFERFLAG_DSTXSCALE)
+		xdststep = VIDEO_DST_XSTEP;
+
+	/* adjust for flipping */
+	if (VIDEO_TRANSFER_FLAGS & XFERFLAG_XFLIP)
+		xdststep = -xdststep;
+	if (VIDEO_TRANSFER_FLAGS & XFERFLAG_YFLIP)
+		ydststep = -ydststep;
+
+	/* loop over Y in src pixels */
+	for (y = 0; y < height; y += ysrcstep, sy += ydststep)
+	{
+		UINT8 *rowsrc = src + (srcdelta >> 8);
+
+		/* in the polygon case, we don't factor in the Y */
+		if (VIDEO_TRANSFER_FLAGS != 0x5490)
+			rowsrc += (y >> 8) * (width >> 8);
+		else
+			width = 1000 << 8;
+
+		/* simpler case: VIDEO_YSTEP_PER_X is zero */
+		if (VIDEO_YSTEP_PER_X == 0)
+		{
+			/* clip in the Y direction */
+			if (sy >= scaled_clip_rect.min_y && sy < scaled_clip_rect.max_y)
+			{
+				UINT32 dstoffs, zbufoffs;
+				INT32 z = z0;
+
+				/* direction matters here */
+				sx = startx;
+				if (xdststep > 0)
+				{
+					/* skip left pixels */
+					for (x = 0; x < width && sx < scaled_clip_rect.min_x; x += xsrcstep, sx += xdststep)
+						z += (INT32)drivedge_zbuf_control[0];
+
+					/* compute the address */
+					dstoffs = compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8);
+					zbufoffs = compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8);
+
+					/* render middle pixels */
+					if (drivedge_zbuf_control[3] & 0x8000)
+					{
+						for ( ; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep)
+						{
+							int pixel = rowsrc[x >> 8];
+							if (pixel != transparent_pen)
+							{
+								base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
+								zbase[(zbufoffs + (sx >> 8)) & vram_mask] = (z >> 8) | zmatch;
+							}
+							z += (INT32)drivedge_zbuf_control[0];
+						}
+					}
+					else if (drivedge_zbuf_control[3] & 0x4000)
+					{
+						for ( ; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep)
+						{
+							int pixel = rowsrc[x >> 8];
+							if (pixel != transparent_pen && zmatch == (zbase[(zbufoffs + (sx >> 8)) & vram_mask] & (0x1f << 11)))
+								base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
+							z += (INT32)drivedge_zbuf_control[0];
+						}
+					}
+					else
+					{
+						for ( ; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep)
+						{
+							int pixel = rowsrc[x >> 8];
+							if (pixel != transparent_pen && ((z >> 8) <= (zbase[(zbufoffs + (sx >> 8)) & vram_mask] & 0x7ff)))
+							{
+								base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
+								zbase[(zbufoffs + (sx >> 8)) & vram_mask] = (z >> 8) | zmatch;
+							}
+							z += (INT32)drivedge_zbuf_control[0];
+						}
+					}
+				}
+				else
+				{
+					/* skip right pixels */
+					for (x = 0; x < width && sx >= scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep)
+						z += (INT32)drivedge_zbuf_control[0];
+
+					/* compute the address */
+					dstoffs = compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8);
+					zbufoffs = compute_safe_address(sx >> 8, sy >> 8) - (sx >> 8);
+
+					/* render middle pixels */
+					if (drivedge_zbuf_control[3] & 0x8000)
+					{
+						for ( ; x < width && sx >= scaled_clip_rect.min_x; x += xsrcstep, sx += xdststep)
+						{
+							int pixel = rowsrc[x >> 8];
+							if (pixel != transparent_pen)
+							{
+								base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
+								zbase[(zbufoffs + (sx >> 8)) & vram_mask] = (z >> 8) | zmatch;
+							}
+							z += (INT32)drivedge_zbuf_control[0];
+						}
+					}
+					else if (drivedge_zbuf_control[3] & 0x4000)
+					{
+						for ( ; x < width && sx >= scaled_clip_rect.min_x; x += xsrcstep, sx += xdststep)
+						{
+							int pixel = rowsrc[x >> 8];
+							if (pixel != transparent_pen && zmatch == (zbase[(zbufoffs + (sx >> 8)) & vram_mask] & (0x1f << 11)))
+								base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
+							z += (INT32)drivedge_zbuf_control[0];
+						}
+					}
+					else
+					{
+						for ( ; x < width && sx >= scaled_clip_rect.min_x; x += xsrcstep, sx += xdststep)
+						{
+							int pixel = rowsrc[x >> 8];
+							if (pixel != transparent_pen && ((z >> 8) <= (zbase[(zbufoffs + (sx >> 8)) & vram_mask] & 0x7ff)))
+							{
+								base[(dstoffs + (sx >> 8)) & vram_mask] = pixel | color;
+								zbase[(zbufoffs + (sx >> 8)) & vram_mask] = (z >> 8) | zmatch;
+							}
+							z += (INT32)drivedge_zbuf_control[0];
+						}
+					}
+				}
+			}
+		}
+
+		/* slow case: VIDEO_YSTEP_PER_X is non-zero */
+		else
+		{
+			int ystep = (VIDEO_TRANSFER_FLAGS & XFERFLAG_DYDXSIGN) ? -VIDEO_YSTEP_PER_X : VIDEO_YSTEP_PER_X;
+			int ty = sy;
+			INT32 z = z0;
+
+			/* render all pixels */
+			sx = startx;
+			if (drivedge_zbuf_control[3] & 0x8000)
+			{
+				for (x = 0; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep, ty += ystep)
+					if (ty >= scaled_clip_rect.min_y && ty < scaled_clip_rect.max_y &&
+						sx >= scaled_clip_rect.min_x && sx < scaled_clip_rect.max_x)
+					{
+						int pixel = rowsrc[x >> 8];
+						if (pixel != transparent_pen)
+						{
+							base[compute_safe_address(sx >> 8, ty >> 8)] = pixel | color;
+							zbase[compute_safe_address(sx >> 8, ty >> 8)] = (z >> 8) | zmatch;
+						}
+						z += (INT32)drivedge_zbuf_control[0];
+					}
+			}
+			else if (drivedge_zbuf_control[3] & 0x4000)
+			{
+				for (x = 0; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep, ty += ystep)
+					if (ty >= scaled_clip_rect.min_y && ty < scaled_clip_rect.max_y &&
+						sx >= scaled_clip_rect.min_x && sx < scaled_clip_rect.max_x)
+					{
+						int pixel = rowsrc[x >> 8];
+						UINT16 *zbuf = &zbase[compute_safe_address(sx >> 8, ty >> 8)];
+						if (pixel != transparent_pen && zmatch == (*zbuf & (0x1f << 11)))
+						{
+							base[compute_safe_address(sx >> 8, ty >> 8)] = pixel | color;
+							*zbuf = (z >> 8) | zmatch;
+						}
+						z += (INT32)drivedge_zbuf_control[0];
+					}
+			}
+			else
+			{
+				for (x = 0; x < width && sx < scaled_clip_rect.max_x; x += xsrcstep, sx += xdststep, ty += ystep)
+					if (ty >= scaled_clip_rect.min_y && ty < scaled_clip_rect.max_y &&
+						sx >= scaled_clip_rect.min_x && sx < scaled_clip_rect.max_x)
+					{
+						int pixel = rowsrc[x >> 8];
+						UINT16 *zbuf = &zbase[compute_safe_address(sx >> 8, ty >> 8)];
+						if (pixel != transparent_pen && ((z >> 8) <= (*zbuf & 0x7ff)))
+						{
+							base[compute_safe_address(sx >> 8, ty >> 8)] = pixel | color;
+							*zbuf = (z >> 8) | zmatch;
+						}
+						z += (INT32)drivedge_zbuf_control[0];
+					}
+			}
+		}
+
+		/* apply skew */
+		if (VIDEO_TRANSFER_FLAGS & XFERFLAG_DXDYSIGN)
+			startx += VIDEO_XSTEP_PER_Y;
+		else
+			startx -= VIDEO_XSTEP_PER_Y;
+
+		/* update the per-scanline parameters */
+		if (VIDEO_TRANSFER_FLAGS == 0x5490)
+		{
+			startx += (INT32)((VIDEO_LEFTSTEPHI << 16) | VIDEO_LEFTSTEPLO);
+			scaled_clip_rect.max_x += (INT32)((VIDEO_RIGHTSTEPHI << 16) | VIDEO_RIGHTSTEPLO);
+			srcdelta += (INT16)VIDEO_STARTSTEP;
+		}
+		z0 += (INT32)drivedge_zbuf_control[1];
+	}
+
+	/* restore cliprects */
+	if (!(VIDEO_TRANSFER_FLAGS & XFERFLAG_CLIP))
+		enable_clipping();
+
+	/* reflect the final values into registers */
+	VIDEO_TRANSFER_X = (VIDEO_TRANSFER_X & ~0xfff) | (startx >> 8);
+	VIDEO_RIGHTCLIP = (VIDEO_RIGHTCLIP & ~0xfff) | (scaled_clip_rect.max_x >> 8);
+	VIDEO_TRANSFER_Y = (VIDEO_TRANSFER_Y & ~0xfff) | ((VIDEO_TRANSFER_Y + (y >> 8)) & 0xfff);
+	VIDEO_TRANSFER_ADDRLO += srcdelta >> 8;
+
+	drivedge_zbuf_control[2] = (drivedge_zbuf_control[2] & ~0x7ff00) | (z0 & 0x7ff00);
+}
+
+
 
 /*************************************
  *
- *	Compressed blitter macros
+ *  Compressed blitter macros
  *
  *************************************/
 
@@ -620,7 +887,7 @@ do {												\
 
 /*************************************
  *
- *	Fast compressed blitter functions
+ *  Fast compressed blitter functions
  *
  *************************************/
 
@@ -651,7 +918,7 @@ INLINE void draw_rle_fast(UINT16 *base, UINT16 color)
 	/* loop over Y in src pixels */
 	for (y = 0; y < height; y++, sy += ydststep)
 	{
-		UINT16 *dstbase;
+		UINT32 dstoffs;
 
 		/* clip in the Y direction */
 		if (sy < scaled_clip_rect.min_y || sy >= scaled_clip_rect.max_y)
@@ -661,7 +928,7 @@ INLINE void draw_rle_fast(UINT16 *base, UINT16 color)
 		}
 
 		/* compute the address */
-		dstbase = &base[compute_safe_address(sx, sy >> 8)];
+		dstoffs = compute_safe_address(sx, sy >> 8);
 
 		/* left clip */
 		SKIP_RLE(lclip, xleft, count, innercount, src);
@@ -678,8 +945,8 @@ INLINE void draw_rle_fast(UINT16 *base, UINT16 color)
 				{
 					int pixel = *src++;
 					if (pixel != transparent_pen)
-						*dstbase = color | pixel;
-					dstbase++;
+						base[dstoffs & vram_mask] = color | pixel;
+					dstoffs++;
 				}
 
 			/* run of non-transparent repeats */
@@ -687,12 +954,12 @@ INLINE void draw_rle_fast(UINT16 *base, UINT16 color)
 			{
 				val |= color;
 				while (innercount--)
-					*dstbase++ = val;
+					base[dstoffs++ & vram_mask] = val;
 			}
 
 			/* run of transparent repeats */
 			else
-				dstbase += innercount;
+				dstoffs += innercount;
 		}
 
 		/* right clip */
@@ -728,7 +995,7 @@ INLINE void draw_rle_fast_xflip(UINT16 *base, UINT16 color)
 	/* loop over Y in src pixels */
 	for (y = 0; y < height; y++, sy += ydststep)
 	{
-		UINT16 *dstbase;
+		UINT32 dstoffs;
 
 		/* clip in the Y direction */
 		if (sy < scaled_clip_rect.min_y || sy >= scaled_clip_rect.max_y)
@@ -738,7 +1005,7 @@ INLINE void draw_rle_fast_xflip(UINT16 *base, UINT16 color)
 		}
 
 		/* compute the address */
-		dstbase = &base[compute_safe_address(sx, sy >> 8)];
+		dstoffs = compute_safe_address(sx, sy >> 8);
 
 		/* left clip */
 		SKIP_RLE(lclip, xleft, count, innercount, src);
@@ -755,8 +1022,8 @@ INLINE void draw_rle_fast_xflip(UINT16 *base, UINT16 color)
 				{
 					int pixel = *src++;
 					if (pixel != transparent_pen)
-						*dstbase = color | pixel;
-					dstbase--;
+						base[dstoffs & vram_mask] = color | pixel;
+					dstoffs--;
 				}
 
 			/* run of non-transparent repeats */
@@ -764,12 +1031,12 @@ INLINE void draw_rle_fast_xflip(UINT16 *base, UINT16 color)
 			{
 				val |= color;
 				while (innercount--)
-					*dstbase-- = val;
+					base[dstoffs-- & vram_mask] = val;
 			}
 
 			/* run of transparent repeats */
 			else
-				dstbase -= innercount;
+				dstoffs -= innercount;
 		}
 
 		/* right clip */
@@ -781,7 +1048,7 @@ INLINE void draw_rle_fast_xflip(UINT16 *base, UINT16 color)
 
 /*************************************
  *
- *	Slow compressed blitter functions
+ *  Slow compressed blitter functions
  *
  *************************************/
 
@@ -810,7 +1077,7 @@ INLINE void draw_rle_slow(UINT16 *base, UINT16 color)
 	/* loop over Y in src pixels */
 	for (y = 0; y < height; y++, sy += ydststep)
 	{
-		UINT16 *dstbase;
+		UINT32 dstoffs;
 
 		/* clip in the Y direction */
 		if (sy < scaled_clip_rect.min_y || sy >= scaled_clip_rect.max_y)
@@ -821,7 +1088,7 @@ INLINE void draw_rle_slow(UINT16 *base, UINT16 color)
 
 		/* compute the address */
 		sx = startx;
-		dstbase = &base[compute_safe_address(clip_rect.min_x, sy >> 8) - clip_rect.min_x];
+		dstoffs = compute_safe_address(clip_rect.min_x, sy >> 8) - clip_rect.min_x;
 
 		/* loop until gone */
 		for (xleft = width; xleft > 0; )
@@ -836,7 +1103,7 @@ INLINE void draw_rle_slow(UINT16 *base, UINT16 color)
 					int pixel = *src++;
 					if (pixel != transparent_pen)
 						if (sx >= scaled_clip_rect.min_x && sx < scaled_clip_rect.max_x)
-							dstbase[sx >> 8] = color | pixel;
+							base[(dstoffs + (sx >> 8)) & vram_mask] = color | pixel;
 				}
 
 			/* run of non-transparent repeats */
@@ -845,7 +1112,7 @@ INLINE void draw_rle_slow(UINT16 *base, UINT16 color)
 				val |= color;
 				for ( ; innercount--; sx += xdststep)
 					if (sx >= scaled_clip_rect.min_x && sx < scaled_clip_rect.max_x)
-						dstbase[sx >> 8] = val;
+						base[(dstoffs + (sx >> 8)) & vram_mask] = val;
 			}
 
 			/* run of transparent repeats */
@@ -888,11 +1155,11 @@ static void draw_rle(UINT16 *base, UINT16 color)
 
 /*************************************
  *
- *	Shift register manipulation
+ *  Shift register manipulation
  *
  *************************************/
 
-static void shiftreg_clear(UINT16 *base)
+static void shiftreg_clear(UINT16 *base, UINT16 *zbase)
 {
 	int ydir = (VIDEO_TRANSFER_FLAGS & XFERFLAG_YFLIP) ? -1 : 1;
 	int height = ADJUSTED_HEIGHT(VIDEO_TRANSFER_HEIGHT);
@@ -909,6 +1176,14 @@ static void shiftreg_clear(UINT16 *base)
 	for (y = 1; y < height; y++)
 	{
 		memcpy(&base[compute_safe_address(sx, sy)], src, 512*2);
+		if (zbase)
+		{
+			UINT16 zval = ((drivedge_zbuf_control[2] >> 8) & 0x7ff) | ((drivedge_zbuf_control[2] & 0x1f) << 11);
+			UINT16 *dst = &zbase[compute_safe_address(sx, sy)];
+			int x;
+			for (x = 0; x < 512; x++)
+				*dst++ = zval;
+		}
 		sy += ydir;
 	}
 }
@@ -917,7 +1192,7 @@ static void shiftreg_clear(UINT16 *base)
 
 /*************************************
  *
- *	Video commands
+ *  Video commands
  *
  *************************************/
 
@@ -931,8 +1206,15 @@ static void handle_video_command(void)
 			profiler_mark(PROFILER_USER1);
 			if (BLIT_LOGGING) logblit("Blit Raw");
 
-			if (enable_latch[0]) draw_raw(videoplane[0], color_latch[0]);
-			if (enable_latch[1]) draw_raw(videoplane[1], color_latch[1]);
+			if (is_drivedge)
+			{
+				if (enable_latch[0]) draw_raw_drivedge(videoplane[0], videoplane[1], color_latch[0]);
+			}
+			else
+			{
+				if (enable_latch[0]) draw_raw(videoplane[0], color_latch[0]);
+				if (enable_latch[1]) draw_raw(videoplane[1], color_latch[1]);
+			}
 
 			profiler_mark(PROFILER_END);
 			break;
@@ -970,11 +1252,22 @@ static void handle_video_command(void)
 			profiler_mark(PROFILER_USER3);
 			if (BLIT_LOGGING) logblit("ShiftReg");
 
-			if (enable_latch[0]) shiftreg_clear(videoplane[0]);
-			if (enable_latch[1]) shiftreg_clear(videoplane[1]);
+			if (is_drivedge)
+			{
+				if (enable_latch[0]) shiftreg_clear(videoplane[0], videoplane[1]);
+			}
+			else
+			{
+				if (enable_latch[0]) shiftreg_clear(videoplane[0], NULL);
+				if (enable_latch[1]) shiftreg_clear(videoplane[1], NULL);
+			}
 
 			profiler_mark(PROFILER_END);
 			break;
+
+		default:
+			if (BLIT_LOGGING) logerror("Unknown blit command %d\n", VIDEO_COMMAND);
+			break;
 	}
 
 	/* tell the processor we're done */
@@ -986,7 +1279,7 @@ static void handle_video_command(void)
 
 /*************************************
  *
- *	Video I/O
+ *  Video I/O
  *
  *************************************/
 
@@ -1052,9 +1345,7 @@ WRITE16_HANDLER( itech32_video_w )
 			break;
 
 		case 0x2c/2:	/* VIDEO_INTSCANLINE */
-			if (scanline_timer)
-				timer_remove(scanline_timer);
-			scanline_timer = timer_set(cpu_getscanlinetime(VIDEO_INTSCANLINE), 0, scanline_interrupt);
+			timer_adjust(scanline_timer, cpu_getscanlinetime(VIDEO_INTSCANLINE), 0, 0);
 			break;
 	}
 }
@@ -1064,7 +1355,7 @@ READ16_HANDLER( itech32_video_r )
 {
 	if (offset == 0)
 	{
-		return itech32_video[offset] & ~0x08;
+		return (itech32_video[offset] & ~0x08) | 0x04 | 0x01;
 	}
 	else if (offset == 3)
 	{
@@ -1078,7 +1369,7 @@ READ16_HANDLER( itech32_video_r )
 
 /*************************************
  *
- *	Alternate video I/O
+ *  Alternate video I/O
  *
  *************************************/
 
@@ -1103,6 +1394,13 @@ WRITE32_HANDLER( itech020_video_w )
 }
 
 
+WRITE32_HANDLER( drivedge_zbuf_control_w )
+{
+	COMBINE_DATA(&drivedge_zbuf_control[offset]);
+	is_drivedge = 1;
+}
+
+
 READ32_HANDLER( itech020_video_r )
 {
 	int result = itech32_video_r(offset,0);
@@ -1113,16 +1411,16 @@ READ32_HANDLER( itech020_video_r )
 
 /*************************************
  *
- *	Main refresh
+ *  Main refresh
  *
  *************************************/
 
-void itech32_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( itech32 )
 {
 	int y;
 
 	/* loop over height */
-	for (y = Machine->visible_area.min_y; y <= Machine->visible_area.max_y; y++)
+	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
 	{
 		UINT16 *src1 = &videoplane[0][compute_safe_address(VIDEO_DISPLAY_XORIGIN1, VIDEO_DISPLAY_YORIGIN1 + y)];
 
@@ -1134,7 +1432,7 @@ void itech32_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 			int x;
 
 			/* blend the pixels in the scanline; color xxFF is transparent */
-			for (x = 0; x < 384; x++)
+			for (x = cliprect->min_x; x <= cliprect->max_x; x++)
 			{
 				UINT16 pixel = src1[x];
 				if ((pixel & 0xff) == 0xff)
@@ -1143,11 +1441,11 @@ void itech32_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
 			}
 
 			/* draw from the buffer */
-			draw_scanline16(bitmap, 0, y, 384, scanline, Machine->pens, -1);
+			draw_scanline16(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &scanline[cliprect->min_x], Machine->pens, -1);
 		}
 
 		/* otherwise, draw directly from VRAM */
 		else
-			draw_scanline16(bitmap, 0, y, 384, src1, Machine->pens, -1);
+			draw_scanline16(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &src1[cliprect->min_x], Machine->pens, -1);
 	}
 }
