@@ -1,6 +1,6 @@
 /*******************************************************************************
 
-	Karnov - Bryan McPhail, mish@tendril.co.uk
+    Karnov - Bryan McPhail, mish@tendril.co.uk
 
 *******************************************************************************/
 
@@ -8,9 +8,9 @@
 #include "vidhrdw/generic.h"
 
 static unsigned char *dirty_f;
-static struct mame_bitmap *bitmap_f;
-data16_t karnov_scroll[2], *karnov_pf_data;
-static struct tilemap *fix_tilemap;
+static mame_bitmap *bitmap_f;
+UINT16 karnov_scroll[2], *karnov_pf_data;
+static tilemap *fix_tilemap;
 static int flipscreen;
 
 /***************************************************************************
@@ -40,30 +40,31 @@ static int flipscreen;
   bit 0 -- 2.2kohm resistor  -- BLUE
 
 ***************************************************************************/
-void karnov_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( karnov )
 {
 	int i;
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 		bit0 = (color_prom[0] >> 0) & 0x01;
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		bit0 = (color_prom[0] >> 4) & 0x01;
 		bit1 = (color_prom[0] >> 5) & 0x01;
 		bit2 = (color_prom[0] >> 6) & 0x01;
 		bit3 = (color_prom[0] >> 7) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		bit0 = (color_prom[Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 }
@@ -78,7 +79,7 @@ void karnov_flipscreen_w(int data)
 	tilemap_set_flip(ALL_TILEMAPS,flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 }
 
-static void draw_background(struct mame_bitmap *bitmap)
+static void draw_background(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int my,mx,offs,color,tile,fx,fy;
 	int scrollx=karnov_scroll[0];
@@ -136,10 +137,10 @@ static void draw_background(struct mame_bitmap *bitmap)
 		scrolly=scrolly+256;
 		scrollx=scrollx+256;
 	}
-	copyscrollbitmap(bitmap,bitmap_f,1,&scrollx,1,&scrolly,0,TRANSPARENCY_NONE,0);
+	copyscrollbitmap(bitmap,bitmap_f,1,&scrollx,1,&scrolly,cliprect,TRANSPARENCY_NONE,0);
 }
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
@@ -185,24 +186,24 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 		drawgfx(bitmap,Machine->gfx[2],
 				sprite,
 				colour,fx,fy,x,y,
-				0,TRANSPARENCY_PEN,0);
+				cliprect,TRANSPARENCY_PEN,0);
 
     	/* 1 more sprite drawn underneath */
     	if (extra)
     		drawgfx(bitmap,Machine->gfx[2],
 				sprite2,
 				colour,fx,fy,x,y+16,
-				0,TRANSPARENCY_PEN,0);
+				cliprect,TRANSPARENCY_PEN,0);
 	}
 }
 
 /******************************************************************************/
 
-void karnov_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( karnov )
 {
-	draw_background(bitmap);
-	draw_sprites(bitmap);
-	tilemap_draw(bitmap,fix_tilemap,0,0);
+	draw_background(bitmap,cliprect);
+	draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,fix_tilemap,0,0);
 }
 
 /******************************************************************************/
@@ -231,21 +232,13 @@ WRITE16_HANDLER( karnov_playfield_w )
 
 /******************************************************************************/
 
-void karnov_vh_stop (void)
-{
-	if (dirty_f) free(dirty_f);
-	if (bitmap_f) bitmap_free (bitmap_f);
-}
-
-int karnov_vh_start (void)
+VIDEO_START( karnov )
 {
 	/* Allocate bitmaps */
-	if ((bitmap_f = bitmap_alloc(512,512)) == 0) {
-		karnov_vh_stop ();
+	if ((bitmap_f = auto_bitmap_alloc(512,512)) == 0)
 		return 1;
-	}
 
-	dirty_f=malloc(0x800);
+	dirty_f=auto_malloc(0x800);
 	memset(dirty_f,1,0x800);
 
 	fix_tilemap=tilemap_create(get_fix_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
@@ -256,15 +249,13 @@ int karnov_vh_start (void)
 	return 0;
 }
 
-int wndrplnt_vh_start (void)
+VIDEO_START( wndrplnt )
 {
 	/* Allocate bitmaps */
-	if ((bitmap_f = bitmap_alloc(512,512)) == 0) {
-		karnov_vh_stop ();
+	if ((bitmap_f = auto_bitmap_alloc(512,512)) == 0)
 		return 1;
-	}
 
-	dirty_f=malloc(0x800);
+	dirty_f=auto_malloc(0x800);
 	memset(dirty_f,1,0x800);
 
 	fix_tilemap=tilemap_create(get_fix_tile_info,tilemap_scan_cols,TILEMAP_TRANSPARENT,8,8,32,32);
