@@ -14,7 +14,7 @@ unsigned char *lwings_fgvideoram;
 unsigned char *lwings_bg1videoram;
 
 static int bAvengersHardware, bg2_image;
-static struct tilemap *fg_tilemap, *bg1_tilemap, *bg2_tilemap;
+static tilemap *fg_tilemap, *bg1_tilemap, *bg2_tilemap;
 
 /***************************************************************************
 
@@ -55,7 +55,6 @@ static void lwings_get_bg1_tile_info(int tile_index)
 
 static void trojan_get_bg1_tile_info(int tile_index)
 {
-	const unsigned char avengers_color_remap[8]	= {6,7,4,5,2,3,0,1};
 	int code, color;
 
 	code = lwings_bg1videoram[tile_index];
@@ -64,16 +63,19 @@ static void trojan_get_bg1_tile_info(int tile_index)
 	SET_TILE_INFO(
 			1,
 			code,
-			bAvengersHardware ? avengers_color_remap[color & 7] : (color & 7),
+			bAvengersHardware ? ((color & 7) ^ 6) : (color & 7),
 			TILE_SPLIT((color & 0x08) >> 3) | ((color & 0x10) ? TILE_FLIPX : 0))
 }
 
 static void get_bg2_tile_info(int tile_index)
 {
 	int code, color;
+	UINT8 *rom = memory_region(REGION_GFX5);
+	int mask = memory_region_length(REGION_GFX5) - 1;
 
-	code = memory_region(REGION_GFX5)[bg2_image * 0x20 + tile_index];
-	color = memory_region(REGION_GFX5)[bg2_image * 0x20 + tile_index + 1];
+	tile_index = (tile_index + bg2_image * 0x20) & mask;
+	code = rom[tile_index];
+	color = rom[tile_index + 1];
 	SET_TILE_INFO(
 			3,
 			code + ((color & 0x80) << 1),
@@ -87,7 +89,7 @@ static void get_bg2_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int lwings_vh_start(void)
+VIDEO_START( lwings )
 {
 	fg_tilemap  = tilemap_create(get_fg_tile_info,        tilemap_scan_rows,TILEMAP_TRANSPARENT, 8, 8,32,32);
 	bg1_tilemap = tilemap_create(lwings_get_bg1_tile_info,tilemap_scan_cols,TILEMAP_OPAQUE,     16,16,32,32);
@@ -100,7 +102,7 @@ int lwings_vh_start(void)
 	return 0;
 }
 
-int trojan_vh_start(void)
+VIDEO_START( trojan )
 {
 	fg_tilemap  = tilemap_create(get_fg_tile_info,        tilemap_scan_rows,    TILEMAP_TRANSPARENT,8, 8,32,32);
 	bg1_tilemap = tilemap_create(trojan_get_bg1_tile_info,tilemap_scan_cols,    TILEMAP_SPLIT,     16,16,32,32);
@@ -118,9 +120,9 @@ int trojan_vh_start(void)
 	return 1; /* error */
 }
 
-int avengers_vh_start( void )
+VIDEO_START( avengers )
 {
-	int result = trojan_vh_start();
+	int result = video_start_trojan();
 	bAvengersHardware = 1;
 	return result;
 }
@@ -131,20 +133,20 @@ int avengers_vh_start( void )
 
 ***************************************************************************/
 
-WRITE_HANDLER( lwings_fgvideoram_w )
+WRITE8_HANDLER( lwings_fgvideoram_w )
 {
 	lwings_fgvideoram[offset] = data;
 	tilemap_mark_tile_dirty(fg_tilemap,offset & 0x3ff);
 }
 
-WRITE_HANDLER( lwings_bg1videoram_w )
+WRITE8_HANDLER( lwings_bg1videoram_w )
 {
 	lwings_bg1videoram[offset] = data;
 	tilemap_mark_tile_dirty(bg1_tilemap,offset & 0x3ff);
 }
 
 
-WRITE_HANDLER( lwings_bg1_scrollx_w )
+WRITE8_HANDLER( lwings_bg1_scrollx_w )
 {
 	static unsigned char scroll[2];
 
@@ -152,7 +154,7 @@ WRITE_HANDLER( lwings_bg1_scrollx_w )
 	tilemap_set_scrollx(bg1_tilemap,0,scroll[0] | (scroll[1] << 8));
 }
 
-WRITE_HANDLER( lwings_bg1_scrolly_w )
+WRITE8_HANDLER( lwings_bg1_scrolly_w )
 {
 	static unsigned char scroll[2];
 
@@ -160,12 +162,12 @@ WRITE_HANDLER( lwings_bg1_scrolly_w )
 	tilemap_set_scrolly(bg1_tilemap,0,scroll[0] | (scroll[1] << 8));
 }
 
-WRITE_HANDLER( lwings_bg2_scrollx_w )
+WRITE8_HANDLER( trojan_bg2_scrollx_w )
 {
 	tilemap_set_scrollx(bg2_tilemap,0,data);
 }
 
-WRITE_HANDLER( lwings_bg2_image_w )
+WRITE8_HANDLER( trojan_bg2_image_w )
 {
 	if (bg2_image != data)
 	{
@@ -189,10 +191,10 @@ INLINE int is_sprite_on(int offs)
 	sx = buffered_spriteram[offs + 3] - 0x100 * (buffered_spriteram[offs + 1] & 0x01);
 	sy = buffered_spriteram[offs + 2];
 
-	return sx && sy;
+	return sx || sy;
 }
 
-static void lwings_draw_sprites(struct mame_bitmap *bitmap)
+static void lwings_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs;
 
@@ -206,6 +208,7 @@ static void lwings_draw_sprites(struct mame_bitmap *bitmap)
 
 			sx = buffered_spriteram[offs + 3] - 0x100 * (buffered_spriteram[offs + 1] & 0x01);
 			sy = buffered_spriteram[offs + 2];
+			if (sy > 0xf8) sy-=0x100;
 			code = buffered_spriteram[offs] | (buffered_spriteram[offs + 1] & 0xc0) << 2;
 			color = (buffered_spriteram[offs + 1] & 0x38) >> 3;
 			flipx = buffered_spriteram[offs + 1] & 0x02;
@@ -223,12 +226,12 @@ static void lwings_draw_sprites(struct mame_bitmap *bitmap)
 					code,color,
 					flipx,flipy,
 					sx,sy,
-					&Machine->visible_area,TRANSPARENCY_PEN,15);
+					cliprect,TRANSPARENCY_PEN,15);
 		}
 	}
 }
 
-static void trojan_draw_sprites(struct mame_bitmap *bitmap)
+static void trojan_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs;
 
@@ -242,6 +245,7 @@ static void trojan_draw_sprites(struct mame_bitmap *bitmap)
 
 			sx = buffered_spriteram[offs + 3] - 0x100 * (buffered_spriteram[offs + 1] & 0x01);
 			sy = buffered_spriteram[offs + 2];
+			if (sy > 0xf8) sy-=0x100;
 			code = buffered_spriteram[offs] |
 				   ((buffered_spriteram[offs + 1] & 0x20) << 4) |
 				   ((buffered_spriteram[offs + 1] & 0x40) << 2) |
@@ -271,28 +275,28 @@ static void trojan_draw_sprites(struct mame_bitmap *bitmap)
 					code,color,
 					flipx,flipy,
 					sx,sy,
-					&Machine->visible_area,TRANSPARENCY_PEN,15);
+					cliprect,TRANSPARENCY_PEN,15);
 		}
 	}
 }
 
-void lwings_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( lwings )
 {
-	tilemap_draw(bitmap,bg1_tilemap,0,0);
-	lwings_draw_sprites(bitmap);
-	tilemap_draw(bitmap,fg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg1_tilemap,0,0);
+	lwings_draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 }
 
-void trojan_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( trojan )
 {
-	tilemap_draw(bitmap,bg2_tilemap,0,0);
-	tilemap_draw(bitmap,bg1_tilemap,TILEMAP_BACK,0);
-	trojan_draw_sprites(bitmap);
-	tilemap_draw(bitmap,bg1_tilemap,TILEMAP_FRONT,0);
-	tilemap_draw(bitmap,fg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg2_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg1_tilemap,TILEMAP_BACK,0);
+	trojan_draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,bg1_tilemap,TILEMAP_FRONT,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 }
 
-void lwings_eof_callback(void)
+VIDEO_EOF( lwings )
 {
 	buffer_spriteram_w(0,0);
 }
