@@ -1,43 +1,43 @@
 /****************************************************************************
 
-	Irem M107 video hardware, Bryan McPhail, mish@tendril.co.uk
+    Irem M107 video hardware, Bryan McPhail, mish@tendril.co.uk
 
-	Close to M92 hardware, but with 4 playfields, not 3.
-	Twice as many colours, twice as many sprites.
+    Close to M92 hardware, but with 4 playfields, not 3.
+    Twice as many colours, twice as many sprites.
 
 *****************************************************************************
 
-	Port:
-		0x80: pf1 Y scroll
-		0x82: pf1 X scroll
-		0x84: pf2 Y scroll
-		0x86: pf2 X scroll
-		0x88: pf3 Y scroll
-		0x8a: pf3 X scroll
-		0x8c: pf4 Y scroll
-		0x8e: pf4 X scroll
+    Port:
+        0x80: pf1 Y scroll
+        0x82: pf1 X scroll
+        0x84: pf2 Y scroll
+        0x86: pf2 X scroll
+        0x88: pf3 Y scroll
+        0x8a: pf3 X scroll
+        0x8c: pf4 Y scroll
+        0x8e: pf4 X scroll
 
-		0x90: pf1 control
-		0x92: pf2 control
-		0x94: pf3 control
-		0x96: pf4 control
+        0x90: pf1 control
+        0x92: pf2 control
+        0x94: pf3 control
+        0x96: pf4 control
 
-		0x98: Priority?
-		0x9a:
-		0x9c:
-		0x9e: Raster interrupt value
+        0x98: Priority?
+        0x9a:
+        0x9c:
+        0x9e: Raster interrupt value
 
-	Playfield control:
-		Bit  0x0f00: 	Playfield location in VRAM (in steps of 0x1000)
-		Bit  0x0080:	0 = Playfield enable, 1 = disable
-		Bit  0x0002:	1 = Rowscroll enable, 0 = disable
+    Playfield control:
+        Bit  0x0f00:    Playfield location in VRAM (in steps of 0x1000)
+        Bit  0x0080:    0 = Playfield enable, 1 = disable
+        Bit  0x0002:    1 = Rowscroll enable, 0 = disable
 
 *****************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-static struct tilemap *pf4_layer,*pf3_layer,*pf2_layer,*pf1_layer;
+static tilemap *pf4_layer,*pf3_layer,*pf2_layer,*pf1_layer;
 static int m107_control[0x20];
 static unsigned char *m107_spriteram;
 unsigned char *m107_vram_data;
@@ -121,12 +121,12 @@ static void get_pf4_tile_info(int tile_index)
 
 /*****************************************************************************/
 
-READ_HANDLER( m107_vram_r )
+READ8_HANDLER( m107_vram_r )
 {
 	return m107_vram_data[offset];
 }
 
-WRITE_HANDLER( m107_vram_w )
+WRITE8_HANDLER( m107_vram_w )
 {
 	int a;
 
@@ -151,7 +151,7 @@ WRITE_HANDLER( m107_vram_w )
 
 /*****************************************************************************/
 
-WRITE_HANDLER( m107_control_w )
+WRITE8_HANDLER( m107_control_w )
 {
 	static int last_pf1,last_pf2,last_pf3,last_pf4;
 
@@ -215,7 +215,7 @@ WRITE_HANDLER( m107_control_w )
 
 /*****************************************************************************/
 
-int m107_vh_start(void)
+VIDEO_START( m107 )
 {
 	pf1_layer = tilemap_create(
 		get_pf1_tile_info,tilemap_scan_rows,
@@ -256,7 +256,7 @@ int m107_vh_start(void)
 	pf1_enable=pf2_enable=pf3_enable=pf4_enable=0;
 	pf1_rowscroll=pf2_rowscroll=pf3_rowscroll=pf4_rowscroll=0;
 
-	m107_spriteram = malloc(0x1000);
+	m107_spriteram = auto_malloc(0x1000);
 	memset(m107_spriteram,0,0x1000);
 
 	m107_sprite_list=0;
@@ -264,14 +264,9 @@ int m107_vh_start(void)
 	return 0;
 }
 
-void m107_vh_stop(void)
-{
-	free(m107_spriteram);
-}
-
 /*****************************************************************************/
 
-static void m107_drawsprites(struct mame_bitmap *bitmap, const struct rectangle *clip, int pri)
+static void m107_drawsprites(mame_bitmap *bitmap, const rectangle *cliprect, int pri)
 {
 	int offs;
 
@@ -312,7 +307,7 @@ static void m107_drawsprites(struct mame_bitmap *bitmap, const struct rectangle
 						colour,
 						fx,fy,
 						x,y-i*16,
-						clip,TRANSPARENCY_PEN,0);
+						cliprect,TRANSPARENCY_PEN,0);
 				if (fy) s_ptr++; else s_ptr--;
 			}
 		}
@@ -341,7 +336,7 @@ static void m107_drawsprites(struct mame_bitmap *bitmap, const struct rectangle
 								colour,
 								ffx,ffy,
 								(x+xdisp)&0x1ff,(y-ydisp-16*i)&0x1ff,
-								clip,TRANSPARENCY_PEN,0);
+								cliprect,TRANSPARENCY_PEN,0);
 					}
 
 					if (rom[rom_offs+1]&0x80) break;	/* end of block */
@@ -355,22 +350,15 @@ static void m107_drawsprites(struct mame_bitmap *bitmap, const struct rectangle
 
 /*****************************************************************************/
 
-void m107_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
-{
-	/* Nothing - screen refresh is handled by raster interrupt routine */
-}
-
-/*****************************************************************************/
-
 static void m107_update_scroll_positions(void)
 {
 	int i;
 
-	/*	Playfield 4 rowscroll data is 0xde800 - 0xdebff???
-		Playfield 3 rowscroll data is 0xdf800 - 0xdfbff
-		Playfield 2 rowscroll data is 0xdf400 - 0xdf7ff
-		Playfield 1 rowscroll data is 0xde800 - 0xdebff		??
-	*/
+	/*  Playfield 4 rowscroll data is 0xde800 - 0xdebff???
+        Playfield 3 rowscroll data is 0xdf800 - 0xdfbff
+        Playfield 2 rowscroll data is 0xdf400 - 0xdf7ff
+        Playfield 1 rowscroll data is 0xde800 - 0xdebff     ??
+    */
 
 	if (pf1_rowscroll) {
 		tilemap_set_scroll_rows(pf1_layer,512);
@@ -410,65 +398,50 @@ static void m107_update_scroll_positions(void)
 	tilemap_set_scrolly( pf3_layer,0, (m107_control[9]<<8)+m107_control[8] );
 	tilemap_set_scrolly( pf4_layer,0, (m107_control[13]<<8)+m107_control[12] );
 
-/*	pf4_layer->scrolled=1; */
-/*	pf3_layer->scrolled=1; */
-/*	pf2_layer->scrolled=1; */
-/*	pf1_layer->scrolled=1; */
+/*  pf4_layer->scrolled=1; */
+/*  pf3_layer->scrolled=1; */
+/*  pf2_layer->scrolled=1; */
+/*  pf1_layer->scrolled=1; */
 }
 
 /*****************************************************************************/
 
-void m107_screenrefresh(struct mame_bitmap *bitmap,const struct rectangle *clip)
+void m107_screenrefresh(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	if (pf4_enable)
-		tilemap_draw(bitmap,pf4_layer,0,0);
+		tilemap_draw(bitmap,cliprect,pf4_layer,0,0);
 	else
-		fillbitmap(bitmap,Machine->pens[0],clip);
+		fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	tilemap_draw(bitmap,pf3_layer,0,0);
-	tilemap_draw(bitmap,pf2_layer,0,0);
-	tilemap_draw(bitmap,pf1_layer,0,0);
+	tilemap_draw(bitmap,cliprect,pf3_layer,0,0);
+	tilemap_draw(bitmap,cliprect,pf2_layer,0,0);
+	tilemap_draw(bitmap,cliprect,pf1_layer,0,0);
 
-	m107_drawsprites(bitmap,clip,0);
-	tilemap_draw(bitmap,pf2_layer,1,0);
-	tilemap_draw(bitmap,pf1_layer,1,0);
+	m107_drawsprites(bitmap,cliprect,0);
+	tilemap_draw(bitmap,cliprect,pf2_layer,1,0);
+	tilemap_draw(bitmap,cliprect,pf1_layer,1,0);
 
-	m107_drawsprites(bitmap,clip,1);
+	m107_drawsprites(bitmap,cliprect,1);
 
 	/* This hardware probably has more priority values - but I haven't found
-		any used yet */
-}
-
-void m107_vh_raster_partial_refresh(struct mame_bitmap *bitmap,int start_line,int end_line)
-{
-	struct rectangle clip;
-
-	clip.min_x = Machine->visible_area.min_x;
-	clip.max_x = Machine->visible_area.max_x;
-	clip.min_y = start_line+128;
-	clip.max_y = end_line+128;
-	if (clip.min_y < Machine->visible_area.min_y)
-		clip.min_y = Machine->visible_area.min_y;
-	if (clip.max_y > Machine->visible_area.max_y)
-		clip.max_y = Machine->visible_area.max_y;
-
-	if (clip.max_y > clip.min_y)
-	{
-		m107_update_scroll_positions();
-		tilemap_set_clip(pf1_layer,&clip);
-		tilemap_set_clip(pf2_layer,&clip);
-		tilemap_set_clip(pf3_layer,&clip);
-		tilemap_set_clip(pf4_layer,&clip);
-		m107_screenrefresh(bitmap,&clip);
-	}
+        any used yet */
 }
 
 /*****************************************************************************/
 
-WRITE_HANDLER( m107_spritebuffer_w )
+WRITE8_HANDLER( m107_spritebuffer_w )
 {
 	if (offset==0) {
-/*		logerror("%04x: buffered spriteram\n",cpu_get_pc()); */
+/*      logerror("%04x: buffered spriteram\n",activecpu_get_pc()); */
 		memcpy(m107_spriteram,spriteram,0x1000);
 	}
 }
+
+/*****************************************************************************/
+
+VIDEO_UPDATE( m107 )
+{
+	m107_update_scroll_positions();
+	m107_screenrefresh(bitmap,cliprect);
+}
+
