@@ -1,62 +1,63 @@
 #include "driver.h"
 #include "sndhrdw/m72.h"
+#include "vidhrdw/generic.h"
+#include "state.h"
 
 
 
 unsigned char *m72_videoram1,*m72_videoram2,*majtitle_rowscrollram;
 static unsigned char *m72_spriteram;
-static int rastersplit;
 static int splitline;
-static struct tilemap *fg_tilemap,*bg_tilemap;
+static tilemap *fg_tilemap,*bg_tilemap;
 static int xadjust;
-static int scrollx1[256],scrolly1[256],scrollx2[256],scrolly2[256];
+static int bgadjust;
+static int scrollx1,scrolly1,scrollx2,scrolly2;
 static int video_off;
 extern unsigned char *spriteram,*spriteram_2;
 extern size_t spriteram_size;
 
 static int irqbase;
 
-void m72_init_machine(void)
+MACHINE_INIT( m72 )
 {
 	irqbase = 0x20;
-	m72_init_sound();
+	machine_init_m72_sound();
 }
 
-void xmultipl_init_machine(void)
+MACHINE_INIT( xmultipl )
 {
 	irqbase = 0x08;
-	m72_init_sound();
+	machine_init_m72_sound();
 }
 
-void kengo_init_machine(void)
+MACHINE_INIT( kengo )
 {
 	irqbase = 0x18;
-	m72_init_sound();
+	machine_init_m72_sound();
 }
 
-int m72_interrupt(void)
+INTERRUPT_GEN( m72_interrupt )
 {
 	int line = 255 - cpu_getiloops();
 
 	if (line == 255)	/* vblank */
 	{
-		rastersplit = 0;
-		return irqbase+0;
+		cpunum_set_input_line_and_vector(0, 0, HOLD_LINE, irqbase+0);
 	}
 	else
 	{
 		if (line != splitline - 128)
-			return ignore_interrupt();
+			return;
 
-		rastersplit = line + 1;
+		force_partial_update(line + 128);
 
 		/* this is used to do a raster effect and show the score display at
-		   the bottom of the screen or other things. The line where the
-		   interrupt happens is programmable (and the interrupt can be triggered
-		   multiple times, by changing the interrupt line register in the
-		   interrupt handler).
-		 */
-		return irqbase+2;
+           the bottom of the screen or other things. The line where the
+           interrupt happens is programmable (and the interrupt can be triggered
+           multiple times, by changing the interrupt line register in the
+           interrupt handler).
+         */
+		cpunum_set_input_line_and_vector(0, 0, HOLD_LINE, irqbase+2);
 	}
 }
 
@@ -68,15 +69,15 @@ int m72_interrupt(void)
 
 ***************************************************************************/
 
-INLINE void m72_get_tile_info(int tile_index,unsigned char *videoram,int gfxnum)
+INLINE void m72_get_tile_info(int tile_index,unsigned char *vram,int gfxnum)
 {
 	int code,attr,color,pri;
 
 	tile_index *= 4;
 
-	code  = videoram[tile_index];
-	attr  = videoram[tile_index+1];
-	color = videoram[tile_index+2];
+	code  = vram[tile_index];
+	attr  = vram[tile_index+1];
+	color = vram[tile_index+2];
 
 	if (color & 0x80) pri = 2;
 	else if (color & 0x40) pri = 1;
@@ -90,22 +91,22 @@ INLINE void m72_get_tile_info(int tile_index,unsigned char *videoram,int gfxnum)
 			TILE_FLIPYX((attr & 0xc0) >> 6) | TILE_SPLIT(pri))
 }
 
-INLINE void rtype2_get_tile_info(int tile_index,unsigned char *videoram,int gfxnum)
+INLINE void rtype2_get_tile_info(int tile_index,unsigned char *vram,int gfxnum)
 {
 	int code,attr,color,pri;
 
 	tile_index *= 4;
 
-	code  = videoram[tile_index] + (videoram[tile_index+1] << 8);
-	color = videoram[tile_index+2];
-	attr  = videoram[tile_index+3];
+	code  = vram[tile_index] + (vram[tile_index+1] << 8);
+	color = vram[tile_index+2];
+	attr  = vram[tile_index+3];
 
 	if (attr & 0x01) pri = 2;
 	else if (color & 0x80) pri = 1;
 	else pri = 0;
 
-/* (videoram[tile_index+2] & 0x10) is used by majtitle on the green, but it's not clear for what */
-/* (videoram[tile_index+3] & 0xfe) are used as well */
+/* (vram[tile_index+2] & 0x10) is used by majtitle on the green, but it's not clear for what */
+/* (vram[tile_index+3] & 0xfe) are used as well */
 
 	SET_TILE_INFO(
 			gfxnum,
@@ -130,11 +131,6 @@ static void hharry_get_bg_tile_info(int tile_index)
 	m72_get_tile_info(tile_index,m72_videoram2,1);
 }
 
-static void hharry_get_fg_tile_info(int tile_index)
-{
-	m72_get_tile_info(tile_index,m72_videoram1,1);
-}
-
 static void rtype2_get_bg_tile_info(int tile_index)
 {
 	rtype2_get_tile_info(tile_index,m72_videoram2,1);
@@ -159,14 +155,26 @@ static UINT32 majtitle_scan_rows( UINT32 col, UINT32 row, UINT32 num_cols, UINT3
 
 ***************************************************************************/
 
-int m72_vh_start(void)
+static void register_savestate(void)
+{
+	state_save_register_int  ("video", 0, "splitline",        &splitline);
+	state_save_register_int  ("video", 0, "video_off",        &video_off);
+	state_save_register_int  ("video", 0, "scrollx1",         &scrollx1);
+	state_save_register_int  ("video", 0, "scrolly1",         &scrolly1);
+	state_save_register_int  ("video", 0, "scrollx2",         &scrollx2);
+	state_save_register_int  ("video", 0, "scrolly2",         &scrolly2);
+	state_save_register_UINT8("video", 0, "m72_spriteram",    m72_spriteram, spriteram_size);
+}
+
+
+VIDEO_START( m72 )
 {
 	bg_tilemap = tilemap_create(m72_get_bg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
 	fg_tilemap = tilemap_create(m72_get_fg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
 
-	m72_spriteram = malloc(spriteram_size);
+	m72_spriteram = auto_malloc(spriteram_size);
 
-	if (!fg_tilemap || !bg_tilemap || !m72_spriteram)
+	if (!fg_tilemap || !bg_tilemap)
 		return 1;
 
 	tilemap_set_transmask(fg_tilemap,0,0xffff,0x0001);
@@ -180,16 +188,19 @@ int m72_vh_start(void)
 	memset(m72_spriteram,0,spriteram_size);
 
 	xadjust = 0;
+	bgadjust = 0;
+
+	register_savestate();
 
 	return 0;
 }
 
-int rtype2_vh_start(void)
+VIDEO_START( rtype2 )
 {
 	bg_tilemap = tilemap_create(rtype2_get_bg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
 	fg_tilemap = tilemap_create(rtype2_get_fg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
 
-	m72_spriteram = malloc(spriteram_size);
+	m72_spriteram = auto_malloc(spriteram_size);
 
 	if (!fg_tilemap || !bg_tilemap || !m72_spriteram)
 		return 1;
@@ -205,13 +216,16 @@ int rtype2_vh_start(void)
 	memset(m72_spriteram,0,spriteram_size);
 
 	xadjust = -4;
+	bgadjust = 0;
+
+	register_savestate();
 
 	return 0;
 }
 
-int poundfor_vh_start(void)
+VIDEO_START( poundfor )
 {
-	int res = rtype2_vh_start();
+	int res = video_start_rtype2();
 
 	xadjust = -6;
 
@@ -220,15 +234,15 @@ int poundfor_vh_start(void)
 
 
 /* Major Title has a larger background RAM, and rowscroll */
-int majtitle_vh_start(void)
+VIDEO_START( majtitle )
 {
 /* The tilemap can be 256x64, but seems to be used at 128x64 (scroll wraparound). */
 /* The layout ramains 256x64, the right half is just not displayed. */
-/*	bg_tilemap = tilemap_create(rtype2_get_bg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,256,64); */
+/*  bg_tilemap = tilemap_create(rtype2_get_bg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,256,64); */
 	bg_tilemap = tilemap_create(rtype2_get_bg_tile_info,majtitle_scan_rows,TILEMAP_SPLIT,8,8,128,64);
 	fg_tilemap = tilemap_create(rtype2_get_fg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
 
-	m72_spriteram = malloc(spriteram_size);
+	m72_spriteram = auto_malloc(spriteram_size);
 
 	if (!fg_tilemap || !bg_tilemap || !m72_spriteram)
 		return 1;
@@ -244,16 +258,19 @@ int majtitle_vh_start(void)
 	memset(m72_spriteram,0,spriteram_size);
 
 	xadjust = -4;
+	bgadjust = 0;
+
+	register_savestate();
 
 	return 0;
 }
 
-int hharry_vh_start(void)
+VIDEO_START( hharry )
 {
 	bg_tilemap = tilemap_create(hharry_get_bg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
-	fg_tilemap = tilemap_create(hharry_get_fg_tile_info,tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
+	fg_tilemap = tilemap_create(m72_get_fg_tile_info,   tilemap_scan_rows,TILEMAP_SPLIT,8,8,64,64);
 
-	m72_spriteram = malloc(spriteram_size);
+	m72_spriteram = auto_malloc(spriteram_size);
 
 	if (!fg_tilemap || !bg_tilemap || !m72_spriteram)
 		return 1;
@@ -269,17 +286,13 @@ int hharry_vh_start(void)
 	memset(m72_spriteram,0,spriteram_size);
 
 	xadjust = -4;
+	bgadjust = -2;
+
+	register_savestate();
 
 	return 0;
 }
 
-void m72_vh_stop(void)
-{
-	free(m72_spriteram);
-	m72_spriteram = 0;
-}
-
-
 
 /***************************************************************************
 
@@ -287,7 +300,7 @@ void m72_vh_stop(void)
 
 ***************************************************************************/
 
-READ_HANDLER( m72_palette1_r )
+READ8_HANDLER( m72_palette1_r )
 {
 	/* only D0-D4 are connected */
 	if (offset & 1) return 0xff;
@@ -298,7 +311,7 @@ READ_HANDLER( m72_palette1_r )
 	return paletteram[offset] | 0xe0;	/* only D0-D4 are connected */
 }
 
-READ_HANDLER( m72_palette2_r )
+READ8_HANDLER( m72_palette2_r )
 {
 	/* only D0-D4 are connected */
 	if (offset & 1) return 0xff;
@@ -318,7 +331,7 @@ INLINE void changecolor(int color,int r,int g,int b)
 	palette_set_color(color,r,g,b);
 }
 
-WRITE_HANDLER( m72_palette1_w )
+WRITE8_HANDLER( m72_palette1_w )
 {
 	/* only D0-D4 are connected */
 	if (offset & 1) return;
@@ -334,7 +347,7 @@ WRITE_HANDLER( m72_palette1_w )
 			paletteram[offset + 0x800]);
 }
 
-WRITE_HANDLER( m72_palette2_w )
+WRITE8_HANDLER( m72_palette2_w )
 {
 	/* only D0-D4 are connected */
 	if (offset & 1) return;
@@ -350,17 +363,17 @@ WRITE_HANDLER( m72_palette2_w )
 			paletteram_2[offset + 0x800]);
 }
 
-READ_HANDLER( m72_videoram1_r )
+READ8_HANDLER( m72_videoram1_r )
 {
 	return m72_videoram1[offset];
 }
 
-READ_HANDLER( m72_videoram2_r )
+READ8_HANDLER( m72_videoram2_r )
 {
 	return m72_videoram2[offset];
 }
 
-WRITE_HANDLER( m72_videoram1_w )
+WRITE8_HANDLER( m72_videoram1_w )
 {
 	if (m72_videoram1[offset] != data)
 	{
@@ -369,7 +382,7 @@ WRITE_HANDLER( m72_videoram1_w )
 	}
 }
 
-WRITE_HANDLER( m72_videoram2_w )
+WRITE8_HANDLER( m72_videoram2_w )
 {
 	if (m72_videoram2[offset] != data)
 	{
@@ -378,57 +391,37 @@ WRITE_HANDLER( m72_videoram2_w )
 	}
 }
 
-WRITE_HANDLER( m72_irq_line_w )
+WRITE8_HANDLER( m72_irq_line_w )
 {
 	offset *= 8;
 	splitline = (splitline & (0xff00 >> offset)) | (data << offset);
 }
 
-WRITE_HANDLER( m72_scrollx1_w )
+WRITE8_HANDLER( m72_scrollx1_w )
 {
-	int i;
-
 	offset *= 8;
-	scrollx1[rastersplit] = (scrollx1[rastersplit] & (0xff00 >> offset)) | (data << offset);
-
-	for (i = rastersplit+1;i < 256;i++)
-		scrollx1[i] = scrollx1[rastersplit];
+	scrollx1 = (scrollx1 & (0xff00 >> offset)) | (data << offset);
 }
 
-WRITE_HANDLER( m72_scrollx2_w )
+WRITE8_HANDLER( m72_scrollx2_w )
 {
-	int i;
-
 	offset *= 8;
-	scrollx2[rastersplit] = (scrollx2[rastersplit] & (0xff00 >> offset)) | (data << offset);
-
-	for (i = rastersplit+1;i < 256;i++)
-		scrollx2[i] = scrollx2[rastersplit];
+	scrollx2 = (scrollx2 & (0xff00 >> offset)) | (data << offset);
 }
 
-WRITE_HANDLER( m72_scrolly1_w )
+WRITE8_HANDLER( m72_scrolly1_w )
 {
-	int i;
-
 	offset *= 8;
-	scrolly1[rastersplit] = (scrolly1[rastersplit] & (0xff00 >> offset)) | (data << offset);
-
-	for (i = rastersplit+1;i < 256;i++)
-		scrolly1[i] = scrolly1[rastersplit];
+	scrolly1 = (scrolly1 & (0xff00 >> offset)) | (data << offset);
 }
 
-WRITE_HANDLER( m72_scrolly2_w )
+WRITE8_HANDLER( m72_scrolly2_w )
 {
-	int i;
-
 	offset *= 8;
-	scrolly2[rastersplit] = (scrolly2[rastersplit] & (0xff00 >> offset)) | (data << offset);
-
-	for (i = rastersplit+1;i < 256;i++)
-		scrolly2[i] = scrolly2[rastersplit];
+	scrolly2 = (scrolly2 & (0xff00 >> offset)) | (data << offset);
 }
 
-WRITE_HANDLER( m72_dmaon_w )
+WRITE8_HANDLER( m72_dmaon_w )
 {
 	if (offset == 0)
 	{
@@ -437,7 +430,7 @@ WRITE_HANDLER( m72_dmaon_w )
 }
 
 
-WRITE_HANDLER( m72_port02_w )
+WRITE8_HANDLER( m72_port02_w )
 {
 	if (offset != 0)
 	{
@@ -458,14 +451,14 @@ WRITE_HANDLER( m72_port02_w )
 
 	/* bit 4 resets sound CPU (active low) */
 	if (data & 0x10)
-		cpu_set_reset_line(1,CLEAR_LINE);
+		cpunum_set_input_line(1, INPUT_LINE_RESET, CLEAR_LINE);
 	else
-		cpu_set_reset_line(1,ASSERT_LINE);
+		cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
 
 	/* bit 5 = "bank"? */
 }
 
-WRITE_HANDLER( rtype2_port02_w )
+WRITE8_HANDLER( rtype2_port02_w )
 {
 	if (offset != 0)
 	{
@@ -491,7 +484,7 @@ WRITE_HANDLER( rtype2_port02_w )
 static int majtitle_rowscroll;
 
 /* the following is mostly a kludge. This register seems to be used for something else */
-WRITE_HANDLER( majtitle_gfx_ctrl_w )
+WRITE8_HANDLER( majtitle_gfx_ctrl_w )
 {
 	if (offset == 1)
 	{
@@ -507,7 +500,7 @@ WRITE_HANDLER( majtitle_gfx_ctrl_w )
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
@@ -552,7 +545,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 						color,
 						flipx,flipy,
 						sx + 16*x,sy + 16*y,
-						&Machine->visible_area,TRANSPARENCY_PEN,0);
+						cliprect,TRANSPARENCY_PEN,0);
 			}
 		}
 
@@ -560,7 +553,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 	}
 }
 
-static void majtitle_draw_sprites(struct mame_bitmap *bitmap)
+static void majtitle_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
@@ -604,109 +597,65 @@ static void majtitle_draw_sprites(struct mame_bitmap *bitmap)
 						color,
 						flipx,flipy,
 						sx + 16*x,sy + 16*y,
-						&Machine->visible_area,TRANSPARENCY_PEN,0);
+						cliprect,TRANSPARENCY_PEN,0);
 			}
 		}
 	}
 }
 
-static void draw_layer(struct mame_bitmap *bitmap,
-		struct tilemap *tilemap,int *scrollx,int *scrolly,int priority)
-{
-	int start,i;
-	/* use clip regions to split the screen */
-	struct rectangle clip;
-
-	clip.min_x = Machine->visible_area.min_x;
-	clip.max_x = Machine->visible_area.max_x;
-	start = Machine->visible_area.min_y - 128;
-	do
-	{
-		i = start;
-		while (scrollx[i+1] == scrollx[start] && scrolly[i+1] == scrolly[start]
-				&& i < Machine->visible_area.max_y - 128)
-			i++;
-
-		clip.min_y = start + 128;
-		clip.max_y = i + 128;
-		tilemap_set_clip(tilemap,&clip);
-		tilemap_set_scrollx(tilemap,0,scrollx[start] + xadjust);
-		tilemap_set_scrolly(tilemap,0,scrolly[start]);
-		tilemap_draw(bitmap,tilemap,priority,0);
-
-		start = i+1;
-	} while (start < Machine->visible_area.max_y - 128);
-}
-
-static void draw_bg(struct mame_bitmap *bitmap,int priority)
-{
-	draw_layer(bitmap,bg_tilemap,scrollx2,scrolly2,priority);
-}
-
-static void draw_fg(struct mame_bitmap *bitmap,int priority)
-{
-	draw_layer(bitmap,fg_tilemap,scrollx1,scrolly1,priority);
-}
-
-
-void m72_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( m72 )
 {
 	if (video_off)
 	{
-		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+		fillbitmap(bitmap,get_black_pen(),cliprect);
 		return;
 	}
 
-	draw_bg(bitmap,TILEMAP_BACK);
-	draw_fg(bitmap,TILEMAP_BACK);
-	draw_sprites(bitmap);
-	draw_bg(bitmap,TILEMAP_FRONT);
-	draw_fg(bitmap,TILEMAP_FRONT);
+	tilemap_set_scrollx(fg_tilemap,0,scrollx1 + xadjust);
+	tilemap_set_scrolly(fg_tilemap,0,scrolly1);
+
+	tilemap_set_scrollx(bg_tilemap,0,scrollx2 + xadjust + bgadjust);
+	tilemap_set_scrolly(bg_tilemap,0,scrolly2);
+
+	tilemap_draw(bitmap,cliprect,bg_tilemap,TILEMAP_BACK,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,TILEMAP_BACK,0);
+	draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,TILEMAP_FRONT,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,TILEMAP_FRONT,0);
 }
 
-void majtitle_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( majtitle )
 {
 	int i;
 
 
 	if (video_off)
 	{
-		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+		fillbitmap(bitmap,get_black_pen(),cliprect);
 		return;
 	}
 
+	tilemap_set_scrollx(fg_tilemap,0,scrollx1 + xadjust);
+	tilemap_set_scrolly(fg_tilemap,0,scrolly1);
+
 	if (majtitle_rowscroll)
 	{
 		tilemap_set_scroll_rows(bg_tilemap,512);
 		for (i = 0;i < 512;i++)
-			tilemap_set_scrollx(bg_tilemap,(i+scrolly2[0])&0x1ff,
+			tilemap_set_scrollx(bg_tilemap,(i+scrolly2)&0x1ff,
 					256 + majtitle_rowscrollram[2*i] + (majtitle_rowscrollram[2*i+1] << 8) + xadjust);
 	}
 	else
 	{
 		tilemap_set_scroll_rows(bg_tilemap,1);
-		tilemap_set_scrollx(bg_tilemap,0,256 + scrollx2[0] + xadjust);
+		tilemap_set_scrollx(bg_tilemap,0,256 + scrollx2 + xadjust);
 	}
-	tilemap_set_scrolly(bg_tilemap,0,scrolly2[0]);
+	tilemap_set_scrolly(bg_tilemap,0,scrolly2);
 
-	tilemap_draw(bitmap,bg_tilemap,TILEMAP_BACK,0);
-	draw_fg(bitmap,TILEMAP_BACK);
-	majtitle_draw_sprites(bitmap);
-	draw_sprites(bitmap);
-	tilemap_draw(bitmap,bg_tilemap,TILEMAP_FRONT,0);
-	draw_fg(bitmap,TILEMAP_FRONT);
-}
-
-
-void m72_eof_callback(void)
-{
-	int i;
-
-	for (i = 0;i < 255;i++)
-	{
-		scrollx1[i] = scrollx1[255];
-		scrolly1[i] = scrolly1[255];
-		scrollx2[i] = scrollx2[255];
-		scrolly2[i] = scrolly2[255];
-	}
+	tilemap_draw(bitmap,cliprect,bg_tilemap,TILEMAP_BACK,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,TILEMAP_BACK,0);
+	majtitle_draw_sprites(bitmap,cliprect);
+	draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,TILEMAP_FRONT,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,TILEMAP_FRONT,0);
 }
