@@ -1,35 +1,36 @@
 /*****************************************************************************
 
-	Irem M90 system.  There is 1 video chip - NANAO GA-25, it produces
-	2 tilemaps and sprites.  16 control bytes:
+    Irem M90 system.  There is 1 video chip - NANAO GA-25, it produces
+    2 tilemaps and sprites.  16 control bytes:
 
-	0:  Playfield 1 X scroll
-	2:  Playfield 1 Y scroll
-	4:  Playfield 2 X scroll
-	6:  Playfield 2 Y scroll
-	8:  Bit 0x01 - unknown (set by hasamu)
-	10: Playfield 1 control
-		Bits0x03 - Playfield 1 VRAM base
- 		Bit 0x04 - Playfield 1 width (0 is 64 tiles, 0x4 is 128 tiles)
-		Bit 0x10 - Playfield 1 disable
-		Bit 0x20 - Playfield 1 rowscroll enable
-	12: Playfield 2 control
-		Bits0x03 - Playfield 2 VRAM base
- 		Bit 0x04 - Playfield 2 width (0 is 64 tiles, 0x4 is 128 tiles)
-		Bit 0x10 - Playfield 2 disable
-		Bit 0x20 - Playfield 2 rowscroll enable
-	14: Bit 0x02 - unknown (set by hasamu)
+    0:  Playfield 1 X scroll
+    2:  Playfield 1 Y scroll
+    4:  Playfield 2 X scroll
+    6:  Playfield 2 Y scroll
+    8:  Bit 0x01 - unknown (set by hasamu)
+    10: Playfield 1 control
+        Bits0x03 - Playfield 1 VRAM base
+        Bit 0x04 - Playfield 1 width (0 is 64 tiles, 0x4 is 128 tiles)
+        Bit 0x10 - Playfield 1 disable
+        Bit 0x20 - Playfield 1 rowscroll enable
+    12: Playfield 2 control
+        Bits0x03 - Playfield 2 VRAM base
+        Bit 0x04 - Playfield 2 width (0 is 64 tiles, 0x4 is 128 tiles)
+        Bit 0x10 - Playfield 2 disable
+        Bit 0x20 - Playfield 2 rowscroll enable
+    14: Bit 0x02 - unknown (set by hasamu)
 
-	Emulation by Bryan McPhail, mish@tendril.co.uk, thanks to Chris Hardy!
+    Emulation by Bryan McPhail, mish@tendril.co.uk, thanks to Chris Hardy!
 
 *****************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "state.h"
 
 static unsigned char *m90_spriteram;
 unsigned char *m90_video_data;
-static struct tilemap *pf1_layer,*pf2_layer,*pf1_wide_layer,*pf2_wide_layer;
+static tilemap *pf1_layer,*pf2_layer,*pf1_wide_layer,*pf2_wide_layer;
 static int m90_video_control_data[16];
 
 static void get_tile_info(int tile_index,int layer,int page_mask)
@@ -54,7 +55,7 @@ static void get_pf2_tile_info (int tile_index) { get_tile_info(tile_index,1,3);
 static void get_pf2w_tile_info(int tile_index) { get_tile_info(tile_index,1,2); }
 
 
-int m90_vh_start(void)
+VIDEO_START( m90 )
 {
 	pf1_layer =      tilemap_create(get_pf1_tile_info, tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,64,64);
 	pf1_wide_layer = tilemap_create(get_pf1w_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,128,64);
@@ -67,10 +68,12 @@ int m90_vh_start(void)
 	tilemap_set_transparent_pen(pf1_layer,0);
 	tilemap_set_transparent_pen(pf1_wide_layer,0);
 
+	state_save_register_UINT32("video", 0, "m90_video_control_data", (UINT32*) m90_video_control_data, 16);
+
 	return 0;
 }
 
-static void m90_drawsprites(struct mame_bitmap *bitmap)
+static void m90_drawsprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
@@ -99,13 +102,13 @@ static void m90_drawsprites(struct mame_bitmap *bitmap)
 					colour,
 					fx,fy,
 					x,y+i*16,
-					&Machine->visible_area,TRANSPARENCY_PEN,0,
+					cliprect,TRANSPARENCY_PEN,0,
 					(colour & 0x08) ? 0x00 : 0x02);
 	}
 }
 
 #if 0
-static void bootleg_drawsprites(struct mame_bitmap *bitmap)
+static void bootleg_drawsprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
@@ -131,18 +134,18 @@ static void bootleg_drawsprites(struct mame_bitmap *bitmap)
 				colour,
 				fx,fy,
 				x,y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0);
+				cliprect,TRANSPARENCY_PEN,0);
 	}
 }
 #endif
 
-WRITE_HANDLER( m90_video_control_w )
+WRITE8_HANDLER( m90_video_control_w )
 {
 	m90_video_control_data[offset]=data;
 }
 
 
-static void markdirty(struct tilemap *tilemap,int page,offs_t offset)
+static void markdirty(tilemap *tilemap,int page,offs_t offset)
 {
 	offset -= page * 0x4000;
 
@@ -151,7 +154,7 @@ static void markdirty(struct tilemap *tilemap,int page,offs_t offset)
 }
 
 
-WRITE_HANDLER( m90_video_w )
+WRITE8_HANDLER( m90_video_w )
 {
 	m90_video_data[offset] = data;
 
@@ -161,7 +164,7 @@ WRITE_HANDLER( m90_video_w )
 	markdirty(pf2_wide_layer,m90_video_control_data[0xc] & 0x2,offset);
 }
 
-void m90_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( m90 )
 {
 	static int last_pf1,last_pf2;
 	int pf1_base = m90_video_control_data[0xa] & 0x3;
@@ -170,10 +173,10 @@ void m90_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	if (m90_video_control_data[0xa]&0x10) pf1_enable=0; else pf1_enable=1;
 	if (m90_video_control_data[0xc]&0x10) pf2_enable=0; else pf2_enable=1;
-/*	tilemap_set_enable(pf1_layer,pf1_enable); */
-/*	tilemap_set_enable(pf2_layer,pf2_enable); */
-/*	tilemap_set_enable(pf1_wide_layer,pf1_enable); */
-/*	tilemap_set_enable(pf2_wide_layer,pf2_enable); */
+/*  tilemap_set_enable(pf1_layer,pf1_enable); */
+/*  tilemap_set_enable(pf2_layer,pf2_enable); */
+/*  tilemap_set_enable(pf1_wide_layer,pf1_enable); */
+/*  tilemap_set_enable(pf2_wide_layer,pf2_enable); */
 
 	/* Dirty tilemaps if VRAM base changes */
 	if (pf1_base!=last_pf1)
@@ -229,36 +232,36 @@ void m90_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	tilemap_set_scrolly( pf1_wide_layer,0, (m90_video_control_data[1]<<8)+m90_video_control_data[0] );
 	tilemap_set_scrolly( pf2_wide_layer,0, (m90_video_control_data[5]<<8)+m90_video_control_data[4] );
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
 	if (!pf2_enable)
-		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+		fillbitmap(bitmap,Machine->pens[0],cliprect);
 
 	if (pf2_enable)
 	{
 		if (m90_video_control_data[0xc] & 0x4)
-			tilemap_draw(bitmap,pf2_wide_layer,0,0);
+			tilemap_draw(bitmap,cliprect,pf2_wide_layer,0,0);
 		else
-			tilemap_draw(bitmap,pf2_layer,0,0);
+			tilemap_draw(bitmap,cliprect,pf2_layer,0,0);
 
 		if (m90_video_control_data[0xc] & 0x4)
-			tilemap_draw(bitmap,pf2_wide_layer,1,1);
+			tilemap_draw(bitmap,cliprect,pf2_wide_layer,1,1);
 		else
-			tilemap_draw(bitmap,pf2_layer,1,1);
+			tilemap_draw(bitmap,cliprect,pf2_layer,1,1);
 	}
 
 	if (pf1_enable)
 	{
 		if (m90_video_control_data[0xa] & 0x4)
-			tilemap_draw(bitmap,pf1_wide_layer,0,0);
+			tilemap_draw(bitmap,cliprect,pf1_wide_layer,0,0);
 		else
-			tilemap_draw(bitmap,pf1_layer,0,0);
+			tilemap_draw(bitmap,cliprect,pf1_layer,0,0);
 
 		if (m90_video_control_data[0xa] & 0x4)
-			tilemap_draw(bitmap,pf1_wide_layer,1,1);
+			tilemap_draw(bitmap,cliprect,pf1_wide_layer,1,1);
 		else
-			tilemap_draw(bitmap,pf1_layer,1,1);
+			tilemap_draw(bitmap,cliprect,pf1_layer,1,1);
 	}
 
-	m90_drawsprites(bitmap);
+	m90_drawsprites(bitmap,cliprect);
 }
