@@ -10,8 +10,8 @@ Additional tweaking by Jarek Burczynski
 #include "driver.h"
 #include "generic.h"
 
-data16_t *magmax_scroll_x;
-data16_t *magmax_scroll_y;
+UINT16 *magmax_scroll_x;
+UINT16 *magmax_scroll_y;
 unsigned short magmax_vreg;
 static int flipscreen = 0;
 
@@ -19,83 +19,7 @@ static UINT32 pens_line_tab[256];
 static UINT32 *prom_tab = NULL;
 
 
-typedef void (*blit_horiz_pixel_line_proc)(struct mame_bitmap *bitmap,int x,int y, int width, UINT32* pens);
-static blit_horiz_pixel_line_proc blit_horiz_pixel_line;
-
-static void bhpl_8_nd(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT8* lineadr = &(((UINT8*)b->line[y])[x]);
-	while(w-->0)
-	{
-		*lineadr++ = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_fx(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT8* lineadr = &(((UINT8*)b->line[y])[b->width-1-x]);
-	while(w-->0)
-	{
-		*lineadr-- = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_fy(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT8* lineadr = &(((UINT8*)b->line[b->height-1-y])[x]);
-	while(w-->0)
-	{
-		*lineadr++ = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_fxy(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT8* lineadr = &(((UINT8*)b->line[b->height-1-y])[b->width-1-x]);
-	while(w-->0)
-	{
-		*lineadr-- = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	while(w-->0)
-	{
-		((UINT8 *)b->line[x++])[y] = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_fx_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	y = b->width-1-y;
-	while(w-->0)
-	{
-		((UINT8 *)b->line[x++])[y] = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_fy_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	x = b->height-1-x;
-	while(w-->0)
-	{
-		((UINT8 *)b->line[x--])[y] = (UINT8)(*pens);
-		pens++;
-	}
-}
-static void bhpl_8_nd_fxy_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	x = b->height-1-x;
-	y = b->width-1-y;
-	while(w-->0)
-	{
-		((UINT8 *)b->line[x--])[y] = (UINT8)(*pens);
-		pens++;
-	}
-}
-
-static void bhpl_16_nd(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
+static void blit_horiz_pixel_line(mame_bitmap *b,int x,int y,int w, UINT32* pens)
 {
 	UINT16* lineadr = &(((UINT16*)b->line[y])[x]);
 	while(w-->0)
@@ -104,89 +28,7 @@ static void bhpl_16_nd(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
 		pens++;
 	}
 }
-static void bhpl_16_nd_fx(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT16* lineadr = &(((UINT16*)b->line[y])[b->width-1-x]);
-	while(w-->0)
-	{
-		*lineadr-- = (UINT16)(*pens);
-		pens++;
-	}
-}
-static void bhpl_16_nd_fy(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT16* lineadr = &(((UINT16*)b->line[b->height-1-y])[x]);
-	while(w-->0)
-	{
-		*lineadr++ = (UINT16)(*pens);
-		pens++;
-	}
-}
-static void bhpl_16_nd_fxy(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	UINT16* lineadr = &(((UINT16*)b->line[b->height-1-y])[b->width-1-x]);
-	while(w-->0)
-	{
-		*lineadr-- = (UINT16)(*pens);
-		pens++;
-	}
-}
-static void bhpl_16_nd_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	while(w-->0)
-	{
-		((UINT16*)b->line[x++])[y] = (UINT16)(*pens);
-		pens++;
-	}
-}
-static void bhpl_16_nd_fx_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	y = b->width-1-y;
-	while(w-->0)
-	{
-		((UINT16*)b->line[x++])[y] = (UINT16)(*pens);
-		pens++;
-	}
-}
-static void bhpl_16_nd_fy_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	x = b->height-1-x;
-	while(w-->0)
-	{
-		((UINT16*)b->line[x--])[y] = (UINT16)(*pens);
-		pens++;
-	}
-}
-static void bhpl_16_nd_fxy_s(struct mame_bitmap *b,int x,int y,int w, UINT32* pens)
-{
-	x = b->height-1-x;
-	y = b->width-1-y;
-	while(w-->0)
-	{
-		((UINT16*)b->line[x--])[y] = (UINT16)(*pens);
-		pens++;
-	}
-}
 
-static blit_horiz_pixel_line_proc bhpls_8_nd[] =
-		{ bhpl_8_nd,   bhpl_8_nd_fx,   bhpl_8_nd_fy,   bhpl_8_nd_fxy,
-		  bhpl_8_nd_s, bhpl_8_nd_fx_s, bhpl_8_nd_fy_s, bhpl_8_nd_fxy_s };
-
-static blit_horiz_pixel_line_proc bhpls_16_nd[] =
-		{ bhpl_16_nd,   bhpl_16_nd_fx,   bhpl_16_nd_fy,   bhpl_16_nd_fxy,
-		  bhpl_16_nd_s, bhpl_16_nd_fx_s, bhpl_16_nd_fy_s, bhpl_16_nd_fxy_s };
-
-static void set_custom_blit(void)
-{
-	if (Machine->color_depth == 8)
-	{
-		blit_horiz_pixel_line = bhpls_8_nd[Machine->orientation];
-	}
-	else
-	{
-		blit_horiz_pixel_line = bhpls_16_nd[Machine->orientation];
-	}
-}
 
 /***************************************************************************
 
@@ -201,7 +43,7 @@ static void set_custom_blit(void)
   bit 0 -- 2.2kohm resistor  -- RED/GREEN/BLUE
 
 ***************************************************************************/
-void magmax_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable, const unsigned char *color_prom)
+PALETTE_INIT( magmax )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -209,24 +51,25 @@ void magmax_vh_convert_color_prom(unsigned char *palette, unsigned short *colort
 
 	for (i = 0; i < Machine->drv->total_colors; i++)
 	{
-		int bit0, bit1, bit2, bit3;
+		int bit0, bit1, bit2, bit3, r, g, b;
 
 		bit0 = (color_prom[0] >> 0) & 0x01;
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		bit0 = (color_prom[Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 		bit0 = (color_prom[2*Machine->drv->total_colors] >> 0) & 0x01;
 		bit1 = (color_prom[2*Machine->drv->total_colors] >> 1) & 0x01;
 		bit2 = (color_prom[2*Machine->drv->total_colors] >> 2) & 0x01;
 		bit3 = (color_prom[2*Machine->drv->total_colors] >> 3) & 0x01;
-		*(palette++) = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
+		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
@@ -245,29 +88,16 @@ void magmax_vh_convert_color_prom(unsigned char *palette, unsigned short *colort
 
 }
 
-void magmax_vh_stop(void)
-{
-	free(prom_tab);
-	prom_tab = 0;
-
-	bitmap_free(tmpbitmap);
-	tmpbitmap = 0;
-}
-
-int magmax_vh_start(void)
+VIDEO_START( magmax )
 {
 	int i,v;
 	unsigned char * prom14D = memory_region(REGION_USER2);
 
-	if ((prom_tab = malloc(256 * sizeof(UINT32))) == 0)
-		return 1;
+	prom_tab = auto_malloc(256 * sizeof(UINT32));
 
 	/* Allocate temporary bitmap */
- 	if ((tmpbitmap = bitmap_alloc(256,256)) == 0)
-	{
-		magmax_vh_stop ();
+ 	if ((tmpbitmap = auto_bitmap_alloc(256,256)) == 0)
 		return 1;
-	}
 
 	for (i=0; i<256; i++)
 	{
@@ -275,14 +105,12 @@ int magmax_vh_start(void)
 		prom_tab[i] = ((v&0x1f)<<8) | ((v&0x10)<<10) | ((v&0xe0)>>1); /*convert data into more useful format*/
 	}
 
-	set_custom_blit();
-
 	return 0;
 }
 
 
 
-void magmax_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( magmax )
 {
 	int offs;
 
@@ -350,7 +178,7 @@ void magmax_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 					/* not possible on the surface*/
 					/*if ((map_v_scr_100) && ((graph_data & 0x0c)==0x0c)) */
 					/*{ */
-					/*	plot_pixel(tmpbitmap,h,v,pens[graph_color + graph_data] ); */
+					/*  plot_pixel(tmpbitmap,h,v,pens[graph_color + graph_data] ); */
 					/*} */
 				}
 				for (h = 0x80; h < 0x100; h++)
@@ -384,7 +212,7 @@ void magmax_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 					/* not possible on the surface*/
 					/*if ((map_v_scr_100) && ((graph_data & 0x0c)==0x0c)) */
 					/*{ */
-					/*	plot_pixel(tmpbitmap,h,v,pens[graph_color + graph_data] ); */
+					/*  plot_pixel(tmpbitmap,h,v,pens[graph_color + graph_data] ); */
 					/*} */
 				}
 			}
