@@ -1,16 +1,12 @@
 /***************************************************************************
 
-  vidhrdw/mcr68.c
-
-  Xenophobe video hardware very similar to Rampage.
-
-  Colour 8 in sprites indicates transparency in closed area.
-  Each tile has an attribute to indicate tile drawn on top of sprite.
+    Midway MCR-68k system
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "mcr.h"
 
 
 #define LOW_BYTE(x) ((x) & 0xff)
@@ -19,11 +15,136 @@
 UINT8 mcr68_sprite_clip;
 INT8 mcr68_sprite_xoffset;
 
+static tilemap *bg_tilemap;
+static tilemap *fg_tilemap;
+
 
 
 /*************************************
  *
- *	Palette RAM writes
+ *  Tilemap callbacks
+ *
+ *************************************/
+
+static void get_bg_tile_info(int tile_index)
+{
+	int data = LOW_BYTE(videoram16[tile_index * 2]) | (LOW_BYTE(videoram16[tile_index * 2 + 1]) << 8);
+	int code = (data & 0x3ff) | ((data >> 4) & 0xc00);
+	int color = (~data >> 12) & 3;
+	SET_TILE_INFO(0, code, color, TILE_FLIPYX((data >> 10) & 3));
+	if (Machine->gfx[0]->total_elements < 0x1000)
+		tile_info.priority = (data >> 15) & 1;
+}
+
+
+static void zwackery_get_bg_tile_info(int tile_index)
+{
+	int data = videoram16[tile_index];
+	int color = (data >> 13) & 7;
+	SET_TILE_INFO(0, data & 0x3ff, color, TILE_FLIPYX((data >> 11) & 3));
+}
+
+
+static void zwackery_get_fg_tile_info(int tile_index)
+{
+	int data = videoram16[tile_index];
+	int color = (data >> 13) & 7;
+	SET_TILE_INFO(2, data & 0x3ff, color, TILE_FLIPYX((data >> 11) & 3));
+	tile_info.priority = (color != 0);
+}
+
+
+
+/*************************************
+ *
+ *  Video startup
+ *
+ *************************************/
+
+VIDEO_START( mcr68 )
+{
+	/* initialize the background tilemap */
+	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows, TILEMAP_TRANSPARENT, 16,16, 32,32);
+	if (!bg_tilemap)
+		return 1;
+	tilemap_set_transparent_pen(bg_tilemap, 0);
+	return 0;
+}
+
+
+VIDEO_START( zwackery )
+{
+	/* initialize the background tilemap */
+	bg_tilemap = tilemap_create(zwackery_get_bg_tile_info, tilemap_scan_rows, TILEMAP_OPAQUE, 16,16, 32,32);
+	if (!bg_tilemap)
+		return 1;
+
+	/* initialize the foreground tilemap */
+	fg_tilemap = tilemap_create(zwackery_get_fg_tile_info, tilemap_scan_rows, TILEMAP_TRANSPARENT, 16,16, 32,32);
+	if (!fg_tilemap)
+		return 1;
+	tilemap_set_transparent_pen(fg_tilemap, 0);
+
+	return 0;
+}
+
+
+
+/*************************************
+ *
+ *  Zwackery color data conversion
+ *
+ *************************************/
+
+PALETTE_INIT( zwackery )
+{
+	const UINT8 *colordatabase = (const UINT8 *)memory_region(REGION_GFX3);
+	gfx_element *gfx0 = Machine->gfx[0];
+	gfx_element *gfx2 = Machine->gfx[2];
+	int code, y, x;
+
+	/* "colorize" each code */
+	for (code = 0; code < gfx0->total_elements; code++)
+	{
+		const UINT8 *coldata = colordatabase + code * 32;
+		UINT8 *gfxdata0 = gfx0->gfxdata + code * gfx0->char_modulo;
+		UINT8 *gfxdata2 = gfx2->gfxdata + code * gfx2->char_modulo;
+
+		/* assume 16 rows */
+		for (y = 0; y < 16; y++)
+		{
+			UINT8 *gd0 = gfxdata0;
+			UINT8 *gd2 = gfxdata2;
+
+			/* 16 columns */
+			for (x = 0; x < 16; x++, gd0++, gd2++)
+			{
+				int coloffs = (y & 0x0c) | ((x >> 2) & 0x03);
+				int pen0 = coldata[coloffs * 2 + 0];
+				int pen1 = coldata[coloffs * 2 + 1];
+				int tp0, tp1;
+
+				/* every 4 pixels gets its own foreground/background colors */
+				*gd0 = *gd0 ? pen1 : pen0;
+
+				/* for gfx 2, we convert all low-priority pens to 0 */
+				tp0 = (pen0 & 0x80) ? pen0 : 0;
+				tp1 = (pen1 & 0x80) ? pen1 : 0;
+				*gd2 = *gd2 ? tp1 : tp0;
+			}
+
+			/* advance */
+			gfxdata0 += gfx0->line_modulo;
+			gfxdata2 += gfx2->line_modulo;
+		}
+	}
+}
+
+
+
+/*************************************
+ *
+ *  Palette RAM writes
  *
  *************************************/
 
@@ -47,174 +168,6 @@ WRITE16_HANDLER( mcr68_paletteram_w )
 }
 
 
-
-/*************************************
- *
- *	Video RAM writes
- *
- *************************************/
-
-WRITE16_HANDLER( mcr68_videoram_w )
-{
-	int oldword = videoram16[offset];
-	int newword = oldword;
-	COMBINE_DATA(&newword);
-
-	if (oldword != newword)
-	{
-		dirtybuffer[offset & ~1] = 1;
-		videoram16[offset] = newword;
-	}
-}
-
-
-
-/*************************************
- *
- *	Background update
- *
- *************************************/
-
-static void mcr68_update_background(struct mame_bitmap *bitmap, int overrender)
-{
-	int offs;
-
-	/* for every character in the Video RAM, check if it has been modified */
-	/* since last time and update it accordingly. */
-	for (offs = (videoram_size / 2) - 2; offs >= 0; offs -= 2)
-	{
-		/* this works for overrendering as well, since the sprite code will mark */
-		/* intersecting tiles for us */
-		if (dirtybuffer[offs])
-		{
-			int mx = (offs / 2) % 32;
-			int my = (offs / 2) / 32;
-			int attr = LOW_BYTE(videoram16[offs + 1]);
-			int color = (attr & 0x30) >> 4;
-			int code = LOW_BYTE(videoram16[offs]) + 256 * (attr & 0x03) + 1024 * ((attr >> 6) & 0x03);
-
-			if (!overrender)
-				drawgfx(bitmap, Machine->gfx[0], code, color ^ 3, attr & 0x04, attr & 0x08,
-						16 * mx, 16 * my, &Machine->visible_area, TRANSPARENCY_NONE, 0);
-			else if (Machine->gfx[0]->total_elements < 0x1000 && (attr & 0x80))
-				drawgfx(bitmap, Machine->gfx[0], code, color ^ 3, attr & 0x04, attr & 0x08,
-						16 * mx, 16 * my, &Machine->visible_area, TRANSPARENCY_PEN, 0);
-			else
-				continue;
-
-			/* only clear the dirty flag if we're not overrendering */
-			dirtybuffer[offs] = 0;
-		}
-	}
-}
-
-
-
-/*************************************
- *
- *	Sprite update
- *
- *************************************/
-
-static void mcr68_update_sprites(struct mame_bitmap *bitmap, int priority)
-{
-	struct rectangle sprite_clip = Machine->visible_area;
-	int offs;
-
-	/* adjust for clipping */
-	sprite_clip.min_x += mcr68_sprite_clip;
-	sprite_clip.max_x -= mcr68_sprite_clip;
-
-	fillbitmap(priority_bitmap,1,NULL);
-
-	/* loop over sprite RAM */
-	for (offs = spriteram_size / 2 - 4;offs >= 0;offs -= 4)
-	{
-		int code, color, flipx, flipy, x, y, sx, sy, xcount, ycount, flags;
-
-		flags = LOW_BYTE(spriteram16[offs + 1]);
-		code = LOW_BYTE(spriteram16[offs + 2]) + 256 * ((flags >> 3) & 0x01) + 512 * ((flags >> 6) & 0x03);
-
-		/* skip if zero */
-		if (code == 0)
-			continue;
-
-		/* also skip if this isn't the priority we're drawing right now */
-		if (((flags >> 2) & 1) != priority)
-			continue;
-
-		/* extract the bits of information */
-		color = ~flags & 0x03;
-		flipx = flags & 0x10;
-		flipy = flags & 0x20;
-		x = LOW_BYTE(spriteram16[offs + 3]) * 2 + mcr68_sprite_xoffset;
-		y = (241 - LOW_BYTE(spriteram16[offs])) * 2;
-
-		/* allow sprites to clip off the left side */
-		if (x > 0x1f0) x -= 0x200;
-
-		/* sprites use color 0 for background pen and 8 for the 'under tile' pen.
-			The color 8 is used to cover over other sprites. */
-
-		/* first draw the sprite, visible */
-		pdrawgfx(bitmap, Machine->gfx[1], code, color, flipx, flipy, x, y,
-				&sprite_clip, TRANSPARENCY_PENS, 0x0101, 0x00);
-
-		/* then draw the mask, behind the background but obscuring following sprites */
-		pdrawgfx(bitmap, Machine->gfx[1], code, color, flipx, flipy, x, y,
-				&sprite_clip, TRANSPARENCY_PENS, 0xfeff, 0x02);
-
-
-		/* mark tiles underneath as dirty for overrendering */
-		if (priority == 0)
-		{
-			sx = x / 16;
-			sy = y / 16;
-			xcount = (x & 15) ? 3 : 2;
-			ycount = (y & 15) ? 3 : 2;
-
-			for (y = sy; y < sy + ycount; y++)
-				for (x = sx; x < sx + xcount; x++)
-					if (x >= 0 && x < 32 && y >= 0 && y < 30)
-						dirtybuffer[(32 * y + x) * 2] = 1;
-		}
-	}
-}
-
-
-
-/*************************************
- *
- *	General MCR/68k update
- *
- *************************************/
-
-void mcr68_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
-{
-	/* draw the background */
-	mcr68_update_background(tmpbitmap, 0);
-
-	/* copy it to the destination */
-	copybitmap(bitmap, tmpbitmap, 0, 0, 0, 0, &Machine->visible_area, TRANSPARENCY_NONE, 0);
-
-	/* draw the low-priority sprites */
-	mcr68_update_sprites(bitmap, 0);
-
-    /* redraw tiles with priority over sprites */
-	mcr68_update_background(bitmap, 1);
-
-	/* draw the high-priority sprites */
-	mcr68_update_sprites(bitmap, 1);
-}
-
-
-
-/*************************************
- *
- *	Zwackery palette RAM writes
- *
- *************************************/
-
 WRITE16_HANDLER( zwackery_paletteram_w )
 {
 	int newword, r, g, b;
@@ -238,30 +191,24 @@ WRITE16_HANDLER( zwackery_paletteram_w )
 
 /*************************************
  *
- *	Zwackery video RAM writes
+ *  Video RAM writes
  *
  *************************************/
 
-WRITE16_HANDLER( zwackery_videoram_w )
+WRITE16_HANDLER( mcr68_videoram_w )
 {
-	int oldword = videoram16[offset];
-	int newword = oldword;
-	COMBINE_DATA(&newword);
-
-	if (oldword != newword)
-	{
-		dirtybuffer[offset] = 1;
-		videoram16[offset] = newword;
-	}
+	COMBINE_DATA(&videoram16[offset]);
+	tilemap_mark_tile_dirty(bg_tilemap, offset / 2);
 }
 
 
+WRITE16_HANDLER( zwackery_videoram_w )
+{
+	COMBINE_DATA(&videoram16[offset]);
+	tilemap_mark_tile_dirty(bg_tilemap, offset);
+	tilemap_mark_tile_dirty(fg_tilemap, offset);
+}
 
-/*************************************
- *
- *	Zwackery video RAM writes
- *
- *************************************/
 
 WRITE16_HANDLER( zwackery_spriteram_w )
 {
@@ -275,119 +222,72 @@ WRITE16_HANDLER( zwackery_spriteram_w )
 
 /*************************************
  *
- *	Zwackery color data conversion
+ *  Sprite update
  *
  *************************************/
 
-void zwackery_convert_color_prom(unsigned char *palette, unsigned short *colortable, const unsigned char *color_prom)
-{
-	const UINT8 *colordatabase = (const UINT8 *)memory_region(REGION_GFX3);
-	struct GfxElement *gfx0 = Machine->gfx[0];
-	struct GfxElement *gfx2 = Machine->gfx[2];
-	int code, y, x, ix;
-
-	/* "colorize" each code */
-	for (code = 0; code < gfx0->total_elements; code++)
-	{
-		const UINT8 *coldata = colordatabase + code * 32;
-		UINT8 *gfxdata0 = gfx0->gfxdata + code * gfx0->char_modulo;
-		UINT8 *gfxdata2 = gfx2->gfxdata + code * gfx2->char_modulo;
-
-		/* assume 16 rows */
-		for (y = 0; y < 16; y++)
-		{
-			const UINT8 *cd = coldata;
-			UINT8 *gd0 = gfxdata0;
-			UINT8 *gd2 = gfxdata2;
-
-			/* 16 colums, in batches of 4 pixels */
-			for (x = 0; x < 16; x += 4)
-			{
-				int pen0 = *cd++;
-				int pen1 = *cd++;
-				int tp0, tp1;
-
-				/* every 4 pixels gets its own foreground/background colors */
-				for (ix = 0; ix < 4; ix++, gd0++)
-					*gd0 = *gd0 ? pen1 : pen0;
-
-				/* for gfx 2, we convert all low-priority pens to 0 */
-				tp0 = (pen0 & 0x80) ? pen0 : 0;
-				tp1 = (pen1 & 0x80) ? pen1 : 0;
-				for (ix = 0; ix < 4; ix++, gd2++)
-					*gd2 = *gd2 ? tp1 : tp0;
-			}
-
-			/* advance */
-			if (y % 4 == 3) coldata = cd;
-			gfxdata0 += gfx0->line_modulo;
-			gfxdata2 += gfx2->line_modulo;
-		}
-	}
-}
-
-
-
-/*************************************
- *
- *	Zwackery background update
- *
- *************************************/
-
-static void zwackery_update_background(struct mame_bitmap *bitmap, int overrender)
+static void mcr68_update_sprites(mame_bitmap *bitmap, const rectangle *cliprect, int priority)
 {
+	rectangle sprite_clip = Machine->visible_area;
 	int offs;
 
-	/* for every character in the Video RAM, check if it has been modified */
-	/* since last time and update it accordingly. */
-	for (offs = (videoram_size / 2) - 1; offs >= 0; offs--)
-	{
-		/* this works for overrendering as well, since the sprite code will mark */
-		/* intersecting tiles for us */
-		if (dirtybuffer[offs])
-		{
-			int data = videoram16[offs];
-			int mx = offs % 32;
-			int my = offs / 32;
-			int color = (data >> 13) & 7;
-			int code = data & 0x3ff;
+	/* adjust for clipping */
+	sprite_clip.min_x += mcr68_sprite_clip;
+	sprite_clip.max_x -= mcr68_sprite_clip;
+	sect_rect(&sprite_clip, cliprect);
 
-			/* standard case: draw with no transparency */
-			if (!overrender)
-				drawgfx(bitmap, Machine->gfx[0], code, color, data & 0x0800, data & 0x1000,
-						16 * mx, 16 * my, &Machine->visible_area, TRANSPARENCY_NONE, 0);
-
-			/* overrender case: for non-zero colors, draw with transparency pen 0 */
-			/* we use gfx[2] here, which was generated above to have all low-priority */
-			/* colors set to pen 0 */
-			else if (color != 0)
-				drawgfx(bitmap, Machine->gfx[2], code, color, data & 0x0800, data & 0x1000,
-						16 * mx, 16 * my, &Machine->visible_area, TRANSPARENCY_PEN, 0);
-
-			/* only clear the dirty flag if we're not overrendering */
-			dirtybuffer[offs] = 0;
-		}
-	}
-}
-
-
-
-/*************************************
- *
- *	Sprite update
- *
- *************************************/
-
-static void zwackery_update_sprites(struct mame_bitmap *bitmap, int priority)
-{
-	int offs;
-
-	fillbitmap(priority_bitmap,1,NULL);
+	fillbitmap(priority_bitmap,1,&sprite_clip);
 
 	/* loop over sprite RAM */
 	for (offs = spriteram_size / 2 - 4;offs >= 0;offs -= 4)
 	{
-		int code, color, flipx, flipy, x, y, sx, sy, xcount, ycount, flags;
+		int code, color, flipx, flipy, x, y, flags;
+
+		flags = LOW_BYTE(spriteram16[offs + 1]);
+		code = LOW_BYTE(spriteram16[offs + 2]) + 256 * ((flags >> 3) & 0x01) + 512 * ((flags >> 6) & 0x03);
+
+		/* skip if zero */
+		if (code == 0)
+			continue;
+
+		/* also skip if this isn't the priority we're drawing right now */
+		if (((flags >> 2) & 1) != priority)
+			continue;
+
+		/* extract the bits of information */
+		color = ~flags & 0x03;
+		flipx = flags & 0x10;
+		flipy = flags & 0x20;
+		x = LOW_BYTE(spriteram16[offs + 3]) * 2 + mcr68_sprite_xoffset;
+		y = (241 - LOW_BYTE(spriteram16[offs])) * 2;
+
+		/* allow sprites to clip off the left side */
+		if (x > 0x1f0) x -= 0x200;
+
+		/* sprites use color 0 for background pen and 8 for the 'under tile' pen.
+            The color 8 is used to cover over other sprites. */
+
+		/* first draw the sprite, visible */
+		pdrawgfx(bitmap, Machine->gfx[1], code, color, flipx, flipy, x, y,
+				&sprite_clip, TRANSPARENCY_PENS, 0x0101, 0x00);
+
+		/* then draw the mask, behind the background but obscuring following sprites */
+		pdrawgfx(bitmap, Machine->gfx[1], code, color, flipx, flipy, x, y,
+				&sprite_clip, TRANSPARENCY_PENS, 0xfeff, 0x02);
+	}
+}
+
+
+static void zwackery_update_sprites(mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+{
+	int offs;
+
+	fillbitmap(priority_bitmap,1,cliprect);
+
+	/* loop over sprite RAM */
+	for (offs = spriteram_size / 2 - 4;offs >= 0;offs -= 4)
+	{
+		int code, color, flipx, flipy, x, y, flags;
 
 		/* get the code and skip if zero */
 		code = LOW_BYTE(spriteram16[offs + 2]);
@@ -421,29 +321,15 @@ static void zwackery_update_sprites(struct mame_bitmap *bitmap, int priority)
 		if (x <= -32) x += 512;
 
 		/* sprites use color 0 for background pen and 8 for the 'under tile' pen.
-			The color 8 is used to cover over other sprites. */
+            The color 8 is used to cover over other sprites. */
 
 		/* first draw the sprite, visible */
 		pdrawgfx(bitmap, Machine->gfx[1], code, color, flipx, flipy, x, y,
-				&Machine->visible_area, TRANSPARENCY_PENS, 0x0101, 0x00);
+				cliprect, TRANSPARENCY_PENS, 0x0101, 0x00);
 
 		/* then draw the mask, behind the background but obscuring following sprites */
 		pdrawgfx(bitmap, Machine->gfx[1], code, color, flipx, flipy, x, y,
-				&Machine->visible_area, TRANSPARENCY_PENS, 0xfeff, 0x02);
-
-
-		/* mark tiles underneath as dirty for overrendering */
-		if (priority == 0)
-		{
-			sx = x / 16;
-			sy = y / 16;
-			xcount = (x & 15) ? 3 : 2;
-			ycount = (y & 15) ? 3 : 2;
-
-			for (y = sy; y < sy + ycount; y++)
-				for (x = sx; x < sx + xcount; x++)
-					dirtybuffer[32 * (y & 31) + (x & 31)] = 1;
-		}
+				cliprect, TRANSPARENCY_PENS, 0xfeff, 0x02);
 	}
 }
 
@@ -451,24 +337,38 @@ static void zwackery_update_sprites(struct mame_bitmap *bitmap, int priority)
 
 /*************************************
  *
- *	Zwackery MCR/68k update
+ *  General MCR/68k update
  *
  *************************************/
 
-void zwackery_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( mcr68 )
 {
 	/* draw the background */
-	zwackery_update_background(tmpbitmap, 0);
-
-	/* copy it to the destination */
-	copybitmap(bitmap, tmpbitmap, 0, 0, 0, 0, &Machine->visible_area, TRANSPARENCY_NONE, 0);
+	tilemap_draw(bitmap, cliprect, bg_tilemap, TILEMAP_IGNORE_TRANSPARENCY | 0, 0);
+	tilemap_draw(bitmap, cliprect, bg_tilemap, TILEMAP_IGNORE_TRANSPARENCY | 1, 0);
 
 	/* draw the low-priority sprites */
-	zwackery_update_sprites(bitmap, 0);
+	mcr68_update_sprites(bitmap, cliprect, 0);
 
-	/* draw the background */
-	zwackery_update_background(bitmap, 1);
+    /* redraw tiles with priority over sprites */
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 1, 0);
 
 	/* draw the high-priority sprites */
-	zwackery_update_sprites(bitmap, 1);
+	mcr68_update_sprites(bitmap, cliprect, 1);
+}
+
+
+VIDEO_UPDATE( zwackery )
+{
+	/* draw the background */
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
+
+	/* draw the low-priority sprites */
+	zwackery_update_sprites(bitmap, cliprect, 0);
+
+    /* redraw tiles with priority over sprites */
+	tilemap_draw(bitmap, cliprect, fg_tilemap, 1, 0);
+
+	/* draw the high-priority sprites */
+	zwackery_update_sprites(bitmap, cliprect, 1);
 }
