@@ -4,77 +4,77 @@ Momoko 120% (c) 1986 Jaleco
 
 Video hardware driver by Uki
 
-	02/Mar/2001 -
+    02/Mar/2001 -
 
 *******************************************************************************/
 
 #include "vidhrdw/generic.h"
 
-data8_t *momoko_bg_scrollx;
-data8_t *momoko_bg_scrolly;
-data8_t momoko_fg_scrollx;
-data8_t momoko_fg_scrolly;
-data8_t momoko_fg_select;
-data8_t momoko_text_scrolly;
-data8_t momoko_text_mode;
-data8_t momoko_bg_select;
-data8_t momoko_bg_priority;
-data8_t momoko_bg_mask;
-data8_t momoko_fg_mask;
-data8_t momoko_flipscreen;
+UINT8 *momoko_bg_scrollx;
+UINT8 *momoko_bg_scrolly;
+UINT8 momoko_fg_scrollx;
+UINT8 momoko_fg_scrolly;
+UINT8 momoko_fg_select;
+UINT8 momoko_text_scrolly;
+UINT8 momoko_text_mode;
+UINT8 momoko_bg_select;
+UINT8 momoko_bg_priority;
+UINT8 momoko_bg_mask;
+UINT8 momoko_fg_mask;
+UINT8 momoko_flipscreen;
 
 /****************************************************************************/
 
-WRITE_HANDLER ( momoko_fg_scrollx_w )
+WRITE8_HANDLER ( momoko_fg_scrollx_w )
 {
 	momoko_fg_scrollx = data;
 }
-WRITE_HANDLER ( momoko_fg_scrolly_w )
+WRITE8_HANDLER ( momoko_fg_scrolly_w )
 {
 	momoko_fg_scrolly = data;
 }
-WRITE_HANDLER ( momoko_fg_select_w )
+WRITE8_HANDLER ( momoko_fg_select_w )
 {
 	momoko_fg_select = data & 0x0f;
 	momoko_fg_mask = data & 0x10;
 }
-WRITE_HANDLER ( momoko_text_scrolly_w )
+WRITE8_HANDLER ( momoko_text_scrolly_w )
 {
 	momoko_text_scrolly = data;
 }
-WRITE_HANDLER ( momoko_text_mode_w )
+WRITE8_HANDLER ( momoko_text_mode_w )
 {
 	momoko_text_mode = data;
 }
-WRITE_HANDLER ( momoko_bg_scrollx_w )
+WRITE8_HANDLER ( momoko_bg_scrollx_w )
 {
 	momoko_bg_scrollx[ offset ] = data;
 }
-WRITE_HANDLER ( momoko_bg_scrolly_w )
+WRITE8_HANDLER ( momoko_bg_scrolly_w )
 {
 	momoko_bg_scrolly[ offset ] = data;
 }
-WRITE_HANDLER( momoko_bg_select_w )
+WRITE8_HANDLER( momoko_bg_select_w )
 {
 	momoko_bg_select = data & 0x0f;
 	momoko_bg_mask = data & 0x10;
 }
-WRITE_HANDLER( momoko_bg_priority_w )
+WRITE8_HANDLER( momoko_bg_priority_w )
 {
 	momoko_bg_priority = data & 0x01;
 }
-WRITE_HANDLER( momoko_flipscreen_w )
+WRITE8_HANDLER( momoko_flipscreen_w )
 {
 	momoko_flipscreen = data & 0x01;
 }
 /****************************************************************************/
 
-void momoko_draw_bg_pri(struct mame_bitmap *bitmap, int chr, int col, int flipx, int flipy, int x,int y, int pri)
+void momoko_draw_bg_pri(mame_bitmap *bitmap, int chr, int col, int flipx, int flipy, int x,int y, int pri)
 {
 	int xx,sx,sy,px,py,dot;
-	data32_t gfxadr;
-	data8_t d0, d1;
-	data8_t *BG_GFX = memory_region( REGION_GFX2 );
+	UINT32 gfxadr;
+	UINT8 d0, d1;
+	UINT8 *BG_GFX = memory_region( REGION_GFX2 );
 	for (sy=0; sy<8; sy++)
 	{
 		gfxadr = chr*16 + sy*2;
@@ -101,14 +101,14 @@ void momoko_draw_bg_pri(struct mame_bitmap *bitmap, int chr, int col, int flipx,
 
 /****************************************************************************/
 
-void momoko_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( momoko )
 {
 	int x, y, dx, dy, rx, ry, radr, chr, sy, fx, fy, px, py, offs, col, pri, flip ;
 
-	data8_t *BG_MAP     = memory_region( REGION_USER1 );
-	data8_t *BG_COL_MAP = memory_region( REGION_USER2 );
-	data8_t *FG_MAP     = memory_region( REGION_USER3 );
-	data8_t *TEXT_COLOR = memory_region( REGION_PROMS );
+	UINT8 *BG_MAP     = memory_region( REGION_USER1 );
+	UINT8 *BG_COL_MAP = memory_region( REGION_USER2 );
+	UINT8 *FG_MAP     = memory_region( REGION_USER3 );
+	UINT8 *TEXT_COLOR = memory_region( REGION_PROMS );
 
 
 	flip = momoko_flipscreen ^ (readinputport(4) & 0x01);
