@@ -66,14 +66,188 @@ static int high_tile;
 static int vhigh_tile;
 static int vvhigh_tile;
 static int no_of_tiles;
-static int palette_swap_pending;
 static int fix_bank;
 
 
 static UINT8 *memory_region_gfx4;
 static UINT8 *memory_region_gfx3;
 
+void neogeo_set_lower_resolution( void )
+{
+	/* the neogeo has a display resolution of 320 pixels wide,
+      however, a large amount of the software produced for the
+      system expects the visible display width to be 304 pixels
+      and displays garbage in the left and right most 8 pixel
+      columns.
 
+      this function changes the resolution of the games known
+      to display garbage, thus hiding it.  this is done here
+      as not to misrepresent the real neogeo resolution in the
+      data output from MAME
+
+      I don't like to do this, but I don't like the idea of the
+      bug reports we'd get if we didn't
+    */
+
+	if (!strcmp(Machine->gamedrv->name,"nam1975") ||
+		!strcmp(Machine->gamedrv->name,"tpgolf") ||
+		!strcmp(Machine->gamedrv->name,"mahretsu") ||
+		!strcmp(Machine->gamedrv->name,"ridhero") ||
+		!strcmp(Machine->gamedrv->name,"ridheroh") ||
+		!strcmp(Machine->gamedrv->name,"alpham2") ||
+		!strcmp(Machine->gamedrv->name,"cyberlip") ||
+		!strcmp(Machine->gamedrv->name,"superspy") ||
+		!strcmp(Machine->gamedrv->name,"mutnat") ||
+		!strcmp(Machine->gamedrv->name,"kotm") ||
+		!strcmp(Machine->gamedrv->name,"kotmh") ||
+		!strcmp(Machine->gamedrv->name,"burningf") ||
+		!strcmp(Machine->gamedrv->name,"burningh") ||
+		!strcmp(Machine->gamedrv->name,"lbowling") ||
+		!strcmp(Machine->gamedrv->name,"gpilots") ||
+		!strcmp(Machine->gamedrv->name,"joyjoy") ||
+		!strcmp(Machine->gamedrv->name,"quizdais") ||
+		!strcmp(Machine->gamedrv->name,"lresort") ||
+		!strcmp(Machine->gamedrv->name,"legendos") ||
+		!strcmp(Machine->gamedrv->name,"2020bb") ||
+		!strcmp(Machine->gamedrv->name,"2020bba") ||
+		!strcmp(Machine->gamedrv->name,"2020bbh") ||
+		!strcmp(Machine->gamedrv->name,"socbrawl") ||
+		!strcmp(Machine->gamedrv->name,"roboarmy") ||
+		!strcmp(Machine->gamedrv->name,"roboarma") ||
+		!strcmp(Machine->gamedrv->name,"fbfrenzy") ||
+		!strcmp(Machine->gamedrv->name,"kotm2") ||
+		!strcmp(Machine->gamedrv->name,"sengoku2") ||
+		!strcmp(Machine->gamedrv->name,"bstars2") ||
+		!strcmp(Machine->gamedrv->name,"aof") ||
+		!strcmp(Machine->gamedrv->name,"ssideki") ||
+		!strcmp(Machine->gamedrv->name,"kof94") ||
+		!strcmp(Machine->gamedrv->name,"aof2") ||
+		!strcmp(Machine->gamedrv->name,"aof2a") ||
+		!strcmp(Machine->gamedrv->name,"savagere") ||
+		!strcmp(Machine->gamedrv->name,"kof95") ||
+		!strcmp(Machine->gamedrv->name,"kof95a") ||
+		!strcmp(Machine->gamedrv->name,"samsho3") ||
+		!strcmp(Machine->gamedrv->name,"samsho3a") ||
+		!strcmp(Machine->gamedrv->name,"aof3") ||
+		!strcmp(Machine->gamedrv->name,"kof96") ||
+		!strcmp(Machine->gamedrv->name,"kof96h") ||
+		!strcmp(Machine->gamedrv->name,"kizuna") ||
+		!strcmp(Machine->gamedrv->name,"kof97") ||
+		!strcmp(Machine->gamedrv->name,"kof97a") ||
+		!strcmp(Machine->gamedrv->name,"kof97pls") ||
+		!strcmp(Machine->gamedrv->name,"kog") ||
+		!strcmp(Machine->gamedrv->name,"irrmaze") ||
+		!strcmp(Machine->gamedrv->name,"mslug2") ||
+		!strcmp(Machine->gamedrv->name,"kof98") ||
+		!strcmp(Machine->gamedrv->name,"kof98k") ||
+		!strcmp(Machine->gamedrv->name,"kof98n") ||
+		!strcmp(Machine->gamedrv->name,"mslugx") ||
+		!strcmp(Machine->gamedrv->name,"kof99") ||
+		!strcmp(Machine->gamedrv->name,"kof99a") ||
+		!strcmp(Machine->gamedrv->name,"kof99e") ||
+		!strcmp(Machine->gamedrv->name,"kof99n") ||
+		!strcmp(Machine->gamedrv->name,"kof99p") ||
+		!strcmp(Machine->gamedrv->name,"mslug3") ||
+		!strcmp(Machine->gamedrv->name,"mslug3n") ||
+		!strcmp(Machine->gamedrv->name,"kof2000") ||
+		!strcmp(Machine->gamedrv->name,"kof2000n") ||
+		!strcmp(Machine->gamedrv->name,"zupapa") ||
+		!strcmp(Machine->gamedrv->name,"kof2001") ||
+		!strcmp(Machine->gamedrv->name,"kof2001h") ||
+		!strcmp(Machine->gamedrv->name,"cthd2003") ||
+		!strcmp(Machine->gamedrv->name,"ct2k3sp") ||
+		!strcmp(Machine->gamedrv->name,"kof2002") ||
+		!strcmp(Machine->gamedrv->name,"kf2k2pls") ||
+		!strcmp(Machine->gamedrv->name,"kf2k2pla") ||
+		!strcmp(Machine->gamedrv->name,"kf2k2mp") ||
+		!strcmp(Machine->gamedrv->name,"kf2k2mp2") ||
+		!strcmp(Machine->gamedrv->name,"kof10th") ||
+		!strcmp(Machine->gamedrv->name,"kf2k5uni") ||
+		!strcmp(Machine->gamedrv->name,"kf10thep") ||
+		!strcmp(Machine->gamedrv->name,"kof2k4se") ||
+		!strcmp(Machine->gamedrv->name,"mslug5") ||
+		!strcmp(Machine->gamedrv->name,"ms5plus") ||
+		!strcmp(Machine->gamedrv->name,"svcpcb") ||
+		!strcmp(Machine->gamedrv->name,"svc") ||
+		!strcmp(Machine->gamedrv->name,"svcboot") ||
+		!strcmp(Machine->gamedrv->name,"svcplus") ||
+		!strcmp(Machine->gamedrv->name,"svcplusa") ||
+		!strcmp(Machine->gamedrv->name,"svcsplus") ||
+		!strcmp(Machine->gamedrv->name,"samsho5") ||
+		!strcmp(Machine->gamedrv->name,"samsho5h") ||
+		!strcmp(Machine->gamedrv->name,"samsho5b") ||
+		!strcmp(Machine->gamedrv->name,"kf2k3pcb") ||
+		!strcmp(Machine->gamedrv->name,"kof2003") ||
+		!strcmp(Machine->gamedrv->name,"kf2k3bl") ||
+		!strcmp(Machine->gamedrv->name,"kf2k3bla") ||
+		!strcmp(Machine->gamedrv->name,"kf2k3pl") ||
+		!strcmp(Machine->gamedrv->name,"kf2k3upl") ||
+		!strcmp(Machine->gamedrv->name,"samsh5sp") ||
+		!strcmp(Machine->gamedrv->name,"samsh5sh") ||
+		!strcmp(Machine->gamedrv->name,"samsh5sn") ||
+		!strcmp(Machine->gamedrv->name,"ncombat") ||
+		!strcmp(Machine->gamedrv->name,"ncombata") ||
+		!strcmp(Machine->gamedrv->name,"crsword") ||
+		!strcmp(Machine->gamedrv->name,"ncommand") ||
+		!strcmp(Machine->gamedrv->name,"wh2") ||
+		!strcmp(Machine->gamedrv->name,"wh2j") ||
+		!strcmp(Machine->gamedrv->name,"aodk") ||
+		!strcmp(Machine->gamedrv->name,"mosyougi") ||
+		!strcmp(Machine->gamedrv->name,"overtop") ||
+		!strcmp(Machine->gamedrv->name,"twinspri") ||
+		!strcmp(Machine->gamedrv->name,"zintrckb") ||
+		!strcmp(Machine->gamedrv->name,"spinmast") ||
+		!strcmp(Machine->gamedrv->name,"wjammers") ||
+		!strcmp(Machine->gamedrv->name,"karnovr") ||
+		!strcmp(Machine->gamedrv->name,"strhoop") ||
+		!strcmp(Machine->gamedrv->name,"ghostlop") ||
+		!strcmp(Machine->gamedrv->name,"magdrop2") ||
+		!strcmp(Machine->gamedrv->name,"magdrop3") ||
+		!strcmp(Machine->gamedrv->name,"gururin") ||
+		!strcmp(Machine->gamedrv->name,"miexchng") ||
+		!strcmp(Machine->gamedrv->name,"panicbom") ||
+		!strcmp(Machine->gamedrv->name,"neobombe") ||
+		!strcmp(Machine->gamedrv->name,"minasan") ||
+		!strcmp(Machine->gamedrv->name,"bakatono") ||
+		!strcmp(Machine->gamedrv->name,"turfmast") ||
+		!strcmp(Machine->gamedrv->name,"mslug") ||
+		!strcmp(Machine->gamedrv->name,"zedblade") ||
+		!strcmp(Machine->gamedrv->name,"viewpoin") ||
+		!strcmp(Machine->gamedrv->name,"quizkof") ||
+		!strcmp(Machine->gamedrv->name,"pgoal") ||
+		!strcmp(Machine->gamedrv->name,"shocktro") ||
+		!strcmp(Machine->gamedrv->name,"shocktra") ||
+		!strcmp(Machine->gamedrv->name,"shocktr2") ||
+		!strcmp(Machine->gamedrv->name,"lans2004") ||
+		!strcmp(Machine->gamedrv->name,"galaxyfg") ||
+		!strcmp(Machine->gamedrv->name,"wakuwak7") ||
+		!strcmp(Machine->gamedrv->name,"pbobbl2n") ||
+		!strcmp(Machine->gamedrv->name,"pnyaa") ||
+		!strcmp(Machine->gamedrv->name,"marukodq") ||
+		!strcmp(Machine->gamedrv->name,"gowcaizr") ||
+		!strcmp(Machine->gamedrv->name,"sdodgeb") ||
+		!strcmp(Machine->gamedrv->name,"tws96") ||
+		!strcmp(Machine->gamedrv->name,"preisle2") ||
+		!strcmp(Machine->gamedrv->name,"fightfev") ||
+		!strcmp(Machine->gamedrv->name,"fightfva") ||
+		!strcmp(Machine->gamedrv->name,"popbounc") ||
+		!strcmp(Machine->gamedrv->name,"androdun") ||
+		!strcmp(Machine->gamedrv->name,"puzzledp") ||
+		!strcmp(Machine->gamedrv->name,"neomrdo") ||
+		!strcmp(Machine->gamedrv->name,"goalx3") ||
+		!strcmp(Machine->gamedrv->name,"neodrift") ||
+		!strcmp(Machine->gamedrv->name,"puzzldpr") ||
+		!strcmp(Machine->gamedrv->name,"flipshot") ||
+		!strcmp(Machine->gamedrv->name,"ctomaday") ||
+		!strcmp(Machine->gamedrv->name,"ganryu") ||
+		!strcmp(Machine->gamedrv->name,"bangbead") ||
+		!strcmp(Machine->gamedrv->name,"mslug4") ||
+		!strcmp(Machine->gamedrv->name,"ms4plus") ||
+		!strcmp(Machine->gamedrv->name,"jockeygp") ||
+		!strcmp(Machine->gamedrv->name,"vliner") ||
+		!strcmp(Machine->gamedrv->name,"vlinero"))
+				set_visible_area(1*8,39*8-1,Machine->visible_area.min_y,Machine->visible_area.max_y);
+}
 
 extern unsigned int neogeo_frame_counter;
 
@@ -149,7 +323,6 @@ static void set_palettebank_on_postload(void)
 static void register_savestate(void)
 {
 	state_save_register_int   ("video", 0, "neogeo_palette_index",    &neogeo_palette_index);
-	state_save_register_int   ("video", 0, "palette_swap_pending",    &palette_swap_pending);
 	state_save_register_UINT16("video", 0, "neogeo_palettebank[0]",   neogeo_palettebank[0],    0x2000/2);
 	state_save_register_UINT16("video", 0, "neogeo_palettebank[1]",   neogeo_palettebank[1],    0x2000/2);
 	state_save_register_UINT16("video", 0, "neogeo_vidram16",         neogeo_vidram16,          0x20000/2);
@@ -174,17 +347,11 @@ VIDEO_START( neogeo_mvs )
 	neogeo_vidram16 = NULL;
 
 	neogeo_palettebank[0] = auto_malloc(0x2000);
-	if (!neogeo_palettebank[0])
-		return 1;
 
 	neogeo_palettebank[1] = auto_malloc(0x2000);
-	if (!neogeo_palettebank[1])
-		return 1;
 
 	/* 0x20000 bytes even though only 0x10c00 is used */
 	neogeo_vidram16 = auto_malloc(0x20000);
-	if (!neogeo_vidram16)
-		return 1;
 	memset(neogeo_vidram16,0,0x20000);
 
 	neogeo_paletteram16 = neogeo_palettebank[0];
@@ -192,12 +359,11 @@ VIDEO_START( neogeo_mvs )
 	neogeo_vidram16_modulo = 1;
 	neogeo_vidram16_offset = 0;
 	fix_bank = 0;
-	palette_swap_pending = 0;
 
 	memory_region_gfx4  = memory_region(REGION_GFX4);
 	memory_region_gfx3  = memory_region(REGION_GFX3);
 
-
+	neogeo_set_lower_resolution();
 	register_savestate();
 
 	return 0;
@@ -224,8 +390,6 @@ static void swap_palettes(void)
 
 		palette_set_color(i, r, g, b);
 	}
-
-	palette_swap_pending = 0;
 }
 
 static void neogeo_setpalbank(int n)
@@ -234,7 +398,7 @@ static void neogeo_setpalbank(int n)
 	{
 		neogeo_palette_index = n;
 		neogeo_paletteram16 = neogeo_palettebank[n];
-		palette_swap_pending = 1;
+		swap_palettes();
 	}
 }
 
@@ -452,156 +616,110 @@ static void NeoMVSDrawGfxLine(UINT16 **line,const gfx_element *gfx,
 
 /******************************************************************************/
 
-VIDEO_UPDATE( neogeo )
+
+static void neogeo_draw_sprite( int my, int sx, int sy, int zx, int zy, int offs, int fullmode, UINT16 **line, const rectangle *cliprect, int scanline )
 {
-	int sx =0,sy =0,my =0,zx = 0x0f, zy = 0xff;
-	int offs,count;
-	int tileno,tileatr,t1,t2,t3;
-	char fullmode = 0;
-	void **line=bitmap->line;
-	unsigned int *pen_usage;
+	int drawn_lines = 0;
+	UINT8 *zoomy_rom;
+	int tileno,tileatr;
+	int min_spriteline;
+	int max_spriteline;
+	int tile,yoffs;
+	int zoom_line;
+	int invert=0;
 	gfx_element *gfx=Machine->gfx[2]; /* Save constant struct dereference */
+	zoomy_rom = memory_region_gfx4 + (zy << 8);
 
-profiler_mark(PROFILER_VIDEO);
+	/* the maximum value for my is 0x200 */
+	min_spriteline = sy & 0x1ff;
+	max_spriteline = (sy + my*0x10)&0x1ff;
 
-	/* Palette swap occured after last frame but before this one */
-	if (palette_swap_pending) swap_palettes();
-
-	fillbitmap(bitmap,Machine->pens[4095],cliprect);
-
-	/* Draw sprites */
-	for (count = 0; count < 0x300 >> 1; count++)
+	/* work out if we need to draw the sprite on this scanline */
+	/******* CHECK THE LOGIC HERE, NOT WELL TESTED */
+	if (my == 0x20)
 	{
-		UINT8 *zoomy_rom;
-		int drawn_lines;
+		/* if its a full strip we obviously want to draw */
+		drawn_lines = (scanline - min_spriteline)&0x1ff;
+	}
+	else if (min_spriteline < max_spriteline)
+	{
+		/* if the minimum is lower than the maximum we draw anytihng between the two */
 
-		t3 = neogeo_vidram16[(0x10000 >> 1) + count];
-		t1 = neogeo_vidram16[(0x10400 >> 1) + count];
+		if ((scanline >=min_spriteline) && (scanline < max_spriteline))
+			drawn_lines = (scanline - min_spriteline)&0x1ff;
+		else
+			return; /* outside of sprite */
 
+	}
+	else if (min_spriteline > max_spriteline)
+	{
+		/* if the minimum is higher than the maxium it has wrapped so we draw anything outside outside the two */
+		if ( (scanline < max_spriteline) || (scanline >= min_spriteline) )
+			drawn_lines = (scanline - min_spriteline)&0x1ff; /* check! */
+		else
+			return; /* outside of sprite */
+	}
+	else
+	{
+		return; /* outside of sprite */
+	}
 
-		/* If this bit is set this new column is placed next to last one */
-		if (t1 & 0x40)
+	zoom_line = drawn_lines & 0xff;
+	if (drawn_lines & 0x100)
+	{
+		zoom_line ^= 0xff;
+		invert = 1;
+	}
+	if (fullmode)	/* fix for joyjoy, trally... */
+	{
+		if (zy)
 		{
-			sx += zx+1;
-			if ( sx >= 0x1F0 )
-				sx -= 0x200;
-
-			/* Get new zoom for this column */
-			zx = (t3 >> 8) & 0x0f;
-		}
-		else /* nope it is a new block */
-		{
-			/* Sprite scaling */
-			t2 = neogeo_vidram16[(0x10800 >> 1) + count];
-			zx = (t3 >> 8) & 0x0f;
-			zy = t3 & 0xff;
-
-			sx = (t2 >> 7);
-			if ( sx >= 0x1F0 )
-				sx -= 0x200;
-
-			/* Number of tiles in this strip */
-			my = t1 & 0x3f;
-
-			sy = 0x200 - (t1 >> 7);
-
-			if (my > 0x20)
+			zoom_line %= 2*(zy+1);	/* fixed */
+			if (zoom_line >= (zy+1))	/* fixed */
 			{
-				my = 0x20;
-
-				/*if (sy < 248) */
-					fullmode = 1;
-				/*else */
-				/*     kludge to avoid a white line in KOF94 Japan stage...    */
-				/*     probably indication of a subtle bug somewhere else    */
-				/*  fullmode = 0; */
+				zoom_line = 2*(zy+1)-1 - zoom_line;	/* fixed */
+				invert ^= 1;
 			}
-			else
-				fullmode = 0;
 		}
+	}
 
-		/* No point doing anything if tile strip is 0 */
-		if (my==0) continue;
+	yoffs = zoomy_rom[zoom_line] & 0x0f;
+	tile = zoomy_rom[zoom_line] >> 4;
+	if (invert)
+	{
+		tile ^= 0x1f;
+		yoffs ^= 0x0f;
+	}
 
-		if (sx >= 320)
-			continue;
+	tileno	= neogeo_vidram16[offs+2*tile];
+	tileatr = neogeo_vidram16[offs+2*tile+1];
 
-		offs = count<<6;
+	if (  high_tile && (tileatr & 0x10)) tileno+=0x10000;
+	if ( vhigh_tile && (tileatr & 0x20)) tileno+=0x20000;
+	if (vvhigh_tile && (tileatr & 0x40)) tileno+=0x40000;
 
-		/* get pointer to table in zoom ROM (thanks to Miguel Angel Horna for the info) */
-		zoomy_rom = memory_region_gfx4 + (zy << 8);
-		drawn_lines = 0;
+	if (tileatr & 0x08) tileno=(tileno&~7)|(neogeo_frame_counter&7);	/* fixed */
+	else if (tileatr & 0x04) tileno=(tileno&~3)|(neogeo_frame_counter&3);	/* fixed */
 
-		/* my holds the number of tiles in each vertical multisprite block */
-		while (drawn_lines < my*0x10)
-		{
-			int yy = (sy + drawn_lines) & 0x1ff;
+	if (tileatr & 0x02) yoffs ^= 0x0f;	/* flip y */
 
-			if (yy >= cliprect->min_y && yy <= cliprect->max_y)
-			{
-				int tile,yoffs;
-				int zoom_line;
-				int invert=0;
-
-				zoom_line = drawn_lines & 0xff;
-				if (drawn_lines & 0x100)
-				{
-					zoom_line ^= 0xff;
-					invert = 1;
-				}
-				if (fullmode)	/* fix for joyjoy, trally... */
-				{
-					if (zy)
-					{
-						zoom_line %= 2*(zy+1);	/* fixed */
-						if (zoom_line >= (zy+1))	/* fixed */
-						{
-							zoom_line = 2*(zy+1)-1 - zoom_line;	/* fixed */
-							invert ^= 1;
-						}
-					}
-				}
-
-				yoffs = zoomy_rom[zoom_line] & 0x0f;
-
-				tile = zoomy_rom[zoom_line] >> 4;
-
-				if (invert)
-				{
-					tile ^= 0x1f;
-					yoffs ^= 0x0f;
-				}
-
-				tileno	= neogeo_vidram16[offs+2*tile];
-				tileatr = neogeo_vidram16[offs+2*tile+1];
-
-				if (  high_tile && (tileatr & 0x10)) tileno+=0x10000;
-				if ( vhigh_tile && (tileatr & 0x20)) tileno+=0x20000;
-				if (vvhigh_tile && (tileatr & 0x40)) tileno+=0x40000;
-
-				if (tileatr & 0x08) tileno=(tileno&~7)|(neogeo_frame_counter&7);	/* fixed */
-				else if (tileatr & 0x04) tileno=(tileno&~3)|(neogeo_frame_counter&3);	/* fixed */
-
-				if (tileatr & 0x02) yoffs ^= 0x0f;	/* flip y */
-
-				NeoMVSDrawGfxLine((UINT16 **)line,
-					gfx,
-					tileno,
-					tileatr >> 8,
-					tileatr & 0x01,	/* flip x */
-					sx,yy,zx,yoffs,
-					cliprect
-				);
-			}
-
-			drawn_lines++;
-		}  /* for y */
-	}  /* for count */
+	NeoMVSDrawGfxLine((UINT16 **)line,
+			gfx,
+			tileno,
+			tileatr >> 8,
+			tileatr & 0x01,	/* flip x */
+			sx,scanline,zx,yoffs,
+			cliprect
+		);
 
+}
 
+static void neogeo_draw_s_layer(mame_bitmap *bitmap, const rectangle *cliprect)
+{
+	unsigned int *pen_usage;
+	gfx_element *gfx=Machine->gfx[fix_bank]; /* Save constant struct dereference */
 
 	/* Save some struct de-refs */
-	gfx = Machine->gfx[fix_bank];
 	pen_usage=gfx->pen_usage;
 
 	/* Character foreground */
@@ -688,5 +806,76 @@ profiler_mark(PROFILER_VIDEO);
 		} /* Not banked */
 	}
 
-profiler_mark(PROFILER_END);
+}
+
+VIDEO_UPDATE( neogeo )
+{
+	int sx =0,sy =0,my =0,zx = 0x0f, zy = 0xff;
+	int count;
+	int offs;
+	int t1,t2,t3;
+	char fullmode = 0;
+	void **line=bitmap->line;
+	int scan;
+
+	fillbitmap(bitmap,Machine->pens[4095],cliprect);
+
+	for (scan = cliprect->min_y; scan <= cliprect->max_y ; scan++)
+	{
+
+		/* Process Sprite List */
+		for (count = 0; count < 0x300 >> 1; count++)
+		{
+
+			t3 = neogeo_vidram16[(0x10000 >> 1) + count];
+			t1 = neogeo_vidram16[(0x10400 >> 1) + count];
+
+
+			/* If this bit is set this new column is placed next to last one */
+			if (t1 & 0x40)
+			{
+				sx += zx+1;
+				if ( sx >= 0x1F0 )
+					sx -= 0x200;
+
+				/* Get new zoom for this column */
+				zx = (t3 >> 8) & 0x0f;
+			}
+			else /* nope it is a new block */
+			{
+				/* Sprite scaling */
+				t2 = neogeo_vidram16[(0x10800 >> 1) + count];
+				zx = (t3 >> 8) & 0x0f;
+				zy = t3 & 0xff;
+
+				sx = (t2 >> 7);
+				if ( sx >= 0x1F0 )
+					sx -= 0x200;
+
+				/* Number of tiles in this strip */
+				my = t1 & 0x3f;
+
+				sy = 0x200 - (t1 >> 7);
+
+				if (my > 0x20)
+				{
+					my = 0x20;
+					fullmode = 1;
+				}
+				else
+					fullmode = 0;
+			}
+
+			/* No point doing anything if tile strip is 0 */
+			if (my==0) continue;
+
+			if (sx >= 320)
+				continue;
+
+			offs = count<<6;
+
+			neogeo_draw_sprite( my, sx, sy, zx, zy, offs, fullmode, (UINT16 **)line, cliprect, scan );
+		}  /* for count */
+	}
+	neogeo_draw_s_layer(bitmap,cliprect);
 }
