@@ -5,8 +5,7 @@
 
 #define TC0100SCN_GFX_NUM 1
 
-void othunder_vh_stop(void);
-data16_t *othunder_ram;
+UINT16 *othunder_ram;
 
 struct tempsprite
 {
@@ -21,99 +20,58 @@ static struct tempsprite *spritelist;
 
 static int taito_hide_pixels;
 
+
+
 /**********************************************************/
 
-static int has_TC0110PCR(void)
-{
-	const struct Memory_WriteAddress16 *mwa;
-
-	/* scan the memory handlers and see if the TC0110PCR is used */
-
-	mwa = Machine->drv->cpu[0].memory_write;
-	if (mwa)
-	{
-		while (!IS_MEMPORT_END(mwa))
-		{
-			if (!IS_MEMPORT_MARKER(mwa))
-			{
-				if (mwa->handler == TC0110PCR_step1_rbswap_word_w)
-					return 1;
-			}
-			mwa++;
-		}
-	}
-
-	return 0;
-}
-
-
-static int othunder_core_vh_start (void)
+static VIDEO_START( othunder_core )
 {
 	/* Up to $800/8 big sprites, requires 0x100 * sizeof(*spritelist)
-	   Multiply this by 32 to give room for the number of small sprites,
-	   which are what actually get put in the structure. */
+       Multiply this by 32 to give room for the number of small sprites,
+       which are what actually get put in the structure. */
 
-	spritelist = malloc(0x2000 * sizeof(*spritelist));
-	if (!spritelist)
-		return 1;
+	spritelist = auto_malloc(0x2000 * sizeof(*spritelist));
 
 	if (TC0100SCN_vh_start(1,TC0100SCN_GFX_NUM,taito_hide_pixels,0,0,0,0,0,0))
-	{
-		othunder_vh_stop();
 		return 1;
-	}
 
 	if (has_TC0110PCR())
 		if (TC0110PCR_vh_start())
-		{
-			othunder_vh_stop();
 			return 1;
-		}
 
 	return 0;
 }
 
-int othunder_vh_start (void)
+VIDEO_START( othunder )
 {
 	/* There is a problem here. 4 is correct for text layer/sprite
-	   alignment, but the bg layers [or one of them] are wrong */
+       alignment, but the bg layers [or one of them] are wrong */
 
 	taito_hide_pixels = 4;
-	return (othunder_core_vh_start());
-}
-
-void othunder_vh_stop (void)
-{
-	free(spritelist);
-	spritelist = 0;
-
-	TC0100SCN_vh_stop();
-
-	if (has_TC0110PCR())
-		TC0110PCR_vh_stop();
+	return video_start_othunder_core();
 }
 
 
 /************************************************************
-			SPRITE DRAW ROUTINE
+            SPRITE DRAW ROUTINE
 
 It draws a series of small tiles ("chunks") together to
 create a big sprite. The spritemap rom provides the lookup
 table for this. We look up the 16x8 sprite chunks from
 the spritemap rom, creating each 64x64 sprite as follows:
 
-	 0  1  2  3
-	 4  5  6  7
-	 8  9 10 11
-	12 13 14 15
-	16 17 18 19
-	20 21 22 23
-	24 25 26 27
-	28 29 30 31
+     0  1  2  3
+     4  5  6  7
+     8  9 10 11
+    12 13 14 15
+    16 17 18 19
+    20 21 22 23
+    24 25 26 27
+    28 29 30 31
 
 The game makes heavy use of sprite zooming.
 
-		***
+        ***
 
 NB: unused portions of the spritemap rom contain hex FF's.
 It is a useful coding check to warn in the log if these
@@ -121,32 +79,32 @@ are being accessed. [They can be inadvertently while
 spriteram is being tested, take no notice of that.]
 
 
-		Othunder (modified table from Raine)
+        Othunder (modified table from Raine)
 
-		Byte | Bit(s) | Description
-		-----+76543210+-------------------------------------
-		  0  |xxxxxxx.| ZoomY (0 min, 63 max - msb unused as sprites are 64x64)
-		  0  |.......x| Y position (High)
-		  1  |xxxxxxxx| Y position (Low)
-		  2  |x.......| Sprite/BG Priority (0=sprites high)
-		  2  |.x......| Flip X
-		  2  |..?????.| unknown/unused ?
-		  2  |.......x| X position (High)
-		  3  |xxxxxxxx| X position (Low)
-		  4  |xxxxxxxx| Palette bank
-		  5  |?.......| unknown/unused ?
-		  5  |.xxxxxxx| ZoomX (0 min, 63 max - msb unused as sprites are 64x64)
-		  6  |x.......| Flip Y
-		  6  |.??.....| unknown/unused ?
-		  6  |...xxxxx| Sprite Tile high (2 msbs unused - 3/4 of spritemap rom empty)
-		  7  |xxxxxxxx| Sprite Tile low
+        Byte | Bit(s) | Description
+        -----+76543210+-------------------------------------
+          0  |xxxxxxx.| ZoomY (0 min, 63 max - msb unused as sprites are 64x64)
+          0  |.......x| Y position (High)
+          1  |xxxxxxxx| Y position (Low)
+          2  |x.......| Sprite/BG Priority (0=sprites high)
+          2  |.x......| Flip X
+          2  |..?????.| unknown/unused ?
+          2  |.......x| X position (High)
+          3  |xxxxxxxx| X position (Low)
+          4  |xxxxxxxx| Palette bank
+          5  |?.......| unknown/unused ?
+          5  |.xxxxxxx| ZoomX (0 min, 63 max - msb unused as sprites are 64x64)
+          6  |x.......| Flip Y
+          6  |.??.....| unknown/unused ?
+          6  |...xxxxx| Sprite Tile high (2 msbs unused - 3/4 of spritemap rom empty)
+          7  |xxxxxxxx| Sprite Tile low
 
 ********************************************************/
 
 
-static void othunder_draw_sprites_16x8(struct mame_bitmap *bitmap,int *primasks,int y_offs)
+static void othunder_draw_sprites_16x8(mame_bitmap *bitmap,const rectangle *cliprect,const int *primasks,int y_offs)
 {
-	data16_t *spritemap = (data16_t *)memory_region(REGION_USER1);
+	UINT16 *spritemap = (UINT16 *)memory_region(REGION_USER1);
 	UINT16 tile_mask = (Machine->gfx[0]->total_elements) - 1;
 	int offs, data, tilenum, color, flipx, flipy;
 	int x, y, priority, curx, cury;
@@ -156,7 +114,7 @@ static void othunder_draw_sprites_16x8(struct mame_bitmap *bitmap,int *primasks,
 	int bad_chunks;
 
 	/* pdrawgfx() needs us to draw sprites front to back, so we have to build a list
-	   while processing sprite ram and then draw them all at the end */
+       while processing sprite ram and then draw them all at the end */
 	struct tempsprite *sprite_ptr = spritelist;
 
 	for (offs = (spriteram_size/2)-4;offs >=0;offs -= 4)
@@ -220,8 +178,8 @@ static void othunder_draw_sprites_16x8(struct mame_bitmap *bitmap,int *primasks,
 			if (sprites_flipscreen)
 			{
 				/* -zx/y is there to fix zoomed sprite coords in screenflip.
-				   drawgfxzoom does not know to draw from flip-side of sprites when
-				   screen is flipped; so we must correct the coords ourselves. */
+                   drawgfxzoom does not know to draw from flip-side of sprites when
+                   screen is flipped; so we must correct the coords ourselves. */
 
 				curx = 320 - curx - zx;
 				cury = 256 - cury - zy;
@@ -250,7 +208,7 @@ static void othunder_draw_sprites_16x8(struct mame_bitmap *bitmap,int *primasks,
 						sprite_ptr->color,
 						sprite_ptr->flipx,sprite_ptr->flipy,
 						sprite_ptr->x,sprite_ptr->y,
-						&Machine->visible_area,TRANSPARENCY_PEN,0,
+						cliprect,TRANSPARENCY_PEN,0,
 						sprite_ptr->zoomx,sprite_ptr->zoomy);
 			}
 		}
@@ -269,7 +227,7 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 				sprite_ptr->color,
 				sprite_ptr->flipx,sprite_ptr->flipy,
 				sprite_ptr->x,sprite_ptr->y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0,
+				cliprect,TRANSPARENCY_PEN,0,
 				sprite_ptr->zoomx,sprite_ptr->zoomy,
 				sprite_ptr->primask);
 	}
@@ -277,10 +235,10 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 
 
 /**************************************************************
-				SCREEN REFRESH
+                SCREEN REFRESH
 **************************************************************/
 
-void othunder_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( othunder )
 {
 	int layer[3];
 
@@ -290,24 +248,22 @@ void othunder_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	layer[1] = layer[0]^1;
 	layer[2] = 2;
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
 	/* Ensure screen blanked even when bottom layer not drawn due to disable bit */
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
+	fillbitmap(bitmap, Machine->pens[0], cliprect);
 
-	TC0100SCN_tilemap_draw(bitmap,0,layer[0],TILEMAP_IGNORE_TRANSPARENCY,1);
-	TC0100SCN_tilemap_draw(bitmap,0,layer[1],0,2);
-	TC0100SCN_tilemap_draw(bitmap,0,layer[2],0,4);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,layer[0],TILEMAP_IGNORE_TRANSPARENCY,1);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,layer[1],0,2);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,layer[2],0,4);
 
 	/* Sprites can be under/over the layer below text layer */
 	{
-		int primasks[2] = {0xf0,0xfc};
-		othunder_draw_sprites_16x8(bitmap,primasks,3);
+		static const int primasks[2] = {0xf0,0xfc};
+		othunder_draw_sprites_16x8(bitmap,cliprect,primasks,3);
 	}
 
-	/* See if we should draw artificial gun targets */
-
-	if (input_port_9_word_r(0,0) & 0x1)	/* Fake DSW */
+	/* Draw artificial gun targets */
 	{
 		int rawx, rawy, centrex, centrey, screenx, screeny;
 
@@ -352,7 +308,7 @@ void othunder_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		screeny += 2;
 
 		/* player 1 */
-		draw_crosshair(bitmap,screenx,screeny,&Machine->visible_area);
+		draw_crosshair(bitmap,screenx,screeny,cliprect,0);
 
 		/* calculate p2 screen co-ords by matching routine at $AA48 */
 		rawx = othunder_ram[0x284c/2];
@@ -395,7 +351,7 @@ void othunder_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		screeny += 2;
 
 		/* player 2 */
-		draw_crosshair(bitmap,screenx,screeny,&Machine->visible_area);
+		draw_crosshair(bitmap,screenx,screeny,cliprect,1);
 	}
 }
 
