@@ -98,14 +98,14 @@ void ppu2c03b_init_palette( int first_entry ) {
 	double hue = 332.0;
 	double bright_adjust = 1.0;
 
-	double brightness[3][4] =
+	static const double brightness[3][4] =
 	{
 		{ 0.50, 0.75, 1.0, 1.0 },
 		{ 0.29, 0.45, 0.73, 0.9 },
 		{ 0, 0.24, 0.47, 0.77 }
 	};
 
-	double angle[16] = { 0, 240, 210, 180, 150, 120, 90, 60, 30, 0, 330, 300, 270, 0, 0, 0 };
+	static const double angle[16] = { 0, 240, 210, 180, 150, 120, 90, 60, 30, 0, 330, 300, 270, 0, 0, 0 };
 
 	/* loop through the 4 intensities */
 	for (i = 0; i < 4; i++)
@@ -201,9 +201,6 @@ int ppu2c03b_init( struct ppu2c03b_interface *interface )
 
 	chips = auto_malloc( intf->num * sizeof( ppu2c03b_chip ) );
 
-	if ( chips == 0 )
-		return -1;
-
 	/* intialize our virtual chips */
 	for( i = 0; i < intf->num; i++ )
 	{
@@ -220,7 +217,7 @@ int ppu2c03b_init( struct ppu2c03b_interface *interface )
 		chips[i].colortable_mono = auto_malloc( sizeof( default_colortable_mono ) );
 
 		/* see if it failed */
-		if ( !chips[i].bitmap || !chips[i].videoram || !chips[i].spriteram || !chips[i].dirtychar || !chips[i].colortable_mono )
+		if ( !chips[i].bitmap )
 			return -1;
 
 		/* clear videoram & spriteram */
@@ -253,7 +250,8 @@ int ppu2c03b_init( struct ppu2c03b_interface *interface )
 		/* now create the gfx region */
 		{
 			UINT8 *src = chips[i].has_videorom ? memory_region( intf->vrom_region[i] ) : chips[i].videoram;
-			Machine->gfx[intf->gfx_layout_number[i]] = decodegfx( src, &ppu_charlayout );
+			Machine->gfx[intf->gfx_layout_number[i]] = allocgfx( &ppu_charlayout );
+			decodegfx( Machine->gfx[intf->gfx_layout_number[i]], src, 0, Machine->gfx[intf->gfx_layout_number[i]]->total_elements );
 
 			if ( Machine->gfx[intf->gfx_layout_number[i]] == 0 )
 				return -1;
