@@ -29,21 +29,21 @@ unsigned char *punchout_bigsprite1;
 unsigned char *punchout_bigsprite2;
 unsigned char *punchout_palettebank;
 static unsigned char *dirtybuffer2,*bs1dirtybuffer,*bs2dirtybuffer;
-static struct mame_bitmap *bs1tmpbitmap,*bs2tmpbitmap;
+static mame_bitmap *bs1tmpbitmap,*bs2tmpbitmap;
 
 static int top_palette_bank,bottom_palette_bank;
 
-static struct rectangle topvisiblearea =
+static rectangle topvisiblearea =
 {
 	0*8, 32*8-1,
 	0*8, TOP_MONITOR_ROWS*8-1
 };
-static struct rectangle bottomvisiblearea =
+static rectangle bottomvisiblearea =
 {
 	0*8, 32*8-1,
 	TOP_MONITOR_ROWS*8, (TOP_MONITOR_ROWS+BOTTOM_MONITOR_ROWS)*8-1
 };
-static struct rectangle backgroundvisiblearea =
+static rectangle backgroundvisiblearea =
 {
 	0*8, 64*8-1,
 	TOP_MONITOR_ROWS*8, (TOP_MONITOR_ROWS+BOTTOM_MONITOR_ROWS)*8-1
@@ -65,54 +65,53 @@ static struct rectangle backgroundvisiblearea =
   bit 0 -- 2  kohm resistor -- inverter  -- RED/GREEN/BLUE
 
 ***************************************************************************/
-static void convert_palette(unsigned char *palette,const unsigned char *color_prom)
+static void convert_palette(const unsigned char *color_prom)
 {
 	int i;
 
 
 	for (i = 0;i < 1024;i++)
 	{
-		int bit0,bit1,bit2,bit3;
+		int bit0,bit1,bit2,bit3,r,g,b;
 
 
 		bit0 = (color_prom[0] >> 0) & 0x01;
 		bit1 = (color_prom[0] >> 1) & 0x01;
 		bit2 = (color_prom[0] >> 2) & 0x01;
 		bit3 = (color_prom[0] >> 3) & 0x01;
-		*(palette++) = 255 - (0x10 * bit0 + 0x21 * bit1 + 0x46 * bit2 + 0x88 * bit3);
+		r = 255 - (0x10 * bit0 + 0x21 * bit1 + 0x46 * bit2 + 0x88 * bit3);
 		bit0 = (color_prom[1024] >> 0) & 0x01;
 		bit1 = (color_prom[1024] >> 1) & 0x01;
 		bit2 = (color_prom[1024] >> 2) & 0x01;
 		bit3 = (color_prom[1024] >> 3) & 0x01;
-		*(palette++) = 255 - (0x10 * bit0 + 0x21 * bit1 + 0x46 * bit2 + 0x88 * bit3);
+		g = 255 - (0x10 * bit0 + 0x21 * bit1 + 0x46 * bit2 + 0x88 * bit3);
 		bit0 = (color_prom[2*1024] >> 0) & 0x01;
 		bit1 = (color_prom[2*1024] >> 1) & 0x01;
 		bit2 = (color_prom[2*1024] >> 2) & 0x01;
 		bit3 = (color_prom[2*1024] >> 3) & 0x01;
-		*(palette++) = 255 - (0x10 * bit0 + 0x21 * bit1 + 0x46 * bit2 + 0x88 * bit3);
+		b = 255 - (0x10 * bit0 + 0x21 * bit1 + 0x46 * bit2 + 0x88 * bit3);
 
+		palette_set_color(i,r,g,b);
 		color_prom++;
 	}
 
 	/* reserve the last color for the transparent pen (none of the game colors has */
 	/* these RGB components) */
-	*(palette++) = 240;
-	*(palette++) = 240;
-	*(palette++) = 240;
+	palette_set_color(1024,240,240,240);
 }
 
 
 /* these depend on jumpers on the board and change from game to game */
 static int gfx0inv,gfx1inv,gfx2inv,gfx3inv;
 
-void punchout_vh_convert_color_prom(unsigned char *palette,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( punchout )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
 	#define COLOR(gfxn,offs) (colortable[Machine->drv->gfxdecodeinfo[gfxn].color_codes_start + (offs)])
 
 
-	convert_palette(palette,color_prom);
+	convert_palette(color_prom);
 
 
 	/* top monitor chars */
@@ -138,14 +137,14 @@ void punchout_vh_convert_color_prom(unsigned char *palette,unsigned short *color
 	}
 }
 
-void armwrest_vh_convert_color_prom(unsigned char *palette,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( armwrest )
 {
 	int i;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
 	#define COLOR(gfxn,offs) (colortable[Machine->drv->gfxdecodeinfo[gfxn].color_codes_start + (offs)])
 
 
-	convert_palette(palette,color_prom);
+	convert_palette(color_prom);
 
 
 	/* top monitor / bottom monitor backround chars */
@@ -180,7 +179,7 @@ static void gfx_fix(void)
 	memset(memory_region(REGION_GFX3) + 0x2c000,0xff,0x4000);
 }
 
-void init_punchout(void)
+DRIVER_INIT( punchout )
 {
 	gfx_fix();
 
@@ -190,7 +189,7 @@ void init_punchout(void)
 	gfx3inv = 0xfc;
 }
 
-void init_spnchout(void)
+DRIVER_INIT( spnchout )
 {
 	gfx_fix();
 
@@ -200,7 +199,7 @@ void init_spnchout(void)
 	gfx3inv = 0xff;
 }
 
-void init_spnchotj(void)
+DRIVER_INIT( spnchotj )
 {
 	gfx_fix();
 
@@ -210,7 +209,7 @@ void init_spnchotj(void)
 	gfx3inv = 0xff;
 }
 
-void init_armwrest(void)
+DRIVER_INIT( armwrest )
 {
 	gfx_fix();
 
@@ -227,153 +226,61 @@ void init_armwrest(void)
   Start the video hardware emulation.
 
 ***************************************************************************/
-int punchout_vh_start(void)
+VIDEO_START( punchout )
 {
-	if ((dirtybuffer = malloc(videoram_size)) == 0)
-		return 1;
+	dirtybuffer = auto_malloc(videoram_size);
 	memset(dirtybuffer,1,videoram_size);
 
-	if ((dirtybuffer2 = malloc(punchout_videoram2_size)) == 0)
-	{
-		free(dirtybuffer);
-		return 1;
-	}
+	dirtybuffer2 = auto_malloc(punchout_videoram2_size);
 	memset(dirtybuffer2,1,punchout_videoram2_size);
 
-	if ((tmpbitmap = bitmap_alloc(512,480)) == 0)
-	{
-		free(dirtybuffer);
-		free(dirtybuffer2);
+	if ((tmpbitmap = auto_bitmap_alloc(512,480)) == 0)
 		return 1;
-	}
 
-	if ((bs1dirtybuffer = malloc(punchout_bigsprite1ram_size)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		return 1;
-	}
+	bs1dirtybuffer = auto_malloc(punchout_bigsprite1ram_size);
 	memset(bs1dirtybuffer,1,punchout_bigsprite1ram_size);
 
-	if ((bs1tmpbitmap = bitmap_alloc(BIGSPRITE_WIDTH,BIGSPRITE_HEIGHT)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		free(bs1dirtybuffer);
+	if ((bs1tmpbitmap = auto_bitmap_alloc(BIGSPRITE_WIDTH,BIGSPRITE_HEIGHT)) == 0)
 		return 1;
-	}
 
-	if ((bs2dirtybuffer = malloc(punchout_bigsprite2ram_size)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		bitmap_free(bs1tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		free(bs1dirtybuffer);
-		return 1;
-	}
+	bs2dirtybuffer = auto_malloc(punchout_bigsprite2ram_size);
 	memset(bs2dirtybuffer,1,punchout_bigsprite2ram_size);
 
-	if ((bs2tmpbitmap = bitmap_alloc(BIGSPRITE_WIDTH,BIGSPRITE_HEIGHT)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		bitmap_free(bs1tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		free(bs1dirtybuffer);
-		free(bs2dirtybuffer);
+	if ((bs2tmpbitmap = auto_bitmap_alloc(BIGSPRITE_WIDTH,BIGSPRITE_HEIGHT)) == 0)
 		return 1;
-	}
 
 	return 0;
 }
 
-int armwrest_vh_start(void)
+VIDEO_START( armwrest )
 {
-	if ((dirtybuffer = malloc(videoram_size)) == 0)
-		return 1;
+	dirtybuffer = auto_malloc(videoram_size);
 	memset(dirtybuffer,1,videoram_size);
 
-	if ((dirtybuffer2 = malloc(punchout_videoram2_size)) == 0)
-	{
-		free(dirtybuffer);
-		return 1;
-	}
+	dirtybuffer2 = auto_malloc(punchout_videoram2_size);
 	memset(dirtybuffer2,1,punchout_videoram2_size);
 
-	if ((tmpbitmap = bitmap_alloc(512,480)) == 0)
-	{
-		free(dirtybuffer);
-		free(dirtybuffer2);
+	if ((tmpbitmap = auto_bitmap_alloc(512,480)) == 0)
 		return 1;
-	}
 
-	if ((bs1dirtybuffer = malloc(punchout_bigsprite1ram_size)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		return 1;
-	}
+	bs1dirtybuffer = auto_malloc(punchout_bigsprite1ram_size);
 	memset(bs1dirtybuffer,1,punchout_bigsprite1ram_size);
 
-	if ((bs1tmpbitmap = bitmap_alloc(ARMWREST_BIGSPRITE_WIDTH,ARMWREST_BIGSPRITE_HEIGHT)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		free(bs1dirtybuffer);
+	if ((bs1tmpbitmap = auto_bitmap_alloc(ARMWREST_BIGSPRITE_WIDTH,ARMWREST_BIGSPRITE_HEIGHT)) == 0)
 		return 1;
-	}
 
-	if ((bs2dirtybuffer = malloc(punchout_bigsprite2ram_size)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		bitmap_free(bs1tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		free(bs1dirtybuffer);
-		return 1;
-	}
+	bs2dirtybuffer = auto_malloc(punchout_bigsprite2ram_size);
 	memset(bs2dirtybuffer,1,punchout_bigsprite2ram_size);
 
-	if ((bs2tmpbitmap = bitmap_alloc(BIGSPRITE_WIDTH,BIGSPRITE_HEIGHT)) == 0)
-	{
-		bitmap_free(tmpbitmap);
-		bitmap_free(bs1tmpbitmap);
-		free(dirtybuffer);
-		free(dirtybuffer2);
-		free(bs1dirtybuffer);
-		free(bs2dirtybuffer);
+	if ((bs2tmpbitmap = auto_bitmap_alloc(BIGSPRITE_WIDTH,BIGSPRITE_HEIGHT)) == 0)
 		return 1;
-	}
 
 	return 0;
 }
 
 
 
-/***************************************************************************
-
-  Stop the video hardware emulation.
-
-***************************************************************************/
-void punchout_vh_stop(void)
-{
-	free(dirtybuffer);
-	free(dirtybuffer2);
-	free(bs1dirtybuffer);
-	free(bs2dirtybuffer);
-	bitmap_free(tmpbitmap);
-	bitmap_free(bs1tmpbitmap);
-	bitmap_free(bs2tmpbitmap);
-}
-
-
-
-WRITE_HANDLER( punchout_videoram2_w )
+WRITE8_HANDLER( punchout_videoram2_w )
 {
 	if (punchout_videoram2[offset] != data)
 	{
@@ -383,7 +290,7 @@ WRITE_HANDLER( punchout_videoram2_w )
 	}
 }
 
-WRITE_HANDLER( punchout_bigsprite1ram_w )
+WRITE8_HANDLER( punchout_bigsprite1ram_w )
 {
 	if (punchout_bigsprite1ram[offset] != data)
 	{
@@ -393,7 +300,7 @@ WRITE_HANDLER( punchout_bigsprite1ram_w )
 	}
 }
 
-WRITE_HANDLER( punchout_bigsprite2ram_w )
+WRITE8_HANDLER( punchout_bigsprite2ram_w )
 {
 	if (punchout_bigsprite2ram[offset] != data)
 	{
@@ -405,7 +312,7 @@ WRITE_HANDLER( punchout_bigsprite2ram_w )
 
 
 
-WRITE_HANDLER( punchout_palettebank_w )
+WRITE8_HANDLER( punchout_palettebank_w )
 {
 	*punchout_palettebank = data;
 
@@ -432,7 +339,7 @@ WRITE_HANDLER( punchout_palettebank_w )
   the main emulation engine.
 
 ***************************************************************************/
-void punchout_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( punchout )
 {
 	int offs;
 
@@ -611,7 +518,7 @@ void punchout_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void armwrest_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( armwrest )
 {
 	int offs;
 
@@ -752,7 +659,7 @@ void armwrest_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 			if (punchout_bigsprite1[7] & 2)	/* display in bottom monitor */
 			{
 				copyrozbitmap(bitmap,bs1tmpbitmap,
-					startx,starty - 0x200*TOP_MONITOR_ROWS * zoom,
+					startx,starty - 0x200*(TOP_MONITOR_ROWS-2) * zoom,
 					incxx,0,0,incyy,	/* zoom, no rotation */
 					0,	/* no wraparound */
 					&bottomvisiblearea,TRANSPARENCY_COLOR,1024,0);
