@@ -1,8 +1,8 @@
 /***************************************************************************
 
-	Taito Qix hardware
+    Taito Qix hardware
 
-	driver by John Butler, Ed Mueller, Aaron Giles
+    driver by John Butler, Ed Mueller, Aaron Giles
 
 ***************************************************************************/
 
@@ -16,49 +16,26 @@
 
 
 /* Globals */
-UINT8 *qix_palettebank;
 UINT8 *qix_videoaddress;
 UINT8 qix_cocktail_flip;
 
 
 /* Local variables */
 static UINT8 vram_mask;
-static UINT8 *videoram_cache;
-static UINT8 *palette_cache;
-
+static UINT8 qix_palettebank;
+static int leds;
 
 
 /*************************************
  *
- *	Video startup
+ *  Video startup
  *
  *************************************/
 
-int qix_vh_start(void)
+VIDEO_START( qix )
 {
 	/* allocate memory for the full video RAM */
-	videoram = malloc(256 * 256);
-	if (!videoram)
-		return 1;
-
-	/* allocate memory for the cached video RAM */
-	videoram_cache = malloc(256 * 256);
-	if (!videoram_cache)
-	{
-		free(videoram);
-		videoram = NULL;
-		return 1;
-	}
-
-	/* allocate memory for the cached palette banks */
-	palette_cache = malloc(256 * sizeof(palette_cache[0]));
-	if (!palette_cache)
-	{
-		free(videoram_cache);
-		free(videoram);
-		videoram = videoram_cache = NULL;
-		return 1;
-	}
+	videoram = auto_malloc(256 * 256);
 
 	/* initialize the mask for games that don't use it */
 	vram_mask = 0xff;
@@ -69,55 +46,14 @@ int qix_vh_start(void)
 
 /*************************************
  *
- *	Video shutdown
- *
- *************************************/
-
-void qix_vh_stop(void)
-{
-	/* free memory */
-	free(palette_cache);
-	free(videoram_cache);
-	free(videoram);
-
-	/* reset the pointers */
-	videoram = videoram_cache = NULL;
-	palette_cache = NULL;
-}
-
-
-
-/*************************************
- *
- *	Scanline caching
+ *  Scanline caching
  *
  *************************************/
 
 void qix_scanline_callback(int scanline)
 {
-	/* for non-zero scanlines, cache the previous data and the palette bank */
-	if (scanline != 0)
-	{
-		int offset = (scanline - SCANLINE_INCREMENT) * 256;
-		int count = SCANLINE_INCREMENT * 256;
-		UINT8 *src, *dst = &videoram_cache[offset];
-
-		/* copy the data forwards or backwards, based on the cocktail flip */
-		if (!qix_cocktail_flip)
-		{
-			src = &videoram[offset];
-			memcpy(dst, src, count);
-		}
-		else
-		{
-			src = &videoram[offset ^ 0xffff];
-			while (count--)
-				*dst++ = *src--;
-		}
-
-		/* cache the palette bank as well */
-		memset(&palette_cache[scanline - SCANLINE_INCREMENT], *qix_palettebank, SCANLINE_INCREMENT);
-	}
+	/* force a partial update */
+	force_partial_update(scanline - 1);
 
 	/* set a timer for the next increment */
 	scanline += SCANLINE_INCREMENT;
@@ -130,11 +66,11 @@ void qix_scanline_callback(int scanline)
 
 /*************************************
  *
- *	Current scanline read
+ *  Current scanline read
  *
  *************************************/
 
-READ_HANDLER( qix_scanline_r )
+READ8_HANDLER( qix_scanline_r )
 {
 	int scanline = cpu_getscanline();
 	return (scanline <= 0xff) ? scanline : 0;
@@ -144,11 +80,11 @@ READ_HANDLER( qix_scanline_r )
 
 /*************************************
  *
- *	Video RAM mask
+ *  Video RAM mask
  *
  *************************************/
 
-WRITE_HANDLER( slither_vram_mask_w )
+WRITE8_HANDLER( slither_vram_mask_w )
 {
 	/* Slither appears to extend the basic hardware by providing */
 	/* a mask register which controls which data bits get written */
@@ -160,20 +96,20 @@ WRITE_HANDLER( slither_vram_mask_w )
 
 /*************************************
  *
- *	Direct video RAM read/write
+ *  Direct video RAM read/write
  *
- *	The screen is 256x256 with eight
- *	bit pixels (64K).  The screen is
- *	divided into two halves each half
- *	mapped by the video CPU at
- *	$0000-$7FFF.  The high order bit
- *	of the address latch at $9402
- *	specifies which half of the screen
- *	is being accessed.
+ *  The screen is 256x256 with eight
+ *  bit pixels (64K).  The screen is
+ *  divided into two halves each half
+ *  mapped by the video CPU at
+ *  $0000-$7FFF.  The high order bit
+ *  of the address latch at $9402
+ *  specifies which half of the screen
+ *  is being accessed.
  *
  *************************************/
 
-READ_HANDLER( qix_videoram_r )
+READ8_HANDLER( qix_videoram_r )
 {
 	/* add in the upper bit of the address latch */
 	offset += (qix_videoaddress[0] & 0x80) << 8;
@@ -181,7 +117,7 @@ READ_HANDLER( qix_videoram_r )
 }
 
 
-WRITE_HANDLER( qix_videoram_w )
+WRITE8_HANDLER( qix_videoram_w )
 {
 	/* add in the upper bit of the address latch */
 	offset += (qix_videoaddress[0] & 0x80) << 8;
@@ -194,20 +130,20 @@ WRITE_HANDLER( qix_videoram_w )
 
 /*************************************
  *
- *	Latched video RAM read/write
+ *  Latched video RAM read/write
  *
- *	The address latch works as follows.
- *	When the video CPU accesses $9400,
- *	the screen address is computed by
- *	using the values at $9402 (high
- *	byte) and $9403 (low byte) to get
- *	a value between $0000-$FFFF.  The
- *	value at that location is either
- *	returned or written.
+ *  The address latch works as follows.
+ *  When the video CPU accesses $9400,
+ *  the screen address is computed by
+ *  using the values at $9402 (high
+ *  byte) and $9403 (low byte) to get
+ *  a value between $0000-$FFFF.  The
+ *  value at that location is either
+ *  returned or written.
  *
  *************************************/
 
-READ_HANDLER( qix_addresslatch_r )
+READ8_HANDLER( qix_addresslatch_r )
 {
 	/* compute the value at the address latch */
 	offset = (qix_videoaddress[0] << 8) | qix_videoaddress[1];
@@ -216,7 +152,7 @@ READ_HANDLER( qix_addresslatch_r )
 
 
 
-WRITE_HANDLER( qix_addresslatch_w )
+WRITE8_HANDLER( qix_addresslatch_w )
 {
 	/* compute the value at the address latch */
 	offset = (qix_videoaddress[0] << 8) | qix_videoaddress[1];
@@ -229,11 +165,11 @@ WRITE_HANDLER( qix_addresslatch_w )
 
 /*************************************
  *
- *	Palette RAM
+ *  Palette RAM
  *
  *************************************/
 
-WRITE_HANDLER( qix_paletteram_w )
+WRITE8_HANDLER( qix_paletteram_w )
 {
 	/* this conversion table should be about right. It gives a reasonable */
 	/* gray scale in the test screen, and the red, green and blue squares */
@@ -276,30 +212,57 @@ WRITE_HANDLER( qix_paletteram_w )
 }
 
 
-WRITE_HANDLER( qix_palettebank_w )
+WRITE8_HANDLER( qix_palettebank_w )
 {
-	/* set the bank value; this is cached per-scanline above */
-	*qix_palettebank = data;
+	/* set the bank value */
+	if (qix_palettebank != (data & 3))
+	{
+		force_partial_update(cpu_getscanline() - 1);
+		qix_palettebank = data & 3;
+	}
 
 	/* LEDs are in the upper 6 bits */
+	leds = ~data & 0xfc;
 }
 
 
 
 /*************************************
  *
- *	Core video refresh
+ *  Core video refresh
  *
  *************************************/
 
-void qix_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( qix )
 {
-	int y;
+	pen_t *pens = &Machine->pens[qix_palettebank * 256];
+	UINT8 *vram;
+	UINT8 scanline[256];
+	int x,y;
 
 	/* draw the bitmap */
-	for (y = 0; y < 256; y++)
+	if (qix_cocktail_flip)
 	{
-		pen_t *pens = &Machine->pens[(palette_cache[y] & 3) * 256];
-		draw_scanline8(bitmap, 0, y, 256, &videoram_cache[y * 256], pens, -1);
+		for (y = cliprect->min_y; y <= cliprect->max_y; y++)
+		{
+			vram = &videoram[(y ^ 0xff) * 256];
+			for (x = 0;x < 256;x++)
+				scanline[x] = vram[x ^ 0xff];
+			draw_scanline8(bitmap, 0, y, 256, scanline, pens, -1);
+		}
 	}
+	else
+	{
+		for (y = cliprect->min_y; y <= cliprect->max_y; y++)
+		{
+			vram = &videoram[y * 256];
+			for (x = 0;x < 256;x++)
+				scanline[x] = vram[x];
+			draw_scanline8(bitmap, 0, y, 256, scanline, pens, -1);
+		}
+	}
+#if 0
+	/* note the confusing bit order! */
+	ui_popup("self test leds: %d%d %d%d%d%d",BIT(leds,7),BIT(leds,5),BIT(leds,6),BIT(leds,4),BIT(leds,2),BIT(leds,3));
+#endif
 }
