@@ -1,48 +1,45 @@
 /***************************************************************************
 
-	Atari Rampart hardware
+    Atari Rampart hardware
 
 ****************************************************************************/
 
 #include "driver.h"
 #include "machine/atarigen.h"
 #include "vidhrdw/generic.h"
+#include "rampart.h"
 
 
 
 /*************************************
  *
- *	Globals we own
+ *  Globals we own
  *
  *************************************/
 
-data16_t *rampart_bitmap;
+UINT16 *rampart_bitmap;
 
 
 
 /*************************************
  *
- *	Statics
+ *  Statics
  *
  *************************************/
 
 static UINT8 *pfdirty;
-static struct mame_bitmap *pfbitmap;
+static mame_bitmap *pfbitmap;
 static int xdim, ydim;
 
-int rampart_bitmap_init(int _xdim, int _ydim);
-void rampart_bitmap_free(void);
-void rampart_bitmap_render(struct mame_bitmap *bitmap);
-
 
 
 /*************************************
  *
- *	Video system start
+ *  Video system start
  *
  *************************************/
 
-int rampart_vh_start(void)
+VIDEO_START( rampart )
 {
 	static const struct atarimo_desc modesc =
 	{
@@ -54,7 +51,8 @@ int rampart_vh_start(void)
 		0,					/* render in swapped X/Y order? */
 		0,					/* does the neighbor bit affect the next object? */
 		8,					/* pixels per SLIP entry (0 for no-slip) */
-		8,					/* number of scanlines between MO updates */
+		0,					/* pixel offset for SLIPs */
+		0,					/* maximum number of links to visit/scanline (0=all) */
 
 		0x100,				/* base palette entry */
 		0x100,				/* maximum number of colors */
@@ -75,64 +73,66 @@ int rampart_vh_start(void)
 		{{ 0 }},			/* mask for the neighbor */
 		{{ 0 }},			/* mask for absolute coordinates */
 
-		{{ 0 }},			/* mask for the ignore value */
-		0,					/* resulting value to indicate "ignore" */
-		0,					/* callback routine for ignored entries */
+		{{ 0 }},			/* mask for the special value */
+		0,					/* resulting value to indicate "special" */
+		0,					/* callback routine for special entries */
 	};
 
 	/* initialize the playfield */
 	if (!rampart_bitmap_init(43*8, 30*8))
-		goto cant_create_pf;
+		return 1;
 
 	/* initialize the motion objects */
 	if (!atarimo_init(0, &modesc))
-		goto cant_create_mo;
+		return 1;
 
 	/* set the intial scroll offset */
-	atarimo_set_xscroll(0, -4, 0);
+	atarimo_set_xscroll(0, -4);
 	return 0;
-
-	/* error cases */
-cant_create_mo:
-	rampart_bitmap_free();
-cant_create_pf:
-	return 1;
 }
 
 
 
 /*************************************
  *
- *	Video system shutdown
+ *  Main refresh
  *
  *************************************/
 
-void rampart_vh_stop(void)
+VIDEO_UPDATE( rampart )
 {
-	atarimo_free();
-	rampart_bitmap_free();
+	struct atarimo_rect_list rectlist;
+	mame_bitmap *mobitmap;
+	int x, y, r;
+
+	/* draw the playfield */
+	rampart_bitmap_render(bitmap, cliprect);
+
+	/* draw and merge the MO */
+	mobitmap = atarimo_render(0, cliprect, &rectlist);
+	for (r = 0; r < rectlist.numrects; r++, rectlist.rect++)
+		for (y = rectlist.rect->min_y; y <= rectlist.rect->max_y; y++)
+		{
+			UINT16 *mo = (UINT16 *)mobitmap->base + mobitmap->rowpixels * y;
+			UINT16 *pf = (UINT16 *)bitmap->base + bitmap->rowpixels * y;
+			for (x = rectlist.rect->min_x; x <= rectlist.rect->max_x; x++)
+				if (mo[x])
+				{
+					/* not yet verified
+                    */
+					pf[x] = mo[x];
+
+					/* erase behind ourselves */
+					mo[x] = 0;
+				}
+		}
 }
 
 
 
 /*************************************
  *
- *	Main refresh
- *
- *************************************/
-
-void rampart_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
-{
-	/* draw the layers */
-	rampart_bitmap_render(bitmap);
-	atarimo_render(0, bitmap, NULL, NULL);
-}
-
-
-
-/*************************************
- *
- *	Bitmap initialization
+ *  Bitmap initialization
  *
  *************************************/
 
@@ -143,43 +143,21 @@ int rampart_bitmap_init(int _xdim, int _ydim)
 	ydim = _ydim;
 
 	/* allocate dirty map */
-	pfdirty = malloc(sizeof(pfdirty[0]) * ydim);
-	if (!pfdirty)
-		goto cant_alloc_dirty;
+	pfdirty = auto_malloc(sizeof(pfdirty[0]) * ydim);
 	memset(pfdirty, 1, sizeof(pfdirty[0]) * ydim);
 
 	/* allocate playfield bitmap */
-	pfbitmap = bitmap_alloc(xdim, ydim);
+	pfbitmap = auto_bitmap_alloc(xdim, ydim);
 	if (!pfbitmap)
-		goto cant_alloc_pf;
+		return 0;
 	return 1;
-
-	/* error cases */
-cant_alloc_pf:
-	free(pfdirty);
-cant_alloc_dirty:
-	return 0;
 }
 
 
 
 /*************************************
  *
- *	Bitmap freeing
- *
- *************************************/
-
-void rampart_bitmap_free(void)
-{
-	bitmap_free(pfbitmap);
-	free(pfdirty);
-}
-
-
-
-/*************************************
- *
- *	Bitmap RAM write handler
+ *  Bitmap RAM write handler
  *
  *************************************/
 
@@ -206,11 +184,11 @@ WRITE16_HANDLER( rampart_bitmap_w )
 
 /*************************************
  *
- *	Bitmap rendering
+ *  Bitmap rendering
  *
  *************************************/
 
-void rampart_bitmap_render(struct mame_bitmap *bitmap)
+void rampart_bitmap_render(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int x, y;
 
@@ -218,7 +196,7 @@ void rampart_bitmap_render(struct mame_bitmap *bitmap)
 	for (y = 0; y < ydim; y++)
 		if (pfdirty[y])
 		{
-			const data16_t *src = &rampart_bitmap[256 * y];
+			const UINT16 *src = &rampart_bitmap[256 * y];
 			UINT8 scanline[512];
 			UINT8 *dst = scanline;
 
@@ -236,5 +214,5 @@ void rampart_bitmap_render(struct mame_bitmap *bitmap)
 		}
 
 	/* copy the cached bitmap */
-	copybitmap(bitmap, pfbitmap, 0, 0, 0, 0, NULL, TRANSPARENCY_NONE, 0);
+	copybitmap(bitmap, pfbitmap, 0, 0, 0, 0, cliprect, TRANSPARENCY_NONE, 0);
 }
