@@ -1,19 +1,18 @@
 /***************************************************************************
 
-  vidhrdw.c
-
-  Functions to emulate the video hardware of the machine.
+    Sega G-80 raster hardware
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
+#include "segar.h"
 
 
-unsigned char *segar_characterram;
-unsigned char *segar_characterram2;
-unsigned char *segar_mem_colortable;
-unsigned char *segar_mem_bcolortable;
+UINT8 *segar_characterram;
+UINT8 *segar_characterram2;
+UINT8 *segar_mem_colortable;
+UINT8 *segar_mem_bcolortable;
 
 typedef struct
 {
@@ -41,8 +40,8 @@ typedef struct
 	unsigned char backfill;
 	unsigned char fill_background;
 	unsigned int backshift;
-	struct mame_bitmap *horizbackbitmap;
-	struct mame_bitmap *vertbackbitmap;
+	mame_bitmap *horizbackbitmap;
+	mame_bitmap *vertbackbitmap;
 } SEGAR_VID_STRUCT;
 
 static SEGAR_VID_STRUCT sv;
@@ -57,28 +56,27 @@ static SEGAR_VID_STRUCT sv;
 
 ***************************************************************************/
 
-void segar_init_colors(unsigned char *palette, unsigned short *colortable, const unsigned char *color_prom)
+PALETTE_INIT( segar )
 {
 	static unsigned char color_scale[] = {0x00, 0x40, 0x80, 0xC0 };
 	int i;
 
 	/* Our first color needs to be black (transparent) */
-	*(palette++) = 0;
-	*(palette++) = 0;
-	*(palette++) = 0;
+	palette_set_color(0,0,0,0);
 
 	/* Space Odyssey uses a static palette for the background, so
-	   our choice of colors isn't exactly arbitrary.  S.O. uses a
-	   6-bit color setup, so we make sure that every 0x40 colors
-	   gets a nice 6-bit palette.
+       our choice of colors isn't exactly arbitrary.  S.O. uses a
+       6-bit color setup, so we make sure that every 0x40 colors
+       gets a nice 6-bit palette.
 
        (All of the other G80 games overwrite the default colors on startup)
-	*/
+    */
 	for (i = 0;i < (Machine->drv->total_colors - 1);i++)
 	{
-		*(palette++) = color_scale[((i & 0x30) >> 4)];
-		*(palette++) = color_scale[((i & 0x0C) >> 2)];
-		*(palette++) = color_scale[((i & 0x03) << 0)];
+		int r = color_scale[((i & 0x30) >> 4)];
+		int g = color_scale[((i & 0x0C) >> 2)];
+		int b = color_scale[((i & 0x03) << 0)];
+		palette_set_color(i+1,r,g,b);
 	}
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
@@ -92,14 +90,14 @@ The two bit planes are separated in memory.  If either bit plane changes,
 mark the character as modified.
 ***************************************************************************/
 
-WRITE_HANDLER( segar_characterram_w )
+WRITE8_HANDLER( segar_characterram_w )
 {
 	sv.dirtychar[offset / 8] = 1;
 
 	segar_characterram[offset] = data;
 }
 
-WRITE_HANDLER( segar_characterram2_w )
+WRITE8_HANDLER( segar_characterram2_w )
 {
 	sv.dirtychar[offset / 8] = 1;
 
@@ -115,7 +113,7 @@ D3 = ??? (looks to be unused on the schems)
 D4-D7 = unused?
 ***************************************************************************/
 
-WRITE_HANDLER( segar_video_port_w )
+WRITE8_HANDLER( segar_video_port_w )
 {
 	logerror("VPort = %02X\n",data);
 
@@ -138,7 +136,7 @@ WRITE_HANDLER( segar_video_port_w )
 If a color changes, refresh the entire screen because it's possible that the
 color change affected the transparency (switched either to or from black)
 ***************************************************************************/
-WRITE_HANDLER( segar_colortable_w )
+WRITE8_HANDLER( segar_colortable_w )
 {
 	static unsigned char red[] = {0x00, 0x24, 0x49, 0x6D, 0x92, 0xB6, 0xDB, 0xFF };
 	static unsigned char grn[] = {0x00, 0x24, 0x49, 0x6D, 0x92, 0xB6, 0xDB, 0xFF };
@@ -177,7 +175,7 @@ WRITE_HANDLER( segar_colortable_w )
 	}
 }
 
-WRITE_HANDLER( segar_bcolortable_w )
+WRITE8_HANDLER( segar_bcolortable_w )
 {
 	static unsigned char red[] = {0x00, 0x24, 0x49, 0x6D, 0x92, 0xB6, 0xDB, 0xFF };
 	static unsigned char grn[] = {0x00, 0x24, 0x49, 0x6D, 0x92, 0xB6, 0xDB, 0xFF };
@@ -208,10 +206,9 @@ WRITE_HANDLER( segar_bcolortable_w )
 
 ***************************************************************************/
 
-
-int segar_vh_start(void)
+VIDEO_START( segar )
 {
-	if (generic_vh_start()!=0)
+	if (video_start_generic()!=0)
 		return 1;
 
 	/* Init our vid struct, everything defaults to 0 */
@@ -224,7 +221,7 @@ int segar_vh_start(void)
 This is the refresh code that is common across all the G80 games.  This
 corresponds to the VIDEO I board.
 ***************************************************************************/
-static void segar_common_screenrefresh(struct mame_bitmap *bitmap, int sprite_transparency, int copy_transparency)
+static void segar_common_screenrefresh(mame_bitmap *bitmap, int sprite_transparency, int copy_transparency)
 {
 	int offs;
 	int charcode;
@@ -233,7 +230,7 @@ static void segar_common_screenrefresh(struct mame_bitmap *bitmap, int sprite_tr
 	/* since last time and update it accordingly. */
 	for (offs = videoram_size - 1;offs >= 0;offs--)
 	{
-		if ((sv.char_refresh) && (sv.dirtychar[videoram[offs]]))
+		if ((sv.char_refresh) || (sv.dirtychar[videoram[offs]]))
 			dirtybuffer[offs]=1;
 
 		/* Redraw every character if our palette or scene changed */
@@ -285,9 +282,10 @@ static void segar_common_screenrefresh(struct mame_bitmap *bitmap, int sprite_tr
 /***************************************************************************
 "Standard" refresh for games without special background boards.
 ***************************************************************************/
-void segar_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+
+VIDEO_UPDATE( segar )
 {
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 		sv.refresh = 1;
 
 	segar_common_screenrefresh(bitmap, TRANSPARENCY_NONE, TRANSPARENCY_NONE);
@@ -308,47 +306,28 @@ scrolls that's 4 times taller than the screen.
 
 ***************************************************************************/
 
-int spaceod_vh_start(void)
+VIDEO_START( spaceod )
 {
-	if (segar_vh_start()!=0)
+	if (video_start_segar())
 		return 1;
 
-	if ((sv.horizbackbitmap = bitmap_alloc(4*Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
-	{
-		generic_vh_stop();
+	if ((sv.horizbackbitmap = auto_bitmap_alloc(4*Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
 		return 1;
-	}
 
-	if ((sv.vertbackbitmap = bitmap_alloc(Machine->drv->screen_width,4*Machine->drv->screen_height)) == 0)
-	{
-		bitmap_free(sv.horizbackbitmap);
-		generic_vh_stop();
+	if ((sv.vertbackbitmap = auto_bitmap_alloc(Machine->drv->screen_width,4*Machine->drv->screen_height)) == 0)
 		return 1;
-	}
 
 	return 0;
 }
 
-/***************************************************************************
-
-Get rid of the Space Odyssey background bitmaps.
-
-***************************************************************************/
-
-void spaceod_vh_stop(void)
-{
-	bitmap_free(sv.horizbackbitmap);
-	bitmap_free(sv.vertbackbitmap);
-	generic_vh_stop();
-}
 
 /***************************************************************************
-This port controls which background to draw for Space Odyssey.	The temp_scene
+This port controls which background to draw for Space Odyssey.  The temp_scene
 and temp_charset are analogous to control lines used to select the background.
 If the background changed, refresh the screen.
 ***************************************************************************/
 
-WRITE_HANDLER( spaceod_back_port_w )
+WRITE8_HANDLER( spaceod_back_port_w )
 {
 	unsigned int temp_scene, temp_charset;
 
@@ -378,13 +357,13 @@ WRITE_HANDLER( spaceod_back_port_w )
 }
 
 /***************************************************************************
-This port controls the Space Odyssey background scrolling.	Each write to
+This port controls the Space Odyssey background scrolling.  Each write to
 this port scrolls the background by one bit.  Faster speeds are achieved
 by the program writing more often to this port.  Oddly enough, the value
 sent to this port also seems to indicate the speed, but the value itself
 is never checked.
 ***************************************************************************/
-WRITE_HANDLER( spaceod_backshift_w )
+WRITE8_HANDLER( spaceod_backshift_w )
 {
 	sv.backshift= (sv.backshift + 1) % 0x400;
 	sv.background_enable=1;
@@ -397,7 +376,7 @@ really important for the Black Hole level, since the only way the program
 can line up the background's Black Hole with knowing when to spin the ship
 is to force the background to restart every time you die.
 ***************************************************************************/
-WRITE_HANDLER( spaceod_backshift_clear_w )
+WRITE8_HANDLER( spaceod_backshift_clear_w )
 {
 	sv.backshift=0;
 	sv.background_enable=1;
@@ -407,7 +386,7 @@ WRITE_HANDLER( spaceod_backshift_clear_w )
 /***************************************************************************
 Space Odyssey also lets you fill the background with a specific color.
 ***************************************************************************/
-WRITE_HANDLER( spaceod_backfill_w )
+WRITE8_HANDLER( spaceod_backfill_w )
 {
 	sv.backfill=data + 0x40 + 1;
 	sv.fill_background=1;
@@ -415,7 +394,7 @@ WRITE_HANDLER( spaceod_backfill_w )
 
 /***************************************************************************
 ***************************************************************************/
-WRITE_HANDLER( spaceod_nobackfill_w )
+WRITE8_HANDLER( spaceod_nobackfill_w )
 {
 	sv.backfill=0;
 	sv.fill_background=0;
@@ -425,7 +404,8 @@ WRITE_HANDLER( spaceod_nobackfill_w )
 /***************************************************************************
 Special refresh for Space Odyssey, this code refreshes the static background.
 ***************************************************************************/
-void spaceod_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+
+VIDEO_UPDATE( spaceod )
 {
 	int offs;
 	int charcode;
@@ -434,7 +414,7 @@ void spaceod_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	unsigned char *back_charmap = memory_region(REGION_USER1);
 
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 		sv.refresh = 1;
 
 	/* scenes 0,1 are horiz.  scenes 2,3 are vert. */
@@ -538,9 +518,9 @@ void spaceod_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
  ---------------------------------------------------------------------------
 ***************************************************************************/
 
-int monsterb_vh_start(void)
+VIDEO_START( monsterb )
 {
-	if (segar_vh_start()!=0)
+	if (video_start_segar())
 		return 1;
 
 	sv.has_bcolorRAM = 1;
@@ -553,7 +533,7 @@ and tempoffset are analogous to control lines used to bank switch the
 background ROMs.  If the background changed, refresh the screen.
 ***************************************************************************/
 
-WRITE_HANDLER( monsterb_back_port_w )
+WRITE8_HANDLER( monsterb_back_port_w )
 {
 	unsigned int temp_scene, temp_charset;
 
@@ -584,10 +564,75 @@ WRITE_HANDLER( monsterb_back_port_w )
 	}
 }
 
+/* for set 2 */
+/* other ports are also used */
+static UINT8 monster2_bbdata;
+static UINT8 monster2_b9data;
+
+WRITE8_HANDLER( monster2_bb_back_port_w )
+{
+	unsigned int temp_scene, temp_charset;
+
+	/* maybe */
+	monster2_bbdata=data;
+
+	temp_scene   = (monster2_b9data & 0x03)|monster2_bbdata<<2;
+	temp_charset = monster2_b9data & 0x03;
+
+	temp_scene = 0x400*temp_scene;
+
+	sv.back_scene = temp_scene;
+	sv.refresh=1;
+
+	sv.back_charset = temp_charset;
+	sv.refresh=1;
+
+/*  printf("bb_data %02x\n",data); */
+}
+
+WRITE8_HANDLER( monster2_b9_back_port_w )
+{
+	unsigned int temp_scene, temp_charset;
+
+	monster2_b9data = data;
+
+
+	temp_scene   = (monster2_b9data & 0x03)|monster2_bbdata<<2;
+	temp_charset = monster2_b9data & 0x03;
+
+	temp_scene = 0x400*temp_scene;
+
+/*  printf("data %02x\n",data); */
+
+	if (sv.back_scene != temp_scene)
+	{
+		sv.back_scene = temp_scene;
+		sv.refresh=1;
+	}
+	if (sv.back_charset != temp_charset)
+	{
+		sv.back_charset = temp_charset;
+		sv.refresh=1;
+	}
+
+	/* This bit turns the background off and on. */
+	if ((data & 0x80) && (sv.background_enable==0))
+	{
+		sv.background_enable=1;
+		sv.refresh=1;
+	}
+	else if (((data & 0x80)==0) && (sv.background_enable==1))
+	{
+		sv.background_enable=0;
+		sv.refresh=1;
+	}
+}
+
 /***************************************************************************
 Special refresh for Monster Bash, this code refreshes the static background.
 ***************************************************************************/
-void monsterb_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+
+VIDEO_UPDATE( monsterb )
 {
 	int offs;
 	int charcode;
@@ -595,7 +640,7 @@ void monsterb_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	unsigned char *back_charmap = memory_region(REGION_USER1);
 
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 		sv.refresh = 1;
 
 	sprite_transparency=TRANSPARENCY_NONE;
@@ -607,7 +652,7 @@ void monsterb_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		/* since last time and update it accordingly. */
 		for (offs = videoram_size - 1;offs >= 0;offs--)
 		{
-			if ((sv.char_refresh) && (sv.dirtychar[videoram[offs]]))
+			if ((sv.char_refresh) || (sv.dirtychar[videoram[offs]]))
 				dirtybuffer[offs]=1;
 
 			/* Redraw every background character if our palette or scene changed */
@@ -649,7 +694,7 @@ void monsterb_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 This port seems to control the background colors for Pig Newton.
 ***************************************************************************/
 
-WRITE_HANDLER( pignewt_back_color_w )
+WRITE8_HANDLER( pignewt_back_color_w )
 {
 	if (offset == 0)
 	{
@@ -670,7 +715,7 @@ are analogous to registers used to control bank-switching of the background
 If the background changed, refresh the screen.
 ***************************************************************************/
 
-WRITE_HANDLER( pignewt_back_ports_w )
+WRITE8_HANDLER( pignewt_back_ports_w )
 {
 	unsigned int tempscene;
 
@@ -728,7 +773,7 @@ WRITE_HANDLER( pignewt_back_ports_w )
 Controls the background image
 ***************************************************************************/
 
-WRITE_HANDLER( sindbadm_back_port_w )
+WRITE8_HANDLER( sindbadm_back_port_w )
 {
 	unsigned int tempscene;
 
@@ -761,7 +806,8 @@ WRITE_HANDLER( sindbadm_back_port_w )
 /***************************************************************************
 Special refresh for Sinbad Mystery, this code refreshes the static background.
 ***************************************************************************/
-void sindbadm_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+
+VIDEO_UPDATE( sindbadm )
 {
 	int offs;
 	int charcode;
@@ -771,7 +817,7 @@ void sindbadm_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	unsigned char *back_charmap = memory_region(REGION_USER1);
 
-	if (full_refresh)
+	if (get_vh_global_attribute_changed())
 		sv.refresh = 1;
 
 	sprite_transparency=TRANSPARENCY_NONE;
@@ -783,7 +829,7 @@ void sindbadm_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		/* since last time and update it accordingly. */
 		for (offs = videoram_size - 1;offs >= 0;offs--)
 		{
-			if ((sv.char_refresh) && (sv.dirtychar[videoram[offs]]))
+			if ((sv.char_refresh) || (sv.dirtychar[videoram[offs]]))
 				dirtybuffer[offs]=1;
 
 			/* Redraw every background character if our palette or scene changed */
