@@ -4,6 +4,14 @@
  driver by David Haywood
 
  see (drivers/segasyse.c) for additional notes
+
+ todo:
+
+ clean up megatech code, covert to rgb_direct? might be needed for megatech
+ some megatech games are also sms based so we'll need a way of supporting that
+ for now support has been quickly added while the menu system is worked out
+ megaplay has an sms vdp too
+
 *******************************************************************************/
 
 #include "driver.h"
@@ -16,7 +24,7 @@
 UINT8  segae_vdp_cmdpart[CHIPS];		/* VDP Command Part Counter */
 UINT16 segae_vdp_command[CHIPS];		/* VDP Command Word */
 
-UINT8  segae_vdp_accessmode[CHIPS];		/* VDP Access Mode (VRAM, CRAM)	*/
+UINT8  segae_vdp_accessmode[CHIPS];		/* VDP Access Mode (VRAM, CRAM) */
 UINT16 segae_vdp_accessaddr[CHIPS];		/* VDP Access Address */
 UINT8  segae_vdp_readbuffer[CHIPS];		/* VDP Read Buffer */
 
@@ -28,6 +36,8 @@ UINT8 segae_vdp_vrambank[CHIPS];		/* Current VRAM Bank number (from writes to Po
 
 UINT8 *cache_bitmap;					/* 8bpp bitmap with raw pen values */
 
+static int segasyse_palettebase; /* needed for megatech for now.. */
+
 /*- in (drivers/segasyse.c) -*/
 
 extern UINT8 vintpending;
@@ -43,6 +53,7 @@ void segae_vdp_setregister ( UINT8 chip, UINT16 cmd );
 
 void segae_drawtilesline(UINT8 *dest, int line, UINT8 chip, UINT8 pri);
 void segae_drawspriteline(UINT8 *dest, UINT8 chip, UINT8 line);
+void segae_drawscanline(int line, int chips, int blank);
 
 static void segae_draw8pix_solid16(UINT8 *dest, UINT8 chip, UINT16 tile, UINT8 line, UINT8 flipx, UINT8 col);
 static void segae_draw8pix(UINT8 *dest, UINT8 chip, UINT16 tile, UINT8 line, UINT8 flipx, UINT8 col);
@@ -52,46 +63,79 @@ static void segae_draw8pixsprite(UINT8 *dest, UINT8 chip, UINT16 tile, UINT8 lin
  vhstart, vhstop and vhrefresh functions
 *******************************************************************************/
 
-int segae_vh_start(void)
+VIDEO_START( segae )
 {
 	UINT8 temp;
 
+	segasyse_palettebase = 0;
+
 	for (temp=0;temp<CHIPS;temp++)
 		if (segae_vdp_start(temp)) return 1;
 
-	cache_bitmap = malloc( (16+256+16) * 192); /* 16 pixels either side to simplify drawing */
-
-	if (!cache_bitmap) return 1;
+	cache_bitmap = auto_malloc( (16+256+16) * 192); /* 16 pixels either side to simplify drawing */
 
 	return 0;
 }
 
-void segae_vh_stop(void)
-{
-	UINT8 temp;
-
-	for (temp=0;temp<CHIPS;temp++)
-		segae_vdp_stop(temp);
-
-	free (cache_bitmap);
-}
-
-void segae_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( segae )
 {
 	int i;
 
 	/*- Draw from cache_bitmap to screen -*/
 
 	for (i = 0;i < 192;i++)
-		draw_scanline8(bitmap,0,i,256,&cache_bitmap[i * (16+256+16) +16],Machine->pens,-1);
+		draw_scanline8(bitmap,0,i,256,&cache_bitmap[i * (16+256+16) +16],&Machine->pens[segasyse_palettebase],15);
 }
 
+/* these are used by megatech */
+
+/* starts vdp for bios screen only */
+int start_megatech_video_normal(void)
+{
+	segasyse_palettebase = 0x40;
+
+	if (segae_vdp_start(0)) return 1;
+
+	cache_bitmap = auto_malloc( (16+256+16) * 192); /* 16 pixels either side to simplify drawing */
+
+	return 0;
+}
+
+void update_megatech_video_normal(mame_bitmap *bitmap, const rectangle *cliprect )
+{
+	int maxy = (cliprect->max_y > 192-1) ? 192-1 : cliprect->max_y;
+	int i;
+
+	/*- Draw from cache_bitmap to screen -*/
+
+	for (i = cliprect->min_y; i <= maxy;i++)
+		segae_drawscanline(i,0,0);
+
+	for (i = cliprect->min_y; i <= maxy;i++)
+		draw_scanline8(bitmap,0,i,256,&cache_bitmap[i * (16+256+16) +16],&Machine->pens[segasyse_palettebase],-1);
+}
+
+void update_megaplay_video_normal(mame_bitmap *bitmap, const rectangle *cliprect )
+{
+	int miny = (cliprect->min_y < 16) ? 16 : cliprect->min_y;
+	int maxy = (cliprect->max_y > 16+192-1) ? 16+192-1 : cliprect->max_y;
+	int i;
+
+	/*- Draw from cache_bitmap to screen -*/
+
+	for (i = miny; i <= maxy;i++)
+		segae_drawscanline(i-16,0,0);
+
+	for (i = miny;i <= maxy;i++)
+		draw_scanline8(bitmap,32,i,256,&cache_bitmap[(i-16) * (16+256+16) +24],&Machine->pens[segasyse_palettebase],0);
+
+}
 
 /*******************************************************************************
  VDP Start / Stop Functions
 ********************************************************************************
  note: we really should check after each allocation to make sure it was
-	   successful then if one allocation fails we can free up the previous ones
+       successful then if one allocation fails we can free up the previous ones
 *******************************************************************************/
 
 int	segae_vdp_start( UINT8 chip )
@@ -100,21 +144,16 @@ int	segae_vdp_start( UINT8 chip )
 
 	/*- VRAM -*/
 
-	segae_vdp_vram[chip] = malloc(0x8000); /* 32kb (2 banks) */
+	segae_vdp_vram[chip] = auto_malloc(0x8000); /* 32kb (2 banks) */
 	segae_vdp_vrambank[chip] = 0;
 
 	/*- CRAM -*/
 
-	segae_vdp_cram[chip] = malloc(0x20);
+	segae_vdp_cram[chip] = auto_malloc(0x20);
 
 	/*- VDP Registers -*/
 
-	segae_vdp_regs[chip] = malloc(0x20);
-
-	/*- Check Allocation was Successful -*/
-
-	if (!segae_vdp_vram[chip] || !segae_vdp_cram[chip] || !segae_vdp_regs[chip])
-		return 1;
+	segae_vdp_regs[chip] = auto_malloc(0x20);
 
 	/*- Clear Memory -*/
 
@@ -132,7 +171,7 @@ int	segae_vdp_start( UINT8 chip )
 	/*- Black the Palette -*/
 
 	for (temp=0;temp<32;temp++)
-		palette_set_color(temp + 32*chip, 0, 0, 0);
+		palette_set_color(temp + 32*chip+segasyse_palettebase, 0, 0, 0);
 
 	/* Save State Stuff (based on vidhrdw/taitoic.c) */
 
@@ -153,15 +192,6 @@ int	segae_vdp_start( UINT8 chip )
 	return 0;
 }
 
-void segae_vdp_stop( UINT8 chip )
-{
-	/*- Free Allocated Memory -*/
-
-	free(segae_vdp_vram[chip]);
-	free(segae_vdp_cram[chip]);
-	free(segae_vdp_regs[chip]);
-}
-
 /*******************************************************************************
  Core VDP Functions
 *******************************************************************************/
@@ -175,9 +205,9 @@ void segae_vdp_stop( UINT8 chip )
  return the following
 
  bit:
-  7	- vert int pending
-  6	- line int pending
-  5	- sprite collision (non 0 pixels) *not currently emulated (not needed by these games)*
+  7 - vert int pending
+  6 - line int pending
+  5 - sprite collision (non 0 pixels) *not currently emulated (not needed by these games)*
   4 - always 0
   3 - always 0
   2 - always 0
@@ -249,7 +279,7 @@ void segae_vdp_data_w ( UINT8 chip, UINT8 data )
 			g = (segae_vdp_cram[chip][segae_vdp_accessaddr[chip]] & 0x0c) << 4;
 			b = (segae_vdp_cram[chip][segae_vdp_accessaddr[chip]] & 0x30) << 2;
 
-			palette_set_color(segae_vdp_accessaddr[chip] + 32*chip, r, g, b);
+			palette_set_color(segae_vdp_accessaddr[chip] + 32*chip+segasyse_palettebase, r, g, b);
 		}
 
 		segae_vdp_accessaddr[chip] += 1;
@@ -364,7 +394,7 @@ void segae_vdp_setregister ( UINT8 chip, UINT16 cmd )
 
 *******************************************************************************/
 
-void segae_drawscanline(int line)
+void segae_drawscanline(int line, int chips, int blank)
 {
 
 	UINT8* dest;
@@ -383,16 +413,22 @@ void segae_drawscanline(int line)
 		segae_drawtilesline (dest+16, line, 0,1);
 	}
 
-	if (segae_vdp_regs[1][1] & 0x40) {
-		segae_drawtilesline (dest+16, line, 1,0);
-		segae_drawspriteline(dest+16, 1, line);
-		segae_drawtilesline (dest+16, line, 1,1);
+	if (chips>0) /* we don't want to do this on megatech */
+	{
+		if (segae_vdp_regs[1][1] & 0x40) {
+			segae_drawtilesline (dest+16, line, 1,0);
+			segae_drawspriteline(dest+16, 1, line);
+			segae_drawtilesline (dest+16, line, 1,1);
+		}
 	}
 
-	memset(dest+16, 32+16, 8); /* Clear Leftmost column, there should be a register for this like on the SMS i imagine    */
-							   /* on the SMS this is bit 5 of register 0 (according to CMD's SMS docs) for system E this  */
-							   /* appears to be incorrect, most games need it blanked 99% of the time so we blank it      */
-
+	/* FIX ME!! */
+	if (blank)
+	{
+		if (strcmp(Machine->gamedrv->name,"tetrisse")) /* and we really don't want to do it on tetrise */
+			memset(dest+16, 32+16, 8); /* Clear Leftmost column, there should be a register for this like on the SMS i imagine    */
+							   			  /* on the SMS this is bit 5 of register 0 (according to CMD's SMS docs) for system E this  */							   			  /* appears to be incorrect, most games need it blanked 99% of the time so we blank it      */
+	}
 }
 
 /*-- Drawing a line of tiles --*/
@@ -440,6 +476,9 @@ void segae_drawtilesline(UINT8 *dest, int line, UINT8 chip, UINT8 pri)
 		palette = (vram_word & 0x0800) >> 11;
 		priority= (vram_word & 0x1000) >> 12;
 
+		tilesline2= (line + vscroll) % 8;
+		if (flipy) tilesline2 = 7-tilesline2;
+
 		if (priority == pri) {
 			if (chip == 0) segae_draw8pix_solid16(dest, chip, tile_no,tilesline2,flipx,palette);
 			else segae_draw8pix(dest, chip, tile_no,tilesline2,flipx,palette);
