@@ -59,21 +59,22 @@ Word | Bit(s)           | Use
 ***************************************************************************/
 
 #include "driver.h"
+#include "vidhrdw/generic.h"
 
 
-data16_t *shangha3_ram;
+UINT16 *shangha3_ram;
 size_t shangha3_ram_size;
 
 int shangha3_do_shadows;
 
-static data16_t gfxlist_addr;
-static struct mame_bitmap *rawbitmap;
+static UINT16 gfxlist_addr;
+static mame_bitmap *rawbitmap;
 
 
 
-int shangha3_vh_start(void)
+VIDEO_START( shangha3 )
 {
-	if ((rawbitmap = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+	if ((rawbitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
 		return 1;
 
 	if (shangha3_do_shadows)
@@ -92,12 +93,6 @@ int shangha3_vh_start(void)
 	return 0;
 }
 
-void shangha3_vh_stop(void)
-{
-	bitmap_free(rawbitmap);
-	rawbitmap = 0;
-}
-
 
 
 WRITE16_HANDLER( shangha3_flipscreen_w )
@@ -107,7 +102,7 @@ WRITE16_HANDLER( shangha3_flipscreen_w )
 		/* bit 7 flips screen, the rest seems to always be set to 0x7e */
 		flip_screen_set(data & 0x80);
 
-		if ((data & 0x7f) != 0x7e) usrintf_showmessage("flipscreen_w %02x",data);
+		if ((data & 0x7f) != 0x7e) ui_popup("flipscreen_w %02x",data);
 	}
 }
 
@@ -154,7 +149,7 @@ WRITE16_HANDLER( shangha3_blitter_go_w )
 				/* avoid garbage on startup */
 && sizex < 512 && sizey < 256 && zoomx < 0x1f0 && zoomy < 0x1f0)
 		{
-			struct rectangle myclip;
+			rectangle myclip;
 
 /*if (shangha3_ram[offs+11] || shangha3_ram[offs+12]) */
 /*logerror("offs %04x: sx %04x sy %04x zoom %04x %04x %04x %04x fx %d fy %d\n",offs,sx,sy,zoomx,shangha3_ram[offs+11]),shangha3_ram[offs+12],zoomy,flipx,flipy); */
@@ -269,7 +264,7 @@ else
 }
 
 
-void shangha3_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( shangha3 )
 {
 	copybitmap(bitmap,rawbitmap,0,0,0,0,&Machine->visible_area,TRANSPARENCY_NONE,0);
 }
