@@ -15,7 +15,7 @@ size_t slapfight_videoram_size;
 unsigned char *slapfight_scrollx_lo,*slapfight_scrollx_hi,*slapfight_scrolly;
 static int flipscreen;
 
-static struct tilemap *pf1_tilemap,*fix_tilemap;
+static tilemap *pf1_tilemap,*fix_tilemap;
 
 
 
@@ -74,7 +74,7 @@ static void get_fix_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int perfrman_vh_start (void)
+VIDEO_START( perfrman )
 {
 	pf1_tilemap = tilemap_create(get_pf_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,64,32);
 
@@ -86,7 +86,7 @@ int perfrman_vh_start (void)
 	return 0;
 }
 
-int slapfight_vh_start (void)
+VIDEO_START( slapfight )
 {
 	pf1_tilemap = tilemap_create(get_pf1_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,8,8,64,32);
 	fix_tilemap = tilemap_create(get_fix_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,64,32);
@@ -106,31 +106,31 @@ int slapfight_vh_start (void)
 
 ***************************************************************************/
 
-WRITE_HANDLER( slapfight_videoram_w )
+WRITE8_HANDLER( slapfight_videoram_w )
 {
 	videoram[offset]=data;
 	tilemap_mark_tile_dirty(pf1_tilemap,offset);
 }
 
-WRITE_HANDLER( slapfight_colorram_w )
+WRITE8_HANDLER( slapfight_colorram_w )
 {
 	colorram[offset]=data;
 	tilemap_mark_tile_dirty(pf1_tilemap,offset);
 }
 
-WRITE_HANDLER( slapfight_fixram_w )
+WRITE8_HANDLER( slapfight_fixram_w )
 {
 	slapfight_videoram[offset]=data;
 	tilemap_mark_tile_dirty(fix_tilemap,offset);
 }
 
-WRITE_HANDLER( slapfight_fixcol_w )
+WRITE8_HANDLER( slapfight_fixcol_w )
 {
 	slapfight_colorram[offset]=data;
 	tilemap_mark_tile_dirty(fix_tilemap,offset);
 }
 
-WRITE_HANDLER( slapfight_flipscreen_w )
+WRITE8_HANDLER( slapfight_flipscreen_w )
 {
 	logerror("Writing %02x to flipscreen\n",offset);
 	if (offset==0) flipscreen=1; /* Port 0x2 is flipscreen */
@@ -140,7 +140,7 @@ WRITE_HANDLER( slapfight_flipscreen_w )
 #ifdef MAME_DEBUG
 void slapfght_log_vram(void)
 {
-	if ( keyboard_pressed_memory(KEYCODE_B) )
+	if ( code_pressed_memory(KEYCODE_B) )
 	{
 		int i;
 		for (i=0; i<0x800; i++)
@@ -156,7 +156,7 @@ void slapfght_log_vram(void)
   Render the Sprites
 
 ***************************************************************************/
-static void perfrman_draw_sprites( struct mame_bitmap *bitmap, int priority_to_display )
+static void perfrman_draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect, int priority_to_display )
 {
 	int offs;
 
@@ -181,11 +181,11 @@ static void perfrman_draw_sprites( struct mame_bitmap *bitmap, int priority_to_d
 				buffered_spriteram[offs],
 				((buffered_spriteram[offs+2] >> 1) & 3)
 					+ ((buffered_spriteram[offs+2] << 2) & 4)
-/*					+ ((buffered_spriteram[offs+2] >> 2) & 8) */
+/*                  + ((buffered_spriteram[offs+2] >> 2) & 8) */
 				,
 				flipscreen, flipscreen,
 				sx, sy,
-				&Machine->visible_area,TRANSPARENCY_PEN,0);
+				cliprect,TRANSPARENCY_PEN,0);
 		}
 	}
 }
@@ -198,7 +198,7 @@ static void perfrman_draw_sprites( struct mame_bitmap *bitmap, int priority_to_d
 
 ***************************************************************************/
 
-void perfrman_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( perfrman )
 {
 	tilemap_set_flip( pf1_tilemap, flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 	tilemap_set_scrolly( pf1_tilemap ,0 , 0 );
@@ -209,11 +209,11 @@ void perfrman_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		tilemap_set_scrollx( pf1_tilemap ,0 , -16 );
 	}
 
-	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+	fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	perfrman_draw_sprites(bitmap,0);
-	tilemap_draw(bitmap,pf1_tilemap,0,0);
-	perfrman_draw_sprites(bitmap,0x80);
+	perfrman_draw_sprites(bitmap,cliprect,0);
+	tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
+	perfrman_draw_sprites(bitmap,cliprect,0x80);
 
 #ifdef MAME_DEBUG
 	slapfght_log_vram();
@@ -221,7 +221,7 @@ void perfrman_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 }
 
 
-void slapfight_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( slapfight )
 {
 	int offs;
 
@@ -239,7 +239,7 @@ void slapfight_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		tilemap_set_scrolly( fix_tilemap,0, -1 ); /* Glitch in Tiger Heli otherwise */
 	}
 
-	tilemap_draw(bitmap,pf1_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
 
 	/* Draw the sprites */
 	for (offs = 0;offs < spriteram_size;offs += 4)
@@ -250,17 +250,17 @@ void slapfight_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 				(buffered_spriteram[offs+2] & 0x1e) >> 1,
 				1,1,
 				288-(buffered_spriteram[offs+1] + ((buffered_spriteram[offs+2] & 0x01) << 8)) +18,240-buffered_spriteram[offs+3],
-				&Machine->visible_area,TRANSPARENCY_PEN,0);
+				cliprect,TRANSPARENCY_PEN,0);
 		else
 			drawgfx(bitmap,Machine->gfx[2],
 				buffered_spriteram[offs] + ((buffered_spriteram[offs+2] & 0xc0) << 2),
 				(buffered_spriteram[offs+2] & 0x1e) >> 1,
 				0,0,
 				(buffered_spriteram[offs+1] + ((buffered_spriteram[offs+2] & 0x01) << 8)) - 13,buffered_spriteram[offs+3],
-				&Machine->visible_area,TRANSPARENCY_PEN,0);
+				cliprect,TRANSPARENCY_PEN,0);
 	}
 
-	tilemap_draw(bitmap,fix_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,fix_tilemap,0,0);
 
 #ifdef MAME_DEBUG
 	slapfght_log_vram();
