@@ -7,7 +7,6 @@
 #define TC0100SCN_GFX_NUM 1
 
 extern UINT8 TC0360PRI_regs[16];
-void slapshot_vh_stop(void);
 
 struct tempsprite
 {
@@ -22,68 +21,36 @@ static struct tempsprite *spritelist;
 
 static int sprites_disabled,sprites_active_area,sprites_master_scrollx,sprites_master_scrolly;
 static int sprites_flipscreen = 0;
-static data16_t *spriteram_buffered,*spriteram_delayed;
+static UINT16 *spriteram_buffered,*spriteram_delayed;
 
 int taito_sprite_type = 0;
-data16_t *taito_sprite_ext;
+UINT16 *taito_sprite_ext;
 size_t taito_spriteext_size;
 static UINT16 spritebank[8];
 
 static int taito_hide_pixels;
 
+
+
 /**********************************************************/
 
-static int has_TC0480SCP(void)
-{
-	const struct Memory_WriteAddress16 *mwa;
-
-	/* scan the memory handlers and see if the TC0480SCP is used */
-
-	mwa = Machine->drv->cpu[0].memory_write;
-	if (mwa)
-	{
-		while (!IS_MEMPORT_END(mwa))
-		{
-			if (!IS_MEMPORT_MARKER(mwa))
-			{
-				if (mwa->handler == TC0480SCP_word_w)
-					return 1;
-			}
-			mwa++;
-		}
-	}
-
-	return 0;
-}
-
-
-
-int slapshot_core_vh_start (void)
+VIDEO_START( slapshot_core )
 {
 	int i;
 
-	spriteram_delayed = malloc(spriteram_size);
-	spriteram_buffered = malloc(spriteram_size);
-	spritelist = malloc(0x400 * sizeof(*spritelist));
-
-	if (!spriteram_delayed || !spriteram_buffered || !spritelist)
-		return 1;
+	spriteram_delayed = auto_malloc(spriteram_size);
+	spriteram_buffered = auto_malloc(spriteram_size);
+	spritelist = auto_malloc(0x400 * sizeof(*spritelist));
 
 	if (has_TC0480SCP())	/* it's a tc0480scp game */
 	{
 		if (TC0480SCP_vh_start(TC0480SCP_GFX_NUM,taito_hide_pixels,30,9,-1,1,0,2,256))
-		{
-			slapshot_vh_stop();
 			return 1;
-		}
 	}
 	else	/* it's a tc0100scn game */
 	{
 		if (TC0100SCN_vh_start(1,TC0100SCN_GFX_NUM,taito_hide_pixels,0,0,0,0,0,0))
-		{
-			slapshot_vh_stop();
 			return 1;
-		}
 	}
 
 	TC0360PRI_vh_start();	/* Purely for save-state purposes */
@@ -105,92 +72,73 @@ int slapshot_core_vh_start (void)
 	return 0;
 }
 
-int slapshot_vh_start (void)
+VIDEO_START( slapshot )
 {
 	taito_hide_pixels = 3;
 	taito_sprite_type = 2;
-	return (slapshot_core_vh_start());
-}
-
-void slapshot_vh_stop (void)
-{
-	free(spriteram_delayed);
-	spriteram_delayed = 0;
-	free(spriteram_buffered);
-	spriteram_buffered = 0;
-	free(spritelist);
-	spritelist = 0;
-
-	if (has_TC0480SCP())
-	{
-		TC0480SCP_vh_stop();
-	}
-	else
-	{
-		TC0100SCN_vh_stop();
-	}
+	return video_start_slapshot_core();
 }
 
 
 /************************************************************
-			SPRITE DRAW ROUTINES
+            SPRITE DRAW ROUTINES
 ************************************************************/
 
-static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y_offset)
+static void slapshot_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect,int *primasks,int y_offset)
 {
 	/*
-		Sprite format:
-		0000: ---xxxxxxxxxxxxx tile code (0x0000 - 0x1fff)
-		0002: xxxxxxxx-------- sprite y-zoom level
-		      --------xxxxxxxx sprite x-zoom level
+        Sprite format:
+        0000: ---xxxxxxxxxxxxx tile code (0x0000 - 0x1fff)
+        0002: xxxxxxxx-------- sprite y-zoom level
+              --------xxxxxxxx sprite x-zoom level
 
-			  0x00 - non scaled = 100%
-			  0x80 - scaled to 50%
-			  0xc0 - scaled to 25%
-			  0xe0 - scaled to 12.5%
-			  0xff - scaled to zero pixels size (off)
+              0x00 - non scaled = 100%
+              0x80 - scaled to 50%
+              0xc0 - scaled to 25%
+              0xe0 - scaled to 12.5%
+              0xff - scaled to zero pixels size (off)
 
-		[this zoom scale may not be 100% correct, see Gunfront flame screen]
+        [this zoom scale may not be 100% correct, see Gunfront flame screen]
 
-		0004: ----xxxxxxxxxxxx x-coordinate (-0x800 to 0x07ff)
-		      ---x------------ latch extra scroll
-		      --x------------- latch master scroll
-		      -x-------------- don't use extra scroll compensation
-		      x--------------- absolute screen coordinates (ignore all sprite scrolls)
-		      xxxx------------ the typical use of the above is therefore
-			                   1010 = set master scroll
-		                       0101 = set extra scroll
-		0006: ----xxxxxxxxxxxx y-coordinate (-0x800 to 0x07ff)
-		      x--------------- marks special control commands (used in conjunction with 00a)
-		                       If the special command flag is set:
-		      ---------------x related to sprite ram bank
-		      ---x------------ unknown (deadconx, maybe others)
-		      --x------------- unknown, some games (growl, gunfront) set it to 1 when
-		                       screen is flipped
-		0008: --------xxxxxxxx color (0x00 - 0xff)
-		      -------x-------- flipx
-		      ------x--------- flipy
-		      -----x---------- if set, use latched color, else use & latch specified one
-		      ----x----------- if set, next sprite entry is part of sequence
-		      ---x------------ if clear, use latched y coordinate, else use current y
-		      --x------------- if set, y += 16
-		      -x-------------- if clear, use latched x coordinate, else use current x
-		      x--------------- if set, x += 16
-		000a: only valid when the special command bit in 006 is set
-		      ---------------x related to sprite ram bank. I think this is the one causing
-		                       the bank switch, implementing it this way all games seem
-		                       to properly bank switch except for footchmp which uses the
-		                       bit in byte 006 instead.
-		      ------------x--- unknown; some games toggle it before updating sprite ram.
-		      ------xx-------- unknown (finalb)
-		      -----x---------- unknown (mjnquest)
-		      ---x------------ disable the following sprites until another marker with
-			                   this bit clear is found
-		      --x------------- flip screen
+        0004: ----xxxxxxxxxxxx x-coordinate (-0x800 to 0x07ff)
+              ---x------------ latch extra scroll
+              --x------------- latch master scroll
+              -x-------------- don't use extra scroll compensation
+              x--------------- absolute screen coordinates (ignore all sprite scrolls)
+              xxxx------------ the typical use of the above is therefore
+                               1010 = set master scroll
+                               0101 = set extra scroll
+        0006: ----xxxxxxxxxxxx y-coordinate (-0x800 to 0x07ff)
+              x--------------- marks special control commands (used in conjunction with 00a)
+                               If the special command flag is set:
+              ---------------x related to sprite ram bank
+              ---x------------ unknown (deadconx, maybe others)
+              --x------------- unknown, some games (growl, gunfront) set it to 1 when
+                               screen is flipped
+        0008: --------xxxxxxxx color (0x00 - 0xff)
+              -------x-------- flipx
+              ------x--------- flipy
+              -----x---------- if set, use latched color, else use & latch specified one
+              ----x----------- if set, next sprite entry is part of sequence
+              ---x------------ if clear, use latched y coordinate, else use current y
+              --x------------- if set, y += 16
+              -x-------------- if clear, use latched x coordinate, else use current x
+              x--------------- if set, x += 16
+        000a: only valid when the special command bit in 006 is set
+              ---------------x related to sprite ram bank. I think this is the one causing
+                               the bank switch, implementing it this way all games seem
+                               to properly bank switch except for footchmp which uses the
+                               bit in byte 006 instead.
+              ------------x--- unknown; some games toggle it before updating sprite ram.
+              ------xx-------- unknown (finalb)
+              -----x---------- unknown (mjnquest)
+              ---x------------ disable the following sprites until another marker with
+                               this bit clear is found
+              --x------------- flip screen
 
-		000b - 000f : unused
+        000b - 000f : unused
 
-	*/
+    */
 	int x,y,off,extoffs;
 	int code,color,spritedata,spritecont,flipx,flipy;
 	int xcurrent,ycurrent,big_sprite=0;
@@ -202,15 +150,15 @@ static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y
 	int x_offset;
 
 	/* pdrawgfx() needs us to draw sprites front to back, so we have to build a list
-	   while processing sprite ram and then draw them all at the end */
+       while processing sprite ram and then draw them all at the end */
 	struct tempsprite *sprite_ptr = spritelist;
 
 	/* must remember enable status from last frame because driftout fails to
-	   reactivate them from a certain point onwards. */
+       reactivate them from a certain point onwards. */
 	int disabled = sprites_disabled;
 
 	/* must remember master scroll from previous frame because driftout
-	   sometimes doesn't set it. */
+       sometimes doesn't set it. */
 	int master_scrollx = sprites_master_scrollx;
 	int master_scrolly = sprites_master_scrolly;
 
@@ -248,7 +196,7 @@ static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y
 			continue;
 		}
 
-/*usrintf_showmessage("%04x",area); */
+/*ui_popup("%04x",area); */
 
 		/* check for extra scroll offset */
 		if ((spriteram_buffered[(offs+4)/2] & 0xf000) == 0xa000)
@@ -364,8 +312,8 @@ static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y
 			if (zoomx || zoomy)
 			{
 				/* "Zoom" zx&y is pixel size horizontally and vertically
-				   of our sprite chunk. So it is difference in x and y
-				   coords of our chunk and diagonally adjoining one. */
+                   of our sprite chunk. So it is difference in x and y
+                   coords of our chunk and diagonally adjoining one. */
 
 				x = xlatch + x_no * (0x100 - zoomx) / 16;
 				y = ylatch + y_no * (0x100 - zoomy) / 16;
@@ -443,8 +391,8 @@ static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y
 		if (sprites_flipscreen)
 		{
 			/* -zx/y is there to fix zoomed sprite coords in screenflip.
-			   drawgfxzoom does not know to draw from flip-side of sprites when
-			   screen is flipped; so we must correct the coords ourselves. */
+               drawgfxzoom does not know to draw from flip-side of sprites when
+               screen is flipped; so we must correct the coords ourselves. */
 
 			curx = 319 - curx - zx;
 			cury = 256 - cury - zy;
@@ -479,7 +427,7 @@ static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y
 						sprite_ptr->color,
 						sprite_ptr->flipx,sprite_ptr->flipy,
 						sprite_ptr->x,sprite_ptr->y,
-						&Machine->visible_area,TRANSPARENCY_PEN,0,
+						cliprect,TRANSPARENCY_PEN,0,
 						sprite_ptr->zoomx,sprite_ptr->zoomy);
 			}
 		}
@@ -496,7 +444,7 @@ static void slapshot_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y
 				sprite_ptr->color,
 				sprite_ptr->flipx,sprite_ptr->flipy,
 				sprite_ptr->x,sprite_ptr->y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0,
+				cliprect,TRANSPARENCY_PEN,0,
 				sprite_ptr->zoomx,sprite_ptr->zoomy,
 				sprite_ptr->primask);
 	}
@@ -550,7 +498,7 @@ void taito_update_sprites_active_area(void)
 	}
 }
 
-void taito_no_buffer_eof_callback(void)
+VIDEO_EOF( taito_no_buffer )
 {
 	taito_update_sprites_active_area();
 
@@ -559,22 +507,22 @@ void taito_no_buffer_eof_callback(void)
 
 
 /**************************************************************
-				SCREEN REFRESH
+                SCREEN REFRESH
 
 Slapshot and Metalb use in the PRI chip
 ---------------------------------------
 
-+4	xxxx0000   BG1
-	0000xxxx   BG0
-+6	xxxx0000   BG3
-	0000xxxx   BG2
++4  xxxx0000   BG1
+    0000xxxx   BG0
++6  xxxx0000   BG3
+    0000xxxx   BG2
 
 Slapshot mostly keeps all sprites above the bg layers.
 One exception is the "puck" in early attract which is
 a bg layer given priority over some sprites.
 ********************************************************************/
 
-void slapshot_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( slapshot )
 {
 	UINT8 layer[5];
 	UINT8 tilepri[5];
@@ -583,43 +531,37 @@ void slapshot_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 #ifdef MAME_DEBUG
 	static int dislayer[5];	/* Layer toggles to help get the layers correct */
-	char buf[80];
 #endif
 
 #ifdef MAME_DEBUG
-	if (keyboard_pressed_memory (KEYCODE_Z))
+	if (code_pressed_memory (KEYCODE_Z))
 	{
 		dislayer[0] ^= 1;
-		sprintf(buf,"bg0: %01x",dislayer[0]);
-		usrintf_showmessage(buf);
+		ui_popup("bg0: %01x",dislayer[0]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_X))
+	if (code_pressed_memory (KEYCODE_X))
 	{
 		dislayer[1] ^= 1;
-		sprintf(buf,"bg1: %01x",dislayer[1]);
-		usrintf_showmessage(buf);
+		ui_popup("bg1: %01x",dislayer[1]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_C))
+	if (code_pressed_memory (KEYCODE_C))
 	{
 		dislayer[2] ^= 1;
-			sprintf(buf,"bg2: %01x",dislayer[2]);
-		usrintf_showmessage(buf);
+		ui_popup("bg2: %01x",dislayer[2]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_V))
+	if (code_pressed_memory (KEYCODE_V))
 	{
 		dislayer[3] ^= 1;
-		sprintf(buf,"bg3: %01x",dislayer[3]);
-		usrintf_showmessage(buf);
+		ui_popup("bg3: %01x",dislayer[3]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_B))
+	if (code_pressed_memory (KEYCODE_B))
 	{
 		dislayer[4] ^= 1;
-		sprintf(buf,"text: %01x",dislayer[4]);
-		usrintf_showmessage(buf);
+		ui_popup("text: %01x",dislayer[4]);
 	}
 #endif
 
@@ -648,28 +590,28 @@ void slapshot_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	spritepri[2] = TC0360PRI_regs[7] & 0x0f;
 	spritepri[3] = TC0360PRI_regs[7] >> 4;
 
-	fillbitmap(priority_bitmap,0,NULL);
-	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+	fillbitmap(priority_bitmap,0,cliprect);
+	fillbitmap(bitmap,Machine->pens[0],cliprect);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[0]]==0)
 #endif
-		TC0480SCP_tilemap_draw(bitmap,layer[0],0,1);
+		TC0480SCP_tilemap_draw(bitmap,cliprect,layer[0],0,1);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[1]]==0)
 #endif
-		TC0480SCP_tilemap_draw(bitmap,layer[1],0,2);
+		TC0480SCP_tilemap_draw(bitmap,cliprect,layer[1],0,2);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[2]]==0)
 #endif
-		TC0480SCP_tilemap_draw(bitmap,layer[2],0,4);
+		TC0480SCP_tilemap_draw(bitmap,cliprect,layer[2],0,4);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[3]]==0)
 #endif
-		TC0480SCP_tilemap_draw(bitmap,layer[3],0,8);
+		TC0480SCP_tilemap_draw(bitmap,cliprect,layer[3],0,8);
 
 	{
 		int primasks[4] = {0,0,0,0};
@@ -683,18 +625,18 @@ void slapshot_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 			if (spritepri[i] < tilepri[(layer[3])]) primasks[i] |= 0xff00;
 		}
 
-		slapshot_draw_sprites(bitmap,primasks,0);
+		slapshot_draw_sprites(bitmap,cliprect,primasks,0);
 	}
 
 	/*
-	TODO: This isn't the correct way to handle the priority. At the moment of
-	writing, pdrawgfx() doesn't support 5 layers, so I have to cheat, assuming
-	that the FG layer is always on top of sprites.
-	*/
+    TODO: This isn't the correct way to handle the priority. At the moment of
+    writing, pdrawgfx() doesn't support 5 layers, so I have to cheat, assuming
+    that the FG layer is always on top of sprites.
+    */
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[4]]==0)
 #endif
-	TC0480SCP_tilemap_draw(bitmap,layer[4],0,0);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[4],0,0);
 }
 
