@@ -11,7 +11,7 @@
 
 
 unsigned char *srumbler_backgroundram,*srumbler_foregroundram;
-static struct tilemap *bg_tilemap,*fg_tilemap;
+static tilemap *bg_tilemap,*fg_tilemap;
 
 
 
@@ -49,7 +49,7 @@ static void get_bg_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int srumbler_vh_start(void)
+VIDEO_START( srumbler )
 {
 	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_cols,TILEMAP_TRANSPARENT,8,8,64,32);
 	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_cols,TILEMAP_SPLIT,    16,16,64,64);
@@ -73,7 +73,7 @@ int srumbler_vh_start(void)
 
 ***************************************************************************/
 
-WRITE_HANDLER( srumbler_foreground_w )
+WRITE8_HANDLER( srumbler_foreground_w )
 {
 	if (srumbler_foregroundram[offset] != data)
 	{
@@ -82,7 +82,7 @@ WRITE_HANDLER( srumbler_foreground_w )
 	}
 }
 
-WRITE_HANDLER( srumbler_background_w )
+WRITE8_HANDLER( srumbler_background_w )
 {
 	if (srumbler_backgroundram[offset] != data)
 	{
@@ -92,7 +92,7 @@ WRITE_HANDLER( srumbler_background_w )
 }
 
 
-WRITE_HANDLER( srumbler_4009_w )
+WRITE8_HANDLER( srumbler_4009_w )
 {
 	/* bit 0 flips screen */
 	flip_screen_set(data & 1);
@@ -105,7 +105,7 @@ WRITE_HANDLER( srumbler_4009_w )
 }
 
 
-WRITE_HANDLER( srumbler_scroll_w )
+WRITE8_HANDLER( srumbler_scroll_w )
 {
 	static int scroll[4];
 
@@ -123,7 +123,7 @@ WRITE_HANDLER( srumbler_scroll_w )
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs;
 
@@ -131,17 +131,17 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 	for (offs = spriteram_size-4; offs>=0;offs -= 4)
 	{
 		/* SPRITES
-		=====
-		Attribute
-		0x80 Code MSB
-		0x40 Code MSB
-		0x20 Code MSB
-		0x10 Colour
-		0x08 Colour
-		0x04 Colour
-		0x02 y Flip
-		0x01 X MSB
-		*/
+        =====
+        Attribute
+        0x80 Code MSB
+        0x40 Code MSB
+        0x20 Code MSB
+        0x10 Colour
+        0x08 Colour
+        0x04 Colour
+        0x02 y Flip
+        0x01 X MSB
+        */
 
 
 		int code,colour,sx,sy,flipy;
@@ -165,20 +165,20 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				colour,
 				flip_screen,flipy,
 				sx, sy,
-				&Machine->visible_area,TRANSPARENCY_PEN,15);
+				cliprect,TRANSPARENCY_PEN,15);
 	}
 }
 
 
-void srumbler_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( srumbler )
 {
-	tilemap_draw(bitmap,bg_tilemap,TILEMAP_BACK,0);
-	draw_sprites(bitmap);
-	tilemap_draw(bitmap,bg_tilemap,TILEMAP_FRONT,0);
-	tilemap_draw(bitmap,fg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,TILEMAP_BACK,0);
+	draw_sprites(bitmap,cliprect);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,TILEMAP_FRONT,0);
+	tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 }
 
-void srumbler_eof_callback(void)
+VIDEO_EOF( srumbler )
 {
 	buffer_spriteram_w(0,0);
 }
