@@ -98,11 +98,11 @@ static int f_offset;
 
 static int palette_select;
 
-static struct mame_bitmap *tmpbitmap2;
-static struct mame_bitmap *bitmap_B;
-static struct mame_bitmap *bitmap_D;
-static struct mame_bitmap *bitmap_E;
-static struct mame_bitmap *bitmap_F;
+static mame_bitmap *tmpbitmap2;
+static mame_bitmap *bitmap_B;
+static mame_bitmap *bitmap_D;
+static mame_bitmap *bitmap_E;
+static mame_bitmap *bitmap_F;
 
 static unsigned char *beamdata;
 static int states_per_frame;
@@ -153,9 +153,7 @@ static unsigned char stactics_special_chars[32*8] = {
 static int firebeam_state;
 static int old_firebeam_state;
 
-void stactics_vh_convert_color_prom(unsigned char *palette,
-                                    unsigned short *colortable,
-                                    const unsigned char *color_prom)
+PALETTE_INIT( stactics )
 {
     int i,j;
 
@@ -166,7 +164,7 @@ void stactics_vh_convert_color_prom(unsigned char *palette,
 
     for (i=0;i<16;i++)
     {
-        int bit0,bit1,bit2, bit3;
+        int bit0,bit1,bit2, bit3,r,g,b;
 
         bit0 = i & 1;
         bit1 = (i >> 1) & 1;
@@ -174,13 +172,15 @@ void stactics_vh_convert_color_prom(unsigned char *palette,
         bit3 = (i >> 3) & 1;
 
         /* red component */
-        *(palette++) = 0xff * bit0;
+        r = 0xff * bit0;
 
         /* green component */
-        *(palette++) = 0xff * bit1 - 0xcc * bit3;
+        g = 0xff * bit1 - 0xcc * bit3;
 
         /* blue component */
-        *(palette++) = 0xff * bit2;
+        b = 0xff * bit2;
+
+		palette_set_color(i,r,g,b);
     }
 
     /* The color prom in Space Tactics is used for both   */
@@ -226,28 +226,28 @@ void stactics_vh_convert_color_prom(unsigned char *palette,
 
 ***************************************************************************/
 
-int stactics_vh_start(void)
+VIDEO_START( stactics )
 {
     int i,j;
     const unsigned char *firebeam_data;
     unsigned char firechar[256*8*9];
 
-    if ((tmpbitmap  = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0) return 1;
-    if ((tmpbitmap2 = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0) return 1;
-    if ((bitmap_B = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
-    if ((bitmap_D = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
-    if ((bitmap_E = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
-    if ((bitmap_F = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
+    if ((tmpbitmap  = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0) return 1;
+    if ((tmpbitmap2 = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0) return 1;
+    if ((bitmap_B = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
+    if ((bitmap_D = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
+    if ((bitmap_E = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
+    if ((bitmap_F = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)   return 1;
 
 	/* Allocate dirty buffers */
-	if ((dirty_videoram_b = (unsigned char *)malloc(videoram_size)) == 0)       return 1;
-	if ((dirty_videoram_d = (unsigned char *)malloc(videoram_size)) == 0)       return 1;
-	if ((dirty_videoram_e = (unsigned char *)malloc(videoram_size)) == 0)       return 1;
-	if ((dirty_videoram_f = (unsigned char *)malloc(videoram_size)) == 0)       return 1;
-	if ((dirty_chardata_b = (unsigned char *)malloc(DIRTY_CHARDATA_SIZE)) == 0) return 1;
-	if ((dirty_chardata_d = (unsigned char *)malloc(DIRTY_CHARDATA_SIZE)) == 0) return 1;
-	if ((dirty_chardata_e = (unsigned char *)malloc(DIRTY_CHARDATA_SIZE)) == 0) return 1;
-	if ((dirty_chardata_f = (unsigned char *)malloc(DIRTY_CHARDATA_SIZE)) == 0) return 1;
+	dirty_videoram_b = auto_malloc(videoram_size);
+	dirty_videoram_d = auto_malloc(videoram_size);
+	dirty_videoram_e = auto_malloc(videoram_size);
+	dirty_videoram_f = auto_malloc(videoram_size);
+	dirty_chardata_b = auto_malloc(DIRTY_CHARDATA_SIZE);
+	dirty_chardata_d = auto_malloc(DIRTY_CHARDATA_SIZE);
+	dirty_chardata_e = auto_malloc(DIRTY_CHARDATA_SIZE);
+	dirty_chardata_f = auto_malloc(DIRTY_CHARDATA_SIZE);
 
     memset(dirty_videoram_b,1,videoram_size);
     memset(dirty_videoram_d,1,videoram_size);
@@ -296,7 +296,7 @@ int stactics_vh_start(void)
     /* (I am basically just juggling the bytes */
     /* and storing it again to make it easier) */
 
-	if ((beamdata = (unsigned char *)malloc(BEAMDATA_SIZE)) == 0) return 1;
+	beamdata = auto_malloc(BEAMDATA_SIZE);
 
     firebeam_data = memory_region(REGION_GFX1);
 
@@ -331,34 +331,7 @@ int stactics_vh_start(void)
 }
 
 
-/***************************************************************************
-
-  Stop the video hardware emulation.
-
-***************************************************************************/
-void stactics_vh_stop(void)
-{
-	free(dirty_videoram_b);
-	free(dirty_videoram_d);
-	free(dirty_videoram_e);
-	free(dirty_videoram_f);
-	free(dirty_chardata_b);
-	free(dirty_chardata_d);
-	free(dirty_chardata_e);
-	free(dirty_chardata_f);
-
-	free(beamdata);
-
-    bitmap_free(tmpbitmap);
-    bitmap_free(tmpbitmap2);
-    bitmap_free(bitmap_B);
-    bitmap_free(bitmap_D);
-    bitmap_free(bitmap_E);
-    bitmap_free(bitmap_F);
-}
-
-
-WRITE_HANDLER( stactics_palette_w )
+WRITE8_HANDLER( stactics_palette_w )
 {
     int old_palette_select = palette_select;
 
@@ -385,7 +358,7 @@ WRITE_HANDLER( stactics_palette_w )
 }
 
 
-WRITE_HANDLER( stactics_scroll_ram_w )
+WRITE8_HANDLER( stactics_scroll_ram_w )
 {
     int temp;
 
@@ -417,7 +390,7 @@ WRITE_HANDLER( stactics_scroll_ram_w )
     }
 }
 
-WRITE_HANDLER( stactics_speed_latch_w )
+WRITE8_HANDLER( stactics_speed_latch_w )
 {
     /* This writes to a shift register which is clocked by   */
     /* a 555 oscillator.  This value determines the speed of */
@@ -441,17 +414,17 @@ WRITE_HANDLER( stactics_speed_latch_w )
     states_per_frame = num_rising_edges*19/8;
 }
 
-WRITE_HANDLER( stactics_shot_trigger_w )
+WRITE8_HANDLER( stactics_shot_trigger_w )
 {
     stactics_shot_standby = 0;
 }
 
-WRITE_HANDLER( stactics_shot_flag_clear_w )
+WRITE8_HANDLER( stactics_shot_flag_clear_w )
 {
     stactics_shot_arrive = 0;
 }
 
-WRITE_HANDLER( stactics_videoram_b_w )
+WRITE8_HANDLER( stactics_videoram_b_w )
 {
     if (stactics_videoram_b[offset] != data)
     {
@@ -460,7 +433,7 @@ WRITE_HANDLER( stactics_videoram_b_w )
     }
 }
 
-WRITE_HANDLER( stactics_chardata_b_w )
+WRITE8_HANDLER( stactics_chardata_b_w )
 {
     if (stactics_chardata_b[offset] != data)
     {
@@ -469,7 +442,7 @@ WRITE_HANDLER( stactics_chardata_b_w )
     }
 }
 
-WRITE_HANDLER( stactics_videoram_d_w )
+WRITE8_HANDLER( stactics_videoram_d_w )
 {
     if (stactics_videoram_d[offset] != data)
     {
@@ -478,7 +451,7 @@ WRITE_HANDLER( stactics_videoram_d_w )
     }
 }
 
-WRITE_HANDLER( stactics_chardata_d_w )
+WRITE8_HANDLER( stactics_chardata_d_w )
 {
     if (stactics_chardata_d[offset] != data)
     {
@@ -487,7 +460,7 @@ WRITE_HANDLER( stactics_chardata_d_w )
     }
 }
 
-WRITE_HANDLER( stactics_videoram_e_w )
+WRITE8_HANDLER( stactics_videoram_e_w )
 {
     if (stactics_videoram_e[offset] != data)
     {
@@ -496,7 +469,7 @@ WRITE_HANDLER( stactics_videoram_e_w )
     }
 }
 
-WRITE_HANDLER( stactics_chardata_e_w )
+WRITE8_HANDLER( stactics_chardata_e_w )
 {
     if (stactics_chardata_e[offset] != data)
     {
@@ -505,7 +478,7 @@ WRITE_HANDLER( stactics_chardata_e_w )
     }
 }
 
-WRITE_HANDLER( stactics_videoram_f_w )
+WRITE8_HANDLER( stactics_videoram_f_w )
 {
     if (stactics_videoram_f[offset] != data)
     {
@@ -514,7 +487,7 @@ WRITE_HANDLER( stactics_videoram_f_w )
     }
 }
 
-WRITE_HANDLER( stactics_chardata_f_w )
+WRITE8_HANDLER( stactics_chardata_f_w )
 {
     if (stactics_chardata_f[offset] != data)
     {
@@ -526,7 +499,7 @@ WRITE_HANDLER( stactics_chardata_f_w )
 /* Actual area for visible monitor stuff is only 30*8 lines */
 /* The rest is used for the score, etc. */
 
-static const struct rectangle visible_screen_area = {0*8, 32*8, 0*8, 30*8};
+static const rectangle visible_screen_area = {0*8, 32*8, 0*8, 30*8};
 
 /***************************************************************************
 
@@ -536,7 +509,7 @@ static const struct rectangle visible_screen_area = {0*8, 32*8, 0*8, 30*8};
 
 ***************************************************************************/
 
-void stactics_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( stactics )
 {
     int offs, sx, sy, i;
     int char_number;
