@@ -4,24 +4,24 @@
 
 *********************************************************************
 
-	MXC-06 chip to produce sprites, see dec0.c
-	BAC-06 chip for background?
+    MXC-06 chip to produce sprites, see dec0.c
+    BAC-06 chip for background?
 
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-data16_t *stadhero_pf1_data,*stadhero_pf2_data;
-static struct tilemap *pf1_tilemap,*pf2_tilemap;
+UINT16 *stadhero_pf1_data,*stadhero_pf2_data;
+static tilemap *pf1_tilemap,*pf2_tilemap;
 static int flipscreen;
 
-static data16_t stadhero_pf2_control_0[8];
-static data16_t stadhero_pf2_control_1[8];
+static UINT16 stadhero_pf2_control_0[8];
+static UINT16 stadhero_pf2_control_1[8];
 
 /******************************************************************************/
 
-static void stadhero_drawsprites(struct mame_bitmap *bitmap,int pri_mask,int pri_val)
+static void stadhero_drawsprites(mame_bitmap *bitmap,const rectangle *cliprect,int pri_mask,int pri_val)
 {
 	int offs;
 
@@ -78,7 +78,7 @@ static void stadhero_drawsprites(struct mame_bitmap *bitmap,int pri_mask,int pri
 					colour,
 					fx,fy,
 					x,y + mult * multi,
-					&Machine->visible_area,TRANSPARENCY_PEN,0);
+					cliprect,TRANSPARENCY_PEN,0);
 			multi--;
 		}
 	}
@@ -86,23 +86,23 @@ static void stadhero_drawsprites(struct mame_bitmap *bitmap,int pri_mask,int pri
 
 /******************************************************************************/
 
-void stadhero_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( stadhero )
 {
 	flipscreen=stadhero_pf2_control_0[0]&0x80;
 	tilemap_set_flip(ALL_TILEMAPS,flipscreen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 	tilemap_set_scrollx( pf2_tilemap,0, stadhero_pf2_control_1[0] );
 	tilemap_set_scrolly( pf2_tilemap,0, stadhero_pf2_control_1[1] );
 
-	tilemap_draw(bitmap,pf2_tilemap,0,0);
-	stadhero_drawsprites(bitmap,0x00,0x00);
-	tilemap_draw(bitmap,pf1_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,pf2_tilemap,0,0);
+	stadhero_drawsprites(bitmap,cliprect,0x00,0x00);
+	tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
 }
 
 /******************************************************************************/
 
 WRITE16_HANDLER( stadhero_pf1_data_w )
 {
-	data16_t oldword=stadhero_pf1_data[offset];
+	UINT16 oldword=stadhero_pf1_data[offset];
 	COMBINE_DATA(&stadhero_pf1_data[offset]);
 	if (oldword!=stadhero_pf1_data[offset])
 		tilemap_mark_tile_dirty(pf1_tilemap,offset);
@@ -110,7 +110,7 @@ WRITE16_HANDLER( stadhero_pf1_data_w )
 
 WRITE16_HANDLER( stadhero_pf2_data_w )
 {
-	data16_t oldword=stadhero_pf2_data[offset];
+	UINT16 oldword=stadhero_pf2_data[offset];
 	COMBINE_DATA(&stadhero_pf2_data[offset]);
 	if (oldword!=stadhero_pf2_data[offset])
 		tilemap_mark_tile_dirty(pf2_tilemap,offset);
@@ -162,7 +162,7 @@ static void get_pf1_tile_info(int tile_index)
 			0)
 }
 
-int stadhero_vh_start (void)
+VIDEO_START( stadhero )
 {
 	pf1_tilemap =     tilemap_create(get_pf1_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT, 8, 8,32,32);
 	pf2_tilemap =     tilemap_create(get_pf2_tile_info,stadhero_scan,TILEMAP_OPAQUE,     16,16,64,64);
