@@ -1,94 +1,105 @@
 /***************************************************************************
 
-							-=  SunA 8 Bit Games =-
+                            -=  SunA 8 Bit Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
-	These games have only sprites, of a peculiar type:
+    These games have only sprites, of a peculiar type:
 
-	there is a region of memory where 4 pages of 32x32 tile codes can
-	be written like a tilemap made of 4 pages of 256x256 pixels. Each
-	tile uses 2 bytes. Later games may use more pages through RAM
-	banking.
+    there is a region of memory where 4 pages of 32x32 tile codes can
+    be written like a tilemap made of 4 pages of 256x256 pixels. Each
+    tile uses 2 bytes. Later games may use more pages through RAM
+    banking.
 
-	Sprites are rectangular regions of *tiles* fetched from there and
-	sent to the screen. Each sprite uses 4 bytes, held within the last
-	page of tiles.
+    Sprites are rectangular regions of *tiles* fetched from there and
+    sent to the screen. Each sprite uses 4 bytes, held within the last
+    page of tiles.
 
-	* Note: later games use a more complex format than the following,
-	        which is yet to be completely understood.
+    * Note: later games use a more complex format than the following,
+            which is yet to be completely understood.
 
-							[ Sprites Format ]
+                            [ Sprites Format ]
 
 
-	Offset:			Bits:				Value:
+    Offset:         Bits:               Value:
 
-		0.b								Y (Bottom up)
+        0.b                             Y (Bottom up)
 
-		1.b			7--- ----			Sprite Size (1 = 2x32 tiles; 0 = 2x2)
+        1.b         7--- ----           Sprite Size (1 = 2x32 tiles; 0 = 2x2)
 
-					2x2 Sprites:
-					-65- ----			Tiles Row (height = 8 tiles)
-					---4 ----			Page
+                    2x2 Sprites:
+                    -65- ----           Tiles Row (height = 8 tiles)
+                    ---4 ----           Page
 
-					2x32 Sprites:
-					-6-- ----			Ignore X (Multisprite)
-					--54 ----			Page
+                    2x32 Sprites:
+                    -6-- ----           Ignore X (Multisprite)
+                    --54 ----           Page
 
-					---- 3210			Tiles Column (width = 2 tiles)
+                    ---- 3210           Tiles Column (width = 2 tiles)
 
-		2.b								X
+        2.b                             X
 
-		3.b			7--- ----
-					-6-- ----			X (Sign Bit)
-					--54 3---
-					---- -210			Tiles Bank
+        3.b         7--- ----
+                    -6-- ----           X (Sign Bit)
+                    --54 3---
+                    ---- -210           Tiles Bank
 
 
-						[ Sprite's Tiles Format ]
+                        [ Sprite's Tiles Format ]
 
 
-	Offset: 		Bits:					Value:
+    Offset:         Bits:                   Value:
 
-		0.b								Code (Low Bits)
+        0.b                             Code (Low Bits)
 
-		1.b			7--- ----			Flip Y
-					-6-- ----			Flip X
-					--54 32--			Color
-					---- --10			Code (High Bits)
+        1.b         7--- ----           Flip Y
+                    -6-- ----           Flip X
+                    --54 32--           Color
+                    ---- --10           Code (High Bits)
 
 
+
+    Set TILEMAPS to 1 to debug.
+    Press Z (you see the "tilemaps" in RAM) or
+    Press X (you see the "tilemaps" in ROM) then
+
+    - use Q&W to cycle through the pages.
+    - Use E&R to cycle through the tiles banks.
+    - Use A&S to cycle through the ROM banks (only with X pressed, of course).
+
 ***************************************************************************/
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
+#define TILEMAPS 0
+
 int suna8_text_dim; /* specifies format of text layer */
 
-data8_t suna8_rombank, suna8_spritebank, suna8_palettebank;
-data8_t suna8_unknown;
+UINT8 suna8_rombank, suna8_spritebank, suna8_palettebank;
+UINT8 suna8_unknown;
 
 /* Functions defined in vidhrdw: */
 
-WRITE_HANDLER( suna8_spriteram_w );			/* for debug */
-WRITE_HANDLER( suna8_banked_spriteram_w );	/* for debug */
+WRITE8_HANDLER( suna8_spriteram_w );			/* for debug */
+WRITE8_HANDLER( suna8_banked_spriteram_w );	/* for debug */
 
-int  suna8_vh_start(void);
-void suna8_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh);
+VIDEO_START( suna8 );
+VIDEO_UPDATE( suna8 );
 
 
 /***************************************************************************
-	For Debug: there's no tilemap, just sprites.
+    For Debug: there's no tilemap, just sprites.
 ***************************************************************************/
-
-static struct tilemap *tilemap;
-static int tiles, rombank;
+#if TILEMAPS
+static tilemap *bg_tilemap;
+static int tiles, rombank, page;
 
 static void get_tile_info(int tile_index)
 {
-	data8_t code, attr;
-	if (keyboard_pressed(KEYCODE_X))
-	{	data8_t *rom = memory_region(REGION_CPU1) + 0x10000 + 0x4000*rombank;
+	UINT8 code, attr;
+	if (code_pressed(KEYCODE_X))
+	{	UINT8 *rom = memory_region(REGION_CPU1) + 0x10000 + 0x4000*rombank;
 		code = rom[ 2 * tile_index + 0 ];
 		attr = rom[ 2 * tile_index + 1 ];	}
 	else
@@ -100,44 +111,48 @@ static void get_tile_info(int tile_index)
 			(attr >> 2) & 0xf,
 			TILE_FLIPYX( (attr >> 6) & 3 ))
 }
+#endif
 
 
-
-READ_HANDLER( suna8_banked_paletteram_r )
+READ8_HANDLER( suna8_banked_paletteram_r )
 {
 	offset += suna8_palettebank * 0x200;
 	return paletteram[offset];
 }
 
-READ_HANDLER( suna8_banked_spriteram_r )
+READ8_HANDLER( suna8_banked_spriteram_r )
 {
 	offset += suna8_spritebank * 0x2000;
 	return spriteram[offset];
 }
 
-WRITE_HANDLER( suna8_spriteram_w )
+WRITE8_HANDLER( suna8_spriteram_w )
 {
 	if (spriteram[offset] != data)
 	{
 		spriteram[offset] = data;
-		tilemap_mark_tile_dirty(tilemap,offset/2);
+#if TILEMAPS
+		tilemap_mark_tile_dirty(bg_tilemap,offset/2);
+#endif
 	}
 }
 
-WRITE_HANDLER( suna8_banked_spriteram_w )
+WRITE8_HANDLER( suna8_banked_spriteram_w )
 {
 	offset += suna8_spritebank * 0x2000;
 	if (spriteram[offset] != data)
 	{
 		spriteram[offset] = data;
-		tilemap_mark_tile_dirty(tilemap,offset/2);
+#if TILEMAPS
+		tilemap_mark_tile_dirty(bg_tilemap,offset/2);
+#endif
 	}
 }
 
 /*
-	Banked Palette RAM. The data is scrambled
+    Banked Palette RAM. The data is scrambled
 */
-WRITE_HANDLER( brickzn_banked_paletteram_w )
+WRITE8_HANDLER( brickzn_banked_paletteram_w )
 {
 	int r,g,b;
 	UINT16 rgb;
@@ -168,12 +183,6 @@ WRITE_HANDLER( brickzn_banked_paletteram_w )
 int suna8_vh_start_common(int dim)
 {
 	suna8_text_dim = dim;
-	tilemap = tilemap_create(	get_tile_info, tilemap_scan_cols,
-								TILEMAP_TRANSPARENT,
-								8,8,0x20*((suna8_text_dim > 0)?4:8),0x20);
-
-	if ( tilemap == NULL )	return 1;
-
 	if (!(suna8_text_dim > 0))
 	{
 		paletteram	=	memory_region(REGION_USER1);
@@ -182,23 +191,31 @@ int suna8_vh_start_common(int dim)
 		suna8_palettebank = 0;
 	}
 
-	tilemap_set_transparent_pen(tilemap,15);
+#if TILEMAPS
+	bg_tilemap = tilemap_create(	get_tile_info, tilemap_scan_cols,
+								TILEMAP_TRANSPARENT,
+								8,8,0x20*((suna8_text_dim > 0)?4:8),0x20);
+
+	if ( bg_tilemap == NULL )	return 1;
+	tilemap_set_transparent_pen(bg_tilemap,15);
+#endif
+
 	return 0;
 }
 
-int suna8_vh_start_textdim0(void)	{ return suna8_vh_start_common(0);  }
-int suna8_vh_start_textdim8(void)	{ return suna8_vh_start_common(8);  }
-int suna8_vh_start_textdim12(void)	{ return suna8_vh_start_common(12); }
+VIDEO_START( suna8_textdim0 )	{ return suna8_vh_start_common(0);  }
+VIDEO_START( suna8_textdim8 )	{ return suna8_vh_start_common(8);  }
+VIDEO_START( suna8_textdim12 )	{ return suna8_vh_start_common(12); }
 
 /***************************************************************************
 
 
-								Sprites Drawing
+                                Sprites Drawing
 
 
 ***************************************************************************/
 
-void suna8_draw_normal_sprites(struct mame_bitmap *bitmap)
+void suna8_draw_normal_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int i;
 	int mx = 0;	/* multisprite x counter */
@@ -209,7 +226,7 @@ void suna8_draw_normal_sprites(struct mame_bitmap *bitmap)
 	for (i = 0x1d00; i < 0x2000; i += 4)
 	{
 		int srcpg, srcx,srcy, dimx,dimy, tx, ty;
-		int gfxbank, flipx,flipy, multisprite;
+		int gfxbank, colorbank = 0, flipx,flipy, multisprite;
 
 		int y		=	spriteram[i + 0];
 		int code	=	spriteram[i + 1];
@@ -259,14 +276,16 @@ void suna8_draw_normal_sprites(struct mame_bitmap *bitmap)
 				gfxbank = bank & 0x1f;
 				srcpg = (code >> 4) & 3;
 				break;
+/* hardhea2: fire code=52/54 bank=a4; player code=02/04/06 bank=08; arrow:code=16 bank=27 */
 			case 0x40:
 				dimx = 4;					dimy = 4;
-				srcx  = (code & 0xf) * 2;
-				flipx = 0;
+				srcx  = (code & 0xe) * 2;
+				flipx = code & 0x01;
 				flipy = bank & 0x10;
 				srcy  = (((bank & 0x80)>>4) + (bank & 0x04) + ((~bank >> 4)&2)) * 2;
-				gfxbank = bank & 0x3;	/* ??? brickzn: 06,a6,a2,b2->6. starfigh: 01->01,4->0 */
 				srcpg = (code >> 4) & 7;
+				gfxbank = (bank & 0x3) + (srcpg & 4);	/* brickzn: 06,a6,a2,b2->6. starfigh: 01->01,4->0 */
+				colorbank = (bank & 8) >> 3;
 				break;
 			case 0x00:
 			default:
@@ -317,17 +336,17 @@ void suna8_draw_normal_sprites(struct mame_bitmap *bitmap)
 
 				drawgfx(	bitmap,Machine->gfx[0],
 							tile + (attr & 0x3)*0x100 + gfxbank,
-							(attr >> 2) & 0xf,
+							((attr >> 2) & 0xf) | colorbank,	/* hardhea2 player2 */
 							tile_flipx, tile_flipy,
 							sx, sy,
-							&Machine->visible_area,TRANSPARENCY_PEN,15);
+							cliprect,TRANSPARENCY_PEN,15);
 			}
 		}
 
 	}
 }
 
-void suna8_draw_text_sprites(struct mame_bitmap *bitmap)
+void suna8_draw_text_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int i;
 
@@ -385,7 +404,7 @@ void suna8_draw_text_sprites(struct mame_bitmap *bitmap)
 							(attr >> 2) & 0xf,
 							flipx, flipy,
 							sx, sy,
-							&Machine->visible_area,TRANSPARENCY_PEN,15);
+							cliprect,TRANSPARENCY_PEN,15);
 			}
 		}
 
@@ -395,68 +414,48 @@ void suna8_draw_text_sprites(struct mame_bitmap *bitmap)
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
-/*
-	Set TILEMAPS to 1 to debug.
-	Press Z (you see the "tilemaps" in RAM) or
-	Press X (you see the "tilemaps" in ROM) then
-
-	- use Q&W to cycle through the pages.
-	- Use R&T to cycle through the tiles banks.
-	- Use A&S to cycle through the ROM banks (only with X pressed, of course).
-*/
-#define TILEMAPS 0
-
-void suna8_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( suna8 )
 {
-#ifdef MAME_DEBUG
-#if TILEMAPS
-{
-	char buf[80];
-	int max_tiles = memory_region_length(REGION_GFX1) / (0x400 * 0x20);
-
-	if (keyboard_pressed_memory(KEYCODE_Q))	{ page--;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
-	if (keyboard_pressed_memory(KEYCODE_W))	{ page++;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
-	if (keyboard_pressed_memory(KEYCODE_R))	{ tiles--;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
-	if (keyboard_pressed_memory(KEYCODE_T))	{ tiles++;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
-	if (keyboard_pressed_memory(KEYCODE_A))	{ rombank--;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
-	if (keyboard_pressed_memory(KEYCODE_S))	{ rombank++;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
-
-	rombank  &= 0xf;
-	page  &= (suna8_text_dim > 0)?3:7;
-	tiles %= max_tiles;
-	if (tiles < 0)	tiles += max_tiles;
-
-	tilemap_set_scrollx( tilemap, 0, 0x100 * page);
-	tilemap_set_scrolly( tilemap, 0, 0);
-
-#if 1
-	sprintf(buf,	"%02X %02X %02X %02X - p%2X g%02X r%02X",
-					suna8_rombank, suna8_palettebank, suna8_spritebank, suna8_unknown,
-					page,tiles,rombank	);
-	usrintf_showmessage(buf);
-#endif
-
-}
-#endif
-#endif
-
 	/* see hardhead, hardhea2 test mode (press button 2 for both players) */
-	fillbitmap(bitmap,Machine->pens[0xff],&Machine->visible_area);
+	fillbitmap(bitmap,Machine->pens[0xff],cliprect);
 
 #ifdef MAME_DEBUG
 #if TILEMAPS
-	if (keyboard_pressed(KEYCODE_Z) || keyboard_pressed(KEYCODE_X))
-		tilemap_draw(bitmap, tilemap, 0, 0);
+	if (code_pressed(KEYCODE_Z) || code_pressed(KEYCODE_X))
+	{
+		int max_tiles = memory_region_length(REGION_GFX1) / (0x400 * 0x20);
+
+		if (code_pressed_memory(KEYCODE_Q))	{ page--;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
+		if (code_pressed_memory(KEYCODE_W))	{ page++;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
+		if (code_pressed_memory(KEYCODE_E))	{ tiles--;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
+		if (code_pressed_memory(KEYCODE_R))	{ tiles++;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
+		if (code_pressed_memory(KEYCODE_A))	{ rombank--;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
+		if (code_pressed_memory(KEYCODE_S))	{ rombank++;	tilemap_mark_all_tiles_dirty(ALL_TILEMAPS);	}
+
+		rombank  &= 0xf;
+		page  &= (suna8_text_dim > 0)?3:7;
+		tiles %= max_tiles;
+		if (tiles < 0)	tiles += max_tiles;
+
+		tilemap_set_scrollx( bg_tilemap, 0, 0x100 * page);
+		tilemap_set_scrolly( bg_tilemap, 0, 0);
+		tilemap_draw(bitmap,cliprect, bg_tilemap, 0, 0);
+#if 1
+	ui_popup("%02X %02X %02X %02X - p%2X g%02X r%02X",
+						suna8_rombank, suna8_palettebank, suna8_spritebank, suna8_unknown,
+						page,tiles,rombank	);
+#endif
+	}
 	else
 #endif
 #endif
 	{
-		suna8_draw_normal_sprites(bitmap);
-		suna8_draw_text_sprites(bitmap);
+		suna8_draw_normal_sprites(bitmap,cliprect);
+		suna8_draw_text_sprites(bitmap,cliprect);
 	}
 }
