@@ -15,19 +15,9 @@ struct tempsprite
 };
 static struct tempsprite *spritelist;
 
-void superchs_vh_stop (void)
+VIDEO_START( superchs )
 {
-	free(spritelist);
-	spritelist = 0;
-
-	TC0480SCP_vh_stop();
-}
-
-int superchs_vh_start (void)
-{
-	spritelist = malloc(0x4000 * sizeof(*spritelist));
-	if (!spritelist)
-		return 1;
+	spritelist = auto_malloc(0x4000 * sizeof(*spritelist));
 
 	if (TC0480SCP_vh_start(TC0480SCP_GFX_NUM,0,0x20,0x08,-1,0,0,0,0))
 		return 1;
@@ -36,17 +26,17 @@ int superchs_vh_start (void)
 }
 
 /************************************************************
-			SPRITE DRAW ROUTINES
+            SPRITE DRAW ROUTINES
 
 We draw a series of small tiles ("chunks") together to
 create each big sprite. The spritemap rom provides the lookup
 table for this. The game hardware looks up 16x16 sprite chunks
 from the spritemap rom, creating a 64x64 sprite like this:
 
-	 0  1  2  3
-	 4  5  6  7
-	 8  9 10 11
-	12 13 14 15
+     0  1  2  3
+     4  5  6  7
+     8  9 10 11
+    12 13 14 15
 
 (where the number is the word offset into the spritemap rom).
 It can also create 32x32 sprites.
@@ -58,32 +48,32 @@ spriteram is being tested, take no notice of that.]
 
 Heavy use is made of sprite zooming.
 
-		***
+        ***
 
-	Sprite table layout (4 long words per entry)
+    Sprite table layout (4 long words per entry)
 
-	------------------------------------------
-	 0 | ........ x....... ........ ........ | Flip X
-	 0 | ........ .xxxxxxx ........ ........ | ZoomX
-	 0 | ........ ........ .xxxxxxx xxxxxxxx | Sprite Tile
-	   |                                     |
-	 2 | ........ ....xx.. ........ ........ | Sprite/tile priority [*]
-	 2 | ........ ......xx xxxxxx.. ........ | Palette bank
-	 2 | ........ ........ ......xx xxxxxxxx | X position
-	   |                                     |
-	 3 | ........ .....x.. ........ ........ | Sprite size (0=32x32, 1=64x64)
-	 3 | ........ ......x. ........ ........ | Flip Y
-	 3 | ........ .......x xxxxxx.. ........ | ZoomY
-	 3 | ........ ........ ......xx xxxxxxxx | Y position
-	------------------------------------------
+    ------------------------------------------
+     0 | ........ x....... ........ ........ | Flip X
+     0 | ........ .xxxxxxx ........ ........ | ZoomX
+     0 | ........ ........ .xxxxxxx xxxxxxxx | Sprite Tile
+       |                                     |
+     2 | ........ ....xx.. ........ ........ | Sprite/tile priority [*]
+     2 | ........ ......xx xxxxxx.. ........ | Palette bank
+     2 | ........ ........ ......xx xxxxxxxx | X position
+       |                                     |
+     3 | ........ .....x.. ........ ........ | Sprite size (0=32x32, 1=64x64)
+     3 | ........ ......x. ........ ........ | Flip Y
+     3 | ........ .......x xxxxxx.. ........ | ZoomY
+     3 | ........ ........ ......xx xxxxxxxx | Y position
+    ------------------------------------------
 
-	[* 00=over BG1; 01=BG2; 10=BG3; 11=over text]
+    [* 00=over BG1; 01=BG2; 10=BG3; 11=over text]
 
 ********************************************************/
 
-static void superchs_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks,int x_offs,int y_offs)
+static void superchs_draw_sprites_16x16(mame_bitmap *bitmap,const rectangle *cliprect,const int *primasks,int x_offs,int y_offs)
 {
-	data16_t *spritemap = (data16_t *)memory_region(REGION_USER1);
+	UINT16 *spritemap = (UINT16 *)memory_region(REGION_USER1);
 	int offs, data, tilenum, color, flipx, flipy;
 	int x, y, priority, dblsize, curx, cury;
 	int sprites_flipscreen = 0;
@@ -92,7 +82,7 @@ static void superchs_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks
 	int dimension,total_chunks,bad_chunks;
 
 	/* pdrawgfx() needs us to draw sprites front to back, so we have to build a list
-	   while processing sprite ram and then draw them all at the end */
+       while processing sprite ram and then draw them all at the end */
 	struct tempsprite *sprite_ptr = spritelist;
 
 	for (offs = (spriteram_size/4-4);offs >= 0;offs -= 4)
@@ -163,8 +153,8 @@ static void superchs_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks
 				if (sprites_flipscreen)
 				{
 					/* -zx/y is there to fix zoomed sprite coords in screenflip.
-					   drawgfxzoom does not know to draw from flip-side of sprites when
-					   screen is flipped; so we must correct the coords ourselves. */
+                       drawgfxzoom does not know to draw from flip-side of sprites when
+                       screen is flipped; so we must correct the coords ourselves. */
 
 					curx = 320 - curx - zx;
 					cury = 256 - cury - zy;
@@ -195,7 +185,7 @@ static void superchs_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks
 							sprite_ptr->color,
 							sprite_ptr->flipx,sprite_ptr->flipy,
 							sprite_ptr->x,sprite_ptr->y,
-							&Machine->visible_area,TRANSPARENCY_PEN,0,
+							cliprect,TRANSPARENCY_PEN,0,
 							sprite_ptr->zoomx,sprite_ptr->zoomy);
 				}
 			}
@@ -215,7 +205,7 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 				sprite_ptr->color,
 				sprite_ptr->flipx,sprite_ptr->flipy,
 				sprite_ptr->x,sprite_ptr->y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0,
+				cliprect,TRANSPARENCY_PEN,0,
 				sprite_ptr->zoomx,sprite_ptr->zoomy,
 				sprite_ptr->primask);
 	}
@@ -223,14 +213,14 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 
 
 /**************************************************************
-				SCREEN REFRESH
+                SCREEN REFRESH
 **************************************************************/
 
-void superchs_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( superchs )
 {
 	UINT8 layer[5];
 	UINT16 priority;
-	int primasks[4] = {0xfffc, 0xfff0, 0xff00, 0x0};
+	static const int primasks[4] = {0xfffc, 0xfff0, 0xff00, 0x0};
 
 	TC0480SCP_tilemap_update();
 
@@ -241,24 +231,24 @@ void superchs_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	layer[3] = (priority &0x000f) >>  0;	/* tells us which is top */
 	layer[4] = 4;   /* text layer always over bg layers */
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
 	/* We have to assume 2nd to bottom layer is always underneath
-	   sprites as pdrawgfx cannot yet cope with more than 4 layers */
+       sprites as pdrawgfx cannot yet cope with more than 4 layers */
 
 #ifdef MAME_DEBUG
-	if (!keyboard_pressed (KEYCODE_Z)) TC0480SCP_tilemap_draw(bitmap,layer[0],TILEMAP_IGNORE_TRANSPARENCY,0);
-	if (!keyboard_pressed (KEYCODE_X)) TC0480SCP_tilemap_draw(bitmap,layer[1],0,1);
-	if (!keyboard_pressed (KEYCODE_C)) TC0480SCP_tilemap_draw(bitmap,layer[2],0,2);
-	if (!keyboard_pressed (KEYCODE_V)) TC0480SCP_tilemap_draw(bitmap,layer[3],0,4);
-	if (!keyboard_pressed (KEYCODE_B)) TC0480SCP_tilemap_draw(bitmap,layer[4],0,8);
-	if (!keyboard_pressed (KEYCODE_N)) superchs_draw_sprites_16x16(bitmap,primasks,48,-116);
+	if (!code_pressed (KEYCODE_Z)) TC0480SCP_tilemap_draw(bitmap,cliprect,layer[0],TILEMAP_IGNORE_TRANSPARENCY,0);
+	if (!code_pressed (KEYCODE_X)) TC0480SCP_tilemap_draw(bitmap,cliprect,layer[1],0,1);
+	if (!code_pressed (KEYCODE_C)) TC0480SCP_tilemap_draw(bitmap,cliprect,layer[2],0,2);
+	if (!code_pressed (KEYCODE_V)) TC0480SCP_tilemap_draw(bitmap,cliprect,layer[3],0,4);
+	if (!code_pressed (KEYCODE_B)) TC0480SCP_tilemap_draw(bitmap,cliprect,layer[4],0,8);
+	if (!code_pressed (KEYCODE_N)) superchs_draw_sprites_16x16(bitmap,cliprect,primasks,48,-116);
 #else
-	TC0480SCP_tilemap_draw(bitmap,layer[0],TILEMAP_IGNORE_TRANSPARENCY,0);
-	TC0480SCP_tilemap_draw(bitmap,layer[1],0,1);
-	TC0480SCP_tilemap_draw(bitmap,layer[2],0,2);
-	TC0480SCP_tilemap_draw(bitmap,layer[3],0,4);
-	TC0480SCP_tilemap_draw(bitmap,layer[4],0,8);	/* text layer */
-	superchs_draw_sprites_16x16(bitmap,primasks,48,-116);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[0],TILEMAP_IGNORE_TRANSPARENCY,0);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[1],0,1);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[2],0,2);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[3],0,4);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[4],0,8);	/* text layer */
+	superchs_draw_sprites_16x16(bitmap,cliprect,primasks,48,-116);
 #endif
 }
