@@ -38,31 +38,22 @@ static void sprite_callback(int *code,int *color,int *priority_mask)
 
 /***************************************************************************
 
-	Start the video hardware emulation.
+    Start the video hardware emulation.
 
 ***************************************************************************/
 
-int surpratk_vh_start( void )
+VIDEO_START( surpratk )
 {
+	K053251_vh_start();
+
 	if (K052109_vh_start(REGION_GFX1,NORMAL_PLANE_ORDER,tile_callback))
-	{
 		return 1;
-	}
-	if (K053245_vh_start(REGION_GFX2,NORMAL_PLANE_ORDER,sprite_callback))
-	{
-		K052109_vh_stop();
+	if (K053245_vh_start(0,REGION_GFX2,NORMAL_PLANE_ORDER,sprite_callback))
 		return 1;
-	}
 
 	return 0;
 }
 
-void surpratk_vh_stop( void )
-{
-	K052109_vh_stop();
-	K053245_vh_stop();
-}
-
 /* useful function to sort the three tile layers by priority order */
 static void sortlayers(int *layer,int *pri)
 {
@@ -79,7 +70,7 @@ static void sortlayers(int *layer,int *pri)
 	SWAP(1,2)
 }
 
-void surpratk_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( surpratk )
 {
 	int layer[3];
 
@@ -101,11 +92,11 @@ void surpratk_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	sortlayers(layer,layerpri);
 
-	fillbitmap(priority_bitmap,0,NULL);
-	fillbitmap(bitmap,Machine->pens[16 * bg_colorbase],&Machine->visible_area);
-	K052109_tilemap_draw(bitmap,layer[0],0,1);
-	K052109_tilemap_draw(bitmap,layer[1],0,2);
-	K052109_tilemap_draw(bitmap,layer[2],0,4);
+	fillbitmap(priority_bitmap,0,cliprect);
+	fillbitmap(bitmap,Machine->pens[16 * bg_colorbase],cliprect);
+	tilemap_draw(bitmap,cliprect,K052109_tilemap[layer[0]],0,1);
+	tilemap_draw(bitmap,cliprect,K052109_tilemap[layer[1]],0,2);
+	tilemap_draw(bitmap,cliprect,K052109_tilemap[layer[2]],0,4);
 
-	K053245_sprites_draw(bitmap);
+	K053245_sprites_draw(0,bitmap,cliprect);
 }
