@@ -24,7 +24,7 @@ static int background_scrollx=0,background_scrolly=0;
 static unsigned char *bg_dirtybuffer;
 
 static int scrollx_row[32];
-static struct mame_bitmap *tmp_bitmap;
+static mame_bitmap *tmp_bitmap;
 
 /*static int system1_pixel_mode = 0 */
 static int system1_background_memory,system1_video_mode=0;
@@ -34,6 +34,8 @@ static const unsigned char *system1_color_prom;
 static unsigned char *wbml_paged_videoram;
 static unsigned char wbml_videoram_bank=0,wbml_videoram_bank_latch=0;
 
+static int blockgal_kludgeoffset;
+
 /***************************************************************************
 
   There are two kind of color handling: in the System 1 games, values in the
@@ -49,19 +51,19 @@ static unsigned char wbml_videoram_bank=0,wbml_videoram_bank_latch=0;
   Green:.250K ohms
   Green:.495K ohms
   Green:.995K ohms
-  Red: .495K ohms
-  Red: .250K ohms
-  Red: .995K ohms
+  Red:  .495K ohms
+  Red:  .250K ohms
+  Red:  .995K ohms
 
   accurate to +/- .003K ohms.
 
 ***************************************************************************/
-void system1_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( system1 )
 {
 	system1_color_prom = color_prom;
 }
 
-WRITE_HANDLER( system1_paletteram_w )
+WRITE8_HANDLER( system1_paletteram_w )
 {
 	int val,r,g,b;
 
@@ -111,45 +113,23 @@ WRITE_HANDLER( system1_paletteram_w )
 
 
 
-int system1_vh_start(void)
+VIDEO_START( system1 )
 {
-	if ((sprite_onscreen_map = malloc(256*256)) == 0)
-		return 1;
+	sprite_onscreen_map = auto_malloc(256*256);
 	memset(sprite_onscreen_map,255,256*256);
 
-	if ((bg_dirtybuffer = malloc(1024)) == 0)
-	{
-		free(sprite_onscreen_map);
-		return 1;
-	}
+	bg_dirtybuffer = auto_malloc(1024);
 	memset(bg_dirtybuffer,1,1024);
-	if ((wbml_paged_videoram = malloc(0x4000)) == 0)			/* Allocate 16k for background banked ram */
-	{
-		free(bg_dirtybuffer);
-		free(sprite_onscreen_map);
-		return 1;
-	}
+	wbml_paged_videoram = auto_malloc(0x4000);	/* Allocate 16k for background banked ram */
 	memset(wbml_paged_videoram,0,0x4000);
-	if ((tmp_bitmap = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
-	{
-		free(wbml_paged_videoram);
-		free(bg_dirtybuffer);
-		free(sprite_onscreen_map);
+
+	if ((tmp_bitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
 		return 1;
-	}
 
 	return 0;
 }
 
-void system1_vh_stop(void)
-{
-	bitmap_free(tmp_bitmap);
-	free(wbml_paged_videoram);
-	free(bg_dirtybuffer);
-	free(sprite_onscreen_map);
-}
-
-WRITE_HANDLER( system1_videomode_w )
+WRITE8_HANDLER( system1_videomode_w )
 {
 if (data & 0x6e) logerror("videomode = %02x\n",data);
 
@@ -163,7 +143,7 @@ if (data & 0x6e) logerror("videomode = %02x\n",data);
 	flip_screen_set(data & 0x80);
 }
 
-READ_HANDLER( system1_videomode_r )
+READ8_HANDLER( system1_videomode_r )
 {
 	return system1_video_mode;
 }
@@ -179,7 +159,7 @@ INLINE int get_sprite_bottom_y(int spr_number)
 	return  spriteram[0x10 * spr_number + SPR_Y_BOTTOM];
 }
 
-INLINE void draw_pixel(struct mame_bitmap *bitmap,
+INLINE void draw_pixel(mame_bitmap *bitmap,
 				  	   int x,int y,int x_flipped,int y_flipped,
 				  	   int spr_number,int color)
 {
@@ -187,8 +167,8 @@ INLINE void draw_pixel(struct mame_bitmap *bitmap,
 	int sprite_onscreen;
 
 
-	if (x < 0 || x >= Machine->scrbitmap->width ||
-		y < 0 || y >= Machine->scrbitmap->height)
+	if (x < 0 || x >= Machine->drv->screen_width ||
+		y < 0 || y >= Machine->drv->screen_height)
 		return;
 
 	if (sprite_onscreen_map[256*y+x] != 255)
@@ -231,14 +211,14 @@ INLINE void draw_pixel(struct mame_bitmap *bitmap,
 	/* (TeddyBoy Blues, head of the tiger in girl bonus round) */
 }
 
-WRITE_HANDLER( system1_background_collisionram_w )
+WRITE8_HANDLER( system1_background_collisionram_w )
 {
 	/* to do the RAM check, Mister Viking writes 0xff and immediately */
 	/* reads it back, expecting bit 0 to be NOT set. */
 	system1_background_collisionram[offset] = 0x7e;
 }
 
-WRITE_HANDLER( system1_sprites_collisionram_w )
+WRITE8_HANDLER( system1_sprites_collisionram_w )
 {
 	/* to do the RAM check, Mister Viking write 0xff and immediately */
 	/* reads it back, expecting bit 0 to be NOT set. */
@@ -249,9 +229,10 @@ WRITE_HANDLER( system1_sprites_collisionram_w )
 
 
 
-extern struct GameDriver driver_wbml;
+extern game_driver driver_wbml;
+extern game_driver driver_ufosensi;
 
-static void draw_sprite(struct mame_bitmap *bitmap,int spr_number)
+static void draw_sprite(mame_bitmap *bitmap,int spr_number)
 {
 	int sy,row,height,src,bank;
 	unsigned char *sprite_base;
@@ -285,7 +266,8 @@ static void draw_sprite(struct mame_bitmap *bitmap,int spr_number)
 
 		/* the +1 prevents sprite lag in Wonder Boy */
 		x = sprite_base[SPR_X_LO] + ((sprite_base[SPR_X_HI] & 0x01) << 8) + 1;
-		if (Machine->gamedrv == &driver_wbml || Machine->gamedrv->clone_of == &driver_wbml)
+		if (Machine->gamedrv == &driver_wbml || Machine->gamedrv->clone_of == &driver_wbml ||
+			Machine->gamedrv == &driver_ufosensi || Machine->gamedrv->clone_of == &driver_ufosensi)
 		{
 			x += 7*2;
 		}
@@ -338,7 +320,7 @@ static void draw_sprite(struct mame_bitmap *bitmap,int spr_number)
 }
 
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap)
 {
 	int spr_number,sprite_bottom_y,sprite_top_y;
 	unsigned char *sprite_base;
@@ -358,14 +340,14 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 
 
 
-WRITE_HANDLER( system1_backgroundram_w )
+WRITE8_HANDLER( system1_backgroundram_w )
 {
 	system1_backgroundram[offset] = data;
 	bg_dirtybuffer[offset>>1] = 1;
 }
 
 
-static int system1_draw_fg(struct mame_bitmap *bitmap,int priority)
+static int system1_draw_fg(mame_bitmap *bitmap,int priority)
 {
 	int sx,sy,offs;
 	int drawn = 0;
@@ -392,6 +374,7 @@ static int system1_draw_fg(struct mame_bitmap *bitmap,int priority)
 				sy = 31 - sy;
 			}
 
+			code %= Machine->gfx[0]->total_elements;
 			if (Machine->gfx[0]->pen_usage[code] & ~1)
 			{
 				drawn = 1;
@@ -400,7 +383,7 @@ static int system1_draw_fg(struct mame_bitmap *bitmap,int priority)
 						code,
 						color,
 						flip_screen,flip_screen,
-						8*sx,8*sy,
+						8*sx + blockgal_kludgeoffset,8*sy,
 						&Machine->visible_area,TRANSPARENCY_PEN,0);
 			}
 		}
@@ -409,13 +392,13 @@ static int system1_draw_fg(struct mame_bitmap *bitmap,int priority)
 	return drawn;
 }
 
-static void system1_draw_bg(struct mame_bitmap *bitmap,int priority)
+static void system1_draw_bg(mame_bitmap *bitmap,int priority)
 {
 	int sx,sy,offs;
 	int background_scrollx_flip, background_scrolly_flip;
 
 
-	background_scrollx = ((system1_scroll_x[0] >> 1) + ((system1_scroll_x[1] & 1) << 7) + 14) & 0xff;
+	background_scrollx = ((system1_scroll_x[0] >> 1) + ((system1_scroll_x[1] & 1) << 7) + 14 + 2*blockgal_kludgeoffset) & 0xff;
 	background_scrolly = (-*system1_scroll_y) & 0xff;
 
 	background_scrollx_flip = (275 - background_scrollx) & 0xff;
@@ -426,8 +409,8 @@ static void system1_draw_bg(struct mame_bitmap *bitmap,int priority)
 		/* optimized far background */
 
 		/* for every character in the background video RAM, check if it has
-		 * been modified since last time and update it accordingly.
-		 */
+         * been modified since last time and update it accordingly.
+         */
 
 		for (offs = 0;offs < system1_backgroundram_size;offs += 2)
 		{
@@ -523,7 +506,7 @@ static void system1_draw_bg(struct mame_bitmap *bitmap,int priority)
 	}
 }
 
-void system1_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( system1 )
 {
 	int drawn;
 
@@ -549,14 +532,14 @@ void system1_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 
 
-WRITE_HANDLER( choplifter_scroll_x_w )
+WRITE8_HANDLER( choplifter_scroll_x_w )
 {
 	system1_scrollx_ram[offset] = data;
 
 	scrollx_row[offset/2] = (system1_scrollx_ram[offset & ~1] >> 1) + ((system1_scrollx_ram[offset | 1] & 1) << 7);
 }
 
-static void chplft_draw_bg(struct mame_bitmap *bitmap, int priority)
+static void chplft_draw_bg(mame_bitmap *bitmap, int priority)
 {
 	int sx,sy,offs;
 	int choplifter_scroll_x_on = (system1_scrollx_ram[0] == 0xe5 && system1_scrollx_ram[1] == 0xff) ? 0 : 1;
@@ -567,8 +550,8 @@ static void chplft_draw_bg(struct mame_bitmap *bitmap, int priority)
 		/* optimized far background */
 
 		/* for every character in the background video RAM, check if it has
-		 * been modified since last time and update it accordingly.
-		 */
+         * been modified since last time and update it accordingly.
+         */
 
 		for (offs = 0;offs < system1_backgroundram_size;offs += 2)
 		{
@@ -663,7 +646,7 @@ static void chplft_draw_bg(struct mame_bitmap *bitmap, int priority)
 	}
 }
 
-void choplifter_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( choplifter )
 {
 	int drawn;
 
@@ -682,7 +665,7 @@ void choplifter_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 
 #ifdef MAME_DEBUG
-	if (keyboard_pressed(KEYCODE_SPACE))		/* goto next level */
+	if (code_pressed(KEYCODE_SPACE))		/* goto next level */
 	{
 		memory_region(REGION_CPU1)[0xC085]=33;
 	}
@@ -691,32 +674,31 @@ void choplifter_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 
 
-READ_HANDLER( wbml_videoram_bank_latch_r )
+READ8_HANDLER( wbml_videoram_bank_latch_r )
 {
 	return wbml_videoram_bank_latch;
 }
 
-WRITE_HANDLER( wbml_videoram_bank_latch_w )
+WRITE8_HANDLER( wbml_videoram_bank_latch_w )
 {
 	wbml_videoram_bank_latch = data;
 	wbml_videoram_bank = (data >> 1) & 0x03;	/* Select 4 banks of 4k, bit 2,1 */
 }
 
-READ_HANDLER( wbml_paged_videoram_r )
+READ8_HANDLER( wbml_paged_videoram_r )
 {
 	return wbml_paged_videoram[0x1000*wbml_videoram_bank + offset];
 }
 
-WRITE_HANDLER( wbml_paged_videoram_w )
+WRITE8_HANDLER( wbml_paged_videoram_w )
 {
 	wbml_paged_videoram[0x1000*wbml_videoram_bank + offset] = data;
 }
 
-static void wbml_draw_bg(struct mame_bitmap *bitmap, int trasp)
+static void wbml_draw_bg(mame_bitmap *bitmap, int trasp)
 {
 	int page;
 
-
 	int xscroll = (wbml_paged_videoram[0x7c0] >> 1) + ((wbml_paged_videoram[0x7c1] & 1) << 7) - 256 + 5;
 	int yscroll = -wbml_paged_videoram[0x7ba];
 
@@ -769,7 +751,7 @@ static void wbml_draw_bg(struct mame_bitmap *bitmap, int trasp)
 	} /* next page */
 }
 
-static void wbml_draw_fg(struct mame_bitmap *bitmap)
+static void wbml_draw_fg(mame_bitmap *bitmap)
 {
 	int offs;
 
@@ -800,7 +782,7 @@ static void wbml_draw_fg(struct mame_bitmap *bitmap)
 }
 
 
-void wbml_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( wbml )
 {
 	wbml_draw_bg(bitmap,0);
 	draw_sprites(bitmap);
@@ -811,3 +793,94 @@ void wbml_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	if (system1_video_mode & 0x10)  /* screen off */
 		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
 }
+
+/* same as wbml but with rows scroll */
+static void ufosensi_draw_bg(mame_bitmap *bitmap, int trasp)
+{
+	int page;
+
+	int yscroll = -wbml_paged_videoram[0x7ba];
+
+	for (page=0; page < 4; page++)
+	{
+		const unsigned char *source = wbml_paged_videoram + (wbml_paged_videoram[0x0740 + page*2] & 0x07)*0x800;
+		int starty = (page>>1)*256+yscroll;
+		int row,col;
+
+
+		for( row=0; row<32*8; row+=8 )
+		{
+			for( col=0; col<32*8; col+=8 )
+			{
+				int code,priority;
+				int xscroll = (wbml_paged_videoram[0x7c0 + row/4] >> 1) + ((wbml_paged_videoram[0x7c1 + row/4] & 1) << 7) - 256 + 5;
+				int startx = (page&1)*256+xscroll;
+				int x = (startx+col) & 0x1ff;
+				int y = (starty+row) & 0x1ff;
+				if (x > 256) x -= 512;
+				if (y > 224) y -= 512;
+
+				if (flip_screen)
+				{
+					x = 248 - x;
+					y = 248 - y;
+				}
+
+				code = source[0] + (source[1] << 8);
+				priority = code & 0x800;
+				code = ((code >> 4) & 0x800) | (code & 0x7ff);
+
+				if (!trasp)
+					drawgfx(bitmap,Machine->gfx[0],
+							code,
+							((code >> 5) & 0x3f) + 64,
+							flip_screen,flip_screen,
+							x,y,
+							&Machine->visible_area, TRANSPARENCY_NONE, 0);
+				else if (priority)
+					drawgfx(bitmap,Machine->gfx[0],
+							code,
+							((code >> 5) & 0x3f) + 64,
+							flip_screen,flip_screen,
+							x,y,
+							&Machine->visible_area, TRANSPARENCY_PEN, 0);
+
+				source+=2;
+			}
+		}
+	} /* next page */
+}
+
+VIDEO_UPDATE( ufosensi )
+{
+	ufosensi_draw_bg(bitmap,0);
+	draw_sprites(bitmap);
+	ufosensi_draw_bg(bitmap,1);
+	wbml_draw_fg(bitmap);
+
+	/* even if screen is off, sprites must still be drawn to update the collision table */
+	if (system1_video_mode & 0x10)  /* screen off */
+		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+}
+
+VIDEO_UPDATE( blockgal )
+{
+	int drawn;
+
+
+	blockgal_kludgeoffset = -8;
+
+	system1_draw_bg(bitmap,-1);
+	drawn = system1_draw_fg(bitmap,0);
+	/* redraw low priority bg tiles if necessary */
+	if (drawn) system1_draw_bg(bitmap,0);
+	draw_sprites(bitmap);
+	system1_draw_bg(bitmap,1);
+	system1_draw_fg(bitmap,1);
+
+	/* even if screen is off, sprites must still be drawn to update the collision table */
+	if (system1_video_mode & 0x10)  /* screen off */
+		fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+
+	blockgal_kludgeoffset = 0;
+}
