@@ -51,10 +51,10 @@ sprite RAM
 #include "taitoic.h"
 
 
-extern data16_t	*TC0080VCO_chain_ram_0;
-extern data16_t	*TC0080VCO_chain_ram_1;
-extern data16_t	*TC0080VCO_spriteram;
-extern data16_t	*TC0080VCO_scroll_ram;
+extern UINT16	*TC0080VCO_chain_ram_0;
+extern UINT16	*TC0080VCO_chain_ram_1;
+extern UINT16	*TC0080VCO_spriteram;
+extern UINT16	*TC0080VCO_scroll_ram;
 extern int		TC0080VCO_flipscreen;
 
 /* Needed in the sprite palette color marking */
@@ -81,53 +81,41 @@ static int zoomy_conv_table[] =
   Initialize and destroy video hardware emulation
 ***************************************************************************/
 
-int syvalion_vh_start(void)
+VIDEO_START( syvalion )
 {
 	if ( TC0080VCO_vh_start(0,1,1,1,-2))
-	{
 		return 1;
-	}
 
 	return 0;
 }
 
-int recordbr_vh_start(void)
+VIDEO_START( recordbr )
 {
 	if ( TC0080VCO_vh_start(0,0,1,1,-2))
-	{
 		return 1;
-	}
 
 	return 0;
 }
 
-int dleague_vh_start(void)
+VIDEO_START( dleague )
 {
 	if ( TC0080VCO_vh_start(0,0,1,1,-2))
-	{
 		return 1;
-	}
 
 	return 0;
 }
 
-void syvalion_vh_stop(void)
-{
-	TC0080VCO_vh_stop();
-	return;
-}
-
 
 /***************************************************************************
   Screen refresh
 ***************************************************************************/
 
-static void syvalion_draw_sprites(struct mame_bitmap *bitmap)
+static void syvalion_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	/* Y chain size is 16/32?/64/64? pixels. X chain size
-	   is always 64 pixels. */
+       is always 64 pixels. */
 
-	int size[] = { 1, 2, 4, 4 };
+	static const int size[] = { 1, 2, 4, 4 };
 	int x0, y0, x, y, dx, ex, zx;
 	int ysize;
 	int j, k;
@@ -201,7 +189,7 @@ static void syvalion_draw_sprites(struct mame_bitmap *bitmap)
 								 color,
 								 flipx, flipy,
 								 x, y,
-								 &Machine->visible_area,
+								 cliprect,
 								 TRANSPARENCY_PEN, 0,
 								 zx, zx
 						);
@@ -215,12 +203,12 @@ static void syvalion_draw_sprites(struct mame_bitmap *bitmap)
 	}
 }
 
-static void recordbr_draw_sprites(struct mame_bitmap *bitmap, int priority)
+static void recordbr_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect, int priority)
 {
 	/* Y chain size is 16/32?/64/64? pixels. X chain size
-	   is always 64 pixels. */
+       is always 64 pixels. */
 
-	int size[] = { 1, 2, 4, 4 };
+	static const int size[] = { 1, 2, 4, 4 };
 	int x0, y0, x, y, dx, dy, ex, ey, zx, zy;
 	int ysize;
 	int j, k;
@@ -313,7 +301,7 @@ static void recordbr_draw_sprites(struct mame_bitmap *bitmap, int priority)
 								 color,
 								 flipx, flipy,
 								 x, y,
-								 &Machine->visible_area,
+								 cliprect,
 								 TRANSPARENCY_PEN, 0,
 								 zx, zy
 						);
@@ -327,12 +315,12 @@ static void recordbr_draw_sprites(struct mame_bitmap *bitmap, int priority)
 	}
 }
 
-static void dleague_draw_sprites(struct mame_bitmap *bitmap, int priority)
+static void dleague_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect, int priority)
 {
 	/* Y chain size is 16/32?/64/64? pixels. X chain size
-	   is always 64 pixels. */
+       is always 64 pixels. */
 
-	int size[] = { 1, 2, 4, 4 };
+	static const int size[] = { 1, 2, 4, 4 };
 	int x0, y0, x, y, dx, ex, zx;
 	int ysize;
 	int j, k;
@@ -414,7 +402,7 @@ static void dleague_draw_sprites(struct mame_bitmap *bitmap, int priority)
 									 color,
 									 flipx, flipy,
 									 x, y,
-									 &Machine->visible_area,
+									 cliprect,
 									 TRANSPARENCY_PEN, 0,
 									 zx, zx
 							);
@@ -444,7 +432,7 @@ static void taitoh_log_vram(void)
 
 /**************************************************************************/
 
-void syvalion_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( syvalion )
 {
 	TC0080VCO_tilemap_update();
 
@@ -452,16 +440,16 @@ void syvalion_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	taitoh_log_vram();
 #endif
 
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
+	fillbitmap(bitmap, Machine->pens[0], cliprect);
 
-	TC0080VCO_tilemap_draw(bitmap,0,TILEMAP_IGNORE_TRANSPARENCY,0);
-	TC0080VCO_tilemap_draw(bitmap,1,0,0);
-	syvalion_draw_sprites (bitmap);
-	TC0080VCO_tilemap_draw(bitmap,2,0,0);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,0,TILEMAP_IGNORE_TRANSPARENCY,0);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,1,0,0);
+	syvalion_draw_sprites (bitmap,cliprect);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,2,0,0);
 }
 
 
-void recordbr_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( recordbr )
 {
 	TC0080VCO_tilemap_update();
 
@@ -469,29 +457,29 @@ void recordbr_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	taitoh_log_vram();
 #endif
 
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
+	fillbitmap(bitmap, Machine->pens[0], cliprect);
 
 #ifdef MAME_DEBUG
-	if ( !keyboard_pressed(KEYCODE_A) )
-		TC0080VCO_tilemap_draw(bitmap,0,TILEMAP_IGNORE_TRANSPARENCY,0);
-	if ( !keyboard_pressed(KEYCODE_S) )
-		recordbr_draw_sprites(bitmap,0);
-	if ( !keyboard_pressed(KEYCODE_D) )
-		TC0080VCO_tilemap_draw(bitmap,1,0,0);
-	if ( !keyboard_pressed(KEYCODE_F) )
-		recordbr_draw_sprites(bitmap,1);
+	if ( !code_pressed(KEYCODE_A) )
+		TC0080VCO_tilemap_draw(bitmap,cliprect,0,TILEMAP_IGNORE_TRANSPARENCY,0);
+	if ( !code_pressed(KEYCODE_S) )
+		recordbr_draw_sprites(bitmap,cliprect,0);
+	if ( !code_pressed(KEYCODE_D) )
+		TC0080VCO_tilemap_draw(bitmap,cliprect,1,0,0);
+	if ( !code_pressed(KEYCODE_F) )
+		recordbr_draw_sprites(bitmap,cliprect,1);
 #else
-	TC0080VCO_tilemap_draw(bitmap,0,TILEMAP_IGNORE_TRANSPARENCY,0);
-	recordbr_draw_sprites (bitmap,0);
-	TC0080VCO_tilemap_draw(bitmap,1,0,0);
-	recordbr_draw_sprites (bitmap,1);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,0,TILEMAP_IGNORE_TRANSPARENCY,0);
+	recordbr_draw_sprites (bitmap,cliprect,0);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,1,0,0);
+	recordbr_draw_sprites (bitmap,cliprect,1);
 #endif
 
-	TC0080VCO_tilemap_draw(bitmap,2,0,0);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,2,0,0);
 }
 
 
-void dleague_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( dleague )
 {
 	TC0080VCO_tilemap_update();
 
@@ -499,24 +487,24 @@ void dleague_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	taitoh_log_vram();
 #endif
 
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
+	fillbitmap(bitmap, Machine->pens[0], cliprect);
 
 #ifdef MAME_DEBUG
-	if ( !keyboard_pressed(KEYCODE_A) )
-		TC0080VCO_tilemap_draw(bitmap,0,TILEMAP_IGNORE_TRANSPARENCY,0);
-	if ( !keyboard_pressed(KEYCODE_S) )
-		dleague_draw_sprites(bitmap,0);
-	if ( !keyboard_pressed(KEYCODE_D) )
-		TC0080VCO_tilemap_draw(bitmap,1,0,0);
-	if ( !keyboard_pressed(KEYCODE_F) )
-		dleague_draw_sprites(bitmap,1);
+	if ( !code_pressed(KEYCODE_A) )
+		TC0080VCO_tilemap_draw(bitmap,cliprect,0,TILEMAP_IGNORE_TRANSPARENCY,0);
+	if ( !code_pressed(KEYCODE_S) )
+		dleague_draw_sprites(bitmap,cliprect,0);
+	if ( !code_pressed(KEYCODE_D) )
+		TC0080VCO_tilemap_draw(bitmap,cliprect,1,0,0);
+	if ( !code_pressed(KEYCODE_F) )
+		dleague_draw_sprites(bitmap,cliprect,1);
 #else
-	TC0080VCO_tilemap_draw(bitmap,0,TILEMAP_IGNORE_TRANSPARENCY,0);
-	dleague_draw_sprites  (bitmap,0);
-	TC0080VCO_tilemap_draw(bitmap,1,0,0);
-	dleague_draw_sprites  (bitmap,1);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,0,TILEMAP_IGNORE_TRANSPARENCY,0);
+	dleague_draw_sprites  (bitmap,cliprect,0);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,1,0,0);
+	dleague_draw_sprites  (bitmap,cliprect,1);
 #endif
 
-	TC0080VCO_tilemap_draw(bitmap,2,0,0);
+	TC0080VCO_tilemap_draw(bitmap,cliprect,2,0,0);
 }
 
