@@ -1,12 +1,12 @@
-/*	video hardware for Pacific Novelty games:
-**	Thief/Nato Defense
+/*  video hardware for Pacific Novelty games:
+**  Thief/Nato Defense
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-struct mame_bitmap *thief_page0;
-struct mame_bitmap *thief_page1;
+mame_bitmap *thief_page0;
+mame_bitmap *thief_page1;
 
 static UINT8 thief_read_mask, thief_write_mask;
 static UINT8 thief_video_control;
@@ -32,21 +32,21 @@ enum {
 
 /***************************************************************************/
 
-READ_HANDLER( thief_context_ram_r ){
+READ8_HANDLER( thief_context_ram_r ){
 	return thief_coprocessor.context_ram[0x40*thief_coprocessor.bank+offset];
 }
 
-WRITE_HANDLER( thief_context_ram_w ){
+WRITE8_HANDLER( thief_context_ram_w ){
 	thief_coprocessor.context_ram[0x40*thief_coprocessor.bank+offset] = data;
 }
 
-WRITE_HANDLER( thief_context_bank_w ){
+WRITE8_HANDLER( thief_context_bank_w ){
 	thief_coprocessor.bank = data&0xf;
 }
 
 /***************************************************************************/
 
-WRITE_HANDLER( thief_video_control_w ){
+WRITE8_HANDLER( thief_video_control_w ){
 	if( (data^thief_video_control)&1 ){
 		/* screen flipped */
 		memset( dirtybuffer, 0x00, 0x2000*2 );
@@ -54,25 +54,25 @@ WRITE_HANDLER( thief_video_control_w ){
 
 	thief_video_control = data;
 /*
-	bit 0: screen flip
-	bit 1: working page
-	bit 2: visible page
-	bit 3: mirrors bit 1
-	bit 4: mirrors bit 2
+    bit 0: screen flip
+    bit 1: working page
+    bit 2: visible page
+    bit 3: mirrors bit 1
+    bit 4: mirrors bit 2
 */
 }
 
-WRITE_HANDLER( thief_vtcsel_w ){
+WRITE8_HANDLER( thief_vtcsel_w ){
 	/* TMS9927 VTAC registers */
 }
 
-WRITE_HANDLER( thief_color_map_w ){
+WRITE8_HANDLER( thief_color_map_w ){
 /*
-	--xx----	blue
-	----xx--	green
-	------xx	red
+    --xx----    blue
+    ----xx--    green
+    ------xx    red
 */
-	const UINT8 intensity[4] = {0x00,0x55,0xAA,0xFF};
+	static const UINT8 intensity[4] = {0x00,0x55,0xAA,0xFF};
 	int r = intensity[(data & 0x03) >> 0];
     int g = intensity[(data & 0x0C) >> 2];
     int b = intensity[(data & 0x30) >> 4];
@@ -81,22 +81,22 @@ WRITE_HANDLER( thief_color_map_w ){
 
 /***************************************************************************/
 
-WRITE_HANDLER( thief_color_plane_w ){
+WRITE8_HANDLER( thief_color_plane_w ){
 /*
-	--xx----	selects bitplane to read from (0..3)
-	----xxxx	selects bitplane(s) to write to (0x0 = none, 0xf = all)
+    --xx----    selects bitplane to read from (0..3)
+    ----xxxx    selects bitplane(s) to write to (0x0 = none, 0xf = all)
 */
 	thief_write_mask = data&0xf;
 	thief_read_mask = (data>>4)&3;
 }
 
-READ_HANDLER( thief_videoram_r ){
+READ8_HANDLER( thief_videoram_r ){
 	unsigned char *source = &videoram[offset];
 	if( thief_video_control&0x02 ) source+=0x2000*4; /* foreground/background */
 	return source[thief_read_mask*0x2000];
 }
 
-WRITE_HANDLER( thief_videoram_w ){
+WRITE8_HANDLER( thief_videoram_w ){
 	UINT8 *dest = &videoram[offset];
 	if( thief_video_control&0x02 ){
 		dest+=0x2000*4; /* foreground/background */
@@ -113,45 +113,33 @@ WRITE_HANDLER( thief_videoram_w ){
 
 /***************************************************************************/
 
-void thief_vh_stop( void ){
-	free( videoram );
-	free( dirtybuffer );
-	bitmap_free( thief_page1 );
-	bitmap_free( thief_page0 );
-	free( thief_coprocessor.context_ram );
-	free( thief_coprocessor.image_ram );
-}
-
-int thief_vh_start( void ){
+VIDEO_START( thief ){
 	memset( &thief_coprocessor, 0x00, sizeof(thief_coprocessor) );
 
-	thief_page0	= bitmap_alloc( 256,256 );
-	thief_page1	= bitmap_alloc( 256,256 );
-	videoram = calloc( 0x2000*4*2,1 );
-	dirtybuffer = malloc( 0x2000*2 );
+	thief_page0	= auto_bitmap_alloc( 256,256 );
+	thief_page1	= auto_bitmap_alloc( 256,256 );
+	if (!thief_page0 || !thief_page1)
+		return 1;
 
-	thief_coprocessor.image_ram = malloc( 0x2000 );
-	thief_coprocessor.context_ram = malloc( 0x400 );
+	videoram = auto_malloc( 0x2000*4*2 );
+	memset( videoram, 0, 0x2000*4*2 );
 
-	if( thief_page0 && thief_page1 &&
-		videoram && dirtybuffer &&
-		thief_coprocessor.image_ram &&
-		thief_coprocessor.context_ram )
-	{
-		memset( dirtybuffer, 1, 0x2000*2 );
-		return 0;
-	}
-	thief_vh_stop();
-	return 1;
+	dirtybuffer = auto_malloc( 0x2000*2 );
+	memset( dirtybuffer, 1, 0x2000*2 );
+
+	thief_coprocessor.image_ram = auto_malloc( 0x2000 );
+	thief_coprocessor.context_ram = auto_malloc( 0x400 );
+
+	return 0;
 }
 
-void thief_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh){
+VIDEO_UPDATE( thief ){
 	unsigned int offs;
 	int flipscreen = thief_video_control&1;
 	const pen_t *pal_data = Machine->pens;
 	UINT8 *dirty = dirtybuffer;
 	const UINT8 *source = videoram;
-	struct mame_bitmap *page;
+	mame_bitmap *page;
 
 	if( thief_video_control&4 ){ /* visible page */
 		dirty += 0x2000;
@@ -213,7 +201,7 @@ static UINT16 fetch_image_addr( void ){
 	return addr;
 }
 
-WRITE_HANDLER( thief_blit_w ){
+WRITE8_HANDLER( thief_blit_w ){
 	int i, offs, xoffset, dy;
 	UINT8 *gfx_rom = memory_region( REGION_GFX1 );
 	UINT8 x = thief_coprocessor.param[SCREEN_XPOS];
@@ -225,7 +213,7 @@ WRITE_HANDLER( thief_blit_w ){
 	UINT8 old_data;
 	int xor_blit = data;
 		/* making the xor behavior selectable fixes score display,
-		but causes minor glitches on the playfield */
+        but causes minor glitches on the playfield */
 
 	x -= width*8;
 	xoffset = x&7;
@@ -273,7 +261,7 @@ WRITE_HANDLER( thief_blit_w ){
 	}
 }
 
-READ_HANDLER( thief_coprocessor_r ){
+READ8_HANDLER( thief_coprocessor_r ){
 	switch( offset ){
  	case SCREEN_XPOS: /* xpos */
 	case SCREEN_YPOS: /* ypos */
@@ -316,7 +304,7 @@ READ_HANDLER( thief_coprocessor_r ){
 	return thief_coprocessor.param[offset];
 }
 
-WRITE_HANDLER( thief_coprocessor_w ){
+WRITE8_HANDLER( thief_coprocessor_w ){
 	switch( offset ){
 	case GFX_PORT:
 		{
