@@ -2,58 +2,51 @@
 #include "vidhrdw/generic.h"
 #include "vidhrdw/taitoic.h"
 
-data16_t *topspeed_spritemap;
-data16_t *topspeed_raster_ctrl;
+UINT16 *topspeed_spritemap;
+UINT16 *topspeed_raster_ctrl;
 
 /****************************************************************************/
 
-int topspeed_vh_start (void)
+VIDEO_START( topspeed )
 {
 	/* (chips, gfxnum, x_offs, y_offs, y_invert, opaque, dblwidth) */
 	if (PC080SN_vh_start(2,1,0,8,0,0,0))
-	{
 		return 1;
-	}
 
 	return 0;
 }
 
-void topspeed_vh_stop(void)
-{
-	PC080SN_vh_stop();
-}
-
 
 /********************************************************************************
                                      SPRITES
 
-	Layout 8 bytes per sprite
-	-------------------------
+    Layout 8 bytes per sprite
+    -------------------------
 
-	+0x00   xxxxxxx. ........   Zoom Y
-	        .......x xxxxxxxx   Y
+    +0x00   xxxxxxx. ........   Zoom Y
+            .......x xxxxxxxx   Y
 
-	+0x02   x....... ........   Flip Y
-	        ........ .xxxxxxx   Zoom X
+    +0x02   x....... ........   Flip Y
+            ........ .xxxxxxx   Zoom X
 
-	+0x04   x....... ........   Priority
-	        .x...... ........   Flip X
-	        ..x..... ........   Unknown
-	        .......x xxxxxxxx   X
+    +0x04   x....... ........   Priority
+            .x...... ........   Flip X
+            ..x..... ........   Unknown
+            .......x xxxxxxxx   X
 
-	+0x06   xxxxxxxx ........   Color
-	        ........ xxxxxxxx   Tile number
+    +0x06   xxxxxxxx ........   Color
+            ........ xxxxxxxx   Tile number
 
 ********************************************************************************/
 
-void topspeed_draw_sprites(struct mame_bitmap *bitmap)
+void topspeed_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs,map_offset,x,y,curx,cury,sprite_chunk;
-	data16_t *spritemap = topspeed_spritemap;
+	UINT16 *spritemap = topspeed_spritemap;
 	UINT16 data,tilenum,code,color;
 	UINT8 flipx,flipy,priority,bad_chunks;
 	UINT8 j,k,px,py,zx,zy,zoomx,zoomy;
-	int primasks[2] = {0xff00,0xfffc};	/* Sprites are over bottom layer or under top layer */
+	static const int primasks[2] = {0xff00,0xfffc};	/* Sprites are over bottom layer or under top layer */
 
 	/* Most of spriteram is not used by the 68000: rest is scratch space for the h/w perhaps ? */
 
@@ -70,7 +63,7 @@ void topspeed_draw_sprites(struct mame_bitmap *bitmap)
 		zoomx = (spriteram16[offs+1]& 0x7f);
 		zoomy = (spriteram16[offs] & 0xfe00) >> 9;
 		priority = (data & 0x8000) >> 15;
-/*		unknown = (data & 0x2000) >> 13; */
+/*      unknown = (data & 0x2000) >> 13; */
 
 		if (y == 0x180) continue;	/* dead sprite */
 
@@ -115,7 +108,7 @@ void topspeed_draw_sprites(struct mame_bitmap *bitmap)
 					color,
 					flipx,flipy,
 					curx,cury,
-					&Machine->visible_area,TRANSPARENCY_PEN,0,
+					cliprect,TRANSPARENCY_PEN,0,
 					zx<<12,zy<<13,
 					primasks[priority]);
 		}
@@ -128,49 +121,43 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 
 /***************************************************************************/
 
-void topspeed_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( topspeed )
 {
 	UINT8 layer[4];
 
 #ifdef MAME_DEBUG
 	static UINT8 dislayer[5];
-	char buf[80];
 #endif
 
 #ifdef MAME_DEBUG
-	if (keyboard_pressed_memory (KEYCODE_V))
+	if (code_pressed_memory (KEYCODE_V))
 	{
 		dislayer[0] ^= 1;
-		sprintf(buf,"bg: %01x",dislayer[0]);
-		usrintf_showmessage(buf);
+		ui_popup("bg: %01x",dislayer[0]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_B))
+	if (code_pressed_memory (KEYCODE_B))
 	{
 		dislayer[1] ^= 1;
-		sprintf(buf,"fg: %01x",dislayer[1]);
-		usrintf_showmessage(buf);
+		ui_popup("fg: %01x",dislayer[1]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_N))
+	if (code_pressed_memory (KEYCODE_N))
 	{
 		dislayer[2] ^= 1;
-		sprintf(buf,"bg2: %01x",dislayer[2]);
-		usrintf_showmessage(buf);
+		ui_popup("bg2: %01x",dislayer[2]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_M))
+	if (code_pressed_memory (KEYCODE_M))
 	{
 		dislayer[3] ^= 1;
-		sprintf(buf,"fg2: %01x",dislayer[3]);
-		usrintf_showmessage(buf);
+		ui_popup("fg2: %01x",dislayer[3]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_C))
+	if (code_pressed_memory (KEYCODE_C))
 	{
 		dislayer[4] ^= 1;
-		sprintf(buf,"sprites: %01x",dislayer[4]);
-		usrintf_showmessage(buf);
+		ui_popup("sprites: %01x",dislayer[4]);
 	}
 #endif
 
@@ -182,34 +169,34 @@ void topspeed_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	layer[2] = 1;
 	layer[3] = 0;
 
-	fillbitmap(priority_bitmap,0,NULL);
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
+	fillbitmap(priority_bitmap,0,cliprect);
+	fillbitmap(bitmap, Machine->pens[0], cliprect);
 
 #ifdef MAME_DEBUG
 	if (dislayer[3]==0)
 #endif
-	PC080SN_tilemap_draw(bitmap,1,layer[0],TILEMAP_IGNORE_TRANSPARENCY,1);
+	PC080SN_tilemap_draw(bitmap,cliprect,1,layer[0],TILEMAP_IGNORE_TRANSPARENCY,1);
 
 #ifdef MAME_DEBUG
 	if (dislayer[2]==0)
 #endif
-	PC080SN_tilemap_draw_special(bitmap,1,layer[1],0,2,topspeed_raster_ctrl);
+	PC080SN_tilemap_draw_special(bitmap,cliprect,1,layer[1],0,2,topspeed_raster_ctrl);
 
 #ifdef MAME_DEBUG
 	if (dislayer[1]==0)
 #endif
- 	PC080SN_tilemap_draw_special(bitmap,0,layer[2],0,4,topspeed_raster_ctrl + 0x100);
+ 	PC080SN_tilemap_draw_special(bitmap,cliprect,0,layer[2],0,4,topspeed_raster_ctrl + 0x100);
 
 #ifdef MAME_DEBUG
 	if (dislayer[0]==0)
 #endif
-	PC080SN_tilemap_draw(bitmap,0,layer[3],0,8);
+	PC080SN_tilemap_draw(bitmap,cliprect,0,layer[3],0,8);
 
 #ifdef MAME_DEBUG
 	if (dislayer[4]==0)
 #endif
 
-	topspeed_draw_sprites(bitmap);
+	topspeed_draw_sprites(bitmap,cliprect);
 }
 
 
