@@ -54,11 +54,11 @@ static void zoom_callback_2(int *code,int *color)
 
 /***************************************************************************
 
-	Start the video hardware emulation.
+    Start the video hardware emulation.
 
 ***************************************************************************/
 
-int ultraman_vh_start(void)
+VIDEO_START( ultraman )
 {
 	sprite_colorbase = 192;
 	zoom_colorbase[0] = 0;
@@ -66,30 +66,16 @@ int ultraman_vh_start(void)
 	zoom_colorbase[2] = 128;
 
 	if (K051960_vh_start(SPRITEROM_MEM_REGION,NORMAL_PLANE_ORDER,sprite_callback))
-	{
 		return 1;
-	}
 
 	if (K051316_vh_start_0(ZOOMROM0_MEM_REGION,4,TILEMAP_TRANSPARENT,0,zoom_callback_0))
-	{
-		K051960_vh_stop();
 		return 1;
-	}
 
 	if (K051316_vh_start_1(ZOOMROM1_MEM_REGION,4,TILEMAP_TRANSPARENT,0,zoom_callback_1))
-	{
-		K051960_vh_stop();
-		K051316_vh_stop_0();
 		return 1;
-	}
 
 	if (K051316_vh_start_2(ZOOMROM2_MEM_REGION,4,TILEMAP_OPAQUE,0,zoom_callback_2))
-	{
-		K051960_vh_stop();
-		K051316_vh_stop_0();
-		K051316_vh_stop_1();
 		return 1;
-	}
 
 	K051316_set_offset(0, 8, 0);
 	K051316_set_offset(1, 8, 0);
@@ -98,14 +84,6 @@ int ultraman_vh_start(void)
 	return 0;
 }
 
-void ultraman_vh_stop(void)
-{
-	K051960_vh_stop();
-	K051316_vh_stop_0();
-	K051316_vh_stop_1();
-	K051316_vh_stop_2();
-}
-
 
 
 /***************************************************************************
@@ -118,14 +96,14 @@ WRITE16_HANDLER( ultraman_gfxctrl_w )
 {
 	if (ACCESSING_LSB)
 	{
-		/*	bit 0: enable wraparound for scr #1
-			bit 1: msb of code for scr #1
-			bit 2: enable wraparound for scr #2
-			bit 3: msb of code for scr #2
-			bit 4: enable wraparound for scr #3
-			bit 5: msb of code for scr #3
-			bit 6: coin counter 1
-			bit 7: coin counter 2 */
+		/*  bit 0: enable wraparound for scr #1
+            bit 1: msb of code for scr #1
+            bit 2: enable wraparound for scr #2
+            bit 3: msb of code for scr #2
+            bit 4: enable wraparound for scr #3
+            bit 5: msb of code for scr #3
+            bit 6: coin counter 1
+            bit 7: coin counter 2 */
 		K051316_wraparound_enable(0,data & 0x01);
 		if (bank0 != ((data & 0x02) >> 1))
 		{
@@ -153,15 +131,15 @@ WRITE16_HANDLER( ultraman_gfxctrl_w )
 
 /***************************************************************************
 
-	Display Refresh
+    Display Refresh
 
 ***************************************************************************/
 
-void ultraman_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( ultraman )
 {
-	K051316_zoom_draw_2(bitmap,0,0);
-	K051316_zoom_draw_1(bitmap,0,0);
-	K051960_sprites_draw(bitmap,0,0);
-	K051316_zoom_draw_0(bitmap,0,0);
-	K051960_sprites_draw(bitmap,1,1);
+	K051316_zoom_draw_2(bitmap,cliprect,0,0);
+	K051316_zoom_draw_1(bitmap,cliprect,0,0);
+	K051960_sprites_draw(bitmap,cliprect,0,0);
+	K051316_zoom_draw_0(bitmap,cliprect,0,0);
+	K051960_sprites_draw(bitmap,cliprect,1,1);
 }
