@@ -21,35 +21,17 @@ static struct tempsprite *spritelist;
 
 /******************************************************************/
 
-void undrfire_vh_stop (void)
-{
-	free(spritelist);
-	spritelist = 0;
-
-	TC0100SCN_vh_stop();
-
-	TC0480SCP_vh_stop();
-}
-
-int undrfire_vh_start (void)
+VIDEO_START( undrfire )
 {
 	int i;
 
-	spritelist = malloc(0x4000 * sizeof(*spritelist));
-	if (!spritelist)
-		return 1;
+	spritelist = auto_malloc(0x4000 * sizeof(*spritelist));
 
 	if (TC0100SCN_vh_start(1,TC0100SCN_GFX_NUM,50,8,0,0,0,0,0))
-	{
-		undrfire_vh_stop();
 		return 1;
-	}
 
 	if (TC0480SCP_vh_start(TC0480SCP_GFX_NUM,0,0x24,0,-1,0,0,0,0))
-	{
-		undrfire_vh_stop();
 		return 1;
-	}
 
 	for (i=0; i<16384; i++) /* Fix later - some weird colours in places */
 		palette_set_color(i,0,0,0);
@@ -57,17 +39,17 @@ int undrfire_vh_start (void)
 }
 
 /***************************************************************
-			SPRITE DRAW ROUTINES
+            SPRITE DRAW ROUTINES
 
 We draw a series of small tiles ("chunks") together to
 create each big sprite. The spritemap rom provides the lookup
 table for this. The game hardware looks up 16x16 sprite chunks
 from the spritemap rom, creating a 64x64 sprite like this:
 
-	 0  1  2  3
-	 4  5  6  7
-	 8  9 10 11
-	12 13 14 15
+     0  1  2  3
+     4  5  6  7
+     8  9 10 11
+    12 13 14 15
 
 (where the number is the word offset into the spritemap rom).
 It can also create 32x32 sprites.
@@ -79,33 +61,33 @@ spriteram is being tested, take no notice of that.]
 
 Heavy use is made of sprite zooming.
 
-		***
+        ***
 
-	Sprite table layout (4 long words per entry)
+    Sprite table layout (4 long words per entry)
 
-	------------------------------------------
-	 0 | ........ x....... ........ ........ | Flip X
-	 0 | ........ .xxxxxxx ........ ........ | ZoomX
-	 0 | ........ ........ .xxxxxxx xxxxxxxx | Sprite Tile
-	   |                                     |
-	 2 | ........ ....xx.. ........ ........ | Sprite/tile priority [*]
-	 2 | ........ ......xx xxxxxx.. ........ | Palette bank
-	 2 | ........ ........ ......xx xxxxxxxx | X position
-	   |                                     |
-	 3 | ........ .....x.. ........ ........ | Sprite size (0=32x32, 1=64x64)
-	 3 | ........ ......x. ........ ........ | Flip Y
-	 3 | ........ .......x xxxxxx.. ........ | ZoomY
-	 3 | ........ ........ ......xx xxxxxxxx | Y position
-	------------------------------------------
+    ------------------------------------------
+     0 | ........ x....... ........ ........ | Flip X
+     0 | ........ .xxxxxxx ........ ........ | ZoomX
+     0 | ........ ........ .xxxxxxx xxxxxxxx | Sprite Tile
+       |                                     |
+     2 | ........ ....xx.. ........ ........ | Sprite/tile priority [*]
+     2 | ........ ......xx xxxxxx.. ........ | Palette bank
+     2 | ........ ........ ......xx xxxxxxxx | X position
+       |                                     |
+     3 | ........ .....x.. ........ ........ | Sprite size (0=32x32, 1=64x64)
+     3 | ........ ......x. ........ ........ | Flip Y
+     3 | ........ .......x xxxxxx.. ........ | ZoomY
+     3 | ........ ........ ......xx xxxxxxxx | Y position
+    ------------------------------------------
 
-	[*  00=over BG0, 01=BG1, 10=BG2, 11=BG3 ]
-	[or 00=over BG1, 01=BG2, 10=BG3, 11=BG3 ]
+    [*  00=over BG0, 01=BG1, 10=BG2, 11=BG3 ]
+    [or 00=over BG1, 01=BG2, 10=BG3, 11=BG3 ]
 
 ***************************************************************/
 
-static void undrfire_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks,int x_offs,int y_offs)
+static void undrfire_draw_sprites_16x16(mame_bitmap *bitmap,const rectangle *cliprect,const int *primasks,int x_offs,int y_offs)
 {
-	data16_t *spritemap = (data16_t *)memory_region(REGION_USER1);
+	UINT16 *spritemap = (UINT16 *)memory_region(REGION_USER1);
 	int offs, data, tilenum, color, flipx, flipy;
 	int x, y, priority, dblsize, curx, cury;
 	int sprites_flipscreen = 0;
@@ -114,7 +96,7 @@ static void undrfire_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks
 	int dimension,total_chunks,bad_chunks;
 
 	/* pdrawgfx() needs us to draw sprites front to back, so we have to build a list
-	   while processing sprite ram and then draw them all at the end */
+       while processing sprite ram and then draw them all at the end */
 	struct tempsprite *sprite_ptr = spritelist;
 
 	for (offs = (spriteram_size/4-4);offs >= 0;offs -= 4)
@@ -188,8 +170,8 @@ static void undrfire_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks
 				if (sprites_flipscreen)
 				{
 					/* -zx/y is there to fix zoomed sprite coords in screenflip.
-					   drawgfxzoom does not know to draw from flip-side of sprites when
-					   screen is flipped; so we must correct the coords ourselves. */
+                       drawgfxzoom does not know to draw from flip-side of sprites when
+                       screen is flipped; so we must correct the coords ourselves. */
 
 					curx = 320 - curx - zx;
 					cury = 256 - cury - zy;
@@ -220,7 +202,7 @@ static void undrfire_draw_sprites_16x16(struct mame_bitmap *bitmap,int *primasks
 							sprite_ptr->color,
 							sprite_ptr->flipx,sprite_ptr->flipy,
 							sprite_ptr->x,sprite_ptr->y,
-							&Machine->visible_area,TRANSPARENCY_PEN,0,
+							cliprect,TRANSPARENCY_PEN,0,
 							sprite_ptr->zoomx,sprite_ptr->zoomy);
 				}
 			}
@@ -240,17 +222,17 @@ logerror("Sprite number %04x had %02x invalid chunks\n",tilenum,bad_chunks);
 				sprite_ptr->color,
 				sprite_ptr->flipx,sprite_ptr->flipy,
 				sprite_ptr->x,sprite_ptr->y,
-				&Machine->visible_area,TRANSPARENCY_PEN,0,
+				cliprect,TRANSPARENCY_PEN,0,
 				sprite_ptr->zoomx,sprite_ptr->zoomy,
 				sprite_ptr->primask);
 	}
 }
 
 /**************************************************************
-				SCREEN REFRESH
+                SCREEN REFRESH
 **************************************************************/
 
-void undrfire_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( undrfire )
 {
 	UINT8 layer[5];
 	UINT8 pivlayer[3];
@@ -258,49 +240,42 @@ void undrfire_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 #ifdef MAME_DEBUG
 	static UINT8 dislayer[6];	/* Layer toggles to help get layers correct */
-	char buf[80];
 #endif
 
 #ifdef MAME_DEBUG
-	if (keyboard_pressed_memory (KEYCODE_X))
+	if (code_pressed_memory (KEYCODE_X))
 	{
 		dislayer[5] ^= 1;
-		sprintf(buf,"piv text: %01x",dislayer[5]);
-		usrintf_showmessage(buf);
+		ui_popup("piv text: %01x",dislayer[5]);
 	}
-	if (keyboard_pressed_memory (KEYCODE_C))
+	if (code_pressed_memory (KEYCODE_C))
 	{
 		dislayer[0] ^= 1;
-		sprintf(buf,"bg0: %01x",dislayer[0]);
-		usrintf_showmessage(buf);
+		ui_popup("bg0: %01x",dislayer[0]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_V))
+	if (code_pressed_memory (KEYCODE_V))
 	{
 		dislayer[1] ^= 1;
-		sprintf(buf,"bg1: %01x",dislayer[1]);
-		usrintf_showmessage(buf);
+		ui_popup("bg1: %01x",dislayer[1]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_B))
+	if (code_pressed_memory (KEYCODE_B))
 	{
 		dislayer[2] ^= 1;
-			sprintf(buf,"bg2: %01x",dislayer[2]);
-		usrintf_showmessage(buf);
+		ui_popup("bg2: %01x",dislayer[2]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_N))
+	if (code_pressed_memory (KEYCODE_N))
 	{
 		dislayer[3] ^= 1;
-		sprintf(buf,"bg3: %01x",dislayer[3]);
-		usrintf_showmessage(buf);
+		ui_popup("bg3: %01x",dislayer[3]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_M))
+	if (code_pressed_memory (KEYCODE_M))
 	{
 		dislayer[4] ^= 1;
-		sprintf(buf,"sprites: %01x",dislayer[4]);
-		usrintf_showmessage(buf);
+		ui_popup("sprites: %01x",dislayer[4]);
 	}
 #endif
 
@@ -319,8 +294,8 @@ void undrfire_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	pivlayer[1] = pivlayer[0]^1;
 	pivlayer[2] = 2;
 
-	fillbitmap(priority_bitmap,0,NULL);
-	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);	/* wrong color? */
+	fillbitmap(priority_bitmap,0,cliprect);
+	fillbitmap(bitmap,Machine->pens[0],cliprect);	/* wrong color? */
 
 
 /* The "PIV" chip seems to be a renamed TC0100SCN. It has a
@@ -329,28 +304,28 @@ void undrfire_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
    pointless - it's always hidden by other layers. Does it
    serve some blending pupose ? */
 
-	TC0100SCN_tilemap_draw(bitmap,0,pivlayer[0],0,0);
-	TC0100SCN_tilemap_draw(bitmap,0,pivlayer[1],0,0);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,pivlayer[0],0,0);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,pivlayer[1],0,0);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[0]]==0)
 #endif
-	TC0480SCP_tilemap_draw(bitmap,layer[0],0,1);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[0],0,1);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[1]]==0)
 #endif
-	TC0480SCP_tilemap_draw(bitmap,layer[1],0,2);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[1],0,2);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[2]]==0)
 #endif
-	TC0480SCP_tilemap_draw(bitmap,layer[2],0,4);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[2],0,4);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[3]]==0)
 #endif
-	TC0480SCP_tilemap_draw(bitmap,layer[3],0,8);
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[3],0,8);
 
 #ifdef MAME_DEBUG
 	if (dislayer[4]==0)
@@ -359,29 +334,29 @@ void undrfire_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	{
 		if ((TC0480SCP_pri_reg &0x3) == 3)	/* on road levels kludge sprites up 1 priority */
 		{
-			int primasks[4] = {0xfff0, 0xff00, 0x0, 0x0};
-			undrfire_draw_sprites_16x16(bitmap,primasks,44,-574);
+			static const int primasks[4] = {0xfff0, 0xff00, 0x0, 0x0};
+			undrfire_draw_sprites_16x16(bitmap,cliprect,primasks,44,-574);
 		}
 		else
 		{
-			int primasks[4] = {0xfffc, 0xfff0, 0xff00, 0x0};
-			undrfire_draw_sprites_16x16(bitmap,primasks,44,-574);
+			static const int primasks[4] = {0xfffc, 0xfff0, 0xff00, 0x0};
+			undrfire_draw_sprites_16x16(bitmap,cliprect,primasks,44,-574);
 		}
 	}
 
 #ifdef MAME_DEBUG
 	if (dislayer[5]==0)
 #endif
-	TC0100SCN_tilemap_draw(bitmap,0,pivlayer[2],0,0);	/* piv text layer */
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,pivlayer[2],0,0);	/* piv text layer */
 
-	TC0480SCP_tilemap_draw(bitmap,layer[4],0,0);	/* TC0480SCP text layer */
+	TC0480SCP_tilemap_draw(bitmap,cliprect,layer[4],0,0);	/* TC0480SCP text layer */
 
 	/* See if we should draw artificial gun targets */
 	/* (not yet implemented...) */
 
 	if (input_port_7_word_r(0,0) & 0x1)	/* Fake DSW */
 	{
-		usrintf_showmessage("Gunsights on");
+		ui_popup("Gunsights on");
 	}
 
 /* Enable this to see rotation (?) control words */
@@ -393,7 +368,7 @@ void undrfire_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		for (i = 0; i < 8; i += 1)
 		{
 			sprintf (buf, "%02x: %04x", i, undrfire_rotate_ctrl[i]);
-			ui_text (Machine->scrbitmap, buf, 0, i*8);
+			ui_draw_text (buf, 0, i*8);
 		}
 	}
 #endif
