@@ -8,6 +8,8 @@
  *        anti-alias code by Andrew Caldwell
  *        (still more to add)
  *
+ * 040227 Fixed miny clip scaling which was breaking in mhavoc. AREK
+ * 010903 added support for direct RGB modes MLR
  * 980611 use translucent vectors. Thanks to Peter Hirschberg
  *        and Neil Bradley for the inspiration. BW
  * 980307 added cleverer dirty handling. BW, ASG
@@ -25,13 +27,9 @@
  *        modified avgdvg.c and sega.c to support new line draw routine
  *        added two new tables Tinten and Tmerge (for 256 color support)
  *        added find_color routine to build above tables .ac
- * 010903 added support for direct RGB modes MLR
  *
  **************************************************************************** */
 
-/* GLmame and FXmame provide their own vector implementations */
-#if !(defined xgl) && !(defined xfx) && !(defined svgafx)
-
 #include <math.h>
 #include "osinline.h"
 #include "driver.h"
@@ -39,15 +37,11 @@
 #include "vector.h"
 #include "artwork.h"
 
-#define VCLEAN  0
-#define VDIRTY  1
-#define VCLIP   2
+#define MAX_DIRTY_PIXELS (2*MAX_PIXELS)
 
 unsigned char *vectorram;
 size_t vectorram_size;
 
-static int vector_orientation;
-
 static int antialias;                            /* flag for anti-aliasing */
 static int beam;                                 /* size of vector beam    */
 static int flicker;                              /* beam flicker value     */
@@ -55,22 +49,14 @@ int translucency;
 
 static int beam_diameter_is_one;		  /* flag that beam is one pixel wide */
 
-static int vector_scale_x;                /* scaling to screen */
-static int vector_scale_y;                /* scaling to screen */
+static float vector_scale_x;              /* scaling to screen */
+static float vector_scale_y;              /* scaling to screen */
 
 static float gamma_correction = 1.2;
 static float flicker_correction = 0.0;
 static float intensity_correction = 1.5;
 
-/* The vectices are buffered here */
-typedef struct
-{
-	int x; int y;
-	int col;
-	int intensity;
-	int arg1; int arg2; /* start/end in pixel array or clipping info */
-	int status;         /* for dirty and clipping handling */
-} point;
+static int (*vector_aux_renderer)(point *start, int num_points) = NULL;
 
 static point *new_list;
 static point *old_list;
@@ -78,7 +64,10 @@ static int new_index;
 static int old_index;
 
 /* coordinates of pixels are stored here for faster removal */
-static unsigned int *pixel;
+vector_pixel_t *vector_dirty_list;
+static int dirty_index;
+
+static vector_pixel_t *pixel;
 static int p_index=0;
 
 static UINT32 *pTcosin;            /* adjust line width */
@@ -91,17 +80,21 @@ static UINT32 *pTcosin;            /* adjust line width */
 static UINT8 Tgamma[256];         /* quick gamma anti-alias table  */
 static UINT8 Tgammar[256];        /* same as above, reversed order */
 
-static struct mame_bitmap *vecbitmap;
+static mame_bitmap *vecbitmap;
 static int vecwidth, vecheight;
-static int vecshift;
 static int xmin, ymin, xmax, ymax; /* clipping area */
 
 static int vector_runs;	/* vector runs per refresh */
 
-static void (*vector_draw_aa_pixel)(int x, int y, int col, int dirty);
+static void (*vector_draw_aa_pixel)(int x, int y, rgb_t col, int dirty);
 
-static void vector_draw_aa_pixel_15 (int x, int y, int col, int dirty);
-static void vector_draw_aa_pixel_32 (int x, int y, int col, int dirty);
+static void vector_draw_aa_pixel_15 (int x, int y, rgb_t col, int dirty);
+static void vector_draw_aa_pixel_32 (int x, int y, rgb_t col, int dirty);
+
+void vector_register_aux_renderer(int (*aux_renderer)(point *start, int num_points))
+{
+	vector_aux_renderer = aux_renderer;
+}
 
 /*
  * multiply and divide routines for drawing lines
@@ -144,11 +137,6 @@ INLINE int vec_div(int parm1, int parm2)
 }
 #endif
 
-#define Tinten(intensity, col) \
-((((col) & 0xff) * (intensity)) >> 8) \
-	| (((((col) >> 8) & 0xff) * (intensity)) & 0xff00) \
-	| (((((col) >> 16) * (intensity)) >> 8) << 16)
-
 /* MLR 990316 new gamma handling added */
 void vector_set_gamma(float _gamma)
 {
@@ -194,7 +182,7 @@ float vector_get_intensity(void)
  * Initializes vector game video emulation
  */
 
-int vector_vh_start (void)
+VIDEO_START( vector )
 {
 	int i;
 
@@ -202,6 +190,7 @@ int vector_vh_start (void)
 	antialias = options.antialias;
 	translucency = options.translucency;
 	vector_set_flicker(options.vector_flicker);
+	vector_set_intensity(options.vector_intensity);
 	beam = options.beam;
 
 
@@ -231,19 +220,11 @@ int vector_vh_start (void)
 	}
 
 	/* allocate memory for tables */
-	pTcosin = malloc ( (2048+1) * sizeof(INT32));   /* yes! 2049 is correct */
-	pixel = malloc (MAX_PIXELS * sizeof (UINT32));
-	old_list = malloc (MAX_POINTS * sizeof (point));
-	new_list = malloc (MAX_POINTS * sizeof (point));
-
-	/* did we get the requested memory? */
-	if (!(pTcosin && pixel && old_list && new_list))
-	{
-		/* vector_vh_stop should better be called by the main engine */
-		/* if vector_vh_start fails */
-		vector_vh_stop();
-		return 1;
-	}
+	pTcosin = auto_malloc ( (2048+1) * sizeof(pTcosin[0]));   /* yes! 2049 is correct */
+	pixel = auto_malloc (MAX_PIXELS * sizeof (pixel[0]));
+	vector_dirty_list = auto_malloc (MAX_DIRTY_PIXELS * sizeof (vector_dirty_list[0]));
+	old_list = auto_malloc (MAX_POINTS * sizeof (old_list[0]));
+	new_list = auto_malloc (MAX_POINTS * sizeof (new_list[0]));
 
 	/* build cosine table for fixing line width in antialias */
 	for (i=0; i<=2048; i++)
@@ -251,66 +232,30 @@ int vector_vh_start (void)
 		Tcosin(i) = (int)((double)(1.0/cos(atan((double)(i)/2048.0)))*0x10000000 + 0.5);
 	}
 
-	vector_set_flip_x(0);
-	vector_set_flip_y(0);
-	vector_set_swap_xy(0);
-
 	/* build gamma correction table */
 	vector_set_gamma (gamma_correction);
 
+	/* make sure we reset the list */
+	vector_dirty_list[0] = VECTOR_PIXEL_END;
+
 	return 0;
 }
 
 
-
-void vector_set_flip_x (int flip)
-{
-	if (flip)
-		vector_orientation |=  ORIENTATION_FLIP_X;
-	else
-		vector_orientation &= ~ORIENTATION_FLIP_X;
-}
-
-void vector_set_flip_y (int flip)
-{
-	if (flip)
-		vector_orientation |=  ORIENTATION_FLIP_Y;
-	else
-		vector_orientation &= ~ORIENTATION_FLIP_Y;
-}
-
-void vector_set_swap_xy (int swap)
-{
-	if (swap)
-		vector_orientation |=  ORIENTATION_SWAP_XY;
-	else
-		vector_orientation &= ~ORIENTATION_SWAP_XY;
-}
-
-
-/*
- * Setup scaling. Currently the Sega games are stuck at VECSHIFT 15
- * and the the AVG games at VECSHIFT 16
- */
-void vector_set_shift (int shift)
-{
-	vecshift = shift;
-}
-
 /*
  * Clear the old bitmap. Delete pixel for pixel, this is faster than memset.
  */
 static void vector_clear_pixels (void)
 {
+	vector_pixel_t coords;
 	int i;
-	int coords;
 
 	if (Machine->color_depth == 32)
 	{
 		for (i=p_index-1; i>=0; i--)
 		{
 			coords = pixel[i];
-			((UINT32 *)vecbitmap->line[coords & 0xffff])[coords >> 16] = 0;
+			((UINT32 *)vecbitmap->line[VECTOR_PIXEL_Y(coords)])[VECTOR_PIXEL_X(coords)] = 0;
 		}
 	}
 	else
@@ -318,39 +263,21 @@ static void vector_clear_pixels (void)
 		for (i=p_index-1; i>=0; i--)
 		{
 			coords = pixel[i];
-			((UINT16 *)vecbitmap->line[coords & 0xffff])[coords >> 16] = 0;
+			((UINT16 *)vecbitmap->line[VECTOR_PIXEL_Y(coords)])[VECTOR_PIXEL_X(coords)] = 0;
 		}
 	}
 	p_index=0;
 }
 
-/*
- * Stop the vector video hardware emulation. Free memory.
- */
-void vector_vh_stop (void)
-{
-	if (pTcosin)
-		free (pTcosin);
-	pTcosin = NULL;
-	if (pixel)
-		free (pixel);
-	pixel = NULL;
-	if (old_list)
-		free (old_list);
-	old_list = NULL;
-	if (new_list)
-		free (new_list);
-	new_list = NULL;
-}
-
 /*
  * draws an anti-aliased pixel (blends pixel with background)
  */
 #define LIMIT5(x) ((x < 0x1f)? x : 0x1f)
 #define LIMIT8(x) ((x < 0xff)? x : 0xff)
 
-static void vector_draw_aa_pixel_15 (int x, int y, int col, int dirty)
+static void vector_draw_aa_pixel_15 (int x, int y, rgb_t col, int dirty)
 {
+	vector_pixel_t coords;
 	UINT32 dst;
 
 	if (x < xmin || x >= xmax)
@@ -359,23 +286,22 @@ static void vector_draw_aa_pixel_15 (int x, int y, int col, int dirty)
 		return;
 
 	dst = ((UINT16 *)vecbitmap->line[y])[x];
-	((UINT16 *)vecbitmap->line[y])[x] = LIMIT5(((col>>3) & 0x1f) + (dst & 0x1f))
-		| (LIMIT5(((col >> 11) & 0x1f) + ((dst >> 5) & 0x1f)) << 5)
-		| (LIMIT5((col >> 19) + (dst >> 10)) << 10);
+	((UINT16 *)vecbitmap->line[y])[x] = LIMIT5((RGB_BLUE(col) >> 3) + (dst & 0x1f))
+		| (LIMIT5((RGB_GREEN(col) >> 3) + ((dst >> 5) & 0x1f)) << 5)
+		| (LIMIT5((RGB_RED(col) >> 3) + (dst >> 10)) << 10);
 
+	coords = VECTOR_PIXEL(x,y);
 	if (p_index<MAX_PIXELS)
-	{
-		pixel[p_index] = y | (x << 16);
-		p_index++;
-	}
+		pixel[p_index++] = coords;
 
 	/* Mark this pixel as dirty */
-	if (dirty)
-		osd_mark_vector_dirty (x, y);
+	if (dirty_index<MAX_DIRTY_PIXELS)
+		vector_dirty_list[dirty_index++] = coords;
 }
 
-static void vector_draw_aa_pixel_32 (int x, int y, int col, int dirty)
+static void vector_draw_aa_pixel_32 (int x, int y, rgb_t col, int dirty)
 {
+	vector_pixel_t coords;
 	UINT32 dst;
 
 	if (x < xmin || x >= xmax)
@@ -384,19 +310,17 @@ static void vector_draw_aa_pixel_32 (int x, int y, int col, int dirty)
 		return;
 
 	dst = ((UINT32 *)vecbitmap->line[y])[x];
-	((UINT32 *)vecbitmap->line[y])[x] = LIMIT8((col & 0xff) + (dst & 0xff))
-		| (LIMIT8(((col >> 8) & 0xff) + ((dst >> 8) & 0xff)) << 8)
-		| (LIMIT8((col >> 16) + (dst >> 16)) << 16);
+	((UINT32 *)vecbitmap->line[y])[x] = LIMIT8(RGB_BLUE(col) + (dst & 0xff))
+		| (LIMIT8(RGB_GREEN(col) + ((dst >> 8) & 0xff)) << 8)
+		| (LIMIT8(RGB_RED(col) + (dst >> 16)) << 16);
 
+	coords = VECTOR_PIXEL(x,y);
 	if (p_index<MAX_PIXELS)
-	{
-		pixel[p_index] = y | (x << 16);
-		p_index++;
-	}
+		pixel[p_index++] = coords;
 
 	/* Mark this pixel as dirty */
-	if (dirty)
-		osd_mark_vector_dirty (x, y);
+	if (dirty_index<MAX_DIRTY_PIXELS)
+		vector_dirty_list[dirty_index++] = coords;
 }
 
 
@@ -412,54 +336,17 @@ static void vector_draw_aa_pixel_32 (int x, int y, int col, int dirty)
  * written by Andrew Caldwell
  */
 
-void vector_draw_to (int x2, int y2, int col, int intensity, int dirty)
+void vector_draw_to(int x2, int y2, rgb_t col, int intensity, int dirty, rgb_t (*color_callback)(void))
 {
 	unsigned char a1;
 	int dx,dy,sx,sy,cx,cy,width;
 	static int x1,yy1;
 	int xx,yy;
-	int xy_swap;
 
-	/* [1] scale coordinates to display */
+	x2 = (int)(vector_scale_x*x2);
+	y2 = (int)(vector_scale_y*y2);
 
-	x2 = vec_mult(x2<<4,vector_scale_x);
-	y2 = vec_mult(y2<<4,vector_scale_y);
-
-	/* [2] fix display orientation */
-
-	if ((Machine->orientation ^ vector_orientation) & ORIENTATION_SWAP_XY)
-		xy_swap = 1;
-	else
-		xy_swap = 0;
-
-	if (vector_orientation & ORIENTATION_FLIP_X)
-	{
-		if (xy_swap)
-			x2 = ((vecheight-1)<<16)-x2;
-		else
-			x2 = ((vecwidth-1)<<16)-x2;
-	}
-	if (vector_orientation & ORIENTATION_FLIP_Y)
-	{
-		if (xy_swap)
-			y2 = ((vecwidth-1)<<16)-y2;
-		else
-			y2 = ((vecheight-1)<<16)-y2;
-	}
-
-	if ((Machine->orientation ^ vector_orientation) & ORIENTATION_SWAP_XY)
-	{
-		int temp;
-		temp = x2;
-		x2 = y2;
-		y2 = temp;
-	}
-	if (Machine->orientation & ORIENTATION_FLIP_X)
-		x2 = ((vecwidth-1)<<16)-x2;
-	if (Machine->orientation & ORIENTATION_FLIP_Y)
-		y2 = ((vecheight-1)<<16)-y2;
-
-	/* [3] adjust cords if needed */
+	/* [2] adjust cords if needed */
 
 	if (antialias)
 	{
@@ -471,92 +358,96 @@ void vector_draw_to (int x2, int y2, int col, int intensity, int dirty)
 	}
 	else /* noantialiasing */
 	{
-		x2 >>= 16;
-		y2 >>= 16;
+		x2 = (x2 + 0x8000) >> 16;
+		y2 = (y2 + 0x8000) >> 16;
 	}
 
-	/* [4] handle color and intensity */
+	/* [3] handle color and intensity */
 
 	if (intensity == 0) goto end_draw;
 
-	col = Tinten(intensity,col);
+	col = Tinten(intensity, col);
 
-	/* [5] draw line */
+	/* [4] draw line */
 
 	if (antialias)
 	{
 		/* draw an anti-aliased line */
-		dx=abs(x1-x2);
-		dy=abs(yy1-y2);
-		if (dx>=dy)
+		dx = abs(x1 - x2);
+		dy = abs(yy1 - y2);
+
+		if (dx >= dy)
 		{
-			sx = ((x1 <= x2) ? 1:-1);
-			sy = vec_div(y2-yy1,dx);
-			if (sy<0)
+			sx = ((x1 <= x2) ? 1 : -1);
+			sy = vec_div(y2 - yy1, dx);
+			if (sy < 0)
 				dy--;
 			x1 >>= 16;
-			xx = x2>>16;
-			width = vec_mult(beam<<4,Tcosin(abs(sy)>>5));
+			xx = x2 >> 16;
+			width = vec_mult(beam << 4, Tcosin(abs(sy) >> 5));
 			if (!beam_diameter_is_one)
-				yy1-= width>>1; /* start back half the diameter */
+				yy1 -= width >> 1; /* start back half the diameter */
 			for (;;)
 			{
+				if (color_callback) col = Tinten(intensity, (*color_callback)());
 				dx = width;    /* init diameter of beam */
-				dy = yy1>>16;
-				vector_draw_aa_pixel(x1,dy++,Tinten(Tgammar[0xff&(yy1>>8)],col), dirty);
-				dx -= 0x10000-(0xffff & yy1); /* take off amount plotted */
-				a1 = Tgamma[(dx>>8)&0xff];   /* calc remainder pixel */
+				dy = yy1 >> 16;
+				vector_draw_aa_pixel(x1, dy++, Tinten(Tgammar[0xff & (yy1 >> 8)], col), dirty);
+				dx -= 0x10000 - (0xffff & yy1); /* take off amount plotted */
+				a1 = Tgamma[(dx >> 8) & 0xff];   /* calc remainder pixel */
 				dx >>= 16;                   /* adjust to pixel (solid) count */
 				while (dx--)                 /* plot rest of pixels */
-					vector_draw_aa_pixel(x1,dy++,col, dirty);
-				vector_draw_aa_pixel(x1,dy,Tinten(a1,col), dirty);
+					vector_draw_aa_pixel(x1, dy++, col, dirty);
+				vector_draw_aa_pixel(x1, dy, Tinten(a1,col), dirty);
 				if (x1 == xx) break;
-				x1+=sx;
-				yy1+=sy;
+				x1 += sx;
+				yy1 += sy;
 			}
 		}
 		else
 		{
-			sy = ((yy1 <= y2) ? 1:-1);
-			sx = vec_div(x2-x1,dy);
-			if (sx<0)
+			sy = ((yy1 <= y2) ? 1: -1);
+			sx = vec_div(x2 - x1, dy);
+			if (sx < 0)
 				dx--;
 			yy1 >>= 16;
-			yy = y2>>16;
-			width = vec_mult(beam<<4,Tcosin(abs(sx)>>5));
-			if( !beam_diameter_is_one )
-				x1-= width>>1; /* start back half the width */
+			yy = y2 >> 16;
+			width = vec_mult(beam << 4,Tcosin(abs(sx) >> 5));
+			if (!beam_diameter_is_one)
+				x1 -= width >> 1; /* start back half the width */
 			for (;;)
 			{
+				if (color_callback) col = Tinten(intensity, (*color_callback)());
 				dy = width;    /* calc diameter of beam */
-				dx = x1>>16;
-				vector_draw_aa_pixel(dx++,yy1,Tinten(Tgammar[0xff&(x1>>8)],col), dirty);
-				dy -= 0x10000-(0xffff & x1); /* take off amount plotted */
-				a1 = Tgamma[(dy>>8)&0xff];   /* remainder pixel */
+				dx = x1 >> 16;
+				vector_draw_aa_pixel(dx++, yy1, Tinten(Tgammar[0xff & (x1 >> 8)], col), dirty);
+				dy -= 0x10000 - (0xffff & x1); /* take off amount plotted */
+				a1 = Tgamma[(dy >> 8) & 0xff];   /* remainder pixel */
 				dy >>= 16;                   /* adjust to pixel (solid) count */
 				while (dy--)                 /* plot rest of pixels */
-					vector_draw_aa_pixel(dx++,yy1,col, dirty);
-				vector_draw_aa_pixel(dx,yy1,Tinten(a1,col), dirty);
+					vector_draw_aa_pixel(dx++, yy1, col, dirty);
+				vector_draw_aa_pixel(dx, yy1, Tinten(a1, col), dirty);
 				if (yy1 == yy) break;
-				yy1+=sy;
-				x1+=sx;
+				yy1 += sy;
+				x1 += sx;
 			}
 		}
 	}
 	else /* use good old Bresenham for non-antialiasing 980317 BW */
 	{
-		dx = abs(x1-x2);
-		dy = abs(yy1-y2);
-		sx = (x1 <= x2) ? 1: -1;
-		sy = (yy1 <= y2) ? 1: -1;
-		cx = dx/2;
-		cy = dy/2;
+		dx = abs(x1 - x2);
+		dy = abs(yy1 - y2);
+		sx = (x1 <= x2) ? 1 : -1;
+		sy = (yy1 <= y2) ? 1 : -1;
+		cx = dx / 2;
+		cy = dy / 2;
 
-		if (dx>=dy)
+		if (dx >= dy)
 		{
 			for (;;)
 			{
-				vector_draw_aa_pixel (x1, yy1, col, dirty);
+				if (color_callback) col = Tinten(intensity, (*color_callback)());
+				vector_draw_aa_pixel(x1, yy1, col, dirty);
 				if (x1 == x2) break;
 				x1 += sx;
 				cx -= dy;
@@ -571,7 +462,8 @@ void vector_draw_to (int x2, int y2, int col, int intensity, int dirty)
 		{
 			for (;;)
 			{
-				vector_draw_aa_pixel (x1, yy1, col, dirty);
+				if (color_callback) col = Tinten(intensity, (*color_callback)());
+				vector_draw_aa_pixel(x1, yy1, col, dirty);
 				if (yy1 == y2) break;
 				yy1 += sy;
 				cy -= dx;
@@ -586,18 +478,19 @@ void vector_draw_to (int x2, int y2, int col, int intensity, int dirty)
 
 end_draw:
 
-	x1=x2;
-	yy1=y2;
+	x1 = x2;
+	yy1 = y2;
 }
 
+int vector_logging = 0;
 
 /*
  * Adds a line end point to the vertices list. The vector processor emulation
  * needs to call this.
  */
-void vector_add_point (int x, int y, int color, int intensity)
+void vector_add_point (int x, int y, rgb_t color, int intensity)
 {
-	point *new;
+	point *newpoint;
 
 	intensity *= intensity_correction;
 	if (intensity > 0xff)
@@ -611,12 +504,45 @@ void vector_add_point (int x, int y, int color, int intensity)
 		if (intensity > 0xff)
 			intensity = 0xff;
 	}
-	new = &new_list[new_index];
-	new->x = x;
-	new->y = y;
-	new->col = color;
-	new->intensity = intensity;
-	new->status = VDIRTY; /* mark identical lines as clean later */
+	newpoint = &new_list[new_index];
+	newpoint->x = x;
+	newpoint->y = y;
+	newpoint->col = color;
+	newpoint->intensity = intensity;
+	newpoint->callback = 0;
+	newpoint->status = VDIRTY; /* mark identical lines as clean later */
+
+	new_index++;
+	if (new_index >= MAX_POINTS)
+	{
+		new_index--;
+		logerror("*** Warning! Vector list overflow!\n");
+	}
+}
+
+void vector_add_point_callback (int x, int y, rgb_t (*color_callback)(void), int intensity)
+{
+	point *newpoint;
+
+	intensity *= intensity_correction;
+	if (intensity > 0xff)
+		intensity = 0xff;
+
+	if (flicker && (intensity > 0))
+	{
+		intensity += (intensity * (0x80-(rand()&0xff)) * flicker)>>16;
+		if (intensity < 0)
+			intensity = 0;
+		if (intensity > 0xff)
+			intensity = 0xff;
+	}
+	newpoint = &new_list[new_index];
+	newpoint->x = x;
+	newpoint->y = y;
+	newpoint->col = 1;
+	newpoint->intensity = intensity;
+	newpoint->callback = color_callback;
+	newpoint->status = VDIRTY; /* mark identical lines as clean later */
 
 	new_index++;
 	if (new_index >= MAX_POINTS)
@@ -631,14 +557,14 @@ void vector_add_point (int x, int y, int color, int intensity)
  */
 void vector_add_clip (int x1, int yy1, int x2, int y2)
 {
-	point *new;
+	point *newpoint;
 
-	new = &new_list[new_index];
-	new->x = x1;
-	new->y = yy1;
-	new->arg1 = x2;
-	new->arg2 = y2;
-	new->status = VCLIP;
+	newpoint = &new_list[new_index];
+	newpoint->x = x1;
+	newpoint->y = yy1;
+	newpoint->arg1 = x2;
+	newpoint->arg2 = y2;
+	newpoint->status = VCLIP;
 
 	new_index++;
 	if (new_index >= MAX_POINTS)
@@ -654,8 +580,6 @@ void vector_add_clip (int x1, int yy1, int x2, int y2)
  */
 void vector_set_clip (int x1, int yy1, int x2, int y2)
 {
-	int tmp;
-
 	/* failsafe */
 	if ((x1 >= x2) || (yy1 >= y2))
 	{
@@ -668,52 +592,15 @@ void vector_set_clip (int x1, int yy1, int x2, int y2)
 	}
 
 	/* scale coordinates to display */
-	x1 = vec_mult(x1<<4,vector_scale_x);
-	yy1 = vec_mult(yy1<<4,vector_scale_y);
-	x2 = vec_mult(x2<<4,vector_scale_x);
-	y2 = vec_mult(y2<<4,vector_scale_y);
+	x1 = (int)(vector_scale_x*x1);
+	yy1= (int)(vector_scale_y*yy1);
+	x2 = (int)(vector_scale_x*x2);
+	y2 = (int)(vector_scale_y*y2);
 
-	/* fix orientation */
-
-	/* don't forget to swap x1,x2, since x2 becomes the minimum */
-	if (vector_orientation & ORIENTATION_FLIP_X)
-	{
-		x1 = ((vecwidth-1)<<16)-x1;
-		x2 = ((vecwidth-1)<<16)-x2;
-		tmp = x1; x1 = x2; x2 = tmp;
-	}
-	/* don't forget to swap yy1,y2, since y2 becomes the minimum */
-	if (vector_orientation & ORIENTATION_FLIP_Y)
-	{
-		yy1 = ((vecheight-1)<<16)-yy1;
-		y2 = ((vecheight-1)<<16)-y2;
-		tmp = yy1; yy1 = y2; y2 = tmp;
-	}
-	/* swapping x/y coordinates will still have the minima in x1,yy1 */
-	if ((Machine->orientation ^ vector_orientation) & ORIENTATION_SWAP_XY)
-	{
-		tmp = x1; x1 = yy1; yy1 = tmp;
-		tmp = x2; x2 = y2; y2 = tmp;
-	}
-	/* don't forget to swap x1,x2, since x2 becomes the minimum */
-	if (Machine->orientation & ORIENTATION_FLIP_X)
-	{
-		x1 = ((vecwidth-1)<<16)-x1;
-		x2 = ((vecwidth-1)<<16)-x2;
-		tmp = x1; x1 = x2; x2 = tmp;
-	}
-	/* don't forget to swap yy1,y2, since y2 becomes the minimum */
-	if (Machine->orientation & ORIENTATION_FLIP_Y)
-	{
-		yy1 = ((vecheight-1)<<16)-yy1;
-		y2 = ((vecheight-1)<<16)-y2;
-		tmp = yy1; yy1 = y2; y2 = tmp;
-	}
-
-	xmin = x1 >> 16;
-	ymin = yy1 >> 16;
-	xmax = x2 >> 16;
-	ymax = y2 >> 16;
+	xmin = (x1 + 0x8000) >> 16;
+	ymin = (yy1 + 0x8000) >> 16;
+	xmax = (x2 + 0x8000) >> 16;
+	ymax = (y2 + 0x8000) >> 16;
 
 	/* Make it foolproof by trapping rounding errors */
 	if (xmin < 0) xmin = 0;
@@ -749,8 +636,7 @@ void vector_clear_list (void)
  */
 static void clever_mark_dirty (void)
 {
-	int i, j, min_index, last_match = 0;
-	unsigned int *coords;
+	int i, min_index, last_match = 0;
 	point *new, *old;
 	point newclip, oldclip;
 	int clips_match = 1;
@@ -788,7 +674,8 @@ static void clever_mark_dirty (void)
 
 		/* If the clips match and the vectors match, update */
 		else if (clips_match && (new->x == old->x) && (new->y == old->y) &&
-			(new->col == old->col) && (new->intensity == old->intensity))
+			(new->col == old->col) && (new->intensity == old->intensity) &&
+			(!new->callback && !old->callback))
 		{
 			if (last_match)
 			{
@@ -803,11 +690,10 @@ static void clever_mark_dirty (void)
 			last_match = 0;
 
 		/* mark the pixels of the old vector dirty */
-		coords = &pixel[old->arg1];
-		for (j = (old->arg2 - old->arg1); j > 0; j--)
+		if (dirty_index + old->arg2 - old->arg1 < MAX_DIRTY_PIXELS)
 		{
-			osd_mark_vector_dirty (*coords >> 16, *coords & 0x0000ffff);
-			coords++;
+			memcpy(&vector_dirty_list[dirty_index], &pixel[old->arg1], (old->arg2 - old->arg1) * sizeof(pixel[0]));
+			dirty_index += old->arg2 - old->arg1;
 		}
 	}
 
@@ -820,54 +706,55 @@ static void clever_mark_dirty (void)
 			continue;
 
 		/* mark the pixels of the old vector dirty */
-		coords = &pixel[old->arg1];
-		for (j = (old->arg2 - old->arg1); j > 0; j--)
+		if (dirty_index + old->arg2 - old->arg1 < MAX_DIRTY_PIXELS)
 		{
-			osd_mark_vector_dirty (*coords >> 16, *coords & 0x0000ffff);
-			coords++;
+			memcpy(&vector_dirty_list[dirty_index], &pixel[old->arg1], (old->arg2 - old->arg1) * sizeof(pixel[0]));
+			dirty_index += old->arg2 - old->arg1;
 		}
 	}
 }
 
-void vector_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( vector )
 {
 	int i;
-	int temp_x, temp_y;
-	point *new;
+	point *curpoint;
 
+	int rv = 1;
 
-	if (full_refresh)
-		fillbitmap(bitmap,0,NULL);
+	/* if there is an auxiliary renderer set, let it run */
+	if (vector_aux_renderer)
+		rv = vector_aux_renderer(new_list, new_index);
 
+	/* if the aux renderer chooses, it can override the bitmap */
+	if (!rv)
+	{
+		/* This prevents a crash in the artwork system */
+		vector_dirty_list[0] = VECTOR_PIXEL_END;
+		return;
+	}
 
 	/* copy parameters */
 	vecbitmap = bitmap;
 	vecwidth  = bitmap->width;
 	vecheight = bitmap->height;
 
-	/* setup scaling */
-	temp_x = (1<<(44-vecshift)) / (Machine->visible_area.max_x - Machine->visible_area.min_x);
-	temp_y = (1<<(44-vecshift)) / (Machine->visible_area.max_y - Machine->visible_area.min_y);
-
-	if ((Machine->orientation ^ vector_orientation) & ORIENTATION_SWAP_XY)
-	{
-		vector_scale_x = temp_x * vecheight;
-		vector_scale_y = temp_y * vecwidth;
-	}
-	else
-	{
-		vector_scale_x = temp_x * vecwidth;
-		vector_scale_y = temp_y * vecheight;
-	}
 	/* reset clipping area */
-	xmin = 0; xmax = vecwidth; ymin = 0; ymax = vecheight;
+	xmin = 0;
+	xmax = vecwidth;
+	ymin = 0;
+	ymax = vecheight;
+
+	/* setup scaling */
+	vector_scale_x = ((float)vecwidth)/(Machine->visible_area.max_x - Machine->visible_area.min_x);
+	vector_scale_y = ((float)vecheight)/(Machine->visible_area.max_y - Machine->visible_area.min_y);
 
 	/* next call to vector_clear_list() is allowed to swap the lists */
 	vector_runs = 0;
 
 	/* mark pixels which are not idential in newlist and oldlist dirty */
 	/* the old pixels which get removed are marked dirty immediately,  */
-	/* new pixels are recognized by setting new->dirty                 */
+	/* new pixels are recognized by setting new->dirty */
+	dirty_index = 0;
 	clever_mark_dirty();
 
 	/* clear ALL pixels in the hidden map */
@@ -875,20 +762,23 @@ void vector_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	/* Draw ALL lines into the hidden map. Mark only those lines with */
 	/* new->dirty = 1 as dirty. Remember the pixel start/end indices  */
-	new = new_list;
+	curpoint = new_list;
+
 	for (i = 0; i < new_index; i++)
 	{
-		if (new->status == VCLIP)
-			vector_set_clip (new->x, new->y, new->arg1, new->arg2);
+		if (curpoint->status == VCLIP)
+		{
+			vector_set_clip(curpoint->x, curpoint->y, curpoint->arg1, curpoint->arg2);
+		}
 		else
 		{
-			new->arg1 = p_index;
-			vector_draw_to (new->x, new->y, new->col, Tgamma[new->intensity], new->status);
+			curpoint->arg1 = p_index;
+			vector_draw_to(curpoint->x, curpoint->y, curpoint->col, Tgamma[curpoint->intensity], curpoint->status, curpoint->callback);
 
-			new->arg2 = p_index;
+			curpoint->arg2 = p_index;
 		}
-		new++;
+		curpoint++;
 	}
-}
 
-#endif /* if !(defined xgl) && !(defined xfx) && !(defined svgafx) */
+	vector_dirty_list[dirty_index] = VECTOR_PIXEL_END;
+}
