@@ -1,6 +1,6 @@
 /***************************************************************************
 
-	Victory video system
+    Victory video system
 
 ***************************************************************************/
 
@@ -36,6 +36,7 @@ static struct
 	UINT8	x,xp,y,yp;
 	UINT8	cmd,cmdlo;
 	void *	timer;
+	UINT8	timer_active;
 	double	endtime;
 } micro;
 
@@ -53,8 +54,6 @@ static struct
 
 
 /* function prototypes */
-void victory_vh_stop(void);
-
 static int command2(void);
 static int command3(void);
 static int command4(void);
@@ -66,32 +65,25 @@ static int command7(void);
 
 /*************************************
  *
- *	Initialize the video system
+ *  Initialize the video system
  *
  *************************************/
 
-int victory_vh_start(void)
+VIDEO_START( victory )
 {
 	/* allocate bitmapram */
-	rram = malloc(0x4000);
-	gram = malloc(0x4000);
-	bram = malloc(0x4000);
+	rram = auto_malloc(0x4000);
+	gram = auto_malloc(0x4000);
+	bram = auto_malloc(0x4000);
 
 	/* allocate bitmaps */
-	bgbitmap = malloc(256 * 256);
-	fgbitmap = malloc(256 * 256);
+	bgbitmap = auto_malloc(256 * 256);
+	fgbitmap = auto_malloc(256 * 256);
 
 	/* allocate dirty maps */
-	bgdirty = malloc(32 * 32);
-	chardirty = malloc(256);
-	scandirty = malloc(512);
-
-	/* fail if something went wrong */
-	if (!rram || !gram || !bram || !bgbitmap || !fgbitmap || !bgdirty || !chardirty || !scandirty)
-	{
-		victory_vh_stop();
-		return 1;
-	}
+	bgdirty = auto_malloc(32 * 32);
+	chardirty = auto_malloc(256);
+	scandirty = auto_malloc(512);
 
 	/* mark everything dirty */
 	memset(bgdirty, 1, 32 * 32);
@@ -106,6 +98,7 @@ int victory_vh_start(void)
 	update_complete = 0;
 	video_control = 0;
 	memset(&micro, 0, sizeof(micro));
+	micro.timer = timer_alloc(NULL);
 
 	return 0;
 }
@@ -114,77 +107,35 @@ int victory_vh_start(void)
 
 /*************************************
  *
- *	Tear down the video system
- *
- *************************************/
-
-void victory_vh_stop(void)
-{
-	/* free dirty maps */
-	if (bgdirty)
-		free(bgdirty);
-	bgdirty = NULL;
-	if (chardirty)
-		free(chardirty);
-	chardirty = NULL;
-	if (scandirty)
-		free(scandirty);
-	scandirty = NULL;
-
-	/* free bitmaps */
-	if (bgbitmap)
-		free(bgbitmap);
-	bgbitmap = NULL;
-	if (fgbitmap)
-		free(fgbitmap);
-	fgbitmap = NULL;
-
-	/* free bitmapram */
-	if (rram)
-		free(rram);
-	rram = NULL;
-	if (gram)
-		free(gram);
-	gram = NULL;
-	if (bram)
-		free(bram);
-	bram = NULL;
-}
-
-
-
-/*************************************
- *
- *	Interrupt generation
+ *  Interrupt generation
  *
  *************************************/
 
 void victory_update_irq(void)
 {
 	if (vblank_irq || fgcoll || (bgcoll && (video_control & 0x20)))
-		cpu_set_irq_line(0, 0, ASSERT_LINE);
+		cpunum_set_input_line(0, 0, ASSERT_LINE);
 	else
-		cpu_set_irq_line(0, 0, CLEAR_LINE);
+		cpunum_set_input_line(0, 0, CLEAR_LINE);
 }
 
 
-int victory_vblank_interrupt(void)
+INTERRUPT_GEN( victory_vblank_interrupt )
 {
 	vblank_irq = 1;
 	victory_update_irq();
 	logerror("------------- VBLANK ----------------\n");
-	return ignore_interrupt();
 }
 
 
 
 /*************************************
  *
- *	Video RAM write
+ *  Video RAM write
  *
  *************************************/
 
-WRITE_HANDLER( victory_videoram_w )
+WRITE8_HANDLER( victory_videoram_w )
 {
 	if (videoram[offset] != data)
 	{
@@ -197,11 +148,11 @@ WRITE_HANDLER( victory_videoram_w )
 
 /*************************************
  *
- *	Character RAM write
+ *  Character RAM write
  *
  *************************************/
 
-WRITE_HANDLER( victory_charram_w )
+WRITE8_HANDLER( victory_charram_w )
 {
 	if (victory_charram[offset] != data)
 	{
@@ -214,11 +165,11 @@ WRITE_HANDLER( victory_charram_w )
 
 /*************************************
  *
- *	Palette RAM write
+ *  Palette RAM write
  *
  *************************************/
 
-WRITE_HANDLER( victory_paletteram_w )
+WRITE8_HANDLER( victory_paletteram_w )
 {
 	int red = ((offset & 0x80) >> 5) | ((data & 0xc0) >> 6);
 	int blue = (data & 0x38) >> 3;
@@ -237,11 +188,11 @@ WRITE_HANDLER( victory_paletteram_w )
 
 /*************************************
  *
- *	Video control read
+ *  Video control read
  *
  *************************************/
 
-READ_HANDLER( victory_video_control_r )
+READ8_HANDLER( victory_video_control_r )
 {
 	int result = 0;
 
@@ -249,7 +200,7 @@ READ_HANDLER( victory_video_control_r )
 	{
 		case 0:		/* 5XFIQ */
 			result = fgcollx;
-			if (LOG_COLLISION) logerror("%04X:5XFIQ read = %02X\n", cpu_getpreviouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5XFIQ read = %02X\n", activecpu_get_previouspc(), result);
 			return result;
 
 		case 1:		/* 5CLFIQ */
@@ -259,12 +210,12 @@ READ_HANDLER( victory_video_control_r )
 				fgcoll = 0;
 				victory_update_irq();
 			}
-			if (LOG_COLLISION) logerror("%04X:5CLFIQ read = %02X\n", cpu_getpreviouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5CLFIQ read = %02X\n", activecpu_get_previouspc(), result);
 			return result;
 
 		case 2:		/* 5BACKX */
 			result = bgcollx & 0xfc;
-			if (LOG_COLLISION) logerror("%04X:5BACKX read = %02X\n", cpu_getpreviouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5BACKX read = %02X\n", activecpu_get_previouspc(), result);
 			return result;
 
 		case 3:		/* 5BACKY */
@@ -274,7 +225,7 @@ READ_HANDLER( victory_video_control_r )
 				bgcoll = 0;
 				victory_update_irq();
 			}
-			if (LOG_COLLISION) logerror("%04X:5BACKY read = %02X\n", cpu_getpreviouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5BACKY read = %02X\n", activecpu_get_previouspc(), result);
 			return result;
 
 		case 4:		/* 5STAT */
@@ -283,17 +234,17 @@ READ_HANDLER( victory_video_control_r )
 			/* D5 = 5VIRQ */
 			/* D4 = 5BCIRQ (3B1) */
 			/* D3 = SL256 */
-			if (micro.timer && timer_timeelapsed(micro.timer) < micro.endtime)
+			if (micro.timer_active && timer_timeelapsed(micro.timer) < micro.endtime)
 				result |= 0x80;
 			result |= (~fgcoll & 1) << 6;
 			result |= (~vblank_irq & 1) << 5;
 			result |= (~bgcoll & 1) << 4;
 			result |= (cpu_getscanline() & 0x100) >> 5;
-			if (LOG_COLLISION) logerror("%04X:5STAT read = %02X\n", cpu_getpreviouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5STAT read = %02X\n", activecpu_get_previouspc(), result);
 			return result;
 
 		default:
-			logerror("%04X:victory_video_control_r(%02X)\n", cpu_getpreviouspc(), offset);
+			logerror("%04X:victory_video_control_r(%02X)\n", activecpu_get_previouspc(), offset);
 			break;
 	}
 	return 0;
@@ -303,21 +254,21 @@ READ_HANDLER( victory_video_control_r )
 
 /*************************************
  *
- *	Video control write
+ *  Video control write
  *
  *************************************/
 
-WRITE_HANDLER( victory_video_control_w )
+WRITE8_HANDLER( victory_video_control_w )
 {
 	switch (offset)
 	{
 		case 0:		/* LOAD IL */
-			if (LOG_MICROCODE) logerror("%04X:IL=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:IL=%02X\n", activecpu_get_previouspc(), data);
 			micro.i = (micro.i & 0xff00) | (data & 0x00ff);
 			break;
 
 		case 1:		/* LOAD IH */
-			if (LOG_MICROCODE) logerror("%04X:IH=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:IH=%02X\n", activecpu_get_previouspc(), data);
 			micro.i = (micro.i & 0x00ff) | ((data << 8) & 0xff00);
 			if (micro.cmdlo == 5)
 			{
@@ -327,7 +278,7 @@ WRITE_HANDLER( victory_video_control_w )
 			break;
 
 		case 2:		/* LOAD CMD */
-			if (LOG_MICROCODE) logerror("%04X:CMD=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:CMD=%02X\n", activecpu_get_previouspc(), data);
 			micro.cmd = data;
 			micro.cmdlo = data & 7;
 			if (micro.cmdlo == 0)
@@ -342,12 +293,12 @@ WRITE_HANDLER( victory_video_control_w )
 			break;
 
 		case 3:		/* LOAD G */
-			if (LOG_MICROCODE) logerror("%04X:G=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:G=%02X\n", activecpu_get_previouspc(), data);
 			micro.g = data;
 			break;
 
 		case 4:		/* LOAD X */
-			if (LOG_MICROCODE) logerror("%04X:X=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:X=%02X\n", activecpu_get_previouspc(), data);
 			micro.xp = data;
 			if (micro.cmdlo == 3)
 			{
@@ -357,7 +308,7 @@ WRITE_HANDLER( victory_video_control_w )
 			break;
 
 		case 5:		/* LOAD Y */
-			if (LOG_MICROCODE) logerror("%04X:Y=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:Y=%02X\n", activecpu_get_previouspc(), data);
 			micro.yp = data;
 			if (micro.cmdlo == 4)
 			{
@@ -367,12 +318,12 @@ WRITE_HANDLER( victory_video_control_w )
 			break;
 
 		case 6:		/* LOAD R */
-			if (LOG_MICROCODE) logerror("%04X:R=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:R=%02X\n", activecpu_get_previouspc(), data);
 			micro.r = data;
 			break;
 
 		case 7:		/* LOAD B */
-			if (LOG_MICROCODE) logerror("%04X:B=%02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:B=%02X\n", activecpu_get_previouspc(), data);
 			micro.b = data;
 			if (micro.cmdlo == 2)
 			{
@@ -387,12 +338,12 @@ WRITE_HANDLER( victory_video_control_w )
 			break;
 
 		case 8:		/* SCROLLX */
-			if (LOG_MICROCODE) logerror("%04X:SCROLLX write = %02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:SCROLLX write = %02X\n", activecpu_get_previouspc(), data);
 			scrollx = data;
 			break;
 
 		case 9:		/* SCROLLY */
-			if (LOG_MICROCODE) logerror("%04X:SCROLLY write = %02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:SCROLLY write = %02X\n", activecpu_get_previouspc(), data);
 			scrolly = data;
 			break;
 
@@ -404,18 +355,18 @@ WRITE_HANDLER( victory_video_control_w )
 			/* D3 = SINVERT */
 			/* D2 = BIR12 */
 			/* D1 = SELOVER */
-			if (LOG_MICROCODE) logerror("%04X:CONTROL write = %02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:CONTROL write = %02X\n", activecpu_get_previouspc(), data);
 			video_control = data;
 			break;
 
 		case 11:	/* CLRVIRQ */
-			if (LOG_MICROCODE) logerror("%04X:CLRVIRQ write = %02X\n", cpu_getpreviouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:CLRVIRQ write = %02X\n", activecpu_get_previouspc(), data);
 			vblank_irq = 0;
 			victory_update_irq();
 			break;
 
 		default:
-			if (LOG_MICROCODE) logerror("%04X:victory_video_control_w(%02X) = %02X\n", cpu_getpreviouspc(), offset, data);
+			if (LOG_MICROCODE) logerror("%04X:victory_video_control_w(%02X) = %02X\n", activecpu_get_previouspc(), offset, data);
 			break;
 	}
 }
@@ -423,195 +374,195 @@ WRITE_HANDLER( victory_video_control_w )
 
 /***************************************************************************************************
 
-	Victory Microcode
-	-----------------
+    Victory Microcode
+    -----------------
 
-	The cool thing about this hardware is the use of microcode, which is like having a little
-	graphics coprocessor around to do the hard stuff. The operations that can be performed by
-	this bit of circuitry include pixel plotting, line drawing, sprite drawing, and data
-	transfer, all with optional collision detection. In addition, data can be uploaded into
-	the $2000-$21FF address range and then "executed" as mini subroutines.
+    The cool thing about this hardware is the use of microcode, which is like having a little
+    graphics coprocessor around to do the hard stuff. The operations that can be performed by
+    this bit of circuitry include pixel plotting, line drawing, sprite drawing, and data
+    transfer, all with optional collision detection. In addition, data can be uploaded into
+    the $2000-$21FF address range and then "executed" as mini subroutines.
 
-	Commands to the microcode are written to the command register at $C102, followed by
-	whatever parameters are needed. Parameters are stored in registers. There are a number
-	of registers, accessed at these addresses:
+    Commands to the microcode are written to the command register at $C102, followed by
+    whatever parameters are needed. Parameters are stored in registers. There are a number
+    of registers, accessed at these addresses:
 
-		C100-C101:	I (16 bits)
-		C102:		CMD (8 bits)
-		C103:		G (8 bits)
-		C104:		X' (8 bits)
-		C105:		Y' (8 bits)
-		C106:		R (8 bits)
-		C107:		B (8 bits)
+        C100-C101:  I (16 bits)
+        C102:       CMD (8 bits)
+        C103:       G (8 bits)
+        C104:       X' (8 bits)
+        C105:       Y' (8 bits)
+        C106:       R (8 bits)
+        C107:       B (8 bits)
 
-	Writing the last parameter triggers the command. There are a total of 6 commands supported:
+    Writing the last parameter triggers the command. There are a total of 6 commands supported:
 
-		command 2: copy data
-			when register B is written, take the bytes from R, G and B and transfer them
-			into video RAM at address I
+        command 2: copy data
+            when register B is written, take the bytes from R, G and B and transfer them
+            into video RAM at address I
 
-		command 3: draw sprite
-			when register X is written, draw a sprite at location (X,Y) using the data from
-			video RAM address I; the width is given by (R >> 5) * 8, and then height is
-			given by (R & 31) * 2; data is XORed with the current VRAM contents
+        command 3: draw sprite
+            when register X is written, draw a sprite at location (X,Y) using the data from
+            video RAM address I; the width is given by (R >> 5) * 8, and then height is
+            given by (R & 31) * 2; data is XORed with the current VRAM contents
 
-		command 4: execute program
-			when register Y is written, copy Y * 2 to the PC and begin executing the commands
-			at ($2000 + PC); each command loads 6 bytes from VRAM into registers CMD,X,Y,I and R;
-			the program stops executing after it receives a command with the high bit off
+        command 4: execute program
+            when register Y is written, copy Y * 2 to the PC and begin executing the commands
+            at ($2000 + PC); each command loads 6 bytes from VRAM into registers CMD,X,Y,I and R;
+            the program stops executing after it receives a command with the high bit off
 
-		command 5: draw vector
-			when register IH is written, draw a vector of length IL starting at location (X,Y);
-			IH serves as the bresenhem increment for the minor axis; bits 4-6 of the command
-			select which octant to draw into; each VRAM write XORs the data from R,G and B
-			with the current VRAM contents
+        command 5: draw vector
+            when register IH is written, draw a vector of length IL starting at location (X,Y);
+            IH serves as the bresenhem increment for the minor axis; bits 4-6 of the command
+            select which octant to draw into; each VRAM write XORs the data from R,G and B
+            with the current VRAM contents
 
-		command 6: copy data
-			when the command is written, copy (R & 31) * 2 bytes of data from video RAM location
-			I to video RAM location ($2000 + PC)
+        command 6: copy data
+            when the command is written, copy (R & 31) * 2 bytes of data from video RAM location
+            I to video RAM location ($2000 + PC)
 
-		command 7: plot pixel
-			when register B is written, take the bytes from R, G and B and XOR them with the
-			video RAM contents at (X,Y)
+        command 7: plot pixel
+            when register B is written, take the bytes from R, G and B and XOR them with the
+            video RAM contents at (X,Y)
 
-	The command register is actually broken down into bitfields as follows:
+    The command register is actually broken down into bitfields as follows:
 
-		D7    -> must be high for a program to continue execution; otherwise, it will stop
-		D4-D6 -> for non-vector commands, enables VRAM writes to the red, blue and green planes
-		D3    -> enable collision detection for commands 3,5,7
-		D0-D2 -> command
+        D7    -> must be high for a program to continue execution; otherwise, it will stop
+        D4-D6 -> for non-vector commands, enables VRAM writes to the red, blue and green planes
+        D3    -> enable collision detection for commands 3,5,7
+        D0-D2 -> command
 
-	The microcode is actually a big state machine, driven by the 4 PROMs at 19B,19C,19D and 19E.
-	Below are some of the gory details of the state machine.
+    The microcode is actually a big state machine, driven by the 4 PROMs at 19B,19C,19D and 19E.
+    Below are some of the gory details of the state machine.
 
 ***************************************************************************************************
 
-	19E:
-		D7 -> inverter -> ZERO RAM [11C8, 13D8]
-		D6 -> select on the mux at 18F
-		D5 -> BUSY [4B6]
-		D4 -> D on flip flop at 16E
-		D3 -> D3 of alternate selection from mux at 18F
-		D2 -> D2 of alternate selection from mux at 18F
-		D1 -> D1 of alternate selection from mux at 18F
-		D0 -> D0 of alternate selection from mux at 18F
+    19E:
+        D7 -> inverter -> ZERO RAM [11C8, 13D8]
+        D6 -> select on the mux at 18F
+        D5 -> BUSY [4B6]
+        D4 -> D on flip flop at 16E
+        D3 -> D3 of alternate selection from mux at 18F
+        D2 -> D2 of alternate selection from mux at 18F
+        D1 -> D1 of alternate selection from mux at 18F
+        D0 -> D0 of alternate selection from mux at 18F
 
-	19B:
-		D7 -> S LOAD LH [11B8]
-		D6 -> INC I (AND with WRITE EA) [8A8]
-		D5 -> S INC Y (AND with WRITE EA) [8C8]
-		D4 -> SXFERY (AND with WRITE EA) [8C8]
-		D3 -> D on flip flop at 15E, output goes to SADDX [8C8]
-		D2 -> S LOAD PC [8B8]
-		D1 -> CPU0 [11C8, 13C7]
-		D0 -> INC X (AND with WRITE EA) [8C8]
+    19B:
+        D7 -> S LOAD LH [11B8]
+        D6 -> INC I (AND with WRITE EA) [8A8]
+        D5 -> S INC Y (AND with WRITE EA) [8C8]
+        D4 -> SXFERY (AND with WRITE EA) [8C8]
+        D3 -> D on flip flop at 15E, output goes to SADDX [8C8]
+        D2 -> S LOAD PC [8B8]
+        D1 -> CPU0 [11C8, 13C7]
+        D0 -> INC X (AND with WRITE EA) [8C8]
 
-	19C:
-		D7 -> SXFERX/INC X (AND with WRITE EA) [8C8, 11B8, 12C8]
-		D6 -> see D5
-		D5 -> selects one of 4 with D6:
-				0 -> SEA VDATA
-				1 -> SEA BUFF
-				2 -> SEA SR 1
-				3 -> SEA SR 2
-		D4 -> ADD 128 [11C8, 12C8]
-		      also: S ACC CLEAR (AND with WRITE EA) [10B8]
-		D3 -> S ACC CLK (AND with S SEQ CLK) [10B8]
-		D2 -> INC PC [8B8]
-		D1 -> INC L [11B8]
-		D0 -> INC H [11B8]
+    19C:
+        D7 -> SXFERX/INC X (AND with WRITE EA) [8C8, 11B8, 12C8]
+        D6 -> see D5
+        D5 -> selects one of 4 with D6:
+                0 -> SEA VDATA
+                1 -> SEA BUFF
+                2 -> SEA SR 1
+                3 -> SEA SR 2
+        D4 -> ADD 128 [11C8, 12C8]
+              also: S ACC CLEAR (AND with WRITE EA) [10B8]
+        D3 -> S ACC CLK (AND with S SEQ CLK) [10B8]
+        D2 -> INC PC [8B8]
+        D1 -> INC L [11B8]
+        D0 -> INC H [11B8]
 
-	19D:
-		D7 -> S W VRAM (AND with WRITE EA) [14A8]
-		D6 -> S WRITE BUSS1 (AND with WRITE EA) [7A8]
-		D5 -> S WRITE BUSS2 (AND with WRITE EA) [7A8]
-		D4 -> D2 of alternate selection from mux at 18E
-		D3 -> D1 of alternate selection from mux at 18E
-		D2 -> D0 of alternate selection from mux at 18E
-		D1 -> ASEL1 (AND with WRITE EA) [8D8]
-		D0 -> ASEL0 (AND with WRITE EA) [8D8]
+    19D:
+        D7 -> S W VRAM (AND with WRITE EA) [14A8]
+        D6 -> S WRITE BUSS1 (AND with WRITE EA) [7A8]
+        D5 -> S WRITE BUSS2 (AND with WRITE EA) [7A8]
+        D4 -> D2 of alternate selection from mux at 18E
+        D3 -> D1 of alternate selection from mux at 18E
+        D2 -> D0 of alternate selection from mux at 18E
+        D1 -> ASEL1 (AND with WRITE EA) [8D8]
+        D0 -> ASEL0 (AND with WRITE EA) [8D8]
 
 
-	Always on in non-zero states: BUSY, CPU0
+    Always on in non-zero states: BUSY, CPU0
 
-	State	Next				ASEL SEA Interesting bits
-	-----	----				---- --- --------------------------------------------
-	  00	/SETRDY ? 00 : 01	  3   0  None
-	  01	CM0-2				  0   0
-	  02	00					  0   0  ZERORAM, INCI, SWVRAM
-	  03	1C					  2   0  SLOADLH, SXFERY
-	  04	1A					  2   0  SLOADPC
-	  05	0A					  1   0  SXFERY, ADD128+SACCCLEAR, SACCCLK
-	  06	0C					  0   0  SLOADLH, SLOADPC
-	  07	08					  1   0  SXFERY, SXFERX+INCX
-	  08	09					  1   2  INCX, SWVRAM
-	  09	00					  1   3  SWVRAM
-	  0A	VFIN ? 19 : 0B		  1   0  SXFERX+INCX
-	  0B	0A					  1   2  INCI, SACCCLK, SWVRAM
-	  0C	0D					  0   1  INCI, SXFERX+INCX, INCL
-	  0D	/LTC ? 0C : 0E		  2   2  ZERORAM, INCPC, SWVRAM
-	  0E	19					  2   2
+    State   Next                ASEL SEA Interesting bits
+    -----   ----                ---- --- --------------------------------------------
+      00    /SETRDY ? 00 : 01     3   0  None
+      01    CM0-2                 0   0
+      02    00                    0   0  ZERORAM, INCI, SWVRAM
+      03    1C                    2   0  SLOADLH, SXFERY
+      04    1A                    2   0  SLOADPC
+      05    0A                    1   0  SXFERY, ADD128+SACCCLEAR, SACCCLK
+      06    0C                    0   0  SLOADLH, SLOADPC
+      07    08                    1   0  SXFERY, SXFERX+INCX
+      08    09                    1   2  INCX, SWVRAM
+      09    00                    1   3  SWVRAM
+      0A    VFIN ? 19 : 0B        1   0  SXFERX+INCX
+      0B    0A                    1   2  INCI, SACCCLK, SWVRAM
+      0C    0D                    0   1  INCI, SXFERX+INCX, INCL
+      0D    /LTC ? 0C : 0E        2   2  ZERORAM, INCPC, SWVRAM
+      0E    19                    2   2
 
-	  19	/CM7 ? 00 : 1A		  2   0
-	  1A	1B					  2   0  INCPC, SWRITEBUSS1
-	  1B	01					  2   0  INCPC, SWRITEBUSS2
-	  1C	HTC ? 19 : 1D		  0   1
-	  1D	1E					  1   2  INCX, SXFERX+INCX, INCL, SWVRAM
-	  1E	/LTC ? 1C : 1F		  1   3  INCI, SINCY, SWVRAM
-	  1F	1C					  1   0  ZERORAM, SXFERY, SADDX, INCH
+      19    /CM7 ? 00 : 1A        2   0
+      1A    1B                    2   0  INCPC, SWRITEBUSS1
+      1B    01                    2   0  INCPC, SWRITEBUSS2
+      1C    HTC ? 19 : 1D         0   1
+      1D    1E                    1   2  INCX, SXFERX+INCX, INCL, SWVRAM
+      1E    /LTC ? 1C : 1F        1   3  INCI, SINCY, SWVRAM
+      1F    1C                    1   0  ZERORAM, SXFERY, SADDX, INCH
 
 Registers:
 
-	X' = 8-bit value = 2 x 4-bit counters at 11B/13B
-			SADDX  -> enables clock to count
-			LF/RT  -> controls direction of counting
-			SLDX   -> loads data from RED VRAM or D0-D7 into X'
-			OUT    -> to X
+    X' = 8-bit value = 2 x 4-bit counters at 11B/13B
+            SADDX  -> enables clock to count
+            LF/RT  -> controls direction of counting
+            SLDX   -> loads data from RED VRAM or D0-D7 into X'
+            OUT    -> to X
 
-	X  = 8-bit value = 2 x 4-bit counters at 12D/13D
-			SINCX  -> enables clock to count
-			SXFERX -> loads data from X' into X, with an XOR of 7
-			OUT    -> to X1-X128
+    X  = 8-bit value = 2 x 4-bit counters at 12D/13D
+            SINCX  -> enables clock to count
+            SXFERX -> loads data from X' into X, with an XOR of 7
+            OUT    -> to X1-X128
 
-	Y' = 8-bit value = 8-bit latch
-			SLDY   -> loads data from BLUE VRAM or D0-D7 into Y'
-			OUT    -> to Y
+    Y' = 8-bit value = 8-bit latch
+            SLDY   -> loads data from BLUE VRAM or D0-D7 into Y'
+            OUT    -> to Y
 
-	Y  = 8-bit value = 2 x 4-bit counters at 10B/8B
-			SINCY  -> enables clock to count
-			SXFERY -> loads data from Y' into Y
-			OUT    -> to Y1-Y128
+    Y  = 8-bit value = 2 x 4-bit counters at 10B/8B
+            SINCY  -> enables clock to count
+            SXFERY -> loads data from Y' into Y
+            OUT    -> to Y1-Y128
 
-	I  = 16-bit value = 4 x 4-bit counters at 12C/11C/12B/14B
-			INCI   -> enables clock to count
-			SLDIH  -> loads data from BLUE VRAM or D0-D7 into upper 8 bits of I
-			SLDIL  -> loads data from RED VRAM or D0-D7 into lower 8 bits of I
-			OUT    -> to I1-I32000
+    I  = 16-bit value = 4 x 4-bit counters at 12C/11C/12B/14B
+            INCI   -> enables clock to count
+            SLDIH  -> loads data from BLUE VRAM or D0-D7 into upper 8 bits of I
+            SLDIL  -> loads data from RED VRAM or D0-D7 into lower 8 bits of I
+            OUT    -> to I1-I32000
 
-	PC = 9-bit value = 2 x 4-bit counters at 9B/7B plus JK flip-flop at 12E
-			INCPC  -> toggles flip-flop and increments
-			SLOADPC-> loads data from Y' into PC
+    PC = 9-bit value = 2 x 4-bit counters at 9B/7B plus JK flip-flop at 12E
+            INCPC  -> toggles flip-flop and increments
+            SLOADPC-> loads data from Y' into PC
 
-	L  = 5-bit value = 2 x 4-bit counters at 3H/4H
-			INCL   -> enables clock to count
-			SLOADLH-> loads data from SEA
+    L  = 5-bit value = 2 x 4-bit counters at 3H/4H
+            INCL   -> enables clock to count
+            SLOADLH-> loads data from SEA
 
-	H  = 3-bit value = 1 x 4-bit counter at 5H
-			INCH   -> enables clock to count
-			SLOADLH-> loads data from SEA
+    H  = 3-bit value = 1 x 4-bit counter at 5H
+            INCH   -> enables clock to count
+            SLOADLH-> loads data from SEA
 
-	14-bit VRAM address comes from one of several sources, depending on ASEL
-		ASEL0 -> I & 0x3fff
-		ASEL1 -> ((Y & 0xff) << 5) | ((X & 0xff) >> 3)
-		ASEL2 -> 0x2000 | (PC & 0x1ff)
-		ASEL3 -> ((L & 0xff) << 5) | ((E & 0xff) >> 3) 	[video refresh]
+    14-bit VRAM address comes from one of several sources, depending on ASEL
+        ASEL0 -> I & 0x3fff
+        ASEL1 -> ((Y & 0xff) << 5) | ((X & 0xff) >> 3)
+        ASEL2 -> 0x2000 | (PC & 0x1ff)
+        ASEL3 -> ((L & 0xff) << 5) | ((E & 0xff) >> 3)  [video refresh]
 
 ***************************************************************************************************/
 
 
 /*************************************
  *
- *	Microcode timing
+ *  Microcode timing
  *
  *************************************/
 
@@ -619,12 +570,14 @@ INLINE void count_states(int states)
 {
 	if (!micro.timer)
 	{
-		micro.timer = timer_set(TIME_NEVER, 0, NULL);
+		timer_adjust(micro.timer, TIME_NEVER, 0, 0);
+		micro.timer_active = 1;
 		micro.endtime = (double)states * MICRO_STATE_CLOCK_PERIOD;
 	}
 	else if (timer_timeelapsed(micro.timer) > micro.endtime)
 	{
-		timer_reset(micro.timer, TIME_NEVER);
+		timer_adjust(micro.timer, TIME_NEVER, 0, 0);
+		micro.timer_active = 1;
 		micro.endtime = (double)states * MICRO_STATE_CLOCK_PERIOD;
 	}
 	else
@@ -634,21 +587,21 @@ INLINE void count_states(int states)
 
 /*************************************
  *
- *	Microcode command 2:
- *		Load data from R/G/B
+ *  Microcode command 2:
+ *      Load data from R/G/B
  *
  *************************************/
 
 static int command2(void)
 {
 /*
-	Actual microcode:
-		  02	00					  0   0  ZERORAM, INCI, SWVRAM
+    Actual microcode:
+          02    00                    0   0  ZERORAM, INCI, SWVRAM
 
-	Basic gist of things:
-		WRITE
-		I++
-		goto state00
+    Basic gist of things:
+        WRITE
+        I++
+        goto state00
 */
 	int addr = micro.i++ & 0x3fff;
 
@@ -667,33 +620,33 @@ static int command2(void)
 
 /*************************************
  *
- *	Microcode command 3:
- *		Draw sprite from I to (X,Y)
+ *  Microcode command 3:
+ *      Draw sprite from I to (X,Y)
  *
  *************************************/
 
 static int command3(void)
 {
 /*
-	Actual microcode:
-		  03	1C					  2   0  SLOADLH, SXFERY
-		  1C	HTC ? 19 : 1D		  0   1
-		  1D	1E					  1   2  INCX, SXFERX+INCX, INCL, SWVRAM
-		  1E	/LTC ? 1C : 1F		  1   3  INCI, SINCY, SWVRAM
-		  1F	1C					  1   0  ZERORAM, SXFERY, SADDX, INCH
+    Actual microcode:
+          03    1C                    2   0  SLOADLH, SXFERY
+          1C    HTC ? 19 : 1D         0   1
+          1D    1E                    1   2  INCX, SXFERX+INCX, INCL, SWVRAM
+          1E    /LTC ? 1C : 1F        1   3  INCI, SINCY, SWVRAM
+          1F    1C                    1   0  ZERORAM, SXFERY, SADDX, INCH
 
-	Basic gist of things:
-		H = R >> 5
-		L = (R & 0x1f) << 1
-		Y = Y'
-		state1C:
-			if (H & 8) goto state19
-			X = X'; L++
-			WRITE
-			I++; Y++
-			if ((L & 0x20) == 0) goto state1C
-			Y = Y'; X'++; H++
-			goto state1C
+    Basic gist of things:
+        H = R >> 5
+        L = (R & 0x1f) << 1
+        Y = Y'
+        state1C:
+            if (H & 8) goto state19
+            X = X'; L++
+            WRITE
+            I++; Y++
+            if ((L & 0x20) == 0) goto state1C
+            Y = Y'; X'++; H++
+            goto state1C
 */
 	int ycount = 64 - (micro.r & 31) * 2;
 	int xcount = 8 - (micro.r >> 5);
@@ -779,29 +732,29 @@ static int command3(void)
 
 /*************************************
  *
- *	Microcode command 4:
- *		Execute commands at (Y * 2)
+ *  Microcode command 4:
+ *      Execute commands at (Y * 2)
  *
  *************************************/
 
 static int command4(void)
 {
 /*
-	Actual microcode:
-		  04	1A					  2   0  SLOADPC
-		  1A	1B					  2   0  INCPC, SWRITEBUSS1
-		  1B	01					  2   0  INCPC, SWRITEBUSS2
+    Actual microcode:
+          04    1A                    2   0  SLOADPC
+          1A    1B                    2   0  INCPC, SWRITEBUSS1
+          1B    01                    2   0  INCPC, SWRITEBUSS2
 
-	Basic gist of things:
-		PC = Y' << 1
-		CM = GREEN[PC]
-		I = (BLUE[PC] << 8) + RED[PC]
-		PC++
-		R = GREEN[PC]
-		X' = RED[PC]
-		Y' = BLUE[PC]
-		PC++
-		goto state01
+    Basic gist of things:
+        PC = Y' << 1
+        CM = GREEN[PC]
+        I = (BLUE[PC] << 8) + RED[PC]
+        PC++
+        R = GREEN[PC]
+        X' = RED[PC]
+        Y' = BLUE[PC]
+        PC++
+        goto state01
 */
 	int keep_going = 0;
 
@@ -842,41 +795,41 @@ static int command4(void)
 
 /*************************************
  *
- *	Microcode command 5:
- *		Draw vector from (X,Y)
+ *  Microcode command 5:
+ *      Draw vector from (X,Y)
  *
  *************************************/
 
 static int command5(void)
 {
 /*
-	Actual microcode:
-		  05	0A					  1   0  SXFERY, ADD128+SACCCLEAR, SACCCLK
-		  0A	VFIN ? 19 : 0B		  1   0  SXFERX+INCX
-		  0B	0A					  1   2  INCI, SACCCLK, SWVRAM
+    Actual microcode:
+          05    0A                    1   0  SXFERY, ADD128+SACCCLEAR, SACCCLK
+          0A    VFIN ? 19 : 0B        1   0  SXFERX+INCX
+          0B    0A                    1   2  INCI, SACCCLK, SWVRAM
 
-	Basic gist of things:
-		Y = Y'; ACC = 128
-		X = X'/CLOCK SR
-		while (!(IL & 0x100))
-		{
-			IL++; ACC += IH
-			adjust X,Y based on carry
-			WRITE(X,Y)  [SR1]
-		}
+    Basic gist of things:
+        Y = Y'; ACC = 128
+        X = X'/CLOCK SR
+        while (!(IL & 0x100))
+        {
+            IL++; ACC += IH
+            adjust X,Y based on carry
+            WRITE(X,Y)  [SR1]
+        }
 
-	line draw: one of 8 cases based on VDATA
+    line draw: one of 8 cases based on VDATA
 
-				no carry			carry
-				--------			-----
-		case 0: 1011 -> X++, Y		1101 -> X++, Y--
-		case 1:	0101 -> X, Y--		1101 -> X++, Y--
-		case 2: 0101 -> X, Y--		1100 -> X--, Y--
-		case 3:	1010 -> X--, Y		1100 -> X--, Y--
-		case 4: 1010 -> X--, Y		1110 -> X--, Y++
-		case 5: 0111 -> X, Y++		1110 -> X--, Y++
-		case 6: 0111 -> X, Y++		1111 -> X++, Y++
-		case 7: 1011 -> X++, Y		1111 -> X++, Y++
+                no carry            carry
+                --------            -----
+        case 0: 1011 -> X++, Y      1101 -> X++, Y--
+        case 1: 0101 -> X, Y--      1101 -> X++, Y--
+        case 2: 0101 -> X, Y--      1100 -> X--, Y--
+        case 3: 1010 -> X--, Y      1100 -> X--, Y--
+        case 4: 1010 -> X--, Y      1110 -> X--, Y++
+        case 5: 0111 -> X, Y++      1110 -> X--, Y++
+        case 6: 0111 -> X, Y++      1111 -> X++, Y++
+        case 7: 1011 -> X++, Y      1111 -> X++, Y++
 
 */
 	static const INT8 inctable[8][4] =
@@ -981,29 +934,29 @@ static int command5(void)
 
 /*************************************
  *
- *	Microcode command 6:
- *		Copy data from I to (Y * 2)
+ *  Microcode command 6:
+ *      Copy data from I to (Y * 2)
  *
  *************************************/
 
 static int command6(void)
 {
 /*
-	Actual microcode:
-		  06	0C					  0   0  SLOADLH, SLOADPC
-		  0C	0D					  0   1  INCI, SXFERX+INCX, INCL
-		  0D	/LTC ? 0C : 0E		  2   2  ZERORAM, INCPC, SWVRAM
-		  0E	19					  2   2
+    Actual microcode:
+          06    0C                    0   0  SLOADLH, SLOADPC
+          0C    0D                    0   1  INCI, SXFERX+INCX, INCL
+          0D    /LTC ? 0C : 0E        2   2  ZERORAM, INCPC, SWVRAM
+          0E    19                    2   2
 
-	Basic gist of things:
-		H = R >> 5
-		L = (R & 0x1f) << 1
-		PC = Y'
-		state0C:
-			I++; X = X'; L++
-			WRITE(I, *PC)
-			PC++
-			if ((L & 0x20) == 0) goto state1C
+    Basic gist of things:
+        H = R >> 5
+        L = (R & 0x1f) << 1
+        PC = Y'
+        state0C:
+            I++; X = X'; L++
+            WRITE(I, *PC)
+            PC++
+            if ((L & 0x20) == 0) goto state1C
 */
 	int i;
 
@@ -1032,25 +985,25 @@ static int command6(void)
 
 /*************************************
  *
- *	Microcode command 7:
- *		Draw pixels to (X,Y)
+ *  Microcode command 7:
+ *      Draw pixels to (X,Y)
  *
  *************************************/
 
 static int command7(void)
 {
 /*
-	Actual microcode:
-		  07	08					  1   0  SXFERY, SXFERX+INCX
-		  08	09					  1   2  INCX, SWVRAM
-		  09	00					  1   3  SWVRAM
+    Actual microcode:
+          07    08                    1   0  SXFERY, SXFERX+INCX
+          08    09                    1   2  INCX, SWVRAM
+          09    00                    1   3  SWVRAM
 
-	Basic gist of things:
-		Y = Y'
-		X = X'/CLOCK SR
-		WRITE SR1
-		X++
-		WRITE SR2
+    Basic gist of things:
+        Y = Y'
+        X = X'/CLOCK SR
+        WRITE SR1
+        X++
+        WRITE SR2
 */
 	int addr = micro.yp * 32 + micro.xp / 8;
 	int shift = micro.xp & 7;
@@ -1112,7 +1065,7 @@ static int command7(void)
 
 /*************************************
  *
- *	Background update
+ *  Background update
  *
  *************************************/
 
@@ -1156,7 +1109,7 @@ static void update_background(void)
 
 /*************************************
  *
- *	Foreground update
+ *  Foreground update
  *
  *************************************/
 
@@ -1193,15 +1146,15 @@ static void update_foreground(void)
 
 /*************************************
  *
- *	Determine the time when the beam
- *	will intersect a given pixel
+ *  Determine the time when the beam
+ *  will intersect a given pixel
  *
  *************************************/
 
 static double pixel_time(int x, int y)
 {
 	/* assuming this is called at refresh time, compute how long until we
-	 * hit the given x,y position */
+     * hit the given x,y position */
 	return cpu_getscanlinetime(y) + (cpu_getscanlineperiod() * (double)x * (1.0 / 256.0));
 }
 
@@ -1218,11 +1171,11 @@ static void bgcoll_irq_callback(int param)
 
 /*************************************
  *
- *	End-of-frame callback
+ *  End-of-frame callback
  *
  *************************************/
 
-void victory_vh_eof(void)
+VIDEO_EOF( victory )
 {
 	int bgcollmask = (video_control & 4) ? 4 : 7;
 	int count = 0;
@@ -1262,11 +1215,11 @@ void victory_vh_eof(void)
 
 /*************************************
  *
- *	Standard screen refresh callback
+ *  Standard screen refresh callback
  *
  *************************************/
 
-void victory_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
+VIDEO_UPDATE( victory )
 {
 	int bgcollmask = (video_control & 4) ? 4 : 7;
 	int count = 0;
