@@ -5,12 +5,12 @@
 
 #define TC0100SCN_GFX_NUM 1
 
-static struct tilemap *wgp_piv_tilemap[3];
+static tilemap *wgp_piv_tilemap[3];
 
-data16_t *wgp_spritemap;
+UINT16 *wgp_spritemap;
 size_t wgp_spritemap_size;
-data16_t *wgp_pivram;
-data16_t *wgp_piv_ctrlram;
+UINT16 *wgp_pivram;
+UINT16 *wgp_piv_ctrlram;
 
 static UINT16 wgp_piv_ctrl_reg;
 static UINT16 wgp_piv_zoom[3],wgp_piv_scrollx[3],wgp_piv_scrolly[3];
@@ -18,32 +18,8 @@ UINT16 wgp_rotate_ctrl[8];
 int wgp_piv_xoffs,wgp_piv_yoffs;
 
 
-void wgp_vh_stop(void);
-
-
-static int has_TC0110PCR(void)
-{
-	const struct Memory_WriteAddress16 *mwa;
-
-	/* scan the memory handlers and see if the TC0110PCR is used */
-
-	mwa = Machine->drv->cpu[0].memory_write;
-	if (mwa)
-	{
-		while (!IS_MEMPORT_END(mwa))
-		{
-			if (!IS_MEMPORT_MARKER(mwa))
-			{
-				if ((mwa->handler == TC0110PCR_step1_word_w) || (mwa->handler == TC0110PCR_step1_rbswap_word_w))
-					return 1;
-			}
-			mwa++;
-		}
-	}
-
-	return 0;
-}
 
+/*******************************************************************/
 
 static void common_get_piv_tile_info(int num,int tile_index)
 {
@@ -94,10 +70,7 @@ int wgp_core_vh_start (int x_offs,int y_offs,int piv_xoffs,int piv_yoffs)
 
 	if (has_TC0110PCR())
 		if (TC0110PCR_vh_start())
-		{
-			wgp_vh_stop();
 			return 1;
-		}
 
 	wgp_piv_xoffs = piv_xoffs;
 	wgp_piv_yoffs = piv_yoffs;
@@ -115,7 +88,7 @@ int wgp_core_vh_start (int x_offs,int y_offs,int piv_xoffs,int piv_yoffs)
 	tilemap_set_scrolldy( wgp_piv_tilemap[2],-piv_yoffs,0 );
 
 	/* We don't need tilemap_set_scroll_rows, as the custom draw routine
-	   applies rowscroll manually */
+       applies rowscroll manually */
 
 	TC0100SCN_set_colbanks(0x80,0xc0,0x40);
 
@@ -125,24 +98,16 @@ int wgp_core_vh_start (int x_offs,int y_offs,int piv_xoffs,int piv_yoffs)
 	return 0;
 }
 
-int wgp_vh_start (void)
+VIDEO_START( wgp )
 {
 	return (wgp_core_vh_start(0,0,32,16));
 }
 
-int wgp2_vh_start (void)
+VIDEO_START( wgp2 )
 {
 	return (wgp_core_vh_start(4,2,32,16));
 }
 
-void wgp_vh_stop (void)
-{
-	TC0100SCN_vh_stop();
-
-	if (has_TC0110PCR())
-		TC0110PCR_vh_stop();
-}
-
 
 /******************************************************************
                  PIV TILEMAP READ AND WRITE HANDLERS
@@ -157,8 +122,8 @@ custom chip capable of four rather than three tilemaps.)
 502000 - 507fff : piv tilemaps 0-2 [tile numbers only]
 
 508000 - 50ffff : this area relates to pixel rows in each piv tilemap.
-	Includes rowscroll for the piv tilemaps, 1-2 of which act as a
-	simple road. To curve, it has rowscroll applied to each row.
+    Includes rowscroll for the piv tilemaps, 1-2 of which act as a
+    simple road. To curve, it has rowscroll applied to each row.
 
 508000 - 5087ff unknown/unused
 
@@ -166,22 +131,22 @@ custom chip capable of four rather than three tilemaps.)
 509000  piv1 row color bank (low byte = row horizontal zoom)
 509800  piv2 row color bank (low byte = row horizontal zoom)
 
-	Usual low byte is 0x7f, the default row horizontal zoom.
+    Usual low byte is 0x7f, the default row horizontal zoom.
 
-	The high byte is the color offset per pixel row. Controlling
-	color bank per scanline is rare in Taito games. Top Speed may
-	have a similar system to make its road 'move'.
+    The high byte is the color offset per pixel row. Controlling
+    color bank per scanline is rare in Taito games. Top Speed may
+    have a similar system to make its road 'move'.
 
-	In-game the high bytes are set to various values (seen 0 - 0x2b).
+    In-game the high bytes are set to various values (seen 0 - 0x2b).
 
 50a000  piv0 rowscroll [sky]  (not used, but the code supports this)
 50c000  piv1 rowscroll [road] (values 0xfd00 - 0x400)
 50e000  piv2 rowscroll [road or scenery] (values 0xfd00 - 0x403)
 
-	[It seems strange that unnecessarily large space allocations were
-	made for rowscroll. Perhaps the raster color/zoom effects were an
-	afterthought, and 508000-9fff was originally slated as rowscroll
-	for 'missing' 4th piv layer. Certainly the layout is illogical.]
+    [It seems strange that unnecessarily large space allocations were
+    made for rowscroll. Perhaps the raster color/zoom effects were an
+    afterthought, and 508000-9fff was originally slated as rowscroll
+    for 'missing' 4th piv layer. Certainly the layout is illogical.]
 
 510000 - 511fff : unknown/unused
 512000 - 517fff : piv tilemaps 0-2 [just tile colors ??]
@@ -260,10 +225,10 @@ WRITE16_HANDLER( wgp_piv_ctrl_word_w )
 
 		case 0x06:
 			/* Overall control reg (?)
-			   0x39  %00111001   normal
-			   0x2d  %00101101   piv2 layer goes under piv1
-			         seen on Wgp stages 4,5,7 in which piv 2 used
-			         for cloud or scenery wandering up screen */
+               0x39  %00111001   normal
+               0x2d  %00101101   piv2 layer goes under piv1
+                     seen on Wgp stages 4,5,7 in which piv 2 used
+                     for cloud or scenery wandering up screen */
 
 			wgp_piv_ctrl_reg = data;
 			break;
@@ -275,13 +240,13 @@ WRITE16_HANDLER( wgp_piv_ctrl_word_w )
 
 		case 0x09:
 			/* piv 1 y zoom (0x7f = normal, values 0 &
-			      0xff7f-ffbc in Wgp2) */
+                  0xff7f-ffbc in Wgp2) */
 			wgp_piv_zoom[1] = data;
 			break;
 
 		case 0x0a:
 			/* piv 2 y zoom (0x7f = normal, values 0 &
-			      0xff7f-ffbc in Wgp2, 0-0x98 in Wgp round 4/5) */
+                  0xff7f-ffbc in Wgp2, 0-0x98 in Wgp round 4/5) */
 			wgp_piv_zoom[2] = data;
 			break;
 	}
@@ -316,79 +281,81 @@ Memory Map
 
 400000 - 40bfff : Sprite tile mapping area
 
-	Tile numbers (0-0x3fff) alternate with word containing
-	tile color/unknown bits.
+    Tile numbers (0-0x3fff) alternate with word containing tile
+    color/unknown bits. I'm _not_ 100% sure that only Wgp2 uses
+    the unknown bits.
 
-	xxxxxxxx x.x.....  unused ??
-	........ .x......  unknown (Wgp2 only)
-	........ ...x....  unknown (Wgp2 only)
-	........ ....cccc  color (0-15)
+    xxxxxxxx x.......  unused ??
+    ........ .x......  unknown (Wgp2 only: Taito tyre bridge on default course)
+    ........ ..x.....  unknown (Wgp2 only)
+    ........ ...x....  unknown (Wgp2 only: Direction signs just before hill # 1)
+    ........ ....cccc  color (0-15)
 
-	Tile map for each standard big sprite is 64 bytes (16 tiles).
-	(standard big sprite comprises 4x4 16x16 tiles)
+    Tile map for each standard big sprite is 64 bytes (16 tiles).
+    (standard big sprite comprises 4x4 16x16 tiles)
 
-	Tile map for each small sprite only uses 16 of the 64 bytes.
+    Tile map for each small sprite only uses 16 of the 64 bytes.
       The remaining 48 bytes are garbage and should be ignored.
-	(small sprite comprises 2x2 16x16 tiles)
+    (small sprite comprises 2x2 16x16 tiles)
 
 40c000 - 40dbff : Sprite Table
 
-	Every 16 bytes contains one sprite entry. First entry is
-	ignored [as 0 in active sprites list means no sprite].
+    Every 16 bytes contains one sprite entry. First entry is
+    ignored [as 0 in active sprites list means no sprite].
 
-	(0x1c0 [no.of entries] * 0x40 [bytes for big sprite] = 0x6fff
-	of sprite tile mapping area can be addressed at any one time.)
+    (0x1c0 [no.of entries] * 0x40 [bytes for big sprite] = 0x6fff
+    of sprite tile mapping area can be addressed at any one time.)
 
-	Sprite entry     (preliminary)
-	------------
+    Sprite entry     (preliminary)
+    ------------
 
-	+0x00  x pos (signed)
-	+0x02  y pos (signed)
-	+0x04  index to tile mapping area [2 msbs always set]
+    +0x00  x pos (signed)
+    +0x02  y pos (signed)
+    +0x04  index to tile mapping area [2 msbs always set]
 
-	       (400000 + (index &0x3fff) << 2) points to relevant part of
-	       sprite tile mapping area. Index >0x2fff would be invalid.
+           (400000 + (index &0x3fff) << 2) points to relevant part of
+           sprite tile mapping area. Index >0x2fff would be invalid.
 
-	+0x06  zoom size (pixels) [typical range 0x1-5f, 0x3f = standard]
-	       Looked up from a logarithm table in the data rom indexed
-	       by the z coordinate. Max size prog allows before it blanks
-	       the sprite is 0x140.
+    +0x06  zoom size (pixels) [typical range 0x1-5f, 0x3f = standard]
+           Looked up from a logarithm table in the data rom indexed
+           by the z coordinate. Max size prog allows before it blanks
+           the sprite is 0x140.
 
-	+0x08  incxx ?? (usually stuck at 0xf800)
-	+0x0a  incyy ?? (usually stuck at 0xf800)
+    +0x08  incxx ?? (usually stuck at 0xf800)
+    +0x0a  incyy ?? (usually stuck at 0xf800)
 
-	+0x0c  z coordinate i.e. how far away the sprite is from you
-	       going into the screen. Max distance prog allows before it
-	       blanks the sprite is 0x3fff. 0x1400 is about the farthest
-	       away that the code creates sprites. 0x400 = standard
-	       distance corresponding to 0x3f zoom.  <0x400 = close to
+    +0x0c  z coordinate i.e. how far away the sprite is from you
+           going into the screen. Max distance prog allows before it
+           blanks the sprite is 0x3fff. 0x1400 is about the farthest
+           away that the code creates sprites. 0x400 = standard
+           distance corresponding to 0x3f zoom.  <0x400 = close to
 
-	+0x0e  non-zero only during rotation.
+    +0x0e  non-zero only during rotation.
 
-	NB: +0x0c and +0x0e are paired. Equivalent of incyx and incxy ??
+    NB: +0x0c and +0x0e are paired. Equivalent of incyx and incxy ??
 
-	(No longer used entries typically have 0xfff6 in +0x06 and +0x08.)
+    (No longer used entries typically have 0xfff6 in +0x06 and +0x08.)
 
-	Only 2 rotation examples (i) at 0x40c000 when Taito
-	logo displayed (Wgp only). (ii) stage 5 (rain).
-	Other in-game sprites are simply using +0x06 and +0x0c,
+    Only 2 rotation examples (i) at 0x40c000 when Taito
+    logo displayed (Wgp only). (ii) stage 5 (rain).
+    Other in-game sprites are simply using +0x06 and +0x0c,
 
-	So the sprite rotation in Wgp screenshots must be a *blanket*
-	rotate effect, identical to the one applied to piv layers.
-	This explains why sprite/piv positions are basically okay
-	despite failure to implement rotation.
+    So the sprite rotation in Wgp screenshots must be a *blanket*
+    rotate effect, identical to the one applied to piv layers.
+    This explains why sprite/piv positions are basically okay
+    despite failure to implement rotation.
 
 40dc00 - 40dfff: Active Sprites list
 
-	Each word is a sprite number, 0x0 thru 0x1bf. If !=0
-	a word makes active the 0x10 bytes of sprite data at
-	(40c000 + sprite_num * 0x10). (Wgp2 fills this in reverse).
+    Each word is a sprite number, 0x0 thru 0x1bf. If !=0
+    a word makes active the 0x10 bytes of sprite data at
+    (40c000 + sprite_num * 0x10). (Wgp2 fills this in reverse).
 
 40fff0: Unknown (sprite control word?)
 
-	Wgp alternates 0x8000 and 0. Wgp2 only pokes 0.
-	Could this be some frame buffer control that would help to
-	reduce the sprite timing glitches in Wgp?
+    Wgp alternates 0x8000 and 0. Wgp2 only pokes 0.
+    Could this be some frame buffer control that would help to
+    reduce the sprite timing glitches in Wgp?
 
 ****************************************************************/
 
@@ -408,17 +375,18 @@ static UINT8 ylookup[16] =
 	  2, 2, 3, 3,
 	  2, 2, 3, 3 };
 
-static void wgp_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y_offs)
+static void wgp_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect,int y_offs)
 {
 	int offs,i,j,k;
 	int x,y,curx,cury;
-	int zx,zy,zoomx,zoomy;
+	int zx,zy,zoomx,zoomy,priority=0;
 	UINT8 small_sprite,col,flipx,flipy;
 	UINT16 code,bigsprite,map_index;
 	UINT16 rotate=0;
 	UINT16 tile_mask = (Machine->gfx[0]->total_elements) - 1;
+	static const int primasks[2] = {0x0, 0xfffc};	/* fff0 => under rhs of road only */
 
-	for (offs = 0;offs <0x200;offs += 1)
+	for (offs = 0x1ff;offs >= 0;offs--)
 	{
 		code = (spriteram16[0xe00+offs]);
 
@@ -431,8 +399,8 @@ static void wgp_draw_sprites(struct mame_bitmap *bitmap,int *primasks,int y_offs
 			bigsprite = spriteram16[i + 2] &0x3fff;
 
 			/* The last five words [i + 3 thru 7] must be zoom/rotation
-			   control: for time being we kludge zoom using 1 word.
-			   Timing problems are causing many glitches. */
+               control: for time being we kludge zoom using 1 word.
+               Timing problems are causing many glitches. */
 
 if ((spriteram16[i + 4]==0xfff6) && (spriteram16[i + 5]==0))
 	continue;
@@ -461,7 +429,8 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 			map_index = bigsprite << 1;	/* now we access sprite tilemap */
 
 			/* don't know what selects 2x2 sprites: we use a nasty kludge
-			   which seems to work ok */
+               which seems to work */
+
 			i = wgp_spritemap[map_index + 0xa];
 			j = wgp_spritemap[map_index + 0xc];
 			small_sprite = ((i > 0) & (i <=8) & (j > 0) & (j <=8));
@@ -473,6 +442,9 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 					code = wgp_spritemap[(map_index + (i << 1))] &tile_mask;
 					col  = wgp_spritemap[(map_index + (i << 1) + 1)] &0xf;
 
+					/* not known what controls priority */
+					priority = (wgp_spritemap[(map_index + (i << 1) + 1)] &0x70) >> 4;
+
 					flipx=0;	/* no flip xy? */
 					flipy=0;
 
@@ -482,16 +454,17 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 					curx = x + ((k*zoomx)/2);
 					cury = y + ((j*zoomy)/2);
 
-					zx= x + (((k+1)*zoomx)/2) - curx;
-					zy= y + (((j+1)*zoomy)/2) - cury;
+					zx = x + (((k+1)*zoomx)/2) - curx;
+					zy = y + (((j+1)*zoomy)/2) - cury;
 
-					drawgfxzoom(bitmap, Machine->gfx[0],
+					pdrawgfxzoom(bitmap, Machine->gfx[0],
 							code,
 							col,
 							flipx, flipy,
 							curx,cury,
-							&Machine->visible_area,TRANSPARENCY_PEN,0,
-							zx << 12, zy << 12);
+							cliprect,TRANSPARENCY_PEN,0,
+							zx << 12, zy << 12,
+							primasks[((priority >> 1) &1)]);	/* maybe >> 2 or 0...? */
 				}
 			}
 			else
@@ -501,6 +474,9 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 					code = wgp_spritemap[(map_index + (i << 1))] &tile_mask;
 					col  = wgp_spritemap[(map_index + (i << 1) + 1)] &0xf;
 
+					/* not known what controls priority */
+					priority = (wgp_spritemap[(map_index + (i << 1) + 1)] &0x70) >> 4;
+
 					flipx=0;	/* no flip xy? */
 					flipy=0;
 
@@ -510,16 +486,17 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 					curx = x + ((k*zoomx)/4);
 					cury = y + ((j*zoomy)/4);
 
-					zx= x + (((k+1)*zoomx)/4) - curx;
-					zy= y + (((j+1)*zoomy)/4) - cury;
+					zx = x + (((k+1)*zoomx)/4) - curx;
+					zy = y + (((j+1)*zoomy)/4) - cury;
 
-					drawgfxzoom(bitmap, Machine->gfx[0],
+					pdrawgfxzoom(bitmap, Machine->gfx[0],
 							code,
 							col,
 							flipx, flipy,
 							curx,cury,
-							&Machine->visible_area,TRANSPARENCY_PEN,0,
-							zx << 12, zy << 12);
+							cliprect,TRANSPARENCY_PEN,0,
+							zx << 12, zy << 12,
+							primasks[((priority >> 1) &1)]);	/* maybe >> 2 or 0...? */
 				}
 			}
 		}
@@ -530,7 +507,7 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 	{
 		char buf[80];
 		sprintf(buf,"sprite rotate offs %04x ?",rotate);
-		usrintf_showmessage(buf);
+		ui_popup(buf);
 	}
 #endif
 }
@@ -550,32 +527,21 @@ if (((spriteram16[i + 4]!=0xf800) && (spriteram16[i + 4]!=0xfff6))
 	if (orientation)														\
 	{																		\
 		int dy = (type *)bitmap->line[1] - (type *)bitmap->line[0];			\
-		int tx = x, ty = y, temp;											\
-		if ((orientation) & ORIENTATION_SWAP_XY)							\
-		{																	\
-			temp = tx; tx = ty; ty = temp;									\
-			xadv = dy / sizeof(type);										\
-		}																	\
+		int tx = x, ty = y;													\
 		if ((orientation) & ORIENTATION_FLIP_X)								\
-		{																	\
 			tx = bitmap->width - 1 - tx;									\
-			if (!((orientation) & ORIENTATION_SWAP_XY)) xadv = -xadv;		\
-		}																	\
 		if ((orientation) & ORIENTATION_FLIP_Y)								\
-		{																	\
 			ty = bitmap->height - 1 - ty;									\
-			if ((orientation) & ORIENTATION_SWAP_XY) xadv = -xadv;			\
-		}																	\
 		/* can't lookup line because it may be negative! */					\
 		dsti = (type *)((type *)bitmapi->line[0] + dy * ty) + tx;			\
 		dstp = (UINT8 *)((UINT8 *)bitmapp->line[0] + dy * ty / sizeof(type)) + tx;	\
 	}
 
 INLINE void bryan2_drawscanline(
-		struct mame_bitmap *bitmap,int x,int y,int length,
+		mame_bitmap *bitmap,int x,int y,int length,
 		const UINT16 *src,int transparent,UINT32 orient,int pri)
 {
-	ADJUST_FOR_ORIENTATION(UINT16, Machine->orientation ^ orient, bitmap, priority_bitmap, x, y);
+	ADJUST_FOR_ORIENTATION(UINT16, orient, bitmap, priority_bitmap, x, y);
 	if (transparent) {
 		while (length--) {
 			UINT32 spixel = *src++;
@@ -599,35 +565,41 @@ INLINE void bryan2_drawscanline(
 
 
 
-static void wgp_piv_layer_draw(struct mame_bitmap *bitmap,int layer,int flags,UINT32 priority)
+static void wgp_piv_layer_draw(mame_bitmap *bitmap,const rectangle *cliprect,int layer,int flags,UINT32 priority)
 {
-	struct mame_bitmap *srcbitmap = tilemap_get_pixmap(wgp_piv_tilemap[layer]);
-	struct mame_bitmap *transbitmap = tilemap_get_transparency_bitmap(wgp_piv_tilemap[layer]);
+	mame_bitmap *srcbitmap = tilemap_get_pixmap(wgp_piv_tilemap[layer]);
+	mame_bitmap *transbitmap = tilemap_get_transparency_bitmap(wgp_piv_tilemap[layer]);
 
 	UINT16 *dst16,*src16;
 	UINT8 *tsrc;
 	int i,y,y_index,src_y_index,row_index,row_zoom;
 
 	/* I have a fairly strong feeling these should be UINT32's, x_index is
-	   falling through from max +ve to max -ve quite a lot in this routine */
+       falling through from max +ve to max -ve quite a lot in this routine */
 	int sx,x_index,x_step,x_max;
 
-	UINT32 zoomx,zoomy,rot=Machine->orientation;
+	UINT32 zoomx,zoomy;
 	UINT16 scanline[512];
 	UINT16 row_colbank,row_scroll;
 	int flipscreen = 0;	/* n/a */
 	int machine_flip = 0;	/* for  ROT 180 ? */
 
-	UINT16 screen_width = Machine->visible_area.max_x -
-							Machine->visible_area.min_x + 1;
-/*	UINT16 min_y = Machine->visible_area.min_y; */
-/*	UINT16 max_y = Machine->visible_area.max_y; */
+	UINT16 screen_width = cliprect->max_x -
+							cliprect->min_x + 1;
+	UINT16 min_y = cliprect->min_y;
+	UINT16 max_y = cliprect->max_y;
 
 	int width_mask=0x3ff;
 
 	zoomx = 0x10000;	/* No overall X zoom, unlike TC0480SCP */
 
-	/* Y-axis zoom offers expansion/compression: 0x7f = no zoom, 0xff = max ??? */
+	/* Y-axis zoom offers expansion/compression: 0x7f = no zoom, 0xff = max ???
+       In WGP see:  stage 4 (big spectator stand)
+                    stage 5 (cloud layer)
+                    stage 7 (two bits of background scenery)
+                    stage 8 (unknown - surely something should be appearing here...)
+       In WGP2 see: road at big hill (default course) */
+
 	/* This calculation may be wrong, the y_index one too */
 	zoomy = 0x10000 - (((wgp_piv_ctrlram[0x08 + layer] &0xff) - 0x7f) * 512);
 
@@ -637,7 +609,7 @@ static void wgp_piv_layer_draw(struct mame_bitmap *bitmap,int layer,int flags,UI
 		sx += (wgp_piv_xoffs) * zoomx;		/* may be imperfect */
 
 		y_index = (wgp_piv_scrolly[layer] << 16);
-		y_index += (wgp_piv_yoffs) * zoomy;		/* may be imperfect */
+		y_index += (wgp_piv_yoffs + min_y) * zoomy;		/* may be imperfect */
 	}
 	else	/* piv tiles flipscreen n/a */
 	{
@@ -645,7 +617,7 @@ static void wgp_piv_layer_draw(struct mame_bitmap *bitmap,int layer,int flags,UI
 		y_index = 0;
 	}
 
-	if (!machine_flip) y=0; else y=255;
+	if (!machine_flip) y=min_y; else y=max_y;
 
 	do
 	{
@@ -702,14 +674,14 @@ static void wgp_piv_layer_draw(struct mame_bitmap *bitmap,int layer,int flags,UI
 		}
 
 		if (flags & TILEMAP_IGNORE_TRANSPARENCY)
-			bryan2_drawscanline(bitmap,0,y,screen_width,scanline,0,rot,priority);
+			bryan2_drawscanline(bitmap,0,y,screen_width,scanline,0,ROT0,priority);
 		else
-			bryan2_drawscanline(bitmap,0,y,screen_width,scanline,1,rot,priority);
+			bryan2_drawscanline(bitmap,0,y,screen_width,scanline,1,ROT0,priority);
 
 		y_index += zoomy;
 		if (!machine_flip) y++; else y--;
 	}
-	while ( (!machine_flip && y<256) || (machine_flip && y>=0) );
+	while ( (!machine_flip && y<=max_y) || (machine_flip && y>=min_y) );
 
 }
 
@@ -719,43 +691,38 @@ static void wgp_piv_layer_draw(struct mame_bitmap *bitmap,int layer,int flags,UI
                         SCREEN REFRESH
 **************************************************************/
 
-void wgp_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( wgp )
 {
 	int i;
 	UINT8 layer[3];
 
 #ifdef MAME_DEBUG
 	static UINT8 dislayer[4];
-	char buf[80];
 #endif
 
 #ifdef MAME_DEBUG
-	if (keyboard_pressed_memory (KEYCODE_V))
+	if (code_pressed_memory (KEYCODE_V))
 	{
 		dislayer[0] ^= 1;
-		sprintf(buf,"piv0: %01x",dislayer[0]);
-		usrintf_showmessage(buf);
+		ui_popup("piv0: %01x",dislayer[0]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_B))
+	if (code_pressed_memory (KEYCODE_B))
 	{
 		dislayer[1] ^= 1;
-		sprintf(buf,"piv1: %01x",dislayer[1]);
-		usrintf_showmessage(buf);
+		ui_popup("piv1: %01x",dislayer[1]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_N))
+	if (code_pressed_memory (KEYCODE_N))
 	{
 		dislayer[2] ^= 1;
-		sprintf(buf,"piv2: %01x",dislayer[2]);
-		usrintf_showmessage(buf);
+		ui_popup("piv2: %01x",dislayer[2]);
 	}
 
-	if (keyboard_pressed_memory (KEYCODE_M))
+	if (code_pressed_memory (KEYCODE_M))
 	{
 		dislayer[3] ^= 1;
-		sprintf(buf,"TC0100SCN top bg layer: %01x",dislayer[3]);
-		usrintf_showmessage(buf);
+		ui_popup("TC0100SCN top bg layer: %01x",dislayer[3]);
 	}
 #endif
 
@@ -767,7 +734,7 @@ void wgp_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	TC0100SCN_tilemap_update();
 
-	fillbitmap(bitmap, Machine->pens[0], &Machine -> visible_area);
+	fillbitmap(bitmap, Machine->pens[0], cliprect);
 
 	layer[0] = 0;
 	layer[1] = 1;
@@ -784,41 +751,41 @@ void wgp_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 #ifdef MAME_DEBUG
 	if (dislayer[layer[0]]==0)
 #endif
-	wgp_piv_layer_draw(bitmap,layer[0],TILEMAP_IGNORE_TRANSPARENCY,0);
+	wgp_piv_layer_draw(bitmap,cliprect,layer[0],TILEMAP_IGNORE_TRANSPARENCY,1);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[1]]==0)
 #endif
-	wgp_piv_layer_draw(bitmap,layer[1],0,0);
+	wgp_piv_layer_draw(bitmap,cliprect,layer[1],0,2);
 
 #ifdef MAME_DEBUG
 	if (dislayer[layer[2]]==0)
 #endif
-	wgp_piv_layer_draw(bitmap,layer[2],0,0);
+	wgp_piv_layer_draw(bitmap,cliprect,layer[2],0,4);
 
-	wgp_draw_sprites(bitmap,0,16);
+	wgp_draw_sprites(bitmap,cliprect,16);
 
-/* ... then here we should apply rotation from wgp_rotate_ctrl[] to
+/* ... then here we should apply rotation from wgp_sate_ctrl[] to
    the bitmap before we draw the TC0100SCN layers on it */
 
 	layer[0] = TC0100SCN_bottomlayer(0);
 	layer[1] = layer[0]^1;
 	layer[2] = 2;
 
-	TC0100SCN_tilemap_draw(bitmap,0,layer[0],0,0);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,layer[0],0,0);
 
 #ifdef MAME_DEBUG
 	if (dislayer[3]==0)
 #endif
-	TC0100SCN_tilemap_draw(bitmap,0,layer[1],0,0);
-	TC0100SCN_tilemap_draw(bitmap,0,layer[2],0,0);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,layer[1],0,0);
+	TC0100SCN_tilemap_draw(bitmap,cliprect,0,layer[2],0,0);
 
 #if 0
 	{
 		char buf[80];
 		sprintf(buf,"wgp_piv_ctrl_reg: %04x y zoom: %04x %04x %04x",wgp_piv_ctrl_reg,
 						wgp_piv_zoom[0],wgp_piv_zoom[1],wgp_piv_zoom[2]);
-		usrintf_showmessage(buf);
+		ui_popup(buf);
 	}
 #endif
 
@@ -831,7 +798,7 @@ void wgp_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		for (i = 0; i < 8; i += 1)
 		{
 			sprintf (buf, "%02x: %04x", i, wgp_rotate_ctrl[i]);
-			ui_text (Machine->scrbitmap, buf, 0, i*8);
+			ui_draw_text (buf, 0, i*8);
 		}
 	}
 #endif
