@@ -1,30 +1,21 @@
 /***************************************************************************
 
-						  -= Yun Sung 16 Bit Games =-
+                          -= Yun Sung 16 Bit Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-Note:	if MAME_DEBUG is defined, pressing Z with:
+    [ 2 Scrolling Layers ]
 
-		Q		shows the background
-		W		shows the foreground
-		A		shows the sprites
+    Tiles are 16 x 16 x 8. The layout of the tilemap is a bit weird:
+    16 consecutive tile codes define a vertical column.
+    16 columns form a page (256 x 256).
+    The tilemap is made of 4 x 4 pages (1024 x 1024)
 
-		Keys can be used together!
+    [ 512? Sprites ]
 
-
-	[ 2 Scrolling Layers ]
-
-	Tiles are 16 x 16 x 8. The layout of the tilemap is a bit weird:
-	16 consecutive tile codes define a vertical column.
-	16 columns form a page (256 x 256).
-	The tilemap is made of 4 x 4 pages (1024 x 1024)
-
-	[ 512? Sprites ]
-
-	Sprites are 16 x 16 x 4 in size. There's RAM for 512, but
-	the game just copies 384 entries.
+    Sprites are 16 x 16 x 4 in size. There's RAM for 512, but
+    the game just copies 384 entries.
 
 
 ***************************************************************************/
@@ -34,20 +25,20 @@ Note:	if MAME_DEBUG is defined, pressing Z with:
 
 /* Variables that driver has access to: */
 
-data16_t *yunsun16_vram_0,   *yunsun16_vram_1;
-data16_t *yunsun16_scroll_0, *yunsun16_scroll_1;
-data16_t *yunsun16_priority;
+UINT16 *yunsun16_vram_0,   *yunsun16_vram_1;
+UINT16 *yunsun16_scroll_0, *yunsun16_scroll_1;
+UINT16 *yunsun16_priority;
 
 
 /***************************************************************************
 
 
-									Tilemaps
+                                    Tilemaps
 
 
 ***************************************************************************/
 
-static struct tilemap *tilemap_0, *tilemap_1;
+static tilemap *tilemap_0, *tilemap_1;
 
 #define TMAP_GFX			(0)
 #define TILES_PER_PAGE_X	(0x10)
@@ -66,8 +57,8 @@ UINT32 yunsun16_tilemap_scan_pages(UINT32 col,UINT32 row,UINT32 num_cols,UINT32
 
 static void get_tile_info_0(int tile_index)
 {
-	data16_t code = yunsun16_vram_0[ 2 * tile_index + 0 ];
-	data16_t attr = yunsun16_vram_0[ 2 * tile_index + 1 ];
+	UINT16 code = yunsun16_vram_0[ 2 * tile_index + 0 ];
+	UINT16 attr = yunsun16_vram_0[ 2 * tile_index + 1 ];
 	SET_TILE_INFO(
 			TMAP_GFX,
 			code,
@@ -77,8 +68,8 @@ static void get_tile_info_0(int tile_index)
 
 static void get_tile_info_1(int tile_index)
 {
-	data16_t code = yunsun16_vram_1[ 2 * tile_index + 0 ];
-	data16_t attr = yunsun16_vram_1[ 2 * tile_index + 1 ];
+	UINT16 code = yunsun16_vram_1[ 2 * tile_index + 0 ];
+	UINT16 attr = yunsun16_vram_1[ 2 * tile_index + 1 ];
 	SET_TILE_INFO(
 			TMAP_GFX,
 			code,
@@ -88,15 +79,15 @@ static void get_tile_info_1(int tile_index)
 
 WRITE16_HANDLER( yunsun16_vram_0_w )
 {
-	data16_t old_data	=	yunsun16_vram_0[offset];
-	data16_t new_data	=	COMBINE_DATA(&yunsun16_vram_0[offset]);
+	UINT16 old_data	=	yunsun16_vram_0[offset];
+	UINT16 new_data	=	COMBINE_DATA(&yunsun16_vram_0[offset]);
 	if (old_data != new_data)	tilemap_mark_tile_dirty(tilemap_0,offset/2);
 }
 
 WRITE16_HANDLER( yunsun16_vram_1_w )
 {
-	data16_t old_data	=	yunsun16_vram_1[offset];
-	data16_t new_data	=	COMBINE_DATA(&yunsun16_vram_1[offset]);
+	UINT16 old_data	=	yunsun16_vram_1[offset];
+	UINT16 new_data	=	COMBINE_DATA(&yunsun16_vram_1[offset]);
 	if (old_data != new_data)	tilemap_mark_tile_dirty(tilemap_1,offset/2);
 }
 
@@ -104,14 +95,14 @@ WRITE16_HANDLER( yunsun16_vram_1_w )
 /***************************************************************************
 
 
-							Video Hardware Init
+                            Video Hardware Init
 
 
 ***************************************************************************/
 
 static int sprites_scrolldx, sprites_scrolldy;
 
-int yunsun16_vh_start(void)
+VIDEO_START( yunsun16 )
 {
 	tilemap_0 = tilemap_create(	get_tile_info_0,yunsun16_tilemap_scan_pages,
 								TILEMAP_TRANSPARENT,
@@ -142,38 +133,38 @@ int yunsun16_vh_start(void)
 /***************************************************************************
 
 
-								Sprites Drawing
+                                Sprites Drawing
 
 
-		0.w								X
+        0.w                             X
 
-		2.w								Y
+        2.w                             Y
 
-		4.w								Code
+        4.w                             Code
 
-		6.w		fedc ba98 7--- ----
-				---- ---- -6-- ----		Flip Y
-				---- ---- --5- ----		Flip X
-				---- ---- ---4 3210		Color
+        6.w     fedc ba98 7--- ----
+                ---- ---- -6-- ----     Flip Y
+                ---- ---- --5- ----     Flip X
+                ---- ---- ---4 3210     Color
 
 
 ***************************************************************************/
 
-static void yunsun16_draw_sprites(struct mame_bitmap *bitmap)
+static void yunsun16_draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
 	int max_x		=	Machine->visible_area.max_x+1;
 	int max_y		=	Machine->visible_area.max_y+1;
 
-	int pri			=	*yunsun16_priority & 7;
+	int pri			=	*yunsun16_priority & 3;
 	int pri_mask;
 
-	switch( pri & 7 )
+	switch( pri )
 	{
-		case 5:		pri_mask = (1<<1)|(1<<2)|(1<<3);	break;
-		case 6:		pri_mask = (1<<2)|(1<<3);			break;
-		case 7:
+		case 1:		pri_mask = (1<<1)|(1<<2)|(1<<3);	break;
+		case 2:		pri_mask = (1<<2)|(1<<3);			break;
+		case 3:
 		default:	pri_mask = 0;
 	}
 
@@ -186,6 +177,7 @@ static void yunsun16_draw_sprites(struct mame_bitmap *bitmap)
 		int flipx	=	attr & 0x20;
 		int flipy	=	attr & 0x40;
 
+
 		x	+=	sprites_scrolldx;
 		y	+=	sprites_scrolldy;
 
@@ -197,10 +189,10 @@ static void yunsun16_draw_sprites(struct mame_bitmap *bitmap)
 
 		pdrawgfx(	bitmap,Machine->gfx[1],
 					code,
-					attr,
+					attr & 0x1f,
 					flipx, flipy,
 					x,y,
-					&Machine->visible_area,TRANSPARENCY_PEN,15,
+					cliprect,TRANSPARENCY_PEN,15,
 					pri_mask	);
 	}
 }
@@ -209,60 +201,54 @@ static void yunsun16_draw_sprites(struct mame_bitmap *bitmap)
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
 
-void yunsun16_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( yunsun16 )
 {
-	int layers_ctrl = -1;
-
 	tilemap_set_scrollx(tilemap_0, 0, yunsun16_scroll_0[ 0 ]);
 	tilemap_set_scrolly(tilemap_0, 0, yunsun16_scroll_0[ 1 ]);
 
 	tilemap_set_scrollx(tilemap_1, 0, yunsun16_scroll_1[ 0 ]);
 	tilemap_set_scrolly(tilemap_1, 0, yunsun16_scroll_1[ 1 ]);
 
-#ifdef MAME_DEBUG
-if (keyboard_pressed(KEYCODE_Z))
-{
-	int msk = 0;
-	if (keyboard_pressed(KEYCODE_Q))	msk |= 1;
-	if (keyboard_pressed(KEYCODE_W))	msk |= 2;
-/*	if (keyboard_pressed(KEYCODE_E))	msk |= 4; */
-	if (keyboard_pressed(KEYCODE_A))	msk |= 8;
-	if (msk != 0) layers_ctrl &= msk;
+/*  ui_popup("%04X", *yunsun16_priority); */
 
-#if 0
-{	char buf[10];
-	sprintf(buf,"%04X", *yunsun16_priority);
-	usrintf_showmessage(buf);	}
-#endif
-}
-#endif
+	fillbitmap(priority_bitmap,0,cliprect);
 
-	fillbitmap(priority_bitmap,0,NULL);
+	if((*yunsun16_priority & 0x0c) == 4)
+	{
+		/* The color of the this layer's transparent pen goes below everything */
+		tilemap_draw(bitmap,cliprect,tilemap_0, TILEMAP_IGNORE_TRANSPARENCY, 0);
 
-	/* The color of the this layer's transparent pen goes below everything */
-	if (layers_ctrl & 1)	tilemap_draw(bitmap,tilemap_0, TILEMAP_IGNORE_TRANSPARENCY, 0);
-	else					fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+		tilemap_draw(bitmap,cliprect,tilemap_0, 0, 1);
 
-	if (layers_ctrl & 1)	tilemap_draw(bitmap,tilemap_0, 0, 1);
+		tilemap_draw(bitmap,cliprect,tilemap_1, 0, 2);
+	}
+	else if((*yunsun16_priority & 0x0c) == 8)
+	{
+		/* The color of the this layer's transparent pen goes below everything */
+		tilemap_draw(bitmap,cliprect,tilemap_1, TILEMAP_IGNORE_TRANSPARENCY, 0);
 
-	if (layers_ctrl & 2)	tilemap_draw(bitmap,tilemap_1, 0, 2);
+		tilemap_draw(bitmap,cliprect,tilemap_1, 0, 1);
 
-	if (layers_ctrl & 8)	yunsun16_draw_sprites(bitmap);
+		tilemap_draw(bitmap,cliprect,tilemap_0, 0, 2);
+	}
+
+	yunsun16_draw_sprites(bitmap,cliprect);
 
 	/* tilemap.c only copes with screen widths which are a multiple of 8 pixels */
 	if ( (Machine->drv->screen_width-1-Machine->visible_area.max_x) & 7 )
 	{
-		struct rectangle clip;
+		rectangle clip;
 		clip.min_x = Machine->visible_area.max_x+1;
 		clip.max_x = Machine->drv->screen_width-1;
 		clip.min_y = Machine->visible_area.min_y;
 		clip.max_y = Machine->visible_area.max_y;
+		sect_rect(&clip,cliprect);
 		fillbitmap(bitmap,Machine->pens[0],&clip);
 	}
 }
