@@ -1,29 +1,29 @@
 /***************************************************************************
 
-						  -= Yun Sung 8 Bit Games =-
+                          -= Yun Sung 8 Bit Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-Note:	if MAME_DEBUG is defined, pressing Z with:
+Note:   if MAME_DEBUG is defined, pressing Z with:
 
-		Q 		shows the background layer
-		W 		shows the foreground layer
+        Q       shows the background layer
+        W       shows the foreground layer
 
-		[ 2 Fixed Layers ]
+        [ 2 Fixed Layers ]
 
-			[ Background ]
+            [ Background ]
 
-			Layer Size:				512 x 256
-			Tiles:					8 x 8 x 8
+            Layer Size:             512 x 256
+            Tiles:                  8 x 8 x 8
 
-			[ Foreground ]
+            [ Foreground ]
 
-			Layer Size:				512 x 256
-			Tiles:					8 x 8 x 4
+            Layer Size:             512 x 256
+            Tiles:                  8 x 8 x 4
 
 
-		There are no sprites.
+        There are no sprites.
 
 ***************************************************************************/
 
@@ -32,33 +32,33 @@ Note:	if MAME_DEBUG is defined, pressing Z with:
 
 /* Variables that driver has access to: */
 
-data8_t *yunsung8_videoram_0, *yunsung8_videoram_1;
+UINT8 *yunsung8_videoram_0, *yunsung8_videoram_1;
 int yunsung8_layers_ctrl;
 
 /* Variables only used here: */
 
-static struct tilemap *tilemap_0, *tilemap_1;
+static tilemap *tilemap_0, *tilemap_1;
 static int yunsung8_videobank;
 
 
 /***************************************************************************
 
-								Memory Handlers
+                                Memory Handlers
 
 ***************************************************************************/
 
-WRITE_HANDLER( yunsung8_videobank_w )
+WRITE8_HANDLER( yunsung8_videobank_w )
 {
 	yunsung8_videobank = data;
 }
 
 
-READ_HANDLER( yunsung8_videoram_r )
+READ8_HANDLER( yunsung8_videoram_r )
 {
 	int bank;
 
-	/*	Bit 1 of the bankswitching register contols the c000-c7ff
-		area (Palette). Bit 0 controls the c800-dfff area (Tiles) */
+	/*  Bit 1 of the bankswitching register contols the c000-c7ff
+        area (Palette). Bit 0 controls the c800-dfff area (Tiles) */
 
 	if (offset < 0x0800)	bank = yunsung8_videobank & 2;
 	else					bank = yunsung8_videobank & 1;
@@ -68,9 +68,9 @@ READ_HANDLER( yunsung8_videoram_r )
 }
 
 
-WRITE_HANDLER( yunsung8_videoram_w )
+WRITE8_HANDLER( yunsung8_videoram_w )
 {
-	if (offset < 0x0800)		/* c000-c7ff	Banked Palette RAM */
+	if (offset < 0x0800)		/* c000-c7ff    Banked Palette RAM */
 	{
 		int bank = yunsung8_videobank & 2;
 		unsigned char *RAM;
@@ -105,7 +105,7 @@ WRITE_HANDLER( yunsung8_videoram_w )
 }
 
 
-WRITE_HANDLER( yunsung8_flipscreen_w )
+WRITE8_HANDLER( yunsung8_flipscreen_w )
 {
 	tilemap_set_flip(ALL_TILEMAPS, (data & 1) ? (TILEMAP_FLIPX|TILEMAP_FLIPY) : 0);
 }
@@ -113,14 +113,14 @@ WRITE_HANDLER( yunsung8_flipscreen_w )
 
 /***************************************************************************
 
-							  [ Tiles Format ]
+                              [ Tiles Format ]
 
-	Offset:
+    Offset:
 
-	Video RAM + 0000.b		Code (Low  Bits)
-	Video RAM + 0001.b		Code (High Bits)
+    Video RAM + 0000.b      Code (Low  Bits)
+    Video RAM + 0001.b      Code (High Bits)
 
-	Color RAM + 0000.b		Color
+    Color RAM + 0000.b      Color
 
 
 ***************************************************************************/
@@ -163,12 +163,12 @@ static void get_tile_info_1( int tile_index )
 /***************************************************************************
 
 
-							Vide Hardware Init
+                            Vide Hardware Init
 
 
 ***************************************************************************/
 
-int yunsung8_vh_start(void)
+VIDEO_START( yunsung8 )
 {
 	tilemap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
 								TILEMAP_OPAQUE, 8,8, DIM_NX_0, DIM_NY_0 );
@@ -189,27 +189,27 @@ int yunsung8_vh_start(void)
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
-void yunsung8_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( yunsung8 )
 {
 	int layers_ctrl = (~yunsung8_layers_ctrl) >> 4;
 
 #ifdef MAME_DEBUG
-if (keyboard_pressed(KEYCODE_Z))
+if (code_pressed(KEYCODE_Z))
 {
 	int msk = 0;
-	if (keyboard_pressed(KEYCODE_Q))	msk |= 1;
-	if (keyboard_pressed(KEYCODE_W))	msk |= 2;
+	if (code_pressed(KEYCODE_Q))	msk |= 1;
+	if (code_pressed(KEYCODE_W))	msk |= 2;
 	if (msk != 0) layers_ctrl &= msk;
 }
 #endif
 
-	if (layers_ctrl&1)	tilemap_draw(bitmap, tilemap_0, 0,0);
-	else				fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+	if (layers_ctrl&1)	tilemap_draw(bitmap,cliprect, tilemap_0, 0,0);
+	else				fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	if (layers_ctrl&2)	tilemap_draw(bitmap, tilemap_1, 0,0);
+	if (layers_ctrl&2)	tilemap_draw(bitmap,cliprect, tilemap_1, 0,0);
 }
