@@ -11,16 +11,16 @@
 
 
 
-data8_t *zaccaria_videoram,*zaccaria_attributesram;
+UINT8 *zaccaria_videoram,*zaccaria_attributesram;
 
-static struct tilemap *bg_tilemap;
+static tilemap *bg_tilemap;
 
-static struct rectangle spritevisiblearea =
+static rectangle spritevisiblearea =
 {
 	2*8+1, 29*8-1,
 	2*8, 30*8-1
 };
-static struct rectangle spritevisiblearea_flipx =
+static rectangle spritevisiblearea_flipx =
 {
 	3*8+1, 30*8-1,
 	2*8, 30*8-1
@@ -50,7 +50,7 @@ Here's the hookup from the proms (82s131) to the r-g-b-outputs
 
 
 ***************************************************************************/
-void zaccaria_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( zaccaria )
 {
 	int i,j,k;
 	#define TOTAL_COLORS(gfxn) (Machine->gfx[gfxn]->total_colors * Machine->gfx[gfxn]->color_granularity)
@@ -59,22 +59,20 @@ void zaccaria_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 
 	for (i = 0;i < Machine->drv->total_colors;i++)
 	{
-		int bit0,bit1,bit2;
+		int bit0,bit1,bit2,r,g,b;
 
 
 		/*
-		  TODO: I'm not sure, but I think that pen 0 must always be black, otherwise
-		  there's some junk brown background in Jack Rabbit.
-		  From the schematics it seems that the background color can be changed, but
-		  I'm not sure where it would be taken from; I think the high bits of
-		  attributesram, but they are always 0 in these games so they would turn out
-		  black anyway.
-		 */
+          TODO: I'm not sure, but I think that pen 0 must always be black, otherwise
+          there's some junk brown background in Jack Rabbit.
+          From the schematics it seems that the background color can be changed, but
+          I'm not sure where it would be taken from; I think the high bits of
+          attributesram, but they are always 0 in these games so they would turn out
+          black anyway.
+         */
 		if (((i % 64) / 8) == 0)
 		{
-			*(palette++) = 0;
-			*(palette++) = 0;
-			*(palette++) = 0;
+			palette_set_color(i,0,0,0);
 		}
 		else
 		{
@@ -82,16 +80,17 @@ void zaccaria_vh_convert_color_prom(unsigned char *palette, unsigned short *colo
 			bit0 = (color_prom[0] >> 3) & 0x01;
 			bit1 = (color_prom[0] >> 2) & 0x01;
 			bit2 = (color_prom[0] >> 1) & 0x01;
-			*(palette++) = 0x46 * bit0 + 0x53 * bit1 + 0x66 * bit2;
+			r = 0x46 * bit0 + 0x53 * bit1 + 0x66 * bit2;
 			/* green component */
 			bit0 = (color_prom[0] >> 0) & 0x01;
 			bit1 = (color_prom[Machine->drv->total_colors] >> 3) & 0x01;
 			bit2 = (color_prom[Machine->drv->total_colors] >> 2) & 0x01;
-			*(palette++) = 0x46 * bit0 + 0x53 * bit1 + 0x66 * bit2;
+			g = 0x46 * bit0 + 0x53 * bit1 + 0x66 * bit2;
 			/* blue component */
 			bit0 = (color_prom[Machine->drv->total_colors] >> 1) & 0x01;
 			bit1 = (color_prom[Machine->drv->total_colors] >> 0) & 0x01;
-			*(palette++) = 0x66 * bit0 + 0x96 * bit1;
+			b = 0x66 * bit0 + 0x96 * bit1;
+			palette_set_color(i,r,g,b);
 		}
 
 		color_prom++;
@@ -151,7 +150,7 @@ static void get_tile_info(int tile_index)
 
 ***************************************************************************/
 
-int zaccaria_vh_start(void)
+VIDEO_START( zaccaria )
 {
 	bg_tilemap = tilemap_create(get_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,8,8,32,32);
 
@@ -171,7 +170,7 @@ int zaccaria_vh_start(void)
 
 ***************************************************************************/
 
-WRITE_HANDLER( zaccaria_videoram_w )
+WRITE8_HANDLER( zaccaria_videoram_w )
 {
 	if (zaccaria_videoram[offset] != data)
 	{
@@ -180,7 +179,7 @@ WRITE_HANDLER( zaccaria_videoram_w )
 	}
 }
 
-WRITE_HANDLER( zaccaria_attributes_w )
+WRITE8_HANDLER( zaccaria_attributes_w )
 {
 	if (offset & 1)
 	{
@@ -198,14 +197,14 @@ WRITE_HANDLER( zaccaria_attributes_w )
 	zaccaria_attributesram[offset] = data;
 }
 
-WRITE_HANDLER( zaccaria_flip_screen_x_w )
+WRITE8_HANDLER( zaccaria_flip_screen_x_w )
 {
-	flip_screen_x_set(data);
+	flip_screen_x_set(data & 1);
 }
 
-WRITE_HANDLER( zaccaria_flip_screen_y_w )
+WRITE8_HANDLER( zaccaria_flip_screen_y_w )
 {
-	flip_screen_y_set(data);
+	flip_screen_y_set(data & 1);
 }
 
 
@@ -216,25 +215,30 @@ WRITE_HANDLER( zaccaria_flip_screen_y_w )
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap,const rectangle *cliprect)
 {
 	int offs;
+	rectangle clip = *cliprect;
 
+	if (flip_screen_x)
+		sect_rect(&clip, &spritevisiblearea_flipx);
+	else
+		sect_rect(&clip, &spritevisiblearea);
 
 	/*
-	  TODO: sprites have 32 color codes, but we are using only 8. In Jack
-	  Rabbit the extra codes are all duplicates, but there is a quadruple
-	  of codes in Money Money which contains two different combinations. That
-	  color code seems to be used only by crocodiles, so the one we are picking
-	  seems the correct one (otherwise they would be red).
-	*/
+      TODO: sprites have 32 color codes, but we are using only 8. In Jack
+      Rabbit the extra codes are all duplicates, but there is a quadruple
+      of codes in Money Money which contains two different combinations. That
+      color code seems to be used only by crocodiles, so the one we are picking
+      seems the correct one (otherwise they would be red).
+    */
 
 	/*
-	  TODO: sprite placement is not perfect, I made the Jack Rabbit mouth
-	  animation correct but this moves one pixel to the left the sprite
-	  which masks the holes when you fall in them. The hardware is probably
-	  similar to Amidar, but the code in the Amidar driver is not good either.
-	*/
+      TODO: sprite placement is not perfect, I made the Jack Rabbit mouth
+      animation correct but this moves one pixel to the left the sprite
+      which masks the holes when you fall in them. The hardware is probably
+      similar to Amidar, but the code in the Amidar driver is not good either.
+    */
 	for (offs = 0;offs < spriteram_2_size;offs += 4)
 	{
 		int sx = spriteram_2[offs + 3] + 1;
@@ -258,7 +262,7 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				4 * (spriteram_2[offs + 1] & 0x07),
 				flipx,flipy,
 				sx,sy,
-				flip_screen_x ? &spritevisiblearea_flipx : &spritevisiblearea,TRANSPARENCY_PEN,0);
+				&clip,TRANSPARENCY_PEN,0);
 	}
 
 	for (offs = 0;offs < spriteram_size;offs += 4)
@@ -284,14 +288,14 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				4 * (spriteram[offs + 2] & 0x07),
 				flipx,flipy,
 				sx,sy,
-				flip_screen_x ? &spritevisiblearea_flipx : &spritevisiblearea,TRANSPARENCY_PEN,0);
+				&clip,TRANSPARENCY_PEN,0);
 	}
 }
 
 
-void zaccaria_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( zaccaria )
 {
-	tilemap_draw(bitmap,bg_tilemap,0,0);
+	tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 
-	draw_sprites(bitmap);
+	draw_sprites(bitmap,cliprect);
 }
