@@ -1,12 +1,13 @@
-/*###################################################################################################
-**
-**
-**      drccore.c
-**      x86 Dynamic recompiler support routines.
-**      Written by Aaron Giles
-**
-**
-**#################################################################################################*/
+/***************************************************************************
+
+    x86drc.c
+
+    x86 Dynamic recompiler support routines.
+
+    Copyright (c) 1996-2006, Nicola Salmoria and the MAME Team.
+    Visit http://mamedev.org for licensing and usage restrictions.
+
+***************************************************************************/
 
 #include "driver.h"
 #include "x86drc.h"
