@@ -1,9 +1,12 @@
-/** \file
- *
- * MAME XML to INFO converter.
- *
- * This file is Public Domain.
- */
+/***************************************************************************
+
+    xml2info.h
+
+    MAME XML to INFO converter.
+
+    This file is Public Domain.
+
+***************************************************************************/
 
 /****************************************************************************/
 /* libexpat */
